(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   2188165,      28274]*)
(*NotebookOutlinePosition[   2188905,      28299]*)
(*  CellTagsIndexPosition[   2188861,      28295]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Dynamics of the F-16", "Title",
  TextAlignment->Left],

Cell["\<\
Harry G. Kwatny
Suba Thomas\
\>", "Subtitle"],

Cell["\<\
Department of mechanical Engineering & Mechanics
Drexel University\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["1. Introduction", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(<< Propac`\), "\[IndentingNewLine]", 
    \(\(\(\(SetDirectory["\<C:\Projects\FlightControl\NASA G\F-16 Model\>"]\)\
\(\ \)\);\) (*\ 
      this\ is\ where\ the\ C - file\ will\ be\ found\ *) \)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("\n    This is ProPac - Version 3.00\n \n ProPac has been successfully \
loaded. It contains several packages\n for multibody dynamics, linear control \
and nonlinear control.\n The package names are:\n    GeoTools\n    Dynamics\n \
   ControlL\n    ControlN\n    DifferentialForms\n    ObserverTools\n    \
NDTools\n    VSCTools\n    MatlabInterface\n    MEXTools\n Appropriate \
packages will be loaded automatically as required.\n To obtain a list of \
functions in a package and links to function\n declarations, enter:\n    \
?ProPac`PackageName`*\n Help is also available in the Help Browser under \
Add-ons."\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell[TextData[{
  "In this notebook we develop a model for the F-16 aircraft. The \
aerodynamics used are the polynomial charaterization given by Gene Morelli in \
E. A. Morelli, \"Global Nonlinear Aerodynamic Modeling Using Multivariate \
Orthogonal Functions,\" ",
  StyleBox["Journal of Aircraft",
    FontSlant->"Italic"],
  ", vol. 32, pp. 270-277, 1995. Other data is obtained from L. T. Nguyen, et \
al., \"Simulator Study of Stall/Post-Stall Characteristics of a Fighter \
Airplane with Relaxed Longitudinal Static Stability,\" NASA NASA TP 1538, \
December, 1979, and F. R. Garza and E. A. Morelli, \"A Collection of \
Nonlinear Aircraft Simulations in MATLAB,\" NASA NASA/TM-2003-212145, 2003."
}], "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@005mGl0@0006`000000000000007/2000U0@00
000000000024C@00`b<00215CDH00040o=DG01@0000200000000000000000@0000@0000300100@00
l0000000000000000000003R1020Z@<0AP0007cX2`1`j0/0AdA9@`4008000`00_nJ_D`00001Hj0/0
0@090003;?@50040o_4500000`0001h01@0000/2000000D0000<0UT1k@850P00m`000`0100000000
E@000:X0003o000T000095D002BZ000To`00B@0004UE0019ZP00BOl006d0001]E@00KJX006go002B
0000TUD009:Z002Bo`00]P000;IE002fZP00]_l00=/0003KE@00fjX00=_o003o0000oeD00?nZ003o
o`0T0000901E02@0ZP0T0?l092@002@TE@0T9:X092Co02A9000TBED094VZ02A9o`0TK@0096eE02A]
ZP0TKOl0998002BBE@0TTZX099;o02Bf000T]UD09;JZ02Bfo`0Tf`009=]E02CKZP0Tfol09?l002Co
E@0TojX09?oo04T0001905D0B@2Z04T0o`199000BBAE04TTZP199?l0BDT004U9E@19BJX0BDWo04U]
0019KED0BFfZ04U]o`19TP00BI9E04VBZP19T_l0BKH004VfE@19]ZX0BKKo04WK0019feD0BM^Z04WK
o`19o`00BOmE04WoZP19ool0K@0006d0E@1]0:X0K@3o06dT001]95D0KBBZ06dTo`1]B@00KDUE06e9
ZP1]BOl0KFd006e]E@1]KJX0KFgo06fB001]TUD0KI:Z06fBo`1]]P00KKIE06ffZP1]]_l0KM/006gK
E@1]fjX0KM_o06go001]oeD0KOnZ06goo`2B0000TP1E0980ZP2B0?l0TR@0098TE@2B9:X0TRCo0999
002BBED0TTVZ0999o`2BK@00TVeE099]ZP2BKOl0TY8009:BE@2BTZX0TY;o09:f002B]UD0T[JZ09:f
o`2Bf`00T]]E09;KZP2Bfol0T_l009;oE@2BojX0T_oo0;H0002f05D0]P2Z0;H0o`2f9000]RAE0;HT
ZP2f9?l0]TT00;I9E@2fBJX0]TWo0;I]002fKED0]VfZ0;I]o`2fTP00]Y9E0;JBZP2fT_l0][H00;Jf
E@2f]ZX0][Ko0;KK002ffeD0]]^Z0;KKo`2fo`00]_mE0;KoZP2fool0f`000=/0E@3K0:X0f`3o0=/T
003K95D0fbBZ0=/To`3KB@00fdUE0=]9ZP3KBOl0ffd00=]]E@3KKJX0ffgo0=^B003KTUD0fi:Z0=^B
o`3K]P00fkIE0=^fZP3K]_l0fm/00=_KE@3KfjX0fm_o0=_o003KoeD0fonZ0=_oo`3o0000o`1E0?l0
ZP3o0?l0ob@00?lTE@3o9:X0obCo0?m9003oBED0odVZ0?m9o`3oK@00ofeE0?m]ZP3oKOl0oi800?nB
E@3oTZX0oi;o0?nf003o]UD0okJZ0?nfo`3of`00om]E0?oKZP3ofol0ool00?ooE@3oojX0oooo00@0
000d0P000`0003D01@0000L10`000?ka1@133b00c00005X1kP800000FP7^0P00000X0000kP8005X1
000101P000000;SS2`343P00a0h0000000000000f=CIeMCHd=?Hbm7Fbm7Hd=7KeM7Lf=;Me=GIe=GI
eMGKe]KLe]GNeMCNe=?Me=?Me=KNe=KNe=KNe=KNe=KNe=KNe=KNe=KNfM_Sa<K>d]CLf]cTblgEg^3X
inWa`L?;a<?=e]GOh=oYf=OQd]7Ke]GOf=OQdm;LdMKOdMKOdmGOdmGOe=GOe=GOe]GOe]GOdmCNdmCN
e=GOeMKPeMKPe=GOdmCNdmCNe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOeMKPeMKPeMKP
e]OQe]OQeMKPe=GOdmCNdmCNdmCNdmCNe=GOeMKPe=KNe=KNe=KNe=KNe=KNe=KNe=KNe=KNeMKPe]OQ
e]OQeMKPdmCNdmCNeMKPemSRe=KNe=KNe=KNe=KNe=KNe=KNe=KNe=KNe=OKe=OKeMSMe]WNe]SPeMKP
e=GOe=GOdmKNdmKNe=KNe=KNe]GNf=GNf=GNf=GNemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNemKOemKOemKOemKOemKOemKO
emKOemKOe=KNe=KNe=KNe=KNe=KNe=KNe=KNe=KNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNdmKKdmKK
dmKKdmKKdmKKdmKKdmKKdmKKdmGMdmGMdmGMdmGMdmGMdmGMdmGMdmGMd]KKd]KKdmKKdmKKeMGKemGK
emGKemGKe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLeMOHeMOHeMOHe]SIe]SIe]SIemWJemWJe]SIe]SI
e]SIe]SIe]SIe]SIe]SIe]SIemWJe]SIeMOHeMOHeMOHeMOHe]SIemWJdmWHdmWHe=WHe=SIe]OKf=OK
f=KLf=KLe]SIe]SIe]SIemWJemWJemWJf=[Kf=[KfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMe]CJe]CJ
e]CJe]CJemGKemGKf=KLf=KLd]OFe=KFe=KFe]GGe]GIf=CIf=CJf]?JeM?IeM?Ie=?Gdm;Fdm;De=CD
eMGEeMGEeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?Be=;Be=;B
e=;Be=;Be=;Be=;Be=;Be=;BeMG?eMG?e=??dm;>dm7@e=;BeM?CeM?Cdm7Adm7Ae=;Be=;Be=;BeM?C
eM?CeM?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?C
eM?CeM?CeM?CeM?CeM?CeM?Cd];Bdm?Ce=CDeMGEe]KFeMGEeMGEe=CDeM?BeM?BeM?BeM?BeM?BeM?B
eM?BeM?Be]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe=;AeM?B
e]CCemGDf=KEemGDemGDe]CCf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFfMOFemGDe]CCemGDf=KEfMOF
f=KEe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CCe]CC
e]CCe]CCe]CCe]CCe]CCe]CCdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBe=;Ae=;AeM?BeM?BeM?Be]CC
e]CCe]CCdmCBdmCBd]?Adm7@eM7@e];Af=?Bf=?BeMC@eMC@eMC@eMC@eMC@eMC@eMC@eMC@e=;Ae=;A
e=;Ae=;Ae=;Ae=;Ae=;Ae=;AeM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=dM3<d]7=dm;>dm;>dM3<d<o;
d]7=dm;>d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?e<o<e<o<e<o<eM3=eM3=eM3=e]7>e]7>dM3<dM3<
dM3<d]7=d]7=d]7=dm;>dm;>d]7=d]7=d]7=d]7=d]7=d]7=d]7=d]7=clk:clk:dM3<d]7=d]7=d]7=
dM3<dM3<dm;>d]7=dM3<d]7=e=??eMC@e=??dm;>eMK=eMK=eMK=eMK=eMK=eMK=eMK=eMK=dmK=dmK=
dmK=eMK=emG=emG=f=G=f=G=e]O>e]O>emG=e]C<emC<f=G=fmG>fmG>fMK>fMK>fMK>fMK>fMK>fMK>
fMK>fMK>f=G=f=G=fMK>fMK>f]O?f]O?f]O?f]O?e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>f=G=f=G=
f=G=f=G=f=G=f=G=f=G=f=G=emC<emC<f=G=f=G=f=G=fMK>fMK>fMK>emC<emC<f=G=f=G=f=G=fMK>
fMK>fMK>eMK=eMK=emG=emG=f=G=f=G=f]C=f]C=f=G=f=G=f=G=f=G=f=G=f=G=f=G=f=G=fMO=fMO=
fMO=fMO=fMO=fMO=fMO=fMO=emG;f=K<fMO=fMO=fMO=fMO=f=K<emG;fMO=fMO=fMO=fMO=fMO=fMO=
fMO=fMO=eMK<eMK<eMK<eMK<eMK<eMK<eMK<eMK<eMK<eMK<emK<emK<f=K<f=K<f]G<f]G<f=K<f=K<
fMO=fMO=f]S>f]S>f]S>f]S>f=K<f=K<fMO=fMO=f]S>f]S>f]S>f]S>f=W@f=W@f=W@f=W@f=W@f=W@
f=W@f=W@f=K<fMO=f]S>f]S>f]S>f]S>fMO=f=K<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]S>f]S>
fMO=f=K<f=K<fMO=f]S>f]S>fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=eMK<eMK<f=O=f=O=f]S>f]S>
g=O>g=O>f]G<f]G<fmK=fmK=g=O>g=O>g=O>g=O>fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmK=fmK=
fmK=fmK=fmK=fmK=fmK=fmK=f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;emG:emG:emG:emG:emG:emG:
003He=WEe=S@dmS;dMK;dMS@dM_EdMcHd]gDeMWDeMWEeM_Fe]cFeMkEe=kDdmgDdmgDe]kDe]kDe]kD
e]kDe]kDe]kDe]kDe]kJg>CDe]kPh^[:c=B/[[K1`l^ATi/72A4000UIF6:WY[2h]l6l^lGAd=[Mg>KE
e=kAe]oAe]oCeMoCeMoDeMoDeMoFeMoFeMoCe=kCe=kDeMoEe^3Ee^3DeMoCe=kCe=kDeMoDeMoDeMoD
eMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoEe^3Ee^3Ee^3Fen7Fen7Ee^3DeMoCe=kCe=kCe=kCe=kDeMoE
e^3De]kDe]kDe]kDe]kDe]kDe]kDe]kDe]kEe^3Fen7Fen7Ee^3Ce=kCe=kEe^3Gf>;De]kDe]kDe]kD
e]kDe]kDe]kDe]kDe]kDem_Dem_Ef=gFfMkFf>3Ee^3DeMoDeMoCe]kCe]kDe]kDe]kFeMkHeMkHeMkH
eMkGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoEemoFeMkFeMkFeMkF
eMkFeMkFeMkFeMkFeMkGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oDe]kDe]kDe]kDe]kDe]kDe]kDe]kD
e]kFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkCe]_Ce]_Ce]_Ce]_Ce]_Ce]_Ce]_Ce]_CeMgCeMgCeMgC
eMgCeMgCeMgCeMgCeMgBe]_Be]_Ce]_Ce]_EeM_GeM_GeM_GeM_Fe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cEemSEemSEemSFf=WFf=WFf=WGfM[GfM[Ff=WFf=WFf=WFf=WFf=WFf=WFf=WFf=WGfM[Ff=WEemSE
emSEemSEemSFf=WGfM[CfMSCfMSDfMSDf=WFem_Hem_He]cHe]cFf=WFf=WFf=WGfM[GfM[GfM[Hf]_H
f]_IemgIemgIemgIemgIemgIemgIemgIemgFe=[Fe=[Fe=[Fe=[GeM_GeM_He]cHe]cBemKDe]KDe]KF
eMOFeMWHe=WHe=[Jdm[EdmWEdmWDdmOCd]KCd]CDe=CEeMGEeMGEdm?Edm?Edm?Edm?Edm?Edm?Edm?E
dm?Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];EeLoEeLoDdloC
d/kCdM3Dd];Edm?Edm?CdM7CdM7Dd];Dd];Dd];Edm?Edm?Edm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Bd];Cdm?De=CE
eMGFe]KEeMGEeMGDe=CEdm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Fe=CFe=CFe=CFe=CFe=CFe=CFe=CF
e=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CDd]7Edm;Fe=?GeMCHe]GGeMCGeMCFe=?He]KHe]KHe]KH
e]KHe]KHe]KHe]KHe]KIemKGeMCFe=?GeMCHe]GIemKHe]GFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?F
e=?Fe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Ce=;Ce=;Ce=;C
e=;Ce=;Ce=;Ce=;Ce=;Dd]7Dd]7Edm;Edm;Edm;Fe=?Fe=?Fe=?Ce=;Ce=;Bdm7CdM3EdM3Fd]7Hdm;H
dm;Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7Ed<gEd<gEd<gE
d<gEd<gEd<gEd<gEd<gAd<cBdLgCd/kCd/kAd<c@cl_BdLgCd/kBd<oBd<oBd<oBd<oBd<oBd<oBd<oB
d<oDclcDclcDclcEd<gEd<gEd<gFdLkFdLkAd<cAd<cAd<cBdLgBdLgBdLgCd/kCd/kBdLgBdLgBdLgB
dLgBdLgBdLgBdLgBdLg?c/[?c/[Ad<cBdLgBdLgBdLgAd<cAd<cCd/kBdLgAd<cBdLgDdloEe=3DdloC
d/kEe/gEe/gEe/gEe/gEe/gEe/gEe/gEe/gCe/gCe/gCe/gEe/gGeLgGeLgHeLgHeLgFelkFelkGeLgF
e<cGe<cHeLgKeLkKeLkIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kHeLgHeLgIe/kIe/kJeloJeloJeloJ
eloFelkFelkFelkFelkFelkFelkFelkFelkHeLgHeLgHeLgHeLgHeLgHeLgHeLgHeLgGe<cGe<cHeLgH
eLgHeLgIe/kIe/kIe/kGe<cGe<cHeLgHeLgHeLgIe/kIe/kIe/kEe/gEe/gGeLgGeLgHeLgHeLgJe<gJ
e<gHeLgHeLgHeLgHeLgHeLgHeLgHeLgHeLgIelgIelgIelgIelgIelgIelgIelgIelgGeL_He/cIelgI
elgIelgIelgHe/cGeL_IelgIelgIelgIelgIelgIelgIelgIelgEe/cEe/cEe/cEe/cEe/cEe/cEe/cE
e/cEe/cEe/cGe/cGe/cHe/cHe/cJeLcJeLcHe/cHe/cIelgIelgJf<kJf<kJf<kJf<kHe/cHe/cIelgI
elgJf<kJf<kJf<kJf<kHfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3He/cIelgJf<kJf<kJf<kJf<kIelgH
e/cJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJf<kJf<kIelgHe/cHe/cIelgJf<kJf<kKe/gKe/gKe/gK
e/gKe/gKe/gKe/gKe/gEe/cEe/cHelgHelgJf<kJf<kLelkLelkJeLcJeLcKe/gKe/gLelkLelkLelkL
elkKelcKelcKelcKelcKelcKelcKelcKelcKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gJe/_Je/_Je/_J
e/_Je/_Je/_Je/_Je/_GeL[GeL[GeL[GeL[GeL[GeLX00=KDf]KDf]KDf]KDf]KDf]KDf]KDf]KDf]SG
h=SGh<c;e=kMi]CCg=oNilG4cMcKi=7@fN;Qj/k=e]WHhMCCg>7PjL_:dlO6ck6c]:^][YVJWZBUZHB4
R/k>e=SGh=GDgNCSk<;1b]OFgkRg`7]jPinNYjVX/JVX/LW8dM3?f=CCg<o>enCSk=7@fM?BfmKEg]GH
g=kQiM;Ef]WLhMGGgmSIhm[KiM;CgM?Dg]?Dg]?Dg]CEgmCEgmCEgmGFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CE
gmCEgmCEgmCEgmCEgm?Dg]?Dg]?Dg]GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CFg]CFg]CFg]GGgmGG
gmGGgmKHh=KHh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgm?EgM?EgM?EgMCFg]CFg]CFg]GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmCF
g]CFg]CFg]CFg]CFg]CFg]CFg]CFg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KE
g]KEg]KEg]KEg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SF
g=SFg=SFg=SFg=SFg=SFg=SFg=SFg=?CfM?CfM?CfM?CfM?CfM?CfM?CfM?CfLoCe=7Ce=7Ce=?Be=?B
e=GBe=GBe=OBe=GDe]GDe]CCeM?Be=?Be=;Adm;Adm7@d]?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm7A
dM7AdM7AdM7AdM7AdM7AdM7AdM7AdM?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?D
d=?Dd=?Dd=?Dd=?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?CdmCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeM;Adm;Adm?Be=?Be=?B
e=CCeMCCeMCCeMCDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]CD
e=CDe=CDe=CDe=CDe=CDe=CDe=CDe=SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SF
e]SFe]SFe]SFe]CDe=CDe=GEeMGEeMGEeMCDe=?Cdm?CdmCEdMCEdMCEdMCEdMCEdMCEdMCEdMCEdMCE
dMCEdMCEdMCEdMCEdMCEdMCEdMCEdMCDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CEdMCEdMCEdMCEdMCE
dMCEdMCEdMCEdM?Ecm?Ecm?Ecm?Ecm?Ecm?Ecm?Ecm?EcmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmGC
d]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]CBdMCBdMCBdMCBdMCB
dMCBdMCBdMCBdM;Ccm;Ccm;Ccm;Ccm;Ccm;Ccm;Ccm;Ccm;CdM;CdM;CdM;CdM;CdM;CdM;CdM;CdM;C
dM;CdM;CdM;CdM;CdM;CdM;CdM;CdM;CdM;CdM;CdM;CdM;CdM;CdM;CdM;CdM7Bc]7Bc]7Bc];Ccm;C
cm?Dd=?Dd=?Dd=;Ccm;Ccm;Ccm;Ccm;Ccm;Ccm;Ccm;Ccm?FcM?FcM?FcM?FcM?FcM?FcM?FcM?FcMKE
dMKEdMKEdMKEdMKEdMKEdMKEdMKEdMKGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KEdMKEdMKEdMKEdMKE
dMKEdMKEdMKEdMKGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KG
c]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGcMKGcMKGcMKGcMKGcMKGcMKGcMKGcMKGc]KGc]KGc]KGc]KG
c]KGc]KGc]KGc]KGcMKGcMKGcMKGcMKGcMKGcMKGcMKGcMKGcMKGcMKGcMKGcMKGcMKGcMKGcMKGcMKG
c]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]KG
c]KGc]KGc]KGc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WF
c]WFc]WFc]WFc]WFc]WFc]WFc]WFc/k;`nCQfM3=aN[WgmGBb]7>a^7Ne][Gcn3MeL_8`>GRf]WFc^;O
elg:`][GcmCAbMcIdMSEcM_Hd=WFc^GRf]GBb^GRf]CAbNGSfLK4^][Hc]oMdmCBb=kLd^?QemOEbm;?
an?Pf=?@b>?Pf>3MeL_8`>3MeM_Hd=7>a^7Ne]SEcMcIdNKSfmSEcM;?amSEcLg:`^3MeM[GcmSEcMOD
c=cIdMCAbN?Pf=GBb]oLe=kKdlc9`M[Gcm[Gcm3=aNWVg][GcmCAbM[GcnGRf]7>a]ODc?;_imWFc]KC
bmkKdnGRf]7>a]cIdM3=aN3MeGMdK=SEcN;Oem?@b=WFc]SEcMODc=ODc=cIdGEbJ/W6_]cIdMoLe=;?
anCQf@00e]CJe]CJe]CJe]CJe]CJe]CJe]CJe]CJdM3Ie=?Lj>O``/7:g]gVd]7Jhn;[gmkWd<oHgmkW
b<O@cLcEXj:[GUeVM7=lh^7ZcLo@^[bm^[^oAdQ<`<36C4aBIVE^G5]TZZVbhn;[d<oHF5MPIVE^h=oX
]KBmgMcU`l;;JFQaPH29CTeF^KS1dm;KnOSo`L39cm;F`<?7gN3UcM3Ee=KNc/oIblcFgMkXdmCNdmCN
dmCNe=GOe=GOe=GOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=GOe=GOe=GOe=GOe=GOe=GOeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOdmGMdmGMdmGMe=KNe=KNe=KN
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOe=KNe=KNe=KNe=KNe=KNe=KNe=KNe=KNe]GNe]GN
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLe=CJe=CJ
e=CJe=CJe=CJe=CJe=CJe=CJcm?DdM?DdM?Ddm;Ddm;DeM;DeM;Dem;DeMCFeMCFe=?Ee=?Edm;Ddm;D
d]7Cd]7Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];BdmCBdmCB
dmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Ce=?Ee=?E
e=?Ee=?Ee=?Ee=?Ee=?Ee=?Ed]7Cd]7Cdm;Ddm;De=?Ee=?Ee=?Ee=?Ee=CDe=CDe=CDe=CDe=CDe=CD
e=CDe=CDe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDf=KFf=KF
f=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFdm?Ce=CDeMGEeMGEe]KFeMGE
e=CDe=CDe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=CDe=CD
e=CDe=CDe=CDe=CDe=CDe=CDe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCdmG?dmG?dmG?dmG?dmG?dmG?
dmG?dmG?e]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?B
eM?BeM?BeM?BeM?BeM?BeM?Be=;Ae=;Ae=;Ae=;Ae=;Ae=;Ae=;Ae=;Ad]??d]??d]??d]??d]??d]??
d]??d]??d]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?A
d]?Ad]?Ad]?Ad]?Ad]?Ad]?AdM;>dM;>d]??d]??d]??dmC@dmC@dmC@d]??d]??d]??d]??d]??d]??
d]??d]??dmK=dmK=dmK=dmK=dmK=dmK=dmK=dmK=e]GAe]GAe]GAe]GAe]GAe]GAe]GAe]GAe]O>e]O>
e]O>e]O>e]O>e]O>e]O>e]O>e]GAe]GAe]GAe]GAe]GAe]GAe]GAe]GAe]O>e]O>e]O>e]O>e]O>e]O>
e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O=e]O=
e]O=e]O=e]O=e]O=e]O=e]O=e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O=e]O=e]O=e]O=e]O=e]O=
e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>
e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>fMK>fMK>fMK>fMK>fMK>fMK>
fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>gmcDh]oG
dLk6blS0MW=[OW]cclc4hMkFe=79h=gEcL[2e=79Hf1HMG9Zl>gUf]O?LVmWMgA/g]_CeM;:Cda4PWmg
JfQPLFiVc/c2k^cRclg3OWabJfUOd]36gM_ALFmUMgA/NWM_Lg1XalBlg=WALg1XLg1Xclc4h]oGgmcD
f=G=JFINJVMOd<g5lNkVf]O?RHInHUmGd<g5j^OONGI^IV=KKfaTKV]SNWM_gM[Bc<W1LFiVNgQ`inCL
emC<IfALMG9ZMW=[NGI^bLJnjnSPemC<a/>ke]?;e]?;eM;:JVMOJVMOOgadOgadL6eUeM;:dm38d/o7
h=gEOGYbHUmGMW=[NGI^JVMOfMK>kN[Rd<g5f]O?e=79emC<003Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[F
e=[JfN;FeMkCd]_JfN;JfN;Ddmc<bmC<bmCKfn78b<jXZ:iQHFNFUYc2`/SEeM_4a<YnP84L7Qm0@DG9
b/k;bm4d=3[FeMj`[kSThnc>cMKDdm`O7RNVYJh000ImO8GMg>GBd]S5aL^JVZ2<S98c<cUJFV2a/KOW
ingKg^;Uj>cCe]_=d=G;cMGFen7JfnG:bmGCe=kCe=kCe=kDeMoDeMoDeMoEe^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3De]kDe]kDe]kE
emoEemoEemoFf>3Ff>3EemoEemoEemoEemoEemoEemoEemoEemoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3EemoEemoEemoE
emoEemoEemoEemoEemoCeMgCeMgCeMgDe]kDe]kDe]kEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoDe]kDe]kDe]kDe]kDe]kDe]kDe]kDe]kFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkF
eMkFeMkFeMkFeMkFeMkGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cDe=[De=[De=[De=[De=[De=[De=[De=[@e=GBe=GBe=GD
dmGDdmGFdmGFdmGHdmGEe=KDdmGDdmGDdmGCd]CCd]CCd]CCd]CDe=CDe=CDe=CDe=CDe=CDe=CDe=CD
e=CCdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?D
eM?DeM?DeM?DeM?DeM?De=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CD
e=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGCd]CCd]CCd]CC
d]CDdmGDdmGEe=KEe=KEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGFe]KFe]KFe]KFe]KFe]KFe]KFe]KF
e]KEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KH
e]KHe]KHe]KHe]KHe]KBd];Cdm?De=CEeMGFe]KFe]KFe]KFe]KEe]CEe]CEe]CEe]CEe]CEe]CEe]CE
e]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEe]CEe]CEe]CE
e]CEe]CEe]CEe]CEe]CDeM7DeM7DeM7DeM7DeM7DeM7DeM7DeM7Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?F
e=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Edm;Edm;Edm;E
dm;Edm;Edm;Edm;Edm;Ce=3Ce=3Ce=3Ce=3Ce=3Ce=3Ce=3Ce=3Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;C
e=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;BdloBdloBdloB
dloCe=3Ce=3Ce=3DeM7Ce=3Ce=3Ce=3Ce=3Ce=3Ce=3Ce=3Ce=3De]3De]3De]3De]3De]3De]3De]3D
e]3Ge];Ge];Ge];Ge];Ge];Ge];Ge];Ge];Gem7Gem7Gem7Gem7Gem7Gem7Gem7Gem7Ge];Ge];Ge];G
e];Ge];Ge];Ge];Ge];Gem7Gem7Gem7Gem7Gem7Gem7Gem7Gem7Gem7Gem7Gem7Gem7Gem7Gem7Gem7G
em7Gem7Gem7Gem7Gem7Gem7Gem7Gem7Gem7Gf<kGf<kGf<kGf<kGf<kGf<kGf<kGf<kGem7Gem7Gem7G
em7Gem7Gem7Gem7Gem7Gf<kGf<kGf<kGf<kGf<kGf<kGf<kGf<kGf<kGf<kGf<kGf<kGf<kGf<kGf<kG
f<kGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oGf<oG
f<oGf<oGf<oGf<oGf<oJeloJeloJeloJeloJeloJeloJeloJeloJeloJeloJeloJeloJeloJeloJeloJ
eloJeloJeloJeloJeloJeloJeloJeloJeloAc/KEd/[ThMWSh=QXIEe]JV;Cd<SLfM7Nfm?ZimoQg]KQ
g]IhMFekN735`[[PgMEcL6QLFE7Kf=2ASXI`KFGWi=cGe<aeLVY/JV3IelejN6ieLfWIelgGeL]aKfEa
KfGNfm?Og=A]JV:0OGGCd<QoO7A[J63XiMgFdl_Fdl_XiMf0OGEjMfoDdLW7a;a/JF5YIUi/JF7XiMeX
IEeVHe_Ie/kkn?1gM6adLFWKf=1dLFUfLf_Qg]K@cLEYIUj2OgOMf];Mf]9]JV9fLf_Ge<cWi=c7a;ch
mNgSh=QnNg>4PGWQg]K@cLEfLf]MFU;]j^;Qg]K^jn=bKfMgM6cLfM7Mf]9SH5R3P7SBclOWi=c=b/;P
gMGOg=CIe/h00=KDf]KDf]KDf]KDf]KDf]KDf]KDf]KDf]3?f=gLiM?Bfn3Oj<_:dmOFgmkMi]oNiiZJ
X2<S:IbLX]KFg<S8cP001?7amm[Jh7MiNWAfMlc=dJ:SYkjna5UIGm7@fN;Qj];Af/_:dm3?f2PW<5=B
F`001YZIX/g<eNCTjS@d>Q<C6DY:D<?3bKbl`Q8B66a/L/;5bMSKglC7c>CWk=CFg]OHh]OHh]7Bg=?D
g]?Dg]?Dg]CEgmCEgmCEgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=KGhMKGhMKGhMGF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=GGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgm?EgM?EgM?EgMCFg]CF
g]CFg]GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmCFg]CFg]CFg]CFg]CFg]CFg]CFg]CFg]KE
g]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]OGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=CD
f]CDf]CDf]CDf]CDf]CDf]CDf]CDf]3DeM;DeM;DeMCCeMCCeMKCeMKCeMSCeMCCeMCCeMCCeMCCeMCC
eMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCD
e=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CD
e=CDe=CDe=CDe=CCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CC
eMCCeMCCeMCCeMCCeMCCeMCCeMCCeM?Be=?Be=CCeMCCeMCCeMGDe]GDe]GDe]GEeMGEeMGEeMGEeMGE
eMGEeMGEeMGEeMKFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]GEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMSF
e]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe];Bd]?CdmCDe=KFe]OG
emOGemOGemOGemGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGE
eMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMCEdMCEdMCEdMCEdMCE
dMCEdMCEdMCEdMKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKD
dmKDdmKDdmKDdmKDdmKDdmKDdmKDdmGCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]?Dd=?Dd=?Dd=?Dd=?D
d=?Dd=?Dd=?Dd=?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?D
d]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd];Ccm;Ccm;Ccm?Dd=?Dd=CEdMCEdMCEdM?Dd=?Dd=?Dd=?Dd=?D
d=?Dd=?Dd=?Dd=CFd=CFd=CFd=CFd=CFd=CFd=CFd=CFd=OFd]OFd]OFd]OFd]OFd]OFd]OFd]OFd]OG
dMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOFd]OFd]OFd]OFd]OFd]OFd]OFd]OFd]OGdMOGdMOGdMOGdMOG
dMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOH
cmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOHcmOHcmOHcmOHcmOH
cmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOH
cmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcm[Gcm[Gcm[Gcm[Gcm[G
cm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcn?P
f=[GcmSEcMSEcG1]IGejL]cIdN7Ne/S5_NGRf[^h/<S5_Hj;Pf5NE^;OemWFcW1]IH5nM]cIdEMDC7]h
L<:o]n?Pf75^IWaiLMCAbFISFgejL/o<a=;?agikLgEbJ^?Pf<G2^WYgKhZ7Ol?0^=WFc^KSfm3=aNSU
gNGRf[bi/G=`J89oMnOTg=SEcHb9PG9_IgAaJM_Hd7MdK8Z7Olo<a=[GcfISFfYWGmkKdgMdK7QeKLS5
_NGRfXf:PV1MEMSEcMoLe>GRf^;OemGBb]?@b>OTg<_8`6ISFgAaJLG2^_Kcjg9_Im[GchV6OV1MEM;?
af9OEg5^I^GRf];?agYgKmKCbfm/I7UfK]7>a]_Hd>3MeM_Hd>;Oe`00e]CJe]CJe]CJe]CJe]CJe]CJ
e]CJe]CJ`l;;emKOi>?/[jjgj>O`f]WRZ:N`0006Jfa`00040003QhR<l_?g]KJjOWn3emSLdmGF0001
51DIUYNK/;2fAdM=i^G^c/gFbl[CfMSQhN3Y>CQ14Q4JdM3IhN3Yg=_TdmCHRHZ>e]OKN7UmTI:F_Kk2
dM;FRX^?1@P<<SDie]WN_;o4g^3Xcm3JblcFh^?]dmCNdmCNdmCNe=GOe=GOe=GOeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPdmCNe=GOe=GOeMKPeMKPe]OQe]OQe]OQeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=KNe=KN
e=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOdmGMdmGMdmGMe=KNe=KNe=KNeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOe=KNe=KNe=KNe=KNe=KNe=KNe=KNe=KNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNe]GNe]GNemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLeMGKeMGKeMGKeMGKeMGKeMGKeMGKeMGKdMGFdmGF
dmGFeMCFeMCFemCFemCFfMCFe=?Ee=?Ee=?EeMCFeMCFeMCFeMCFeMCFeMCHeMCHeMCHeMCHeMCHeMCH
eMCHeMCHeMCHeMCHeMCHeMCHeMCHeMCHeMCHeMCHeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGE
eMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMCHeMCHeMCHeMCHeMCHeMCH
eMCHeMCHeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEe=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?E
e=?Ee=?EeMCFeMCFe]GGe]GGe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KF
f=KFf=KFf=KFf=KFf=KFf=KFd];Bdm?CeMGEe]KFemOGf=SHf=SHemOGe]KFe]KFe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFeMKDeMKDeMKDeMKDeMKDeMKDeMKDeMKDe]CCe]CCe]CCe]CCe]CCe]CC
e]CCe]CCemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDe]CCe]CC
e]CCe]CCe]CCe]CCe]CCe]CCe=GAe=GAe=GAe=GAe=GAe=GAe=GAe=GAe=GCe=GCe=GCe=GCe=GCe=GC
e=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCd]??dmC@
dmC@dmC@e=GAe=GAe=GAeMKBe=GAe=GAe=GAe=GAe=GAe=GAe=GAe=GAeMKBeMKBeMKBeMKBeMKBeMKB
eMKBeMKBf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OC
f=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OC
f=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=SBf=SBf=SBf=SBf=SBf=SBf=SBf=SBf=OCf=OC
f=OCf=OCf=OCf=OCf=OCf=OCf=SBf=SBf=SBf=SBf=SBf=SBf=SBf=SBf=SBf=SBf=SBf=SBf=SBf=SB
f=SBf=SBf=W@f=W@f=W@f=W@f=W@f=W@f=W@f=W@f=W@f=W@f=W@f=W@f=W@f=W@f=W@f=W@f=W@f=W@
f=W@f=W@f=W@f=W@f=W@f=W@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@dLk6gM[Be]?;f=G=NWM_GU]CNWM_J6EMNGI^KV]S
m_?[l>gUGeaDLVmWc/_3gmcDLg1XMG9Z_kbdLFiVS8V1f]O?h=gEOW]cIV9Mm?3[MG5/LViYhMgHg=SC
J6AOL6aWemC<jnSPLg1XI65Ie]?;h]oGd/o7k^_Sd/o7kN[Rd<g5LVmWLFiVfMK>NWM_Hf1HKFYROGYb
gmcDcL[2JfQPPGif^[N_THj6MW=[hMkFHEiFM75YgmcDd<g5JFINP7eeNWM_NgQ`FUM?IV=Kk>WQhn3H
gmcDjNKNP7eeJFINgmcDg=WAf]O?clc4O7UaO7UajNKNRhR0BdQ0l>gUeM;:d<g5kN[RJFINIV=KfmS@
iN;Je=79cL[2h]oG003Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[]k?Fj^L;?c]OblO[Hen1VIFjRXJ[>
cMHD5AW7b<b_/;@l?D75a/[2`lM4ADWDeMWFf=T82P^LWJ6JVio2`/QUIF_6aLkRhN[Wi^oAd=W8am1I
F65OGVOBdM[0_lS8am1UIVZj^koOh>Bf]k]gN7cJfml92Phj>cnd]k^DUi/N8BK3a/_?dMW?d=[Gf>;J
fnGCe=kCe=kCe=kDeMoDeMoDeMoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3BdmgBdmgBdmgCe=kDeMoEe^3Ee^3F
en7Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3De]kDe]kDe]kEemoEemoEemoFf>3Ff>3EemoEemoEemoE
emoEemoEemoEemoEemoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3EemoEemoEemoEemoEemoEemoEemoEemoCeMgCeMgCeMgD
e]kDe]kDe]kEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoDe]kDe]kDe]kDe]kDe]kDe]kDe]kD
e]kFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHe]cHe]cHe]cHe]cHe]cHe]cHe]cH
e]cEeM_EeM_EeM_EeM_EeM_EeM_EeM_EeM_AeMKCeMKCeMKEe=KEe=KGe=KGe=KIe=KDdmGDdmGEe=KE
e=KEe=KFeMOFeMOFeMOEe=SEe=SEe=SEe=SEe=SEe=SEe=SEe=SDdmODdmODdmODdmODdmODdmODdmOD
dmOEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEeMGEeMGEeMGE
eMGEeMGEeMGEeMGEeMGEe=SEe=SEe=SEe=SEe=SEe=SEe=SEe=SEeMGEeMGEeMGEeMGEeMGEeMGEeMGE
eMGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGEe=KEe=KFeMOFeMOFeMOFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KF
e]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KDe=CDe=CFe]KG
emOHf=SHf=SGemOGemOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOEeMGEeMGEeMGE
eMGEeMGEeMGEeMGEeMGFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?GeMCGeMCGeMCGeMCGeMCGeMCGeMCG
eMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?DeM7DeM7DeM7D
eM7DeM7DeM7DeM7DeM7DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?D
eM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?Ce=3Ce=3Ce=3DeM7DeM7Ee];Ee];Ee];DeM7DeM7DeM7D
eM7DeM7DeM7DeM7DeM7Ee];Ee];Ee];Ee];Ee];Ee];Ee];Ee];Hem?Hem?Hem?Hem?Hem?Hem?Hem?H
em?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?H
em?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?H
em?Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hf=;Hf=;Hf=;H
f=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;HfM3HfM3HfM3HfM3HfM3HfM3HfM3H
fM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3Ie/kSh=SAc/K<bL60OGF6Pg_BclOWi=cPgMEfLf]PGEGBclM]JV:3P7SDdLWPgMEcL6QXIEghmNej
MfmRGeO?c<CJelmZIemlN7?CclYVHUe^JVGMfMC>b/E^JVF>RXG>bl?Ie/ifLf^0OGGWi=cRgmO=b/;T
hMWMf];Ed/[Wi=ahMFe_K6CGe<afLf_Sh=QjMfmVHe_@cLGMf];Sh=QfLf^6Pg]PGEEaKVKMf]9oO7Am
NW;Sh=SOg=AbKfM[J63LfM7<bL6@SHEeLV[Ie/kFdl_Ie/kDdLUZIen2OgO@cLGSh=SRgmOak^IOG5Ad
LFWIe/i^Jf>0OGG6`k_Yi]kEd/[Wi=ajMfmkN73Nfm?Kf=3BclOGe<cRgmL00=KDf]KDf]KDf]KDf]KD
f]KDf]KDf]KDf/o>enCSk=KEg/c;e:BS[9nNYl2ob8f<UHV;S96CU30b<lK8bKo1`]CFehF7R4A6Af1R
Hgn1PY>DV<k?dlk>e=_KhLK5c]WHhLO6cn?Rjm7@fM7@fLO6cm_Jhn3Oj>CSk8b>SloAd]CFeb@V9iFG
V61RHkBf]lS:bg]nPXR;SmgPiFIYKZ:T[>GVl>7Rk;bmam?Dg]?Dg]?Dg]CEgmCEgmCEgmGFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=3Afm3Afm7Bg=;CgM?Dg]CEgmCEgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CF
g]CFg]CFg]GGgmGGgmGGgmKHh=KHh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgm?EgM?EgM?EgMCFg]CFg]CFg]GGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmCFg]CFg]CFg]CFg]CFg]CFg]CFg]CFg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]KEg]KEg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=7E
e]?Ee]?Ee]GDe]GDe]ODe]ODe]WDe]CCeMCCeMGDe]GDe]KEemKEemOFf=OFf=GCfMGCfMGCfMGCfMGC
fMGCfMGCfMGCfMCBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GD
e]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGCfMGCfMGCfMGCfMGC
fMGCfMGCfMGCfMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCC
eMGDe]GDe]GDe]KEemKEemKEemKEemOGemOGemOGemOGemOGemOGemOGemOGemKFe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]OGemOGemOGemOGemOGemOGemOGemOGemSFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SF
e]SFe]SFe]SFe]SFe]SFe]SFe]SFe]GEeMKFe]OGemOGemSHf=OGemKFe]KFe]OFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OGemOGemOGemOGemOGemOGemOGemOGemOF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=GEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMKDdmKDdmKDdmKDdmKD
dmKDdmKDdmKDdmOEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=KD
dmKDdmKDdmKDdmKDdmKDdmKDdmKDdmCEdMCEdMCEdMCEdMCEdMCEdMCEdMCEdMCEdmCEdmCEdmCEdmCE
dmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdm?D
d=?Dd=CEdMCEdMCEdMGFd]GFd]GFd]CEdMCEdMCEdMCEdMCEdMCEdMCEdMCEdMGFe=GFe=GFe=GFe=GF
e=GFe=GFe=GFe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WH
e=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WH
e=WHe=WHe=WHe=WJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJ
dMWJdMWJdMWJdMWJdMWJdMWJdMWJdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcI
dMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdM_Hd=kKdnGRf^CQfG=`J7EbJ/g:`]?@b=GB
bVi[Hfm/I>GRfWYgKfMTG8F2N]?@b7AaJFi[HmODc75^IWEbJ^KSfnSUgFYWGg5/JM;=bXAoO6QSH>OR
gnWThFeXIF1KF=[GcnWVgV]XH6ISFl?0^8^8P75^I]7>a^3MeLO4_=kKdgMdK6AQFHF2NVeZH]oLe6eZ
HWejL]GBbWAaJM_Hd=?@b=_Hd7UfKW]hL<W6_W=`J61MEN3MeMcIdF]XH7EbJ]ODc=oLe71]IFAQFMcI
dOWfk]7>a^3MeG5^IWAaJN3MeLW6_]ODc=ODc7aiLFUVG][GcfeZHWMdK>[WgmSEcM_Hd<?0^7=`J7Aa
JMSEcMSEcMSEcN?Pf>CQf@00e]CJe]CJe]CJe]CJe]CJe]CJe]CJe]CJd<oHcLcE_[g6SHbEfm[SiNC]
dM3I0006f=[KADM8>C/le=KG;c4bb/c==CLhB4Y;];Jggn7RdmCHc/oCd];Hbl_AK6]dHf9[IfI_HF1Y
aLC=eMCMfMSQc<_DdM3IbLSA:2X[IVQY;Bl`:B//@dE6:R`]KW1admGFb/gAin[^a/W>b/gBXjF]ZZ^e
cLkHh>7[dmCNdmCNdmCNe=GOe=GOe=GOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPc/oIcm3Jd=7KdM;Ld]?MdmCN
e=GOe=GOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOdmGMdmGM
dmGMe=KNe=KNe=KNeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOe=KNe=KNe=KNe=KNe=KNe=KN
e=KNe=KNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=KLf=KLf=KLf=KLf=KLf=KL
f=KLf=KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLd]KGe=KGe=KGe]GGe]GGf=GGf=GGf]GGe=?Ee=?E
eMCFeMCFe]GGemKHemKHemKHe]CJe]CJe]CJe]CJe]CJe]CJe]CJe]CJdm7Gdm7Gdm7Gdm7Gdm7Gdm7G
dm7Gdm7Ge]GIe]GIe]GIe]GIe]GIe]GIe]GIe]GIe]GIe]GIe]GIe]GIe]GIe]GIe]GIe]GIe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]CJe]CJe]CJe]CJe]CJe]CJe]CJe]CJe]KFe]KFe]KFe]KFe]KFe]KF
e]KFe]KFe=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?EeMCFeMCFeMCFeMCFe]GGe]GGe]GGemKHemOGemOG
emOGemOGemOGemOGemOGemOGe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFemOGemOGemOGemOGemOGemOG
emOGemOGf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFe]KFemOG
emOGf=SHf=SHemOGe]KFeMGEemKJemKJemKJemKJemKJemKJemKJemKJemKJemKJemKJemKJemKJemKJ
emKJemKJemOGemOGemOGemOGemOGemOGemOGemOGemKJemKJemKJemKJemKJemKJemKJemKJe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCf=KEf=KEf=KEf=KEf=KEf=KE
f=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe=GAe=GA
e=GAe=GAe=GAe=GAe=GAe=GAe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GC
e=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCdmC@e=GAe=GAe=GAeMKBeMKBeMKBe]OCe=GAe=GA
e=GAe=GAe=GAe=GAe=GAe=GAe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEfMSDfMSDfMSDfMSDfMSDfMSD
fMSDfMSDfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMOFfMOF
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOF
fMOFfMOFfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMSDfMSD
fMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfM[AfM[AfM[AfM[AfM[AfM[A
fM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[Ag=WAg=WA
g=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WA
g=WAg=WAhMkFblS0h=gEinCLHUmGMW=[jnSPh]oGe]?;MW=[LVmWf]O?N7E]KV]Sclc4O7UaLFiVfMK>
h]oGinCLJfQPMW=[IfALNWM_g]WFLFaYKfYWM6m/LFaYc<O4iN3MLfi[NGI^KFYRNWM_h]oGhn3HJVMO
N7E]hn3He=79k>WQf]O?MG9ZLVmWO7UaeM;:gM[BMgA/IV=KiN;JgmcDK6UQLg1XL6eULFiVfMK>N7E]
MG9ZMG9ZMG9Zc/_3h]oGLg1XMW=[Lg1XLVmWg=WAg=WAgmcDd<g5j^OOL6eUOGYbc/_3kN[RgmcDfMK>
IfALOW]cdm38O7UaJ6EMd/o7inCLdm38j^OOLVmWJVMOh]oGiN;Je=79emC<h=gE003CdMOIemg;bLoN
g>;Jf=k@c]C9algEdmWAcmG9alg8a/b5PhVh][cGeM]aKgDQ7bFm_/:QXZHH6Ad:2`n8RHgTiNW:bloL
gN76al^IVYiIFUh[;30/;C5MGV:TYJWFem_If>6YZ;5IF64U92d_;SMMG6FIV:7;b]>n`LG8blo0`lNb
]KUUJ6cMh>BY[;0d=c_;bm79bLn4Q8Y1@DOHf=kEeM^`/;KMgN?Ff>3?dMW>d=SOh>[;bmOZj_K5aM?S
ho7Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3DeMoDeMoDeMoD
eMoDeMoDeMoDeMoDeMoAd]cBdmgBdmgBdmgCe=kCe=kCe=kDeMoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3De]kDe]kDe]kEemoEemoEemoFf>3Ff>3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkFeMkFeMkFeMkFeMkF
eMkGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFe]cFe]cFe]cGemgGemgGemgHf=kHf=kGemgGemgGemgG
emgGemgGemgGemgGemgHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kGemgGemgGemgGemgGemgGemgGemgGemgFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KDdmGDdmGDdmGD
dmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGD
dmGEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KE
e=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KE
e=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGemOGemOGemOGemOGemOGemOGemOG
emOGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGemOGemOGemOG
emOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGeMGGeMGGeMGG
eMGGeMGGeMGGeMGGeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGDe=CEeMGEeMGEeMGFe]KFe]KFe]KF
e]KGemOGemOGemOGemOGemOGemOGemOGemODeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?D
eM?DeM?DeM?DeM?DeM?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?De=CDe=CDe=CDe=CDe=CDe=CDe=CD
e=CDeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?Ee]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEeMGEeMGEeMGE
eMGEeMGEeMGEeMGEeMGGf=KGf=KGf=KGf=KGf=KGf=KGf=KGf=KIemKIemKIemKIemKIemKIemKIemKI
emKGf=KGf=KGf=KGf=KGf=KGf=KGf=KGf=KJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIemKIemKIemKI
emKIemKIemKIemKIemKIemKIemKJf=OKfMSKfMSJf=OIemKIemKIemKIemKIemKIemKIemKIemKIemKI
emKGeMCHe]GHe]GHe]GIemKIemKIemKJf=OIemKIemKIemKIemKIemKIemKIemKIemKIf=CIf=CIf=CI
f=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CGe];Hem?Hem?Hem?If=CIf=CIf=CJ
fMGIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CGe];Hem?Hem?Hem?If=CIf=CIf=CJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGKf]K>cLWUi>39b<AfMG5oOW[;b/KS
h]kPgm]HEe>=S8S=c<Q]K6QhMg?NgMWAd<cKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KQh=c7a/:AT8aQ
H5cBdLgJfMGLfmOGe];JfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGNfMKJeM;Ke]=XHf1fLFigLVoGd/oV
hMiZIemcL6SUh][XiMgMf];JeloKf=3LfM7ZiN;:aL:>RHISGU_Hdm3Wh]oSg]_Ke]?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?Nfm?Nfm?FdLj3OW]XHf3NfMKNfMIXHf23OW_FdLkKe]?Mf=EdKfaWHUoWh]oKe]=cKV]f
LFkLfM7LfM7LfM7Mf];Mf];Mf]800<G3bMgKhN_Ykl;0a]oMhmSFg>SVk=oMhkfk`N;Pi/_9cbHT:VUW
K@0019^IWj>QYi^LX>7Ri/72a[Nh_=kOhnOXk9NHW2LX;9fNXZ^//<72a]?Df=cMhMgNh][KgmOHg<k=
e]WHhM_JhmgLiMkMi/K5cZBS[9JEWRP[;jf`]=CGfnKYkG5dN3/n@Zja]MOJgZ6QY`8220/;4E]KHLG5
bm7AenCTj[fm`m3Cf>OYlL_=eM7Bg=_KilW9eN;Rl;^kbMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgm;CgM;CgM;CgM?Dg]?D
g]?Dg]CEgmCEgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=OF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmKEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKF
g=KFg=KFg=OGgMOGgMOGgMSHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMKFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KEemKEemKEemKEemKEemKEemKEemKEemKE
emKEemKEemKEemKEemKEemKEemKEemCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCC
eMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMKEemKEemKEemKEemKEemKEemKEemKEemKE
emKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKE
emKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemOF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OGemOGemOGemOGemOGemOGemOGemOGemOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOG
emOGemOGemOGemOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OGemOGemOGemOGemOGemOGemOGemOGemOG
emOGemOGemOGemOGemOGemOGemOGemSFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]KFe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]GEeMGEeMGEeMGEeMKFe]KFe]KFe]OGemOGemOGemOGemOGemOGemOGemOGemOGemCE
dmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmKDdmKDdmKDdmKDdmKD
dmKDdmKDdmKDdmCDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmKG
eMKGeMKGeMKGeMKGeMKGeMKGeMKGeMKFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]OHe]OHe]OHe]OHe]OH
e]OHe]OHe]OHe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe][H
em[Hem[Hem[Hem[Hem[Hem[Hem[HemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe][Hem_If=_I
f=[HemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]SFeMSFeMSFeMWGe]WGe]WGe][Hem[HemWG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WH
e=WHe=WHe=WHe=SGdmSGdmSGdmWHe=WHe=WHe=[IeM[IeMWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=SG
dmSGdmSGdmWHe=WHe=WHe=[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeMcKem7@c>3OflK5`GYiMF9QGG9aKFQWHf]ZIWAcKlk=bMcKegMfLWMfL];AcNWXi=_J
e]_Je]_Je]_Je]_Je]_Je]_Je]_Je^7Pg=SGdkJe/I:ASMOFd][IeM[IeMWHe=[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeMKAc^[Uh][EdXR3P9>>Rl:m^^gXiMC?c7ikLgUfK]?@b=KCbmGBb]kKdn?Pf>GRf^7L
fMcGe<>n^iJAS][Ed]G@cMkIe^7LfMkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdnWThLO2_gehMGUdLGUd
LGehMLO2_nWThM3;b?ObklO2_hJ1OWagM6YUHWehMM;=b]cIdMcIdMcIdMgJd]gJd]gJdP00k>[`b/S>
clgCe=;HemGKa<;8c<[@YZBZe=;H]K>ik^cbKVabEeEKdLoEYJ>Y0004CDeCjNW_dM7Gi^K/WYjTA4A:
f][Pdm?IdM7GemOMgmoUhn?Yh>3Vf][Pe=CJdM7Gf]WRg=_Tdm;Kd<oHfm[Sfm[Se]GNfm[Si>O/];Nl
ADQ=]kZomOSm/KBiZ:^`IVU^F5QN]KFk9BD[e]KL[jne0005f][PbLW?/kJkbLcAe=KN`/C<hnC^g=cX
_;c8lO7meMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=GOe=GO
e=GOe=GOe=GOe=GOe=GOe=GOd]?Md]?Md]?MdmCNdmCNe=GOe=GOe=GOeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNe]GNe]GNe]GN
e]GNe]GNemKOemKOemKOemKOemKOemKOemKOemKOe]KLe]KLe]KLemOMemOMemOMf=SNf=SNemOMemOM
emOMemOMemOMemOMemOMemOMf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOMe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGeMCFeMCF
eMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCF
eMCFeMCFe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGemKHemKHemKHemKHemKHemKHemKHemKHemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemOGemOGemOGemOGemOGemOG
emOGemOGemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemOGemOG
emOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemKHemKHemKHemKHemKHemKH
emKHemKHemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGf=KFf=KF
f=KFf=KFf=KFf=KFf=KFf=KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFeMGEeMGEeMGEe]KFe]KFemOG
emOGemOGemOGemOGemOGemOGemOGemOGemOGemOGeMKDeMKDeMKDeMKDeMKDeMKDeMKDeMKDeMKDeMKD
eMKDeMKDeMKDeMKDeMKDeMKDemGDemGDemGDemGDemGDemGDemGDemGDeMGEeMGEeMGEeMGEeMGEeMGE
eMGEeMGEeMKDeMKDeMKDeMKDeMKDeMKDeMKDeMKDe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFemSFemSFemSFemSFemSFemSFemSFemSFfMOFfMOFfMOFfMOFfMOFfMOF
fMOFfMOFemSFemSFemSFemSFemSFemSFemSFemSFf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMOFfMOF
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf]SGfmWHfmWHf]SGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOF
fMOFfMOFf=KEf=KEf=KEfMOFfMOFf]SGf]SGf]SGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMSDfMSD
fMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf=OCf=OCf=OCfMSDfMSDf]WE
f]WEf]WEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf=OCf=OCf=OCfMSDfMSDf]WEf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEfMSDeMC@h=oKi>?OemKBemKB
gMcHe]GAfm[Ffm[Ffm[Fe]GAfMSDinKRhn;Nbl[6fm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Fi>?O
fMSDbLS4emKBfm[Ff]WEgMcHf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEg]WFi=oLcLS5cLS5a/6nj^GR
i=oLg=ODgM[BaL:jl>gUhn3HfmS@h]oGgM[Bf=G=fmKCi=oLjnKSb<?0hMcId<_8g]WFg]WFg]_Cg]_C
g]_Cg]_Cg]_Cg]_Cg]_Cg]_Ce<o<jnKSfMCAg]WFg]WFfMCAjnKSe<o<h=_HhmkKg]WFe]7>e<o<em;?
gm[Gk>OTg=WAg=WAg=WAgM[BgM[BgM[B003KfMo:b<kRh>K<b]3QgnGJf=je/kVRX:K6a<ZNW:;>c=;F
e=Y5@dUMFf7WiN_Mfn6CTiW;bm6f][anOXCFe]cWing6a/c>c]CLg>;Hf=kAdMO;bm78b<k<c=;De=[J
f^3>cMKEe=gBdM[Cd]_LfnCHen3>cMK@cmS<cmCHfn3FfMkCe]]_LWNe^;gPhnS2aL[OgnFATILF5Qa:
BU0j>T0000CGemgDe=Z:SI7;c]?BeM[Jg>C:c=CHfN?@d=cBd]kEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3DeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoBdmgCe=kCe=kC
e=kDeMoDeMoDeMoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3De]kDe]kDe]kEemoEemoEemoFf>3F
f>3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oFe]cFe]cFe]cGemgGemgGemgHf=kHf=kGemgGemgGemgGemgGemgGemgGemgGemgHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgG
emgGemgGemgGemgGemgFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KE
e=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHemWHemWHemWHemWHemWHemWHemWHemWHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFe]KEeMGEeMGFe]KFe]KGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOG
emOEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CGeMCGeMCGeMCG
eMCGeMCGeMCGeMCGeMCEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEe]CEe]CEe]CEe]CEe]CEe]CEe]CE
e]CFemGFemGFemGFemGFemGFemGFemGFemGFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KHfMOHfMOHfMOH
fMOHfMOHfMOHfMOHfMOJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OHfMOHfMOHfMOHfMOHfMOHfMOHfMOH
fMOKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIemKIemKJf=OK
fMSKfMSJf=OIemKIemKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OHe]GIemKIemKIemKJf=OJf=OJf=OK
fMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGHem?If=CIf=CIf=CJfMGJfMGJfMGKf]KJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGHem?If=CIf=CIf=CJfMGJfMGJfMGKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGQh=cMg=SDdloAd<cHem?JfMGHem?If=CGe];RhMgLfmODdloDdlo9b<C=c<SZ
jNGKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KDdloPgm_Og][Ui>3@cl_NgMWKf]KNgMWKf]KKf]KKf]KK
f]KKf]KKf]KKf]KKf]KMf=GPfmSEd<gck^_LemCVhMkDclcUh=g/jN7DdLWVhm_Mf];HeLgSh=SNfm?L
fM7Mf=GJeM;ZiN;JeM;Wh]oLemCUh=gEd<gNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Of]OOf]O?b/ON
fMKNfMK?b/OOf]OOf]OLemC?b/O@blSJeM;Sg]_Yi>7Sg]_Ac<WLfM7LfM7LfM7Mf];Mf];Mf]800=;@
e/W7cNk/l]OEfm3>e;6_]FESJM?AemKDfRl]<jNUZf5OILS6c:f[/HZ8S]KDf]oNigimQ]KEg]cKi<?2
bm;Af]cKi=gLiM3?f=CCg=WHhM_Jhm_Jhm[Ih]WHhM[Ih^OVknGTkMKEg/c;e=;Af]CCg=GDgMoNilc>
e^7SjlG7clO9dMOIhLO9dGAfO^3Rj/_;d@L73EIFG:RX[RPX;[:b^=SHgZBTZ/O:cV9UJKRk_lW<dNCV
k];Dg=GFh<g>f=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CE
gmCEgmCEgmCEgmCEgmCEgmCEgmCEgm?Dg]?Dg]?Dg]CEgmCEgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=CFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]KEg]KE
g]KEg]KEg]KEg]OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKFg=KFg=KFg=OGgMOGgMOGgMSHg]SHg]OG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMKFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=KE
emKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKE
emKEemKEemKEemOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=WG
emWGemWGemWGemWGemWGemWGemWGemOGemOGemOGemOGemOGemOGemOGemOGemKFe]KFe]KFe]OGemOG
emOGemSHf=SHf=OGemOGemOGemOGemOGemOGemOGemOGemKGeMKGeMKGeMKGeMKGeMKGeMKGeMKGeMKG
eMKGeMKGeMKGeMKGeMKGeMKGeMKGeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMKFe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]KGeMKGeMKGeMKGeMKGeMKGeMKGeMKGeMOHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OG
emOGemOGemOGemOGemOGemOGemOGemSIemSIemSIemSIemSIemSIemSIemSIem[Hem[Hem[Hem[Hem[H
em[Hem[Hem[HemSIemSIemSIemSIemSIemSIemSIemSIem_If=_If=_If=_If=_If=_If=_If=_If=[H
em[Hem[Hem[Hem[Hem[Hem[Hem[HemWGe]WGe][Hem_If=_If=[HemWGe]WGe][Hem[Hem[Hem[Hem[H
em[Hem[Hem[HemWGe]WGe]WGe][Hem[Hem_If=_If=_If=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeMWHe=WHe=WHe=[IeM[I
eM_Je]_Je]_Je][IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeMWHe=WHe=WHe=[IeM[IeM_Je]_Je]_Je]_J
e]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeLg<b=WHe=WHe=[IeNGT
h>7Pg=WHe>3OfnGTh=3?blk=bN?Rg^g/j>CSgmkMfN3Ofm_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]SG
dm[IeMCCcnGTh<W8a>3OfmcKem[IeM_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je];=b^SSh>ORgn3Kf=?>
bnGPgN7LfMWDdMWFc]7>a]WFc][GcmKCbn?Pf=oLe>;Oen3Kf=C?c=oJemcGe>;Mf^7LfNWThMKAc]kK
dmkKdmkKdmkKdmkKdmkKdmkKdmkKdmOBcnKQg^COg>GPgNGPgNCOg>KQg]OBcmcGe>cWi>cWi>;Mf]gH
eMKAc]WDdN_VhmcIdMcIdMcIdMgJd]gJd]gJdP00gM_Qhn7Wa<;8e]CJ/k6g928XfmWOU9:HEUAJf]SN
8AlU?ce3i>;Xf=KLb/S>h^3VHF1Zd]7Kg]gWdm;Lf]WSclkHknkheMCNg=_Ug=_UfMSRe=?Md<oIc/gG
clkHdM3J`/7:c/gFd]7JemKOhN3Yfm[SdM3Idm;KdM;LfM[Tl?7kf]_Uf]_UcLkH[k2jJV]e^KVoa/K<
h^;XUiNMHf=Yfm_QBTY@O7b2jNg^`LG692L[Zjjbf]gRfM_SemWQiNK`eMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOdmCNe=GO
e=GOe=GOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=KNe=KNe=KNeMOOeMOOeMOO
e]SPe]SPemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNemKOemKOemKOemKOemKOemKO
emKOemKOe]KLe]KLe]KLemOMemOMemOMf=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOMf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOM
emOMemOMemOMemOMemOMemOMe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLemKHemKHemKHemKHemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGemKHemKHemKHemKHemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKH
emKHemKHf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGemOGemOG
emOGemOGemOGemOGemOGemOGe]KFe]KFemOGemOGf=SHf=SHf=SHf=SHemOGemOGemOGemOGemOGemOG
emOGemOGe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEf=KEf=KE
f=KEf=KEf=KEf=KEf=KEf=KEe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]OEe]OEe]OEe]OEe]OEe]OE
e]OEe]OEemSFemSFemSFemSFemSFemSFemSFemSFemOGemOGemOGemOGemOGemOGemOGemOGf=WGf=WG
f=WGf=WGf=WGf=WGf=WGf=WGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf=WGf=WGf=WGf=WGf=WGf=WG
f=WGf=WGg=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[If]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMOFfMOF
f]SGfmWHfmWHf]SGfMOFfMOFf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMOFf]SGf]SGf]SGfmWHfmWH
fmWHfmWHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEfMSDf]WEf]WEf]WEfm[Ffm[Ffm[Ffm[Ff]WEf]WEf]WEf]WEf]WEf]WE
f]WEf]WEfMSDf]WEf]WEf]WEfm[Ffm[Ffm[Ffm[Fg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEfMSDi>?Ohn;NgMcHf]WEdM3<c<_7e=??f]WEdm;>h^7Mi>?Oc<_7c/g9
fm[Fc/g9fm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[FhN3Lg=_Gd<o;gmkJc<_7h=oKfMSDf=OCg=_Gg=_G
g=_Gg=_Gg=_Gg=_Gg=_Gg=_GhMcIg=ODfMCAe]7>g]WFhMcIhmkKg]WFhn3Hj>GMhn3HjNKNgM[Bh]oG
fMK>gM[Bgm[GfmKChmkKh=_Hf]GBf]GBi=oLhMcIg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cgm[Gg]WF
f=?@d/g:d/g:f=?@g]WFgm[Gc/W6fmKCe<o<eM3=jNCQi=oLe<o<fmKCg=WAg=WAg=WAgM[BgM[BgM[B
003EdmWEdmWHe]cHe]`71@_@c]CShNN^[;8A3aEZJ6jUXjTe<cV_[K?Bd=K>c=840PSDdmgIf>;JfN?=
c=KIf>;Qh>Zk^/COg^S:bM?@cmWHen7LfnGMg>KKf^CJfN?If>;Kf^?PgnSHen3BdM[FeMkBdM[>cMKE
e=gJfnG6am75a]36am7JfnGBdmg/kOO6am4F5Qc7alg6a/`l?4:UYJ/l?4:ATIO:b]3EfMZo`lB]/K8>
4AG:cM;DemcNh>S4a/kEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3DeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoEe^3Ee^3Ee^3Fen7Fen7Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3De]kDe]kDe]kEemoEemoEemoFf>3Ff>3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkF
eMkFeMkFeMkFeMkFeMkGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFe]cFe]cFe]cGemgGemgGemgHf=kH
f=kGemgGemgGemgGemgGemgGemgGemgGemgHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgGemgGemgGemgGemgGemgFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SGe]SGe]SHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIf=[If=[If=[I
f=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SGemOGemOGemOG
emOHf=SHf=SIfMWIfMWGemOGemOGemOGemOGemOGemOGemOGemOGf=KGf=KGf=KGf=KGf=KGf=KGf=KG
f=KGf=KGf=KGf=KGf=KGf=KGf=KGf=KGf=KIemKIemKIemKIemKIemKIemKIemKIemKGemOGemOGemOG
emOGemOGemOGemOGemOGf=KGf=KGf=KGf=KGf=KGf=KGf=KGf=KHfMOHfMOHfMOHfMOHfMOHfMOHfMOH
fMOHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SIf]SIf]SIf]SIf]SIf]SIf]SIf]SIf]SKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSIf]SIf]SIf]SIf]SIf]SIf]SIf]SIf]SLf]WLf]WLf]WLf]WLf]WLf]WLf]WL
f]WKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSIemKIemKJf=OKfMSKfMSJf=OIemKIemKKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSJf=OJf=OJf=OKfMSKfMSKfMSLf]WLf]WKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KJfMGJfMGJfMGK
f]KKf]KKf]KLfmOLfmOKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KJfMGJfMGJfMGKf]KKf]KKf]KLfmOL
fmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGGe];FeM7FeM7E
e=3Ee=3Kf]KUi>3[j^KNgMWFeM7Mg=SKf]KAd<cRhMgal>cRhMgKf]KKf]KKf]KKf]KKf]KKf]KKf]KK
f]KMg=SNgMWGe];Mg=SGe];Mg=SHem?LfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOZiN;FdLk?b/OT
gmcUh=gLemCIe=7Yi>7?c<CNfm?Ac/KPgMGIe/kRgmOKf=3ThMWMf=GQg=WSg]_RgM[Ke]?Ie=7Mf=GU
h=gNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?RgM[FdLkPfmS]j>G]j>GPfmSFdLkRgM[_j^O[i^?Sg]_K
e]?FdLkHdm3Of]OUh=gLfM7LfM7LfM7Mf];Mf];Mf]800=_IglW7cMgKhIVGWEIDFW]iOk:`]]cJh2@R
:=;@eP001<G3bM[Hg]SFg0001>?QimKEgmgLi/g<e^GTk]_Ji=cKiM7@f]cKiMSGhMWHh]SGhMKEgmCC
gMCCgMOFh=WHh];Af][Ih]OFgmGDgMcKi=WHhMGDgMgLiM?Dg]WJi=WJi=cMilk?fM_Li/S9dmSIhlk>
e0001MkNi=_KhDi>E7AdN/o?eMOGgGn4PcDi>/O;c65TJ9FHW<kAe]OIhM[Li=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmCE
gmCEgmCEgmGFh=GFh=KGhMKGhMKGhMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CFg]CFg]CFg]GGgmGG
gmGGgmKHh=KHh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]OFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmKFg=KFg=KFg=OGgMOGgMOGgMSHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMSH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMKFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=SGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=SGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=OGemOGemOGemSHf=SHf=SHf=WIfMWIfMOGemOGemOGemOGemOG
emOGemOGemOGemOHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]WG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]OGemOGemOGemOGemOGemOGemOGemOGemOHe]OHe]OHe]OHe]OH
e]OHe]OHe]OHe]SIemSIemSIemSIemSIemSIemSIemSIemSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=WJ
f=WJf=WJf=WJf=WJf=WJf=WJf=WJf=_If=_If=_If=_If=_If=_If=_If=_If=WJf=WJf=WJf=WJf=WJ
f=WJf=WJf=WJf=cJfMcJfMcJfMcJfMcJfMcJfMcJfMcJfM_If=_If=_If=_If=_If=_If=_If=_If=WG
e]WGe][Hem_If=_If=[HemWGe]WGe]_If=_If=_If=_If=_If=_If=_If=_If=[Hem[Hem[Hem_If=_I
f=cJfMcJfMcJfM_If=_If=_If=_If=_If=_If=_If=_If=_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_J
e]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM[IeM_Je]_Je]cKemcKemcKem_Je]_Je]_Je]_Je]_J
e]_Je]_Je]_Je][IeM[IeM[IeM_Je]_Je]cKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKem[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeN3OfmSGdm[IeMkMfM[IeMcKemcKem;AcMoNf]OFd]WHe>7Pg>3O
fmWHe=KEdMKEdM_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je];AcMcKemgLf=kMfN3Ofm[IeMSGdnCSgmcK
emcKemcKemcKemcKemcKemcKemcKem?>bncWi>ORgnORglo:anKQg]oJemoJemgJd^cYhMCAbN?Pf=[G
cn?Pf=_Hd>?Pf=cGe>7LfM[Ed]oJen?Nfn?Nfm[Ed^7LfMkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdn3K
f=oJen;Mf]KAc]KAc^;Mf]oJen3Kf=gHeLk9a]oJen[Uh]WDdN3Kf>[Uh]OBcmcIdMcIdMcIdMgJd]gJ
d]gJdP00c/g?e=?Efm[L5A@F_KbnXj:T>CPjShj@=3Di`lC8e=CJ`/;8i>?/GUeWf=OQe=?MeM;QfMSR
IfQ/CU1@e=KFf=WMdM3Jg=WXe=?Me=?MeMCNe]GOfMSRf]WSfMSRemKPe]GOe]GOe]GOemKPemKPemKP
f=OQf=OQclcKeM?OeMCNg]gVfm_Qd]?G`L?4Gf5Rd]7Kg=_UHF1Zf]WRfm_Q30`BQXN;5AHJYjJ_clkG
emKOd]7J2PTBi>?/aLC=f]WReMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPemSRe]OQe]OQeMKPeMKPe=GOdmCNdmCNe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPemKPemKPemKPemKPemKPemKPemKPemKPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemOMemOMemOMemOMemOMemOM
emOMemOMf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMf=SNf=SNfMWO
fMWOfMWOf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOMe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIeMCFeMCF
eMCFeMCFeMCFeMCFeMCFeMCFf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFe]KFe]KF
e]KFe]KFemOGemOGf=SHf=SHemOGemOGemOGf=SHf=SHf=SHfMWIfMWIf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHfMOFfMOFfMOFf]SGf]SGf]SGfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIgM_JgM_JgM_Jg=[IfmWHf]SG
f=KEemGDfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHe]GAemKBfMSDf]WEfm[Fg=_Gg=_Gg=_Gf]WEf]WE
f]WEfm[Ffm[Ffm[Fg=_Gg=_GfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]WEf]WEf]WEfm[Ffm[Ffm[F
g=_Gg=_Gf]WEf]WEfm[Fg=_Gg=_Gfm[Ff]WEf]WEfMSDf]WEfm[Fg=_Gg=_Gg=_Gfm[Ffm[FfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gfm[Ffm[Ffm[Fg=_Gg=_GgMcH
gMcHgMcHg=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[Igm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Gg]WFg]WF
g]WFgm[Ggm[Gh=_Hh=_Hh=_Hgm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Gh=_Hh=_Hh=_Hh=_Hh=_Hh=_H
h=_Hh=_Hg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcD
gmcDgmcDgmcDgmcDgmcDgmcDgM[BgM[BgM[BgM[BgM[BgM[B003Mg=kLfmf=S8i<BdgViNLN7An9R8Ye
M7HR8bN@TIGGemgLg>9eM7gHen7Ge^3Ad=[Ie^G?c]R0P8I4ATMhNW_Ti>[>cMOLfNSIf>;Ge^3Ee=kF
eMoDdmgBdM_Cd]cFeMoFeMoFeMoFeMoGe^3Ge^3Ge^3Hen7Hen7OgNWJf>COg^SIf>7Bd]S3a<Q;C51:
C4gLfnFk^/CFeMn@SiS6a/bZZ[0000?>cm?5a<gViNk<bmCEe=eIF66@SiSEe=gLfnCEe^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Fen7Fen7Fen7Ee^3Ee^3DeMoDeMoC
e=kDeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3G
e^3EemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGemgGemgGemgGemgGemgGemgGemgGemgHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kGemgGemgGemgHf=kHf=kIfMoIfMoIfMoHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kGemgGemgGemgGemgGemgGemgGemgGemgFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[If=[If=[If=[HemWHemWHemWH
emWHemWHemWHemWHemWIf=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[Hf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOI
emOIemKIemKIemKIemKIemKIemKIemKIemKFe]KFe]KFe]KFe]KGemOGemOHf=SHf=SGemOGemOGemOH
f=SHf=SHf=SIfMWIfMWHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SIemKIemKIemKJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWKfMSLf]WLf]WLf]WKfMSJf=OIemKHe]GKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSFeM7Ge];If=CJfMGKf]KLfmOKf]KKf]KJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOJfMGJfMGKf]KLfmOLfmOKf]KJfMGJ
fMGIf=CJfMGKf]KLfmOLfmOLfmOKf]KKf]KKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSLfmOLfmOLfmOL
fmOLfmOLfmOLfmOLfmOKf]KKf]KKf]KLfmOLfmOMg=SMg=SMg=SLf]WLf]WLf]WLf]WLf]WLf]WLf]WL
f]WOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]ONfMKNfMKNfMKOf]OOf]OPfmSPfmSPfmSOf]OOf]OOf]OO
f]OOf]OOf]OOf]OOf]OPfmSPfmSPfmSPfmSPfmSPfmSPfmSPfmSNfMKNfMKNfMKNfMKNfMKNfMKNfMKN
fMKOg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=CMf];Mf];Mf];M
f];Mf];Mf]800=?Be<70`Sln@<C3aM;AdkNf^1`K7LG4aWQiOCTj?]KFg<[:d=cKi=OFh=7@f]KEgmGC
gmcKiL?3bF=TJ38c=jf]/mOFh=CBg][IhmKEgmOFh=_Ji=WHh];AfmCCgM_Ji=KEgmKEgmKEgmOFh=OF
h=OFh=SGhMSGhM[Ihl?2c<g<e]OFgm7Aee5AEeUJGZNX[=kMinKUkm?Bg<C3c=kNi>?SjCTj?ZBUZLo?
eM[Jh>3Pi]OGgKNg_CLg?MKFg<g=dmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=KGhMKGhMGFh=GFh=GFh=CEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=OFh=OFh=OFh=OFh=OFh=OFh=OFh=OFh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMSHg]SH
g]WIgmWIgmWIgmSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMKF
g=KFg=KFg=KFg=KFg=KFg=KFg=KFg=SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMKE
emKEemKEemKEemKEemKEemKEemKEemSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]KF
e]KFe]KFe]KFe]OGemOGemSHf=SHf=OGemOGemOGemSHf=SHf=SHf=WIfMWIfMSHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=WGe]WGe]WGe][Hem[Hem[Hem_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[Hem[Hem_If=_If=_I
f=_If=[HemWGe]_If=_If=_If=_If=_If=_If=_If=_If=OFd]SGdmWHe=[IeM_Je]_Je]_Je]_Je][I
eM[IeM[IeM_Je]_Je]_Je]cKemcKem_If=_If=_If=_If=_If=_If=_If=_If=[IeM[IeM[IeM_Je]_J
e]_Je]cKemcKem[IeM[IeM_Je]cKemcKem_Je][IeM[IeMWHe=[IeM_Je]cKemcKemcKem_Je]_Je]_I
f=_If=_If=_If=_If=_If=_If=_If=cKemcKemcKemcKemcKemcKemcKemcKem_Je]_Je]_Je]cKemcK
emgLf=gLf=gLf=cJfMcJfMcJfMcJfMcJfMcJfMcJfMcJfMoJemoJemoJemoJemoJemoJemoJemoJemkI
e]kIe]kIe]oJemoJen3Kf>3Kf>3Kf=oJemoJemoJemoJemoJemoJemoJemoJen3Kf>3Kf>3Kf>3Kf>3K
f>3Kf>3Kf>3Kf=kIe]kIe]kIe]kIe]kIe]kIe]kIe]kIe]oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oL
e=oLe=oLe=oLe=oLe=oLe=oLe=oLe=gJd]gJd]gJd]gJd]gJd]gJdP00gMcNclk@;bh`inKXemKHBDQ:
NgYl7QdOc/oCc<gAemOM/;2fk>_ddM3Jg=_UemKPh^7Z_kk7k>cbdm?ICdmE?3a2d<oHa/G>e]GOdM3J
e=?Mg=_UgMcVe]GOeMCNfm[Te]GOe]GOe]GOemKPemKPemKPf=OQf=OQf]WRhN3Ybl[Cjn[cHV5Z;Rhd
R8R>l?3faLC>gMcVd<oIh=oXYjN]_ko5aLK:Q8F9dm?Idm?IJFU_9RH//;2f>3Pnh>3Vf=SNeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPemKPemKPemKPemKPemKPemKP
emKPemKPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKO
emKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemOMemOMemOMemOMemOMemOMemOMemOMf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMf=SNf=SNfMWOfMWOfMWOf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOMe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOG
fMOGfMOGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFe]KFe]KFe]KFe]KFemOGemOGf=SHf=SHemOGemOG
emOGf=SHf=SHf=SHfMWIfMWIf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHfMOFfMOFfMOFf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHf=KEfMOFf]SGfmWHfmWHfmWHf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHemKBf=OCfMSDf]WEfm[Ffm[Ffm[Ff]WEf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_GfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_Gf]WEf]WEfm[Fg=_Gg=_Gfm[F
f]WEf]WEfMSDf]WEfm[Fg=_Gg=_Gg=_Gfm[Ffm[FfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfm[Ffm[F
fm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Fg=_Gg=_GgMcHgMcHgMcHg=[Ig=[Ig=[Ig=[Ig=[Ig=[I
g=[Ig=[Igm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Gg]WFg]WFg]WFgm[Ggm[Gh=_Hh=_Hh=_Hgm[Ggm[G
gm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Gg]WFg]WFg]WFg]WFg]WFg]WF
g]WFg]WFg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_CgM[BgM[B
gM[BgM[BgM[BgM[B0037a/QGEURCTYAEE5H0004;2P`:2@/0004V9b_@dMFk^l7Fe]c4`lc9b=;FeMoM
g>K6a/cTi>[:bM;Kf^?Sh^/h=d0g=cg5aL_JfN?FeMoDdmgEe=kEe=kCd]cEe=kHen7FeMoFeMoFeMoG
e^3Ge^3Ge^3Hen7Hen7IfMoBd]Sdm?Y]K7E6ADigMWo6aLkHen3Qh>[LfnGGe^3Kf^?Hf=jm_L?3a<PV
9b]mOX8000>BTiO8bLgUi^ZQXZICE5S8bLgEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3DeMoDeMoDeMoDeMoDeMoDeMoDeMoD
eMoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEe^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3EemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoE
emoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGemgGemgGemgG
emgGemgGemgGemgGemgHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgH
f=kHf=kIfMoIfMoIfMoHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgGemgGemgGemgGemgG
emgFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWIf=[If=[If=[If=[If=[If=[If=[If=[HemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[I
f=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIf=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[Hf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SIemOIemOIemOI
emOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemKIemKIemKIemKIemKIemKIemKI
emKFe]KFe]KFe]KFe]KGemOGemOHf=SHf=SGemOGemOGemOHf=SHf=SHf=SIfMWIfMWHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SIemKIemKIemKJf=OJf=OJf=OKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KHe]GIemKJf=OJ
f=OKfMSJf=OJf=OIemKKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSHem?If=CJfMGKf]KKf]KKf]KJfMGI
f=CJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJfMGJfMGJfMGK
f]KKf]KKf]KLfmOLfmOJfMGJfMGKf]KLfmOLfmOKf]KJfMGJfMGIf=CJfMGKf]KLfmOLfmOLfmOKf]KK
f]KKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KL
fmOLfmOMg=SMg=SMg=SLf]WLf]WLf]WLf]WLf]WLf]WLf]WLf]WOf]OOf]OOf]OOf]OOf]OOf]OOf]OO
f]ONfMKNfMKNfMKOf]OOf]OPfmSPfmSPfmSOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OO
f]OOf]OOf]OOf]OOf]ONfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Mf];Mf];Mf];Mf];Mf];Mf]800=KEegUhN]OFf;^j_=WH
f/K5alO6b<G4a^CUjLC5bJ>SZLc<d]kMi^3OjN;QjlS7dM_Lh<g=dlg<e^;Pk=7?fi^JY3De>e9CElo>
f=[IhmkMimGDg/o>f=CCgM[Ihm[IhmKEgmKEgmKEgmOFh=OFh=OFh=SGhMSGhM?Df=?Df7=cND=3BFa[
M>GTk]gLi];Aflo>f<o>f=;Afm3?f<o?eIFEVoCenLG6bPh?4m[KgmkOhlc=dM?Df;Zk_f=TJ>GVj]GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CEgmCEgmCEgmGFh=GF
h=GFh=KGhMKGhMCEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=OFh=OFh=OFh=OFh=OF
h=OFh=OFh=OFh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMSHg]SHg]WIgmWIgmWIgmSHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMKFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=SG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=SG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWG
emWGemWGemWGemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]KFe]KFe]KFe]KFe]OGemOGemSHf=SHf=OG
emOGemOGemSHf=SHf=SHf=WIfMWIfMSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=WGe]WGe]WGe][Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=[H
em[Hem[Hem[Hem[Hem[Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_J
e]_Je]_Je]_Je]_Je]_Je]_Je]_Je]SFeMWGe][Hem[Hem[HemWGe]SFeMSFeM_If=_If=_If=_If=_I
f=_If=_If=_If=WHe=WHe=[IeM_Je]_Je][IeMWHe=WHe=[IeM[IeM[IeM_Je]_Je]_Je]cKemcKem_I
f=_If=_If=_If=_If=_If=_If=_If=[IeM[IeM[IeM_Je]_Je]_Je]cKemcKem[IeM[IeM_Je]cKemcK
em_Je][IeM[IeMWHe=[IeM_Je]cKemcKemcKem_Je]_Je]_If=_If=_If=_If=_If=_If=_If=_If=[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM_Je]_Je]_Je]cKemcKemgLf=gLf=gLf=cJfMcJfMcJfMcJfMcJ
fMcJfMcJfMcJfMoJemoJemoJemoJemoJemoJemoJemoJemkIe]kIe]kIe]oJemoJen3Kf>3Kf>3Kf=oJ
emoJemoJemoJemoJemoJemoJemoJemkIe]kIe]kIe]kIe]kIe]kIe]kIe]kIe]kIe]kIe]kIe]kIe]kI
e]kIe]kIe]kIe]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJ
d]gJd]gJd]gJd]gJd]gJdP00eMCFH5mQc/g?Ogj0>cXl=SDgIVEWZ:NYe]OKW9fQf][Pk>cbaLC=f]WS
fm[TeMCNfM_LgMgSg]gWc<WH`[o>hN3ZPX:8?Cm0R8NA^KS2g]gWg=_Udm;LfMSRg]gWf=OQe]GOe]GO
e]GOemKPemKPemKPf=OQf=OQdmGFVY^O@T=7K6abemKObLSBh=kZd<kJj^Wc]KBnjNSbg]gVg]kTe=CJ
Z:V]dmCHJfe^ZJ^/L79c<38cI6IWC4i?GV1Qa<K7eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPdmCNe=GOe=GOeMKPeMKPe]OQe]OQe]OQe=GOe=GOe=GOe=GOe=GOe=GO
e=GOe=GOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPemKPemKPemKPemKPemKPemKPemKPemKPeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemOMemOM
emOMemOMemOMemOMemOMemOMf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOM
emOMf=SNf=SNfMWOfMWOfMWOf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMemOMemOMemOM
emOMemOMe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOFfMOFfMOFfMOFfMOFfMOF
fMOFfMOFe]KFe]KFe]KFe]KFemOGemOGf=SHf=SHemOGemOGemOGf=SHf=SHf=SHfMWIfMWIf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHfMOFfMOFfMOFf]SGf]SGf]SG
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfm_Efm_Efm_Efm_Efm_Efm_Efm_Efm_EfMOFf]SG
f]SGf]SGfMOFf=KEemGDe]CCfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfMSDf]WEf]WEfm[Ffm[Ff]WE
fMSDf=OCf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_GfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]WEf]WE
f]WEfm[Ffm[Ffm[Fg=_Gg=_Gf]WEf]WEfm[Fg=_Gg=_Gfm[Ff]WEf]WEfMSDf]WEfm[Fg=_Gg=_Gg=_G
fm[Ffm[FfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEfm[Ffm[F
fm[Fg=_Gg=_GgMcHgMcHgMcHg=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[Igm[Ggm[Ggm[Ggm[Ggm[Ggm[G
gm[Ggm[Gg]WFg]WFg]WFgm[Ggm[Gh=_Hh=_Hh=_Hgm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Gg]WFg]WF
g]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFgM[BgM[BgM[BgM[BgM[BgM[B
gM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[B003;b/bn_KoIf=YC
DUB^[JoEe=KAd=;Kf]c@dMEXJFgBd]S8b<k_k_O6aLoKf^CGe^3GfMW@dMGFeMoPgNcSh>o<bmGLgN6C
UIDa<3Z5Q8k@cmWMg>KEe=kJfN?If>;>cMOFeMoFeMoFeMoGe^3Ge^3Ge^3Hen7Hen6<SXli>caYJVk?
cmGUi>gGe^33`LgUh_78am7Wi_3FeMo?c]OGemg@d=IVIf_DeMW2a<D0005[KFi[KFkAdm@k?Cj;SHk?
dM;Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ce=kCe=kDeMoE
e^3Ee^3Fen7Fen7Gf>;DeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ge^3Ge^3Ge^3G
e^3Ge^3Ge^3Ge^3Ge^3EemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGemgGemgGemgGemgGemgGemgGemgGemgHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgHf=kHf=kIfMoIfMoIfMoHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kGemgGemgGemgGemgGemgGemgGemgGemgFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[If=[If=[I
f=[HemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[Hf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOI
emOIemOIemOIemOIemOIemKIemKIemKIemKIemKIemKIemKIemKFe]KFe]KFe]KFe]KGemOGemOHf=SH
f=SGemOGemOGemOHf=SHf=SHf=SIfMWIfMWHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SIemKIemKIemKJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfmGKfmGKfmGKfmGKfmGKfmGKfmGKfmGJf=OJf=OJf=OJf=OIemKGeMCFe=?Edm;KfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSIf=CJfMGKf]KKf]KKf]KJfMGIf=CHem?JfMGJfMGJfMGKf]KKf]KKf]KLfmOL
fmOKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOJfMGJfMGKf]KL
fmOLfmOKf]KJfMGJfMGIf=CJfMGKf]KLfmOLfmOLfmOKf]KKf]KKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOMg=SMg=SMg=SLf]WLf]WLf]WL
f]WLf]WLf]WLf]WLf]WOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]ONfMKNfMKNfMKOf]OOf]OPfmSPfmSP
fmSOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]ONfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKN
fMKNfMKNfMKNfMKNfMKMf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];M
f];Mf];Mf];Mf];Mf];Mf];Mf]800:n]/lW7cNGSjM_Ighj<TWilP/g;dMCBf=7Be[^l`=[Jh=7AemGD
gLo>f=cKiMCCgMOFh=OFh=OFh=OFh=OFh=OFh=OFh=OFh8F7Qc0b<Wn1P/c=dM_KhNOVkm3?fN3OjN7N
kL?1cM7@f]cKi=OGgLg>d]CFej2RXbh]=hn>V=KEgm[IhmCCgMSGhMSGhMGDg]OHh]gNj<o@f]?Dg/o@
f][KiKbmam;CgM[Li4Y<E<W;da8D7>3RjUMIHFi`N:^]]M[Jj=;Bh=cLj]KFi=WIimWIim?ChMCDh]GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=;Gh=;Gh=;Gh=;Gh=;G
h=;Gh=;Gh=;Gh=CFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=GGgmGGgmGGgmKHh=KHh=OIhMOIhMOIhMGF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmCFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=GG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOFgmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKF
g=KFg=KFg=OGgMOGgMOGgMSHg]SHg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg]SGh=SGh=SGh=SGh=SG
h=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]OIf]OIf]OIf]OIf]OIf]OIf]OIf]OIf]SGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SGfMSGfMSGfMWHf]WH
f]WHf][Ifm[IfmSGfMSGfMSGfMWHf]WHf]WHf][Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[J
f][Jf][Jf][Jf][Jf][Jf][Jf][Jf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM_IfM_IfMSGfMSGfMOFf=OFf=KEemKEemGDe]GDe]WIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWH
g=WHg=WHg=WHg=WHg=WHg=WHg=WHg=_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM[Hf=[Hf=[Hf=_IfM_IfM_IfMcJf]cJf][Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem[Hem[Hem[Hem[HemSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SIemSIemSIemSIemSI
emSIemSIemSIemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe][Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemSIemSIemSIemWJf=WJ
f=WJf=[KfM[KfMSIemSIemSIemWJf=WJf=WJf=[KfM[KfM_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=WGe]WGe]WGe][Hem[Hem[Hem_If=_If=cJfMcJfMcJfMcJfMcJ
fMcJfMcJfMcJfM_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM_Je]cKemcK
em_Je][IeM[IeM[IeM[IeM[IeM_Je]_Je]_Je]cKemcKem[IeM[IeM[IeM_Je]_Je]_Je]cKemcKemWH
e=[IeM_Je]cKemcKemcKem_Je]_Je][IeM[IeM[IeM_Je]_Je]_Je]cKemcKem_Je]_Je]_Je]_Je]_J
e]_Je]_Je]_Je]cKemcKemcKemcKemcKemcKemcKemcKem_Je]_Je]_Je]cKemcKemgLf=gLf=gLf=cK
emcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKen7Ne^3MeN3MeMoLe=oL
e=kKdmkKdmgJd]oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=kK
dmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkK
dmkKdmkKdmkKdmkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]gKdMgKdMgKdMgKdMgKdMgKd@00VINMl>kd
_kg3dm7Gh=kTW9ZP2@L=f]SNSXnC]kRlf=SNfMWOh=oXfMSRf]WSd<oIemKPemKPemKPemKPemKPemKP
emKPemKPf=[J@492G5iOc/oCc/kDd<oHhn;/_[g7d]3Lh=kZg=_Udm;KcLgCgn3Tj^__G5iOKFaf/K2j
g=_UfMSReMCNfMSRemKPeMCNcm3JfM[TemSRgMkXe]OQeMKP]KK0S8fG`/C<OX28`L?;ZjfeYZR`g^3X
_;k6ZjfeeMGQbl_Gd=3LcLgIbl_Gd];NfMWUg]kZeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPd]OPd]OPd]OPd]OPd]OPd]OPd]OPd]OPe=KNe=KNe=KNeMOOeMOOeMOO
e]SPe]SPeMOOeMOOeMOOe]SPe]SPemWQemWQemWQeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPemKOemKO
emKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNemKOemKOemKO
f=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKOe]KLe]KLe]KLemOMemOMemOMf=SNf=SNf]SNf]SN
f]SNf]SNf]SNf]SNf]SNf]SNf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OP
f=OPf=OPf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMemOMemOMemOM
emOMemOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJemWJemWJ
emWJemWJemWJemWJemWJemWJf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OIf=OIfMSJfMSJfMSJf]WKf]WKf=OIf=OIf=OIfMSJfMSJfMSJ
f]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][JfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf=OIf=OI
f=OIemKHe]GGe]GGe]GGeMCFfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHfmWIfmWIfmWI
g=[Jg=[Jf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=WGf=WGf=WGf=WGf=WGf=WGf=WGf=WGfMOFfMOFfMOFfMOFfMOFfMOF
fMOFfMOFf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGf=WGf=WGf=WGfM[HfM[HfM[Hf]_If]_If=WGf=WGf=WGfM[HfM[HfM[H
f]_If]_IfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfMOFfMOF
fMOFf]SGf]SGf]SGfmWHfmWHg=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[IfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfm[Ffm[F
fm[Ffm[Ffm[Ffm[Ffm[Ffm[Ff]WEf]WEfm[Fg=_Gg=_Gfm[Ff]WEf]WEf]WEf]WEf]WEfm[Ffm[Ffm[F
g=_Gg=_Gf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_GfMSDf]WEfm[Fg=_Gg=_Gg=_Gfm[Ffm[Ff]WEf]WE
f]WEfm[Ffm[Ffm[Fg=_Gg=_Gfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Fg=_Gg=_Gg=_Gg=_Gg=_Gg=_G
g=_Gg=_Gfm[Ffm[Ffm[Fg=_Gg=_GgMcHgMcHgMcHg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_G
g=_Gg=_Gg=_Gg=_Gg=_Gg=_Gh=gEh=gEh=gEgmcDgmcDg]_Cg]_Cg]_CgmcDgmcDgmcDgmcDgmcDgmcD
gmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]cBg]cBg]cBg]cBg]cBg]cB
g]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_A002GUI_?cM?Ng>;WiN^n_<;EdmWEdmW8a/aOH6C?d=CIfMoC
dmWGe]oHen7JfN?Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3EemSLg]l];S8k?432`/S>c]CViNkY
j?7?c]S=c=KRhN_FeMk;bm7Fe]`b<cLm?T:c/[cCd]cNgNOFeMoGe^3Hen7Ee=kHen7DeMoGf>;Fen7E
e^3Ad]cGf>;=c]QLGFOWjO6TYZk/k_K8b];3aLg;cMGRi>anP8SFe^;EeN7MgNWUiO7Fe^;EeN7De>3=
cMWEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ben3Ben3Ben3B
en3Ben3Ben3Ben3Ben3De]kDe]kDe]kEemoEemoEemoFf>3Ff>3EemoEemoEemoFf>3Ff>3GfN7GfN7G
fN7Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoDe]kDe]kDe]kEemoEemoEemoFf>3F
f>3EemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oGe]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oFe]cFe]cFe]cGemgGemgGemgHf=kHf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kHen3Hen3Hen3H
en3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kGemgGemgGemgGemgGemgGemgGemgGemgIf=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[GfM[GfM[GfM[GfM[GfM[GfM[GfM[GfM[HemWHemWHemWH
emWHemWHemWHemWHemWIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[HemWHemWHemWI
f=[If=[If=[JfM_JfM_HemWHemWHemWIf=[If=[If=[JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_J
fM_Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][If=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWHemWHemWHemWGe]SGe]SGe]SFeMOFeMOIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIf=[If=[If=[If=[If=[If=[If=[If=[KfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SKfMWKfMWKfMWLf][Lf][Jf=OJf=OJf=OJf=OJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHfMOHfMOHfMOH
fMOHfMOHfMOHfMOHfMOIemKIemKIemKIemKIemKIemKIemKIemKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJ
f=OJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OHfMOHfMOHfMOI
f]SIf]SIf]SJfmWJfmWHfMOHfMOHfMOIf]SIf]SIf]SJfmWJfmWKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSIemKIemKIemKJf=OJf=OJf=OKfMSKfMSLf]WLf]WLf]WL
f]WLf]WLf]WLf]WLf]WKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KJfMGJfMGKf]KL
fmOLfmOKf]KJfMGJfMGJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOJfMGJfMGJfMGKf]KKf]KKf]KLfmOL
fmOIf=CJfMGKf]KLfmOLfmOLfmOKf]KKf]KJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOKf]KKf]KKf]KK
f]KKf]KKf]KKf]KKf]KLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOKf]KKf]KKf]KLfmOLfmOMg=SMg=SM
g=SLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOPgMGPgMGPgMGO
g=COg=CNfm?Nfm?Nfm?Og=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=CO
g=CNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?Nfm?Nfm?Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Mfm7Mfm7Mfm7Mfm7Mfm7Mfm4008Z8
S];@e/k<d/?1anGSjLg;dNKTj]GCfCTj?]gNh]OGgLg=dlo>emGDg]KEgmSGhMOFh=OFh=OFh=OFh=OF
h=OFh=OFh=OFh=SIgN7Ri[Jg^d93AeeMHkjna;fm`mOGgMoNimWHhNCSk<G4cMSGh4U9Ce9BF;Jf_=CC
gMcKiMSGhM;AfmOFh=KEgmCCgMcKiMKGhMGFh=KGhM7Bg<o@f]WJi=gNj3Pi@loAfM?EgMgOim7CfnSZ
l]CFg]OIhI:DW;:c_LK7dL[;eMkOjM;CgMWJi=WJi<k?fMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=;Gh=;Gh=;Gh=;Gh=;Gh=;Gh=;Gh=;Gh=CFg]CFg]CFg]GGgmGG
gmGGgmKHh=KHh=GGgmGGgmGGgmKHh=KHh=OIhMOIhMOIhMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=OF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmCFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOF
gmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKFg=KFg=KFg=OGgMOGgMOGgMSHg]SHg][H
g][Hg][Hg][Hg][Hg][Hg][Hg][Hg]SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SG
h=SGh=SGh=SGh=SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]OI
f]OIf]OIf]OIf]OIf]OIf]OIf]OIf]SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SGfMSGfMSGfMWHf]WHf]WHf][Ifm[IfmSGfMSGfMSGfMWHf]WH
f]WHf][Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfMSG
fMSGfMSGfMSGfMOFf=OFf=OFf=OFf=WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM_I
fM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[Hf=_IfM_I
fM_IfMcJf]cJf][Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemSH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SIemSIemSIemSIemSIemSIemSIemSIemWGe]WGe]WGe]WGe]WG
e]WGe]WGe]WGe][Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
em[Hem[Hem[Hem[Hem[Hem[Hem[HemSIemSIemSIemWJf=WJf=WJf=[KfM[KfMSIemSIemSIemWJf=WJ
f=WJf=[KfM[KfM_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=WG
e]WGe]WGe][Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_J
e]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM_Je]cKemcKem_Je][IeM[IeM[IeM[IeM[IeM_Je]_J
e]_Je]cKemcKem[IeM[IeM[IeM_Je]_Je]_Je]cKemcKemWHe=[IeM_Je]cKemcKemcKem_Je]_Je][I
eM[IeM[IeM_Je]_Je]_Je]cKemcKem_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]cKemcKemcKemcKemcK
emcKemcKemcKem_Je]_Je]_Je]cKemcKemgLf=gLf=gLf=cKemcKemcKemcKemcKemcKemcKemcKemcK
emcKemcKemcKemcKemcKemcKemcKemoLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oL
e=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=kKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkK
dmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkLd]kLd]kLd]kLd]kL
d]kLd]kLd]kLd]gKdMgKdMgKdMgKdMgKdMgKd@00g]cRalG;g=[Ph^3Ve]CJf]SN^kVok>[`8b@Xcm3D
eMGKe=CJf]WRfm[Te=?MdM3JemKPemKPemKPemKPemKPemKPemKPemKPd];Hdm?Ii>CZ`l?9?3e1AdQ<
emSLd=7Ea<C:hN7Wbl_Ah=oXC4]DATE>WijWi>?/e]GOf]WSe=?Mdm;LfMSRe=?Md]7KgMcVc/oIdmCN
fmcVg=gWemSRemSRcm3J8b@^aLO?m?Kn_;k6b<[BcLoGgn7YdmGMd=;J]KK0hN;/blcFd]?MaLK@e]OQ
g=gWf=WSeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPd]OPd]OP
d]OPd]OPd]OPd]OPd]OPd]OPe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOOeMOOe]SPe]SPemWQ
emWQemWQeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOe=KNe=KNe=KNeMOOeMOOeMOO
e]SPe]SPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOe]GNe]GNe]GNemKOemKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKO
emKOemKOe]KLe]KLe]KLemOMemOMemOMf=SNf=SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf=OPf=OP
f=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOMfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJemWJemWJemWJemWJemWJemWJemWJemWJf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OI
f=OIfMSJfMSJfMSJf]WKf]WKf=OIf=OIf=OIfMSJfMSJfMSJf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WK
f]WKf]WKf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][JfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHfmWIfmWIfmWIg=[Jg=[Jf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=WGf=WG
f=WGf=WGf=WGf=WGf=WGf=WGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf=WGf=WG
f=WGfM[HfM[HfM[Hf]_If]_If=WGf=WGf=WGfM[HfM[HfM[Hf]_If]_IfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfMOFfMOFfMOFf]SGf]SGf]SGfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ff]WEf]WE
fm[Fg=_Gg=_Gfm[Ff]WEf]WEf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_Gf]WEf]WEf]WEfm[Ffm[Ffm[F
g=_Gg=_GfMSDf]WEfm[Fg=_Gg=_Gg=_Gfm[Ffm[Ff]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_Gfm[Ffm[F
fm[Ffm[Ffm[Ffm[Ffm[Ffm[Fg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gfm[Ffm[Ffm[Fg=_Gg=_GgMcH
gMcHgMcHg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_GgmcDgmcD
gmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcD
gmcDgmcDg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_A
003=bm7Ng>;Ng>;4`/SKfMoNg>;6a<Zm^l5QHVKBdmOLg>;Fe]cIf>7If>;If>;FeMoGe^3Ge^3Ge^3G
e^3Ge^3Ge^3Ge^3Ge^3JfN;Ad=WLg>;9bLmnOh=ZJfn][k3Ph^?If]kEe][IfMnj^/1kNX>j^L?If>;@
cmWBdM_If>;Ge^3Ge^3LfnGEe=k@cmWJfN?Ad]cEe^3Fen7Gf>;Ee^3LgNOAd]aPHF_9bm??dMWJg>CM
gnOSiNg5alo>d=SKgNF6R93]koOIfn?Jg>C=cmOKgNGCeMgCeMgEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ben3Ben3Ben3Ben3Ben3Ben3Ben3Ben3De]kDe]kDe]kE
emoEemoEemoFf>3Ff>3EemoEemoEemoFf>3Ff>3GfN7GfN7GfN7Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoDe]kDe]kDe]kEemoEemoEemoFf>3Ff>3EemoEemoEemoEemoEemoEemoEemoE
emoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkG
e]oGe]oGe]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFe]cFe]cFe]cGemgGemgGemgHf=kH
f=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kHen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3H
en3Hen3Hen3Hen3Hen3Hf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgG
emgGemgGemgGemgGemgIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[GfM[GfM[GfM[GfM[GfM[GfM[GfM[GfM[HemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[HemWHemWHemWIf=[If=[If=[JfM_JfM_HemWHemWHemWI
f=[If=[If=[JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_Jf][Jf][Jf][Jf][Jf][Jf][Jf][J
f][If=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWGe]SHemWHemWHemWIf=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIf]SIf]SIf]SIf]SIf]SIf]SIf]SI
f]SKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SK
fMWKfMWKfMWLf][Lf][Jf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJ
f=OHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHfMOHfMOHfMOHfMOHfMOHfMOHfMOHfMOIemKIemKIemKI
emKIemKIemKIemKIemKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OHfMOHfMOHfMOIf]SIf]SIf]SJfmWJfmWHfMOHfMOHfMOI
f]SIf]SIf]SJfmWJfmWKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSIemKIemKIemKJf=OJf=OJf=OKfMSKfMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KJfMGJfMGKf]KLfmOLfmOKf]KJfMGJfMGJfMGJfMGJfMGK
f]KKf]KKf]KLfmOLfmOJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOIf=CJfMGKf]KLfmOLfmOLfmOKf]KK
f]KJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KLfmOLfmOLfmOL
fmOLfmOLfmOLfmOLfmOKf]KKf]KKf]KLfmOLfmOMg=SMg=SMg=SLfmOLfmOLfmOLfmOLfmOLfmOLfmOL
fmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmONfm?Nfm?Nfm?Og=COg=CPgMGPgMGPgMGOg=COg=COg=CO
g=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=CNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Ng=;Ng=;Ng=;N
g=;Ng=;Ng=;Ng=;Ng=;Mfm7Mfm7Mfm7Mfm7Mfm7Mfm400=OEfnOUjl_9cl;0a]7?eMCBf>7OiGAbN;Ri
_MGFf^?SjM?CfM?Bfm;AfmgLi]_Ji=OFh=OFh=OFh=OFh=OFh=OFh=OFh=OFh=_Ji>CSkLo>enWYkm7B
eYbNWjFWYhR:R[2b/lG6bVe^LYnOYK2_^=WHh^_YmMWGhm7@f][IhmOFh=CCgM_Ji=WHh]?Bg=OFh=OH
h][KiLk?fM3Afm3Afn7Rk=GFh;ZkaGYlQ;Bf_^;Tk=3Bf[Bf_^?UkLg?emSJhP/=5Ko1bLK8d=?EgM?E
gN3Rj/oAfMWKhmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=;G
h=;Gh=;Gh=;Gh=;Gh=;Gh=;Gh=;Gh=CFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=GGgmGGgmGGgmKHh=KH
h=OIhMOIhMOIhMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmCFg]CFg]CFg]GGgmGG
gmGGgmKHh=KHh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOFgmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmKFg=KFg=KFg=OGgMOGgMOGgMSHg]SHg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg]SG
h=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]OIf]OIf]OIf]OIf]OIf]OIf]OIf]OIf]SG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SG
fMSGfMSGfMWHf]WHf]WHf][Ifm[IfmSGfMSGfMSGfMWHf]WHf]WHf][Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[I
fm[Ifm[Ifm[Ifm[Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfMOFf=SGfMSGfMSGfMWHf][Ifm[Ifm[IfmWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWJf=WJf=WJf=WJf=WJf=WJf=WJf=WJf=_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[Hf=_IfM_IfM_IfMcJf]cJf][Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SI
emSIemSIemSIemSIemSIemSIemSIemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe][Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemSI
emSIemSIemWJf=WJf=WJf=[KfM[KfMSIemSIemSIemWJf=WJf=WJf=[KfM[KfM_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=WGe]WGe]WGe][Hem[Hem[Hem_If=_If=[H
em[Hem[Hem[Hem[Hem[Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][I
eM[IeM_Je]cKemcKem_Je][IeM[IeM[IeM[IeM[IeM_Je]_Je]_Je]cKemcKem[IeM[IeM[IeM_Je]_J
e]_Je]cKemcKemWHe=[IeM_Je]cKemcKemcKem_Je]_Je][IeM[IeM[IeM_Je]_Je]_Je]cKemcKem_J
e]_Je]_Je]_Je]_Je]_Je]_Je]_Je]cKemcKemcKemcKemcKemcKemcKemcKem_Je]_Je]_Je]cKemcK
emgLf=gLf=gLf=cKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemkK
dmkKdmkKdmoLe=oLe>3MeN3MeN3MeMoLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oL
e=oLe=oLe=oLe=kKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkK
dmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]gKdMgKdMgKdMgKdMgK
dMgKd@00gM_QbLO=NWQn?ce30004g=[PclgCHf5Wcm3D_;g1gmoUf=SNfm[Sdm;Lfm[Td<oIemKPemKP
emKPemKPemKPemKPemKPemKPe=?McLcFi>?/b/[@i>GYb/c=LgEeaLO7XZBUM7IggMkR^[[0hn;[a/G?
e]CPdm3Od<oIfMSRdm;Lc/gGfMSRgMcVe]GOe]GOd=7Kf]_UdM;LfM[TemSRh>7[`<7;e=GOFeeUf=[R
dmGM00060049][S0f]cTe]SP0004e=OLfmkSfMcQdMCIf]gRal[?g^7VeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPd]OPd]OPd]OPd]OPd]OPd]OPd]OPd]OPe=KNe=KN
e=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOOeMOOe]SPe]SPemWQemWQemWQeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GN
e]GNemKOemKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKOe]KLe]KLe]KLemOMemOMemOM
f=SNf=SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OP
f=OPf=OPf=OPf=OPf=OPf=OPf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOM
emOMemOMemOMemOMemOMemOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJemWJemWJemWJemWJemWJemWJemWJemWJf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OIf=OIfMSJfMSJfMSJf]WKf]WKf=OIf=OI
f=OIfMSJfMSJfMSJf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKf][Jf][Jf][Jf][Jf][Jf][J
f][Jf][JfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIemKHf=OIf=OIfMSJfMSJf]WKf]WKfm[LfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM[FfM[FfM[FfM[FfM[FfM[F
fM[FfM[FfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SH
f]SHfmWIfmWIfmWIg=[Jg=[Jf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=WGf=WGf=WGf=WGf=WGf=WGf=WGf=WGfMOFfMOF
fMOFfMOFfMOFfMOFfMOFfMOFf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf=WGf=WGf=WGfM[HfM[HfM[Hf]_If]_If=WGf=WG
f=WGfM[HfM[HfM[Hf]_If]_IfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfMOFfMOFfMOFf]SGf]SGf]SGfmWHfmWHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ff]WEf]WEfm[Fg=_Gg=_Gfm[Ff]WEf]WEf]WEf]WE
f]WEfm[Ffm[Ffm[Fg=_Gg=_Gf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_GfMSDf]WEfm[Fg=_Gg=_Gg=_G
fm[Ffm[Ff]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_Gfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Fg=_Gg=_G
g=_Gg=_Gg=_Gg=_Gg=_Gg=_Gfm[Ffm[Ffm[Fg=_Gg=_GgMcHgMcHgMcHg=_Gg=_Gg=_Gg=_Gg=_Gg=_G
g=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_GgM[Bg]_Cg]_CgmcDgmcDh=gEh=gEhMkFgmcDgmcD
gmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]cBg]cB
g]cBg]cBg]cBg]cBg]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_A003=bm7QgnDo?D<k>Cl000C[jNo<b]1T
HVS:blo?d=CDe=[?cmGRhN[=c=KQh>[If>;LfnGGe^3Ad=[JfN?ThngGe^3<bmGFeMoJenOBcmoDdN3G
eN7?c]SDdmcNg^CNg^BTXjbCTY^a/;WLfnCKf^?@cmSFeMkIf>7FeMoJfN?LfnGAd=[Og^S:bM?PgnWC
d]cEe=gPgnS>cMKQh>W<bmCAd=WAd=WAd=UWIVoGe]o2`LX40``X9c1_KWOThncIf>4:2aG2`lgXjO?B
dmgFen7?d=[Mg^SAd]cEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3FeMoFeMoFeMoGe^3Ge^3Ge^3Hen7Hen7Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oHen3H
en3Hen3If>7If>7If>7Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoE
emoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oFeMkFeMkFeMkGe]oGe]oGe]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGemgGemgGemgG
emgGemgGemgGemgGemgIemgIemgIemgIemgIemgIemgIemgIemgGemgGemgGemgHf=kHf=kIfMoIfMoI
fMoHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kJf=kJf=kJf=kJ
f=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kGemgGemgGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgIf=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWEfM[GfM[GfM[If=[If=[Kf=[Kf=[Mf=[If=[If=[If=[If=[If=[If=[If=[I
f=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWJf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][JfM_JfM_JfM_J
fM_JfM_JfM_JfM_JfM_KfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSHfMOHfMOHfMOHfMOHfMOHfMOHfMOHfMOKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJf=OIemKI
emKIemKIemKJf=OKfMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJ
f=OIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKHe]GHe]GHe]GH
e]GIemKIemKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGKf]KKf]KKf]KK
f]KKf]KKf]KKf]KKf]KJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGKf]KKf]KKf]KKf]KKf]KKf]KKf]KK
f]KJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KJfm;Jfm;Jf]CJ
f]CJfMGJfMGJf=OJf=OJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGJfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Mf];Mf];Mf];M
f];Mf];Mf];Mf];Mf];If]7If]7If]7Jfm;Jfm;Jfm;Kg=?Kg=?Mf];Mf];Mf];Mf];Mf];Mf];Mf];M
f];Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Og=CNfm?Nfm?Nfm?Nfm?Nfm?Mf];Mf];Og=COg=COg=CO
g=COg=COg=COg=COg=CNfm?Og=COg=CPgMGPgMGOg=COg=CNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;OgM?OgM?OgM?O
gM?OgM?OgM?OgM?OgM?Pg]COgM?OgM?Ng=;Ng=;OgM?OgM?Pg]CNg=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;N
g=;Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7M
fm7Mfm7Mfm400=_IglS6c<_9ci6?UL6oaLK4b]cJh6aZL:f^/^;SimoOiMOGgN;Qj/k=emWHh];Afl_:
e=oNj=SGhMKEglc;eM[IhmSGhN;Qjl_8f>;Ok^;Ok]_IiMOFh>SWl;Bd^VMWKL[9d]3?f<[9d[Nf_kbk
a>3Oj>g/mMKEg/g<e]OFh=cKiMCCgMgLi/W8d^?Rk=kMim;Af][Ih/o>en7PjMGDgMkMi^?Rjk2_^6UX
LMOFgm7@fIZIXYFDWL_:dmkMi/W8dIBEWm_Li/S9dlc=en?Tk]?Dg][KiM?Dg]GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=KEgmKEgmKEgmOFh=OFh=OFh=SGhMSGhMOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmSGh=SGh=SGh=WHhMWHhMOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOFgmOFgmSGh=SGh=OF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWGgMWGgMWGgMWGgMWG
gMWGgMWGgMWGgMOGgMOGgMOGgMSHg]SHg]WIgmWIgmWIgmSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][H
g][Hg][Hg][Hg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMGIf]OIf]OIf]WHf]WH
f]_Hf]_Hf]gHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM[J
f][Jf][Jf][Jf][Jf][Jf][Jf][Jf][Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=SIemSIemSIemSIemSIemSIemSIemSIem_I
f=_If=_If=_If=_If=_If=_If=_If=_If=[HemWGe]WGe]WGe]WGe][Hem_If=[Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]SFeMSFeMSFeMSFeMWGe]WGe][Hem[Hem[Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeM_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM_J
e]_Je]_Je]_Je]_Je]_Je]_Je]_Je][Kd][Kd][Je=[Je=[IeM[IeM[Hem[Hem[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][K
d][Kd][Kd][Kd][Kd][Kd][Kd][Kd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]WJdMWJdMWJdM[Kd][K
d][Kd]_Ldm_LdmgJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]kKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkK
dmkKdmkKdmkKdmkKdmkKdmkKdmgJd]oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=kKdmoLe=oLe>3MeN3M
eMoLe=oLe=kKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkL
d]kLd]kLd]kLd]kLd]kLd]kLd]kLd]oMdmoMdmoMdmoMdmoMdmoMdmoMdmoMdn3Ne=oMdmoMdmkLd]kL
d]oMdmoMdn3Ne=kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgK
dMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKd@00d]3FgmgSc/cBh^3Vd<kDeM?I
dLoEb<K<HF9Vg]oSemOMd];HgMcUd]7KemKPeMCNd]7KgmkXeMCNe]GObLSBf]WSd]7Kd]7Kf=KRa/C@
`/3<kNcfe]GN`L39]KFkfMWOgMcUc<_D^k[3`;o8c/gFbl[Cb<O@e=?Lf=OQe]GOc/gGd<oIg]gWclkH
fm[Tbl[DfMSQfMSQd]7Jg=_Td]7JemKOg]gVH5mX_Kc5i^G^c/gFdm;K`/7:hn;[fm[Sb<O@`/?=fmcV
b/_EfmcVhnC^blcFemSRf=WSeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPe]GOe]GOe]GOemKPemKPemKPf=OQf=OQemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOf=OPf=OPf=OPfMSQemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOe]GNe]GNe]GNemKOemKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKOemOMemOM
emOMemOMemOMemOMemOMemOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMemOMemOMemOMf=SNf=SNfMWO
fMWOfMWOf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf]SNf]SN
f]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIeMWJemWJemWJfMSJfMSJfmSJfmSJgMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf]WKf]WK
f]WKf]WKf]WKf]WKf]WKf]WKfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHf=WGf=WGf=WGf=WGf=WGf=WGf=WGf=WGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]SG
fMOFfMOFfMOFfMOFf]SGfmWHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf=KEf=KE
f=KEf=KEfMOFfMOFf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]_Bf]_B
f][Df][Df]WEf]WEf]SGf]SGf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WE
f]WEf]WEf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_BgM[BgM[B
gM[BgM[BgM[BgM[BgM[BgM[BfM[AfM[AfM[Af]_Bf]_Bf]_BfmcCfmcCgM[BgM[BgM[BgM[BgM[BgM[B
gM[BgM[Bg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_CgmcDgmcD
gmcDgmcDgmcDgmcDgmcDgmcDg]_CgmcDgmcDh=gEh=gEgmcDgmcDg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgmgCgmgC
gmgCgmgCgmgCgmgCgmgCgmgCh=kDgmgCg]cBg]cBg]cBg]cBgmgCh=kDg]cBg]cBg]cBg]cBg]cBg]cB
g]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_A
gM_AgM_AgM_AgM_A002DTYSAcmG?cM?Ng>;=bm7He]cDd]SLf^0V9b_Ad]K>c]C>c]CGe]oGe^3Ge^3J
fN?Sh^_@cmS?c]OEe=gUi>gSh^_Ddmbg][oMg>KWi_3?c]OEe=g7a/oKf^?3`/_0_lSKf^?Sh^^n_LJF
UIjUY:g5a<gGe]oUi>gMg>GNgNKDdmcMg>GSh^_Ge]oMg>GBdM[NgNKHen3Ee=gFeMkAd=WBdM[Cd]/T
8bcOg^OEe=gIf>7@cmSQh>W?c]OBdMZGUYn_/;[Ce=kKg>KOh>[Ad]c<cMOQh^cCe=kEe^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3FeMoFeMoFeMoGe^3Ge^3Ge^3Hen7H
en7Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkGe]oGe]oGe]oHen3Hen3Hen3Ge]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oGe]oHen3H
en3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGemgGemgGemgGemgGemgGemgGemgGemgIemgIemgIemgI
emgIemgIemgIemgIemgGemgGemgGemgHf=kHf=kIfMoIfMoIfMoHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJ
f=kJf=kJf=kJf=kJf=kGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWEfM[GfM[GfM[I
f=[If=[Kf=[Kf=[Mf=[If=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWJf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][If=[If=[If=[If=[If=[If=[If=[If=[KfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSHfMOHfMOHfMOHfMOHfMOHfMOHfMOH
fMOKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJf=OIemKIemKIemKIemKJf=OKfMSJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIemKIemKIemKIemKIemKIemKIemKI
emKIemKIemKIemKIemKIemKIemKIemKIemKHe]GHe]GHe]GHe]GIemKIemKJf=OJf=OJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfm;Jfm;Jf]CJf]CJfMGJfMGJf=OJf=OJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;J
fm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];If]7If]7If]7J
fm;Jfm;Jfm;Kg=?Kg=?Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?N
fm?Mf];Mf];Mf];Nfm?Nfm?Nfm?Nfm?Og=COg=COg=COg=COg=COg=COg=COg=COg=CNfm?Og=COg=CP
gMGPgMGOg=COg=CNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?N
fm?Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;OgM?OgM?Ng=;M
fm7Mfm7Ng=;OgM?OgM?Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7M
fm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm4008Z8S]7?eNGSjLc:d=oM
hmGCfMcJh<_9cc8c=m;CemWIgmOGgMSGh=[IhmCCgMOFh<O7cLg=dnk^m<g=dmKFg<_;dMkNi;Vi_lO7
cM[Jh=3@e][Jh=SGh=oNim7@fMoNikflaM_JhmgLiM7@fMGDgM3?f<O6cm3?f<S8c]CDf/o?eMkNi=KF
g<c<d]WIgmkNi=SGh=?BfmOFgmSGh=_JhmoNimKEgS<b>m7@fLS7d>CSk<K5c^[Yl]3?f=gLiH:1R]?D
g]WJi=CEglg>f<W:e=cMinSYll[;eMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=KEgmKEgmKEgmOFh=OFh=OFh=SGhMSGhMOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKE
g]KEg]KEg]KEg]OFgmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOFgmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMOGgMOGgMOGgMSHg]SH
g]WIgmWIgmWIgmSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg][H
g][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg]OGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMGIf]OIf]OIf]WHf]WHf]_Hf]_Hf]gHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM[Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem_If=_If=_If=_If=_I
f=_If=_If=_If=SIemSIemSIemSIemSIemSIemSIemSIem_If=_If=_If=_If=_If=_If=_If=_If=_I
f=[HemWGe]WGe]WGe]WGe][Hem_If=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[H
em[Hem[Hem[HemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]SF
eMSFeMSFeMSFeMWGe]WGe][Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[K
d][Kd][Je=[Je=[IeM[IeM[Hem[Hem[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeM[Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd]gJ
d]gJd]gJd]gJd]gJd]gJd]gJd]gJd]WJdMWJdMWJdM[Kd][Kd][Kd]_Ldm_LdmgJd]gJd]gJd]gJd]gJ
d]gJd]gJd]gJd]kKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmcIdMgJd]gJd]kKdmkKdmoLe=oLe=oLe=oL
e=oLe=oLe=oLe=oLe=oLe=oLe=oLe=kKdmoLe=oLe>3MeN3MeMoLe=oLe=kKdmkKdmkKdmkKdmkKdmkK
dmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kL
d]kLd]kLd]kLd]kLd]kLd]kLd]kLd]oMdmkLd]gKdMgKdMgKdMgKdMkLd]oMdmkLd]kLd]kLd]kLd]kL
d]kLd]kLd]kLd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgK
dMgKdMgKdMgKdMgKdMgKd@00[Zbbhn7WcL_AemGKb/S>g]cRe=;Hf]SNHF9V`<75g=cRfm_QemKOf]WS
eMCNe]GOiNG[cLgCa/K<UIFK_;c2fMWOd=3FIfM][Jn`inWZhN;VYjR/ZJV_b<O@emKOe]GNiNC]eMCM
d<oHgMcUe]GN][Fn]KBmf=OPgMgSdM7G];BjcLgCe=CJfMWOfMWOdm?IeMCMdm;KfMSQfMSQgmkWhN3Y
a<?<I6=/eMCMfm[Sg]gVa/G>dM3If]WRhn;[VYVRhnC^dmCNcm3Je=GOeMKPf]_UfmcVd=7KeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe]GOe]GOe]GOemKPemKPemKP
f=OQf=OQemKOemKOemKOemKOemKOemKOemKOemKOeMCMeMCMe]GNe]GNe]GNemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNemKOemKOemKO
f=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKOemOMemOMemOMemOMemOMemOMemOMemOMfMOMfMOM
fMOMfMOMfMOMfMOMfMOMfMOMemOMemOMemOMf=SNf=SNfMWOfMWOfMWOf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SN
f]SNf]SNf]SNf]SNf]SNf]SNemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIeMWJemWJ
emWJfMSJfMSJfmSJfmSJgMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf=WGf=WGf=WGf=WGf=WGf=WG
f=WGf=WGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]SGfMOFfMOFfMOFfMOFf]SGfmWHf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMOFfMOFfMOFfMOFfMOFfMOF
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf=KEf=KEf=KEf=KEfMOFfMOFf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMSDfMSDfMSDfMSDfMSDfMSD
fMSDfMSDf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf]WEf]WEf]WEf]WEf]WEf]WE
f]WEf]WEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf]_Bf]_Bf][Df][Df]WEf]WEf]SGf]SGf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]_Bf]_Bf]_Bf]_Bf]_Bf]_B
f]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BfM[AfM[A
fM[Af]_Bf]_Bf]_BfmcCfmcCgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[Bg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg=WAg=WAgM[BgM[Bg]_CgmcDh=gEh=gEgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDg]_CgmcD
gmcDh=gEh=gEgmcDgmcDg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_Ag]cBg]cB
gM_Ag=[@g=[@gM_Ag]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_A
gM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_A002f];[?cM?EdmWG
eM_Th^S@c]CGeM_=bm6GV9bQXZKEeM_GemgCd]_Ge^3Hen7Ge^34aLWOh>C]k_:l_L5gN7anOh><SI5_
L7AkOGeNH61OHF:2PhOOgnG?c]O<bmCMg>K2`L[JfN;Ui>gFeMk@cmSJfN;0_lR;RY?HfMg0`LFCU9Ra
/[Jm_/;Ad]KEe][DeMWEe=gHen3JfN;Ge]oJfN;Ge]nTXjbJVJ;;b]?LfnCKf^?Mg>GLfnCKf^?Ad=VP
WjS=c]S<cMOIf^COh>[Kg>KBdmg=c]SJfnGEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3FeMoFeMoFeMoGe^3Ge^3Ge^3Hen7Hen7Ge]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oEe=gEe=gEe=gFeMkFeMkFeMkGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoE
emoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oGe]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGemgGemgGemgGemgGemgGemgGemgGemgIemgIemgIemgIemgIemgIemgIemgIemgGemgGemgGemgH
f=kHf=kIfMoIfMoIfMoHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgG
emgIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWEfM[GfM[GfM[If=[If=[Kf=[Kf=[Mf=[If=[If=[If=[I
f=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWJf][Jf][Jf][Jf][Jf][Jf][Jf][J
f][HemWHemWHemWHemWHemWHemWHemWHemWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSHfMOHfMOHfMOHfMOHfMOHfMOHfMOHfMOKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSJf=OIemKIemKIemKIemKJf=OKfMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKI
emKHe]GHe]GHe]GHe]GIemKIemKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIemKIemKIemKI
emKIemKIemKIemKIemKIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGIf=CIf=CIf=CI
f=CIf=CIf=CIf=CIf=CJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGIf=CIf=CIf=CIf=CIf=CIf=CIf=CI
f=CJfm;Jfm;Jf]CJf]CJfMGJfMGJf=OJf=OJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGJfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;J
fm;Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];If]7If]7If]7Jfm;Jfm;Jfm;Kg=?Kg=?Mf];Mf];Mf];M
f];Mf];Mf];Mf];Mf];Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Kf=3LfM7LfM7Mf];Nfm?Og=CPgMGP
gMGOg=COg=COg=COg=COg=COg=COg=COg=CNfm?Og=COg=CPgMGPgMGOg=COg=CNfm?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;N
g=;Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Ng=;Mfm7Lf]3Lf]3Lf]3Lf]3Mfm7Ng=;Ng=;Ng=;Ng=;N
g=;Ng=;Ng=;Ng=;Ng=;Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7M
fm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm400<_9cn3Ni=;@e]OEfl_9cm;@e][Hg]KDf/O8c9JGVmOGgMSHg];A
f]?Bg=KEgm?Bg=kOhmGFf/W:c][Kgh:3Qh21QFY[KfAUJFAWIFIXJ6i`L6EWJ=3@e]WHhN;Qj]CCgN?R
jm7@fM7@fMGDgMOFgn3Oj<[9dYNFWg=dN7]lP6AUJGYkOfY[Kh21QJZ[[mGFf];Af]WHhM[Ih]SGh=[I
h]OFgiJEW/W8dMKEg]7@fLo>elo>en7PjL_:dmGDgL2ob=GFh=_Li]cMilo@f]?Dg]WJi=3AfmWJi=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=KEgmKEgmKEgmOFh=OF
h=OFh=SGhMSGhMOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGDgMGDgMGDgMGDgMKEg]KEg]OFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOF
gmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWG
gMWGgMWGgMWGgMWGgMWGgMWGgMWGgMOGgMOGgMOGgMSHg]SHg]WIgmWIgmWIgmSHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][H
g][Hg][Hg][Hg][Hg][Hg][Hg][Hg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMGI
f]OIf]OIf]WHf]WHf]_Hf]_Hf]gHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfM[Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf]SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfM_I
fM_IfM_IfM_IfM_IfM_IfM_IfM_IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
em[Hem[Hem[Hem[Hem[Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=SIemSIemSIemSIemSI
emSIemSIemSIem_If=_If=_If=_If=_If=_If=_If=_If=_If=[HemWGe]WGe]WGe]WGe][Hem_If=[H
em[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemWGe]WGe]WGe]WGe]WG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]SFeMSFeMSFeMSFeMWGe]WGe][Hem[Hem[H
em[Hem[Hem[Hem[Hem[Hem[Hem[HemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WHe=WHe=WHe=WHe=WH
e=WHe=WHe=WHe=[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeMWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeMWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeMWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=[Kd][Kd][Je=[Je=[IeM[IeM[Hem[Hem[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[Kd][Kd][Kd][Kd][K
d][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]WJ
dMWJdMWJdM[Kd][Kd][Kd]_Ldm_LdmgJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]kKdmkKdmkKdmkKdmkK
dmkKdmkKdmkKdm_Hd=cIdMcIdMgJd]kKdmoLe>3MeN7Ne]oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=kK
dmoLe=oLe>3MeN3MeMoLe=oLe=kKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkK
dmkKdmkKdmkKdmkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMkL
d]gKdMcJd=cJd=cJd=cJd=gKdMkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]gKdMgKdMgKdMgKdMgK
dMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKd@00a/G7c<_=
hN3Re=?Ee]GGf=OIg=_MalK8b<W=<30fgMgSb/WBh^7[dM3JgM_Wd]3Le]CJemGKfm[N];>gJ6MYN7Qh
LG5aHV9RKW1`PH>3MWQhDE=DdM;FalS<hN7We]KLdM3Ifm[Sj^[``l?9hN;Vc/oCalW:LgEfLg=cI6AT
Jf][IFEUKfm_J6QXVYZJb/[:gMcUd<oHh=oXdM3If]WRbl[C=C@mcLcEHVAU_l72e]OKbL[>e=CJcloE
g]gV`l;;emKPemKPemKPemKPemKPemKPemKPemKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPemKOemKOemKOemKOemKOemKO
emKOemKOe]GNe]GNe]GNemKOemKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKOe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLeMGKeMGKeMGKe]KLe]KLe]KLemOMemOMf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIemOMemOM
f=SNf=SNf=SNfMWOfMWOfMWOfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMg=[Pg=[PfmWOf]SNf]SNfMOM
fMOMf=KLfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMOMfMOM
fMOMfMOMfMOMfMOMfMOMfMOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf]WKf]WKf]WKf]WKf]WKf]WK
f]WKf]WKfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=SHf=SHf=SHfMWIfMWIfMWI
f][Jf][JfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJ
fmSJfmSJfmSJfmSJfmSJfmSJg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[JfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfmWIfmWIg=[Jg=[Jg=[JgM_KgM_KgM_Kg=[Jg=[J
g=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[J
g=[Jg=[Jf]SHf]SHf]SHfmWIfmWIfmWIg=[Jg=[Jf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMOFfMOFfMOFf]SGf]SGf]SGfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMSDfMSDfMSDfMSDfMSDfMSD
fMSDfMSDfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[FfMSDfMSD
fMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf=OCf=OCf=OCf=OCfMSDfMSD
f]WEf]WEfmKCfmKCfmKCfmKCg=ODg=ODgMSEgMSEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODgM[BgM[BgM[BgM[BgM[BgM[B
gM[BgM[Bg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AgM[BgM[B
gM[BgM[BgM[BgM[BgM[BgM[Bg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAgM[BgM[BgM[B
g]_Cg]_CgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BfmS@fmS@
fmS@fmS@g=WAg=WAgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[Bg=WAg=WAg=WAgM[BgM[BgM[B
g]_Cg]_CgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM[BgM[B
gM[BgM[BgM[BgM[BgM[BgM[BgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_Ag=[@g=[@g=[@gM_AgM_AgM_A
g]cBg]cBgmgCgmgCgmgCgmgCgmgCgmgCgmgCgmgCg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cB
g]cBg]cBg]cBg]cBg]cBg]cBgm[Agm[Agm[Ah=_Bh=_Bh=_BhMcChMcCh=_Bh=_Bh=_Bh=_Bh=_Bh=_B
h=_Bh=_Bh=_Bh=_Bh=_Bh=_Bh=_Bh=_Bh=_Bh=_Bgm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[A
gm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[A
gm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[A003Cd]B8QhW3`/CAd=;Wi^Rm_;kIf=[Yj>[JfmnFUi_9bLoC
d]_:bM;NgNO9b=;Pg^[;bLnj^;j[ZZj3PXIXIfUiNGUlO7b5QHG8b/Zj_;bPXZ:?TI:UYZZg^;cMgN?=
cM?BdM[8am2m_L?Xj>kQh^KBdmMoPH9JG5f;Rh]lO7bDU9B`/;2[Zj]CDe=ZJV[<c<cFeMkIf>7@cmS6
aLk]k?GBdMZAT9WKf^=LGUo<c/lH6Af^[k>`/;K>c]AZJG;Og^OGe^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3G
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oGe]oHen3H
en3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oHen3Hen3Hen3Hen3Hen3Hen3Hen3H
en3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cEeM_EeM_EeM_Fe]cFe]cFe]cGemgG
emgHemWHemWHemWHemWHemWHemWHemWHemWGemgGemgGemgHf=kHf=kHf=kIfMoIfMoIemgIemgIemgI
emgIemgIemgIemgIemgKfMoKfMoKfMoJf=kJf=kIemgIemgHe]cIf=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[IemgIemgIemgIemgIemgIemgIemgIemgIf=[If=[If=[I
f=[If=[If=[If=[If=[JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[Hf=SHf=SHf=SIfMWIfMWIfMWJf][Jf][IfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWKf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Lf][Lf][Lf][L
f][Lf][Lf][Lf][Lf][KfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWKfMWKfMWKfMWLf][Lf][Lf][Mfm_Mfm_Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][L
f][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Jf=SJf=SJf=SKfMWKfMWKfMWLf][L
f][Jf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJ
f=OIemKIemKIemKIemKJf=OJf=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CKf]KKf]KKf]KKf]KKf]KKf]KKf]KK
f]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CI
f=CIf=CIf=CIf=CIf=CHem?Hem?Hem?Hem?If=CIf=CJfMGJfMGKe]?Ke]?Ke]?Ke]?LemCLemCMf=GM
f=GIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGLemCLemCLemCL
emCLemCLemCLemCLemCMf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];LfM7LfM7LfM7LfM7LfM7LfM7LfM7L
fM7If]7If]7If]7If]7If]7If]7If]7If]7Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];LfM7LfM7LfM7L
fM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7Mf];Mf];Nfm?Nfm?Mf];Mf];Mf];Mf];Mf];Mf];Mf];M
f];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Kf=3Kf=3Kf=3Kf=3LfM7LfM7Mf];Mf];Mf];Mf];Mf];M
f];Mf];Mf];Mf];Mf];LfM7LfM7LfM7Mf];Mf];Mf];Nfm?Nfm?Mf];Mf];Mf];Mf];Mf];Mf];Mf];M
f];Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mfm7Mfm7Mfm7M
fm7Mfm7Mfm7Mfm7Mfm7Lf]3Lf]3Lf]3Mfm7Mfm7Mfm7Ng=;Ng=;OgM?OgM?OgM?OgM?OgM?OgM?OgM?O
gM?Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Of]7Of]7Of]7P
fm;Pfm;Pfm;Qg=?Qg=?Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;P
fm;Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7O
f]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]400=CC
eFASIL[9be5@D^?Ri>;Qhg]jO0000GamPNk_le1AEMcLh^SWl=?BfmGDg]cKiN;Pi/o=dkbk_i>BUWIe
Mg1`L6EUIG9bL/g?cogooloAdHN9RZJWZlk?dn;Rj=GEfn[Yl]SGh=WIgknoaIfNXWAeNEmQHZ2RXiZJ
VXj>SY2@T;:b/]gMgI6ATHZ:R^3Ph<71ao7amlg=dn;Rj=;Bf451AnKVk7MgOKBf]hV;S0T:3/g>dV1P
I/k>e4m>EnCSk=OFh=OFh=OFh=OFh=OFh=OFh=OFh=OFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOFgmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmSGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKF
g=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=GEfmGEfmGEfmKFg=KFg=KFg=OGgMOGgMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMOG
gMOGgMOGgMOGgMSHg]SHg]SHg]WIgmWGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgM_Igm[Hg][Hg][Hg]WG
gMWGgMWGgMWGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WG
gMWGgMWGgMWGgMWGgMWGgMWGgMWGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf][Ifm[Ifm[Ifm[Ifm[I
fm[Ifm[Ifm[IfmWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SHf=SHf=SHf=WIfMWI
fMWIfM[Jf][Jf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_H
f]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf][Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=_IfM_IfM_IfM_IfMcJf]cJf]cJf]gKfmcJ
f]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJ
f]cJf]cJf]cJf][Hf=[Hf=[Hf=_IfM_IfM_IfMcJf]cJf][Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGe]WGe]WGe]WGe]WG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]SFeMSFeMWGe]WGe][Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemWHe=WHe=WHe=WHe=WH
e=WHe=WHe=WHe=[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeMWH
e=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=SGdmSGdmSGdmSGdmWH
e=WHe=[IeM[IeM_Fdm_Fdm_Fdm_FdmcGe=cGe=gHeMgHeMWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WH
e=WHe=WHe=WHe=WHe=WHe=WHe=WHe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cIdMcIdMcIdMcIdMcI
dMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMcI
dMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdM_Hd=_Hd=cIdMcIdMgJ
d]gJd]gJd]gJd]cIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdM_H
d=_Hd=_Hd=_Hd=cIdMcIdMgJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]cIdMcIdMcIdMgJd]gJ
d]gJd]kKdmkKdmgJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgJ
d]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMcJd=cJd=cJd=gKdMgK
dMgKdMkLd]kLd]oMdmoMdmoMdmoMdmoMdmoMdmoMdmoMdmkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kL
d]kLd]kLd]kLd]kLd]kLd]kLd]kLd]oJdMoJdMoJdN3Kd^3Kd^3Kd^7Ldn7Ldn3Kd^3Kd^3Kd^3Kd^3K
d^3Kd^3Kd^3Kd]oJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJ
dMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMkId=kId=kId=kId=kI
d=kId=kId=kId=kId=kId=kId=kId=kId=kId000a/G7ZJRZViZLTi:D0`840001PX63hn;Tf]cMeMOH
W9fQ_l34d];Hd]7Ji>?/d<oIe]CJeM?IfMSLa/G9PH22SHf=PX:2Q8B4]KNgm_ShemWIP8:3d]?GemSL
h^;Xc/kDc<_Dbl[Cj>S^cloEfmcP^;VmK6i_Ngen_;blZ:RXRHV9VYZJg=cLUIFEKfm_ZZZZ_ko5cloE
c<cBdM7Gfm_Q^KVoemOMZ:R^8R@U0001NW]o]KJjX:2VU9BJXj:[emKOemKPemKPemKPemKPemKPemKP
emKPemKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=GOe=GO
e=GOe=GOe=GOe=GOe=GOe=GOemKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNemKOemKOemKO
f=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLeMGKeMGKeMGKe]KLe]KLe]KL
emOMemOMf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIe]KLe]KLemOMemOMemOMf=SNf=SNf=SNfMOMfMOM
fMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJf=SHf=SHf=SHfMWIfMWIfMWIf][Jf][JfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf]SHf]SHfmWIfmWIfmWIg=[Jg=[Jg=[JfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHfmWIfmWIfmWI
g=[Jg=[Jf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOF
fMOFfMOFf=KEf=KEf=KEfMOFfMOFfMOFf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf]WEf]WEf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSD
fMSDfMSDfMSDfMSDfMSDfMSDf=OCf=OCf=OCf=OCfMSDfMSDf]WEf]WEfmKCfmKCfmKCfmKCg=ODg=OD
gMSEgMSEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDg=ODg=OD
g=ODg=ODg=ODg=ODg=ODg=ODg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WA
g=WAg=WAfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[Ag=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WA
g=WAg=WAg=WAg=WAg=WAg=WAfmS@fmS@fmS@g=WAg=WAg=WAgM[BgM[Bg=WAg=WAg=WAg=WAg=WAg=WA
g=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAfmS@fmS@fmS@fmS@g=WAg=WAgM[BgM[BgM[BgM[B
gM[BgM[BgM[BgM[BgM[BgM[Bg=WAg=WAg=WAgM[BgM[BgM[Bg]_Cg]_CgM[BgM[BgM[BgM[BgM[BgM[B
gM[BgM[BgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM_AgM_A
gM_AgM_AgM_AgM_AgM_AgM_Ag=[@g=[@g=[@gM_AgM_AgM_Ag]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cB
g]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgm[Agm[A
gm[Ah=_Bh=_Bh=_BhMcChMcCh=_Bh=_Bh=_Bh=_Bh=_Bh=_Bh=_Bh=_Bgm[Agm[Agm[Agm[Agm[Agm[A
gm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[A
gm[Agm[Agm[Agm[Agm[Agm[Ag]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@
003If=[6aLMFEEOFeML0007Cd]CQh>;:bL^/[ZjYZjcYjnacM7SPh>KAdMOGe]oGe]oCdMOAcmGIf=cJ
fMe`Kg6ZZZZQXJ64Q8AjO7a[KFemOgnEUiSDeMW3a<SOgnG>c]C:bM;PgnSIfMoNg^C1`/KLgN5nP86M
Wj2MWIfEUIFKVi_7alOfm_JIVIV3Ph?Jf][Mg^;<cM7Qh^KHfMeVIf_JfmmkO83Ngn?Ph^>f^;VGV9`@
4AG6a/aHF5kThnc>cMKGe^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3DeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oGe]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cEeM_EeM_EeM_Fe]cFe]cFe]cGemgGemgHemWHemWHemWHemWHemWHemWHemWH
emWFe]cFe]cFe]cFe]cGemgGemgHf=kHf=kIemgIemgIemgIemgIemgIemgIemgIemgHe]cHe]cHe]cI
emgIemgIemgIemgIemgIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[IemgIemgIemgIemgIemgIemgIemgIemgIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[Hf=SHf=SHf=SI
fMWIfMWIfMWJf][Jf][IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWKf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[K
f=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[KfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SJf=SJf=SJf=SJf=SKfMWKfMWLf][L
f][KfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SKfMWKfMWKfMWLf][Lf][Jf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SHe]GHe]GHe]GH
e]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GGeMCGeMCHe]GHe]GIemKIemKIemKI
emKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIf=CIf=CIf=CI
f=CIf=CIf=CIf=CIf=CJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CHem?Hem?Hem?H
em?If=CIf=CJfMGJfMGKe]?Ke]?Ke]?Ke]?LemCLemCMf=GMf=GIf=CIf=CIf=CIf=CIf=CIf=CIf=CI
f=CHem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?LemCLemCLemCLemCLemCLemCLemCLemCKf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7If]7If]7If]7If]7If]7If]7If]7I
f]7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7JeloJeloKf=3K
f=3LfM7LfM7LfM7LfM7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3LfM7LfM7Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];LfM7LfM7LfM7M
f];Mf];Mf];Nfm?Nfm?Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7M
fm7Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Lf]3Lf]3Lf]3M
fm7Mfm7Mfm7Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;N
g=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Of]7Of]7Of]7Pfm;Pfm;Pfm;Qg=?Qg=?Pfm;Pfm;Pfm;P
fm;Pfm;Pfm;Pfm;Pfm;Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7O
f]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Mf<oMf<oMf<oM
f<oMf<oMf<oMf<oMf<oMf<oMf<oMf<oMf<oMf<oMf<l00=3?dOGdmW]jO:FTY[2_/Hb;SKZi^dA3ADE7
Ak>e]M7Ce:BVYkbm`MkNi=;Bf=OGgNCRj=WGgM[IgM[IgGUhN[:b/Xj>STi>CTU;BfAVIUmQHIjPXLc=
dMSIgLk>e=cLh^7PjLk=e/W9cmWIgn3QiLO8c5iPHDQ:Bf][Jf][Jh:2PYRHV:NWYfYZJWQhN;jn_]CE
fLg>d]SIgLc=dJn`]<S9c@000aLH77j0PKJh^M3AeLc=dJ6QYj2PY]WHhM;Af]OFh=OFh=OFh=OFh=OF
h=OFh=OFh=OFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=?D
g]?Dg]?Dg]?Dg]?Dg]?Dg]?Dg]?Dg]OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOF
gmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]KEg]KE
g]KEg]KEg]KEg]OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=GEfmGEfmGEfmKFg=KF
g=KFg=OGgMOGgMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMGEfmGEfmKFg=KFg=KFg=OGgMOGgMOGgMWG
gMWGgMWGgMWGgMWGgMWGgMWGgMWGgMOEfmOEfmSFg=SFg=SFg=WGgMWGgMWGgMWHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMWH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SHf=SHf=SHf=WIfMWIfMWIfM[Jf][Jf]WIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfM_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf][H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWGemWGemWGemWGemOGemOGemOGemOGemOG
emOGemOGemOGemWGemWGem[Hf=[Hf=[Hf=_IfM_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=_IfM_I
fM_IfMcJf]cJf][Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGemWGemSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSF
eMSFeMSFeMSFeMOEe=OEe=OEe=SFeMSFeMWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe][H
em[Hem[Hem[Hem[Hem[Hem[Hem[HemWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WH
e=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WH
e=WHe=WHe=WHe=WHe=WHe=WHe=WHe=SGdmSGdmSGdmSGdmWHe=WHe=[IeM[IeM_Fdm_Fdm_Fdm_FdmcG
e=cGe=gHeMgHeMWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=SGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmcG
e=cGe=cGe=cGe=cGe=cGe=cGe=cGe=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=cIdMcIdMcIdMcIdMcI
dMcIdMcIdMcIdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=cI
dMcIdMcIdMcIdMcIdMcIdMcIdMcIdM[Gcm[Gcm[Gcm_Hd=_Hd=cIdMcIdMcIdM_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=cIdMcIdMgJd]gJd]gJ
d]gJd]gJd]gJd]gJd]gJd]gJd]gJd]cIdMcIdMcIdMgJd]gJd]gJd]kKdmkKdmgJd]gJd]gJd]gJd]gJ
d]gJd]gJd]gJd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gK
dMgKdMgKdMgKdMgKdMgKdMgKdMgKdMcJd=cJd=cJd=gKdMgKdMgKdMkLd]kLd]gKdMgKdMgKdMgKdMgK
dMgKdMgKdMgKdMkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]oJ
dMoJdMoJdN3Kd^3Kd^3Kd^7Ldn7Ldn3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd]kId=kId=kId=kId=kI
d=kId=kId=kId=oJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJ
dMoJdMoJdMoJdMoJdMoJdMoJdMoJdMgHcmgHcmgHcmgHcmgHcmgHcmgHcmgHcmgHcmgHcmgHcmgHcmgH
cmgHc`00e=?Ec/g?gMcN;B`^gMcNIVEWOgj0Cdi@_l;0`lG5d=;BoOooJVa]b<W=emOMd];He=;Hd]3F
fMSLbl[>/K2bb/[:YZJVNWYjJF][e=KF_/30_;jog=gQj>W]a<C:e]KLdM3Ic<_Dlo?idm?Icm3DO7f1
MGMhKg5bKVi^EEEEIfMWL71`N7QhMWIf/[:bg]kNalW:h>;Sd=;CM7Igf=[Ka<K76Q`MEeUJEeUJATQ9
TI:Fgn3T9BD[d];He=?LgmkWemKPemKPemKPemKPemKPemKPemKPemKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPdmCNdmCNdmCNdmCNdmCNdmCNdmCNdmCNemKOemKO
emKOemKOemKOemKOemKOemKOe]GNe]GNe]GNemKOemKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNemKOemKOemKOemKOemKOemKO
emKOemKOe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLeMGKeMGKeMGKe]KLe]KLe]KLemOMemOMf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIeMGKeMGKeMGKe]KLe]KLe]KLemOMemOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMe]CJemGK
emGKf=KLf=KLfMOMfMOMfMOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=SHf=SH
f=SHfMWIfMWIfMWIf][Jf][JfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfmSJfmSJfmSJfmSJfmSJfmSJ
fmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGemOGemOGemOGemOGemOGemOGemOGemOGfMOGfMOGfMOGf]SHf]SHf]SH
fmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfmWIfmWIfmWIg=[Jg=[Jf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGf=KEf=KE
f=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEemGDemGDemGDemGDf=KEf=KE
f=KEfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMSDfMSD
fMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSD
fMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf=OCf=OC
f=OCf=OCfMSDfMSDf]WEf]WEfmKCfmKCfmKCfmKCg=ODg=ODgMSEgMSEfMSDfMSDfMSDfMSDfMSDfMSD
fMSDfMSDf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODfmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@g=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAfM[AfM[AfM[AfM[AfM[AfM[A
fM[AfM[AfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@g=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAf]O?f]O?
f]O?f]O?fmS@fmS@fmS@g=WAfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@g=WAg=WAgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[Bg=WAg=WA
g=WAgM[BgM[BgM[Bg]_Cg]_CgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM_AgM_AgM_AgM_AgM_AgM_A
gM_AgM_AgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_Ag=[@g=[@
g=[@gM_AgM_AgM_Ag]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_Ag]cBg]cBg]cBg]cBg]cBg]cB
g]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgm[Agm[Agm[Ah=_Bh=_Bh=_BhMcChMcCh=_Bh=_B
h=_Bh=_Bh=_Bh=_Bh=_Bh=_Bg]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@gm[Agm[Agm[Agm[Agm[Agm[A
gm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[AgMS?gMS?
gMS?gMS?gMS?gMS?gMS?gMS?gMS?gMS?gMS?gMS?gMS?gMS?003Cd]C=c<kWi^RDTiFGUYSLfmgBdM>i
^;YmP7k:cL]=Cdnd][KCeMIMGV;@dMGMgN?Fe=[Ng>;RhNFf]KWIf=[Hf=SCdm?Lg=a]Kfni^k_UinOF
f=WFem_5a/[Kfn7CdmWFeMkCd]_;bm7>c]C7b<c6al_EemS<c/o:b/YfMWJ2PX:HV9QfMWI?CdnHV9SH
f=SNh>70`/=WJF[?dM:EUiRNX:6m_l00007@d]?2a<GHfMfWZ:bQXJO9bLoLfnCCd]_Ge^3Ge^3Ge^3G
e^3Ge^3Ge^3Ge^3Ge^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ce=kCe=kCe=kCe=kCe=kCe=kCe=kCe=kGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkG
e]oGe]oGe]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkF
eMkFeMkFeMkFeMkFeMkGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cEeM_EeM_EeM_F
e]cFe]cFe]cGemgGemgHemWHemWHemWHemWHemWHemWHemWHemWEeM_EeM_EeM_EeM_Fe]cFe]cGemgG
emgIemgIemgIemgIemgIemgIemgIemgIemgFe=[Fe=[GeM_GeM_He]cIemgIemgIemgIf=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[IemgIemgIemgIemgIemgIemgIemgI
emgIf=[If=[If=[If=[If=[If=[If=[If=[HemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[Hf=SHf=SHf=SIfMWIfMWIfMWJf][Jf][IfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWKf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[K
f=[Jf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SIemOIemOIemOIemOIemOIemOIemOIemOGemOGemOGemOG
emOGemOGemOGemOGemOIemOIemOIemOIemOJf=SJf=SKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SK
fMWKfMWKfMWLf][Lf][Jf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SIemOIemOIemOIemOIemOIemOIemOI
emOIemOIemOIemOIemOIemOIemOIemOIemOGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCG
eMCGeMCGeMCGeMCGeMCFe=?GeMCGeMCGeMCHe]GHe]GHe]GHe]GIemKIemKIemKIemKIemKIemKIemKI
emKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CI
f=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CI
f=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CHem?Hem?Hem?Hem?If=CIf=CJfMGJfMGKe]?Ke]?Ke]?K
e]?LemCLemCMf=GMf=GIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CGe];Ge];Ge];Ge];Ge];Ge];Ge];G
e];LemCLemCLemCLemCLemCLemCLemCLemCJeloJeloJeloJeloJeloJeloJeloJeloLfM7LfM7LfM7L
fM7LfM7LfM7LfM7LfM7If]7If]7If]7If]7If]7If]7If]7If]7JeloJeloJeloJeloJeloJeloJeloJ
eloLfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7Ie/kJeloJeloJeloKf=3Kf=3Kf=3Kf=3JeloJeloJeloJ
eloJeloJeloJeloJeloJeloJeloJeloJeloJeloJeloJeloJeloKf=3Kf=3Kf=3Kf=3LfM7LfM7Mf];M
f];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];LfM7LfM7LfM7Mf];Mf];Mf];Nfm?Nfm?Mf];Mf];Mf];M
f];Mf];Mf];Mf];Mf];Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mf];Mf];Mf];Mf];Mf];Mf];Mf];M
f];Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Lf]3Lf]3Lf]3Mfm7Mfm7Mfm7Ng=;Ng=;Mfm7Mfm7Mfm7M
fm7Mfm7Mfm7Mfm7Mfm7Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;N
g=;Of]7Of]7Of]7Pfm;Pfm;Pfm;Qg=?Qg=?Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;NfM3NfM3NfM3N
fM3NfM3NfM3NfM3NfM3Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7O
f]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7LelkLelkLelkLelkLelkLelkLelkLelkLelkLelkLelkL
elkLelkLelh00=C@e]oKhM7=dmWEf`801>?OiM??eM7=d`000@000Jf/[/S7bIJEUk:a/`400^3OhM;B
f>3Pi]7Aem_KhMOGgM?CfM_KhLg=dkNg_MKFg<_;dMCDf]7AemgMhlc<d^3Pi/k>e=SHg/k>e=7AemOG
gLg=dm7AemSHg]kNi5mOIMOGgN7QilS8c]kNi92@U]CDf]cNg`010[Jh^MGGf>7Si:FWZ5aNGa8D5F1P
I]KFg=[Jh0@42/K6c>WYkmGEflW9cm?EgM?EgM?EgMCFg]CFg]CFg]GGgmGGgmKEg]KEg]KEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]KEg]KEg]SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SF
g=SFg=SFg=SFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=SF
g=SFg=SFg=SFg=SFg=SFg=SFg=SFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SF
g=SFg=SFg=SFg=SFg=SFg=SFg=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OGemOGemOGemSHf=SHf=SHf=WIfMWIfM[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfMWG
emWGemWGem[Hf=[Hf=[Hf=_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WG
emWGemWGemWGemWGemWGemWGemWGem[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemcGe=cGe=cGe=cGe=cG
e=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cG
e=cGe=cGe=cGe=cGe=cGe=cGe=cGe=_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_FdmSGdmSGdmSGdmWHe=WH
e=WHe=[IeM[IeMcGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=cIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMgJ
d]gJd]gJd]cIdM_Hd=_Hd=[Gcm[GcmgJd]gJd]gJd]cIdM_Hd=_Hd=[Gcm[GcmcIdMcIdMcIdMcIdMcI
dMcIdMcIdMcIdMWFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdMWFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdM_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdMWF
c][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=cIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=cJ
d=cJd=cJd=cJd=cJd=cJd=cJd=cJd=cJd=cJd=cJd=cJd=cJd=cJd=cJd=cJd=_Icm_Icm_Icm_Icm_I
cm_Icm_Icm_IcmcJd=cJd=cJd=cJd=cJd=cJd=cJd=cJd=_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_I
cm_Icm_Icm_Icm_Icm_Icm_Icm_IcmWGcM[Hc][Hc][Hc]_Icm_Icm_IcmcJd=gIc]gIc]gIc]gIc]gI
c]gIc]gIc]gIc]_Ic]_Ic]_Ic]_Ic]cJcmcJcmgKd=gKd=kId=kId=kId=kId=kId=kId=kId=kId=kJ
cmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmoKd=oKd=oKd=oKd=oK
d=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd>3L
dN3LdN3LdN3LdN3LdN3LdN3LdN3LdN7Kd>7Kd>7Kd>7Kd>7Kd>7Kd>7Kd>7Kd=kJcmkJcmkJcmkJcmkJ
cmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3JcmgI
c]gIc]gIc]gIc]gIc]gIc]gIc]gIc]kJcmkJcmkJcmkJcmkJcmkJc`00gMWOblO=d/kDf=CJZZJ/QH67
VYJL?SY0Xj:TgMcN];>eKfi`b/W;e=?Ea<?50001d=3F`/;8gMgSemOMd=3Fg=cRcloEgmoUalO=gmoU
d];HemOMd];Hf][Pb<S>e]KLeMGKgMgSdM7GdM7Gh>3Vh>3Vf=SNcloEdM7GalO=c/kDbLW?l?3fd=3F
`L77/;2f0001`/C5d]CE<S@e6Q`MeMOHb/c=/K>d;Rhdc/kDQXJ<][JleMGKcLgCgmoUh^;XdmGMdmGM
dmGMe=KNe=KNe=KNeMOOeMOOe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNf=KLf=KL
f=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLemGKemGK
emGKemGKemGKemGKemGKemGKf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJemKHemKHemKHemKHemKHemKHemKHemKHemOGemOG
emOGf=SHf=SHf=SHfMWIfMWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfMOGfMOGfMOGf]SHf]SHf]SHfmWIfmWIf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=OD
g=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODf]GBf]GB
f]GBf]GBf]GBf]GBf]GBf]GBemKBf=OCf=OCf=OCfMSDfMSDfMSDf]WEg=ODg=ODg=ODg=ODg=ODg=OD
g=ODg=ODg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAgM[BgM[Bg=WAg=WAfmS@fmS@f]O?f]O?gM[BgM[B
g=WAg=WAfmS@fmS@f]O?f]O?g=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAfMK>f]O?f]O?f]O?fmS@fmS@
fmS@g=WAfMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fMK>fMK>fMK>fMK>fMK>fMK>
fMK>fMK>fMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@g=WAg=WAg=WAg=WAg=WAg=WA
g=WAg=WAfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@
g=[@g=[@g=[@g=[@g=[@g=[@fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?g=[@g=[@g=[@g=[@g=[@g=[@
g=[@g=[@fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fMO=f]S>
f]S>f]S>fmW?fmW?fmW?g=[@gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>fmW>fmW>fmW>fmW>g=[?g=[?
gM_@gM_@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?
g][?g][?g][?g][?g][?g][?gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@
gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@h=cAh=cAh=cAh=cAh=cAh=cAh=cAh=cAhM_@hM_@
hM_@hM_@hM_@hM_@hM_@hM_@g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?
g][?g][?h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>g][?g][?
g][?g][?g][?g][?003Bc]CKemgKemgMfMoKemeaKG?4`<K4`<K<blf/ZjeEE5JCTYCMg=k;b/cJfM_T
hnE`L7KFe]cLg>:m_L?MgN?OgnG@d=KBd]S@d=KLg>;=cM?<c=;<c=;Hf=kAdMOLg>;EeM_Lg>;Bd]S7
algCdmWLg>;Fe]cBd]SShnWHf=kJf^3Kfn75aL_AdMOJf^0G5ag3aLJm_l25QhSNh>6SYJH[;Bk7bL[=
cm3Bd]Rn_/AmOH?;bm7Hf=kGemg=cM?>c]CCeMgCeMgCeMgDe]kDe]kDe]kEemoEemoFeMkFeMkFeMkF
eMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkF
eMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cH
e]cHe]cHe]cHe]cHe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cH
e]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_HemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[HemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGemOGemOGemOHf=SHf=SHf=SIfMWIfMWJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SIemOIemOIemOJf=SJf=SJf=SKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOI
emOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemKIemKIemKI
emKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKI
emKIemOIemOIemOIemOIemOIemOIemOIemOIemKIemKIemKIemKIemKIemKIemKIemKKe]?Ke]?Ke]?K
e]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?K
e]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;Ge];Ge];Hem?H
em?Hem?If=CIf=CIf=CKe]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3LfM7LfM7LfM7Kf=3Kf=3Kf=3JeloJeloLfM7LfM7LfM7Kf=3Kf=3Kf=3JeloJeloKf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Ie/kJeloJeloJeloKf=3Kf=3Kf=3LfM7Ie/kJeloJeloJeloKf=3Kf=3Kf=3L
fM7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Ie/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kJeloJeloJeloKf=3Kf=3Kf=3L
fM7Ie/kJeloJeloJeloKf=3Kf=3Kf=3LfM7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3KfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoK
fLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoK
fLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoIelgJf<kJf<kJf<kKfLoKfLoKfLoLf]3MfLkMfLkMfLkM
fLkMfLkMfLkMfLkMfLkKfLkKfLkKfLkKfLkLf/oLf/oMfm3Mfm3NfM3NfM3NfM3NfM3NfM3NfM3NfM3N
fM3Nf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oOfm3Ofm3Ofm3O
fm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3O
fm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Qfm3Qfm3Qfm3Qfm3Qfm3Qfm3Qfm3Qfm3Nf/oNf/oNf/oN
f/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oOfLkOfLkOfLkOfLkOfLkOfLkOfLkO
fLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLh00=[Fg=C@e]GAemGAem3<
d/g9cl>oaMcHg[Je]emNH=cKgC<b=450@U]JG8J5QmOFf<g=dgalP]cLh]oOiMKFg>GUjl;2b>?SjL_;
dMGEfmKFg=_KhMgMhn7QimKFg=7AelO7cMCDf^7QimgMhmkNi=[Jh<g=dmSHg/g=dknoaNKVk<o?eMoO
iMGEfg1`M]SHg]3Bdkfo`0000Fa^Km;DeJ2RXcXl?K^m_]oOiJ6QYmKFg<O7cMWIgmoOiLW9cmKFg=?E
gM?EgM?EgMCFg]CFg]CFg]GGgmGGgmKEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]SF
g=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=KF
g=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=OE
fmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OG
emOGemOGemSHf=SHf=SHf=WIfMWIfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGem[Hf=[Hf=[Hf=_IfM_IfM[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGemWGemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_F
dm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm[E
d][Ed][Ed][Ed][Ed][Ed][Ed][Ed]OFd]OFd]OFd]SGdmSGdmSGdmWHe=WHe=_Fdm_Fdm_Fdm_Fdm_F
dm_Fdm_Fdm_Fdm_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=[Gcm[Gcm_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=[Gcm[Gcm_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=WFc][Gcm[Gcm[Gcm_H
d=_Hd=_Hd=cIdMWFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=WFc]WFc]WFc]WFc]WF
c]WFc]WFc]WFc]WFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdMWFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdM_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_I
cm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_I
cm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_IcmWG
cM[Hc][Hc][Hc]_Icm_Icm_IcmcJd=gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]_Ic]_Ic]_Ic]_Ic]cJ
cmcJcmgKd=gKd=kId=kId=kId=kId=kId=kId=kId=kId=kJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJ
cmkJcmkJcmkJcmkJcmkJcmkJcmkJcmoKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oK
d=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd>7K
d>7Kd>7Kd>7Kd>7Kd>7Kd>7Kd>7Kd=kJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJ
cmkJcmkJcmkJcmoIc]oIc]oIc]oIc]oIc]oIc]oIc]oIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gI
c]gIc]gIc]gIc]gIc]gIcP00hMgS_k_1i>3VblO=fMGKkNW_/JfcSh^Af]WK:bX/[Zf_=cHhYjJXdm;D
fMSJH5mQc<cB`L77`/;8/;2fb/[@b/[@e=CJ`/;8g=cRe]KLdm?Ib/[@b/[@c/kDe=CJcLgCf][Pc/kD
dm?Ibl_Ad=3FdM7GalO=inO]emOMg]kTe=CJgMgSSHfCN7QnfMWOP826ATQ9bL_<F5YKDeEFNWamg^3Q
^kfnj>[[RXZ@b/[@d];Hi^K/cLgCe=CJgmoUf][PdmGMdmGMdmGMe=KNe=KNe=KNeMOOeMOOe]GNe]GN
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KL
f=KLf=KLf=KLf=KLf=KLf=KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLf=KLf=KLf=KLf=KLf=KLf=KL
f=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLemGKemGKemGKemGKemGKemGKemGKemGKf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIemKHemKHemKHemKHemKHemKHemKHemKHemOGemOGemOGf=SHf=SHf=SHfMWIfMWIf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHfMOGfMOGfMOGf]SHf]SHf]SHfmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KF
f=KFf=KFfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KEf=KE
f=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KE
f=KEf=KEf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf]GBf]GB
f]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GB
f]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAe]GAe]GA
emKBemKBemKBf=OCf=OCf=OCf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]O?f]O?f]O?f]O?f]O?f]O?
f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?fmS@fmS@f]O?f]O?f]O?f]O?f]O?f]O?fmS@fmS@f]O?f]O?
f]O?f]O?f]O?f]O?f]O?f]O?fMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfMK>f]O?f]O?f]O?fmS@fmS@
fmS@g=WAfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>f]O?f]O?f]O?fmS@fmS@
fmS@g=WAfMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@f]S>f]S>f]S>f]S>f]S>f]S>f]S>f]S>f]S>f]S>f]S>f]S>f]S>f]S>f]S>f]S>fmW?fmW?
fmW?fmW?fmW?fmW?fmW?fmW?f]S>f]S>f]S>f]S>f]S>f]S>f]S>f]S>fmW?fmW?fmW?fmW?fmW?fmW?
fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fMO=f]S>f]S>f]S>fmW?fmW?fmW?g=[@gMW>gMW>
gMW>gMW>gMW>gMW>gMW>gMW>fmW>fmW>fmW>fmW>g=[?g=[?gM_@gM_@g]W@g]W@g]W@g]W@g]W@g]W@
g]W@g]W@g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?gm_@gm_@
gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@
gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@hM_@hM_@hM_@hM_@hM_@hM_@hM_@hM_@g][?g][?
g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g]S=g]S=g]S=g]S=g]S=g]S=
g]S=g]S=gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>g=S=g=S=g=S=g=S=g=S=g=S=003EdMOAcM?KemgP
g>;:a/cFd]SFd]S4`<Jm_;k9b<X:2@/0007@cm7Mg=iDDeF][:imOH=2@TS>c]CIfMnc/kVb/[S@d=K[
jo7De=[@d=KPh>KJf^3Lg>;Hf=kRh^SBd]SRh^S>c]CHf=kBd]SOgnGTi>[4a<[GemgAdMOAdMNUYJ]U
IF_:b]3<c=;AdMOShnT0006h^[]bM7G@d]=?DE:VZ:Wdm_Nj_;fa/KOalONj^/3De=[Bd]SAdMOMgN?=
cM?CeMgCeMgCeMgDe]kDe]kDe]kEemoEemoFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkF
eMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkF
eMkHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cH
e]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cH
e]cGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_HemWHemWHemWHemWHemWHemWHemWHemWGe]SGe]SGe]SG
e]SGe]SGe]SGe]SGe]SIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[Ge]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGemOGemOGemOHf=SHf=SHf=SIfMWIfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOJf=SJf=SJf=SKfMWK
fMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SHe]KHe]KHe]KH
e]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KIemOIemOIemOIemOIemOIemOIemOI
emOHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GH
e]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHem?Hem?Hem?Hem?Hem?Hem?Hem?H
em?He]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GJeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;J
eM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;J
eM;Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7FeM7FeM7FeM7Ge];Ge];Ge];Hem?Hem?JeM;JeM;JeM;J
eM;JeM;JeM;JeM;JeM;JeloJeloJeloJeloJeloJeloJeloJeloIe/kIe/kIe/kJeloJeloJeloKf=3K
f=3Ie/kIe/kIe/kJeloJeloJeloKf=3Kf=3JeloJeloJeloJeloJeloJeloJeloJeloIe/kJeloJeloJ
eloKf=3Kf=3Kf=3LfM7Ie/kJeloJeloJeloKf=3Kf=3Kf=3LfM7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Ie/kIe/kIe/kI
e/kIe/kIe/kIe/kIe/kIe/kJeloJeloJeloKf=3Kf=3Kf=3LfM7Ie/kJeloJeloJeloKf=3Kf=3Kf=3L
fM7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3JeloJeloJeloJ
eloJeloJeloJeloJeloKf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Jf<kJf<kJf<kJf<kJf<kJf<kJf<kJ
f<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoJf<kJf<kJf<kJ
f<kJf<kJf<kJf<kJf<kKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoK
fLoIelgJf<kJf<kJf<kKfLoKfLoKfLoLf]3MfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkKfLkKfLkKfLkK
fLkLf/oLf/oMfm3Mfm3NfM3NfM3NfM3NfM3NfM3NfM3NfM3NfM3Nf/oNf/oNf/oNf/oNf/oNf/oNf/oN
f/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oOfm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3O
fm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Nf/oNf/oNf/oNf/oNf/oNf/oNf/oN
f/oQfm3Qfm3Qfm3Qfm3Qfm3Qfm3Qfm3Qfm3Nf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oN
f/oNf/oNf/oNf/oNf/oNf<gNf<gNf<gNf<gNf<gNf<gNf<gNf<gMfLkMfLkMfLkMfLkMfLkMfLkMfLkM
fLkLf<gLf<gLf<gLf<gLf<gLf<d00=7=dn7Mhk^g_NKRj=3<d]oKhM;>e<W5bmCCeM_Jg<70`^7Ph]oN
h5EDEUQGFMOFf<71alg=di^KXEiNI:n_]LO7cK>c^DY:D;Fe^k>c^M?CfM3@e]CDf/g=dmgMhlW9clS8
c/c<d^GUjl_;dLg=dmWIgk:b^;Vi_fEUJh^;TMgMhkJf_:6QYn3Pi[^k`GEeNjNYZP43118D5Ko1`]?E
eZ6SY<c>clW;c;^k`MGEfn;Rj=SHg^CTj]CDf/o?eM_KhM?EgM?EgM?EgMCFg]CFg]CFg]GGgmGGgmKE
g]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SF
g=SFg=SFg=SFg=SFg=SFg=SFg=SFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=SFg=SFg=SFg=SFg=SF
g=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=SG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMOFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OGemOGemOGemSHf=SHf=SHf=WIfMWIfM[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGem[Hf=[Hf=[Hf=_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SF
e]SFe]SFe]SFe]WGemWGemWGemWGemWGemWGemWGemWGemSFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SF
eMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSF
eMSFeMSFeMSFeMSHd]SHd]SHd]SHd]SHd]SHd]SHd]SHd]SFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMWD
dMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWD
dMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMSCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=GD
d=KEdMKEdMKEdMOFd]OFd]OFd]SGdmWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWFc]WFc]WFc]WFc]WF
c]WFc]WFc]WFc]SEcMSEcMWFc]WFc][Gcm[Gcm_Hd=_Hd=SEcMSEcMWFc]WFc][Gcm[Gcm_Hd=_Hd=WF
c]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdMWFc][Gcm[Gcm[Gcm_H
d=_Hd=_Hd=cIdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc][Gcm[Gcm[Gcm_H
d=_Hd=_Hd=cIdMWFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=WGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcM_I
cm_Icm_Icm_Icm_Icm_Icm_Icm_IcmWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcM_Icm_Icm_Icm_Icm_I
cm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_IcmWGcM[Hc][Hc][Hc]_Icm_Icm_IcmcJd=gI
c]gIc]gIc]gIc]gIc]gIc]gIc]gIc]_Ic]_Ic]_Ic]_Ic]cJcmcJcmgKd=gKd=kId=kId=kId=kId=kI
d=kId=kId=kId=kJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmoK
d=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oK
d=oKd=oKd=oKd=kJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcn7Kd>7Kd>7Kd>7Kd>7Kd>7Kd>7Kd>7Kd=kJ
cmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmgGc=gGc=gGc=gGc=gG
c=gGc=gGc=gGc=gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]_Gc=_Gc=_Gc=_Gc=_Gc=_Gc000blO=h=cR
f=CJb<C:g=SNem?IcLW?g=SNdm;D][FgemKHclk@VYVKATE7_[foJFQZNGUoemOM_;c21@D;0004=SHl
[ZjdhN7WbLW?TI6GJVY`;ble;bleFEUO]KFke=CJc/kD`<36XZ:X>CTo8b<YJVY`U9BJd];Hf=SNeMGK
d];H_Kg3LW9h_[k4?3a2RXZ@f=[KFUaM0001a<K7h^CUblg>/[Beg^3Qe]KLgmoUbLW?f][PcLgCf=SN
e=CJe]KLdmGMdmGMdmGMe=KNe=KNe=KNeMOOeMOOe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GN
e]GNe]GNf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLf=KLf=KLf=KLf=KLf=KLf=KL
f=KLf=KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KL
f=KLf=KLemGKemGKemGKemGKemGKemGKemGKemGKf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIemKHemKH
emKHemKHemKHemKHemKHemKHfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJemKHemKHemKHemKHemKHemKHemKHemKHf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKH
emKHemKHemOGemOGemOGf=SHf=SHf=SHfMWIfMWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGf]SHf]SHf]SH
fmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHemGEemGE
emGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGEfMOGfMOGfMOGfMOGfMOGfMOG
fMOGfMOGemGEemGEemGEemGEemGEemGEemGEemGEemGDemGDemGDemGDemGDemGDemGDemGDemGDemGD
emGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemOAemOAemOAemOAemOAemOA
emOAemOAemGDemGDemGDemGDemGDemGDemGDemGDfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCA
fMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCA
fMCAfMCAf=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@eMC@eMC@e]GAe]GAe]GAemKBemKBemKBfMCAfMCA
fMCAfMCAfMCAfMCAfMCAfMCAfMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>f=G=f=G=f=G=fMK>f]O?f]O?
fmS@fmS@f=G=f=G=f=G=fMK>f]O?f]O?fmS@fmS@fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>f]O?
f]O?f]O?fmS@fmS@fmS@g=WAfMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fMK>fMK>
fMK>fMK>fMK>fMK>fMK>fMK>fMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfMK>f]O?f]O?f]O?fmS@fmS@
fmS@g=WAfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fMK>fMK>
fMK>fMK>fMK>fMK>fMK>fMK>fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fMO=fMO=fMO=fMO=fMO=fMO=
fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fMO=fMO=
fMO=fMO=fMO=fMO=fMO=fMO=fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?
fmW?fmW?fMO=f]S>f]S>f]S>fmW?fmW?fmW?g=[@gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>fmW>fmW>
fmW>fmW>g=[?g=[?gM_@gM_@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g][?g][?g][?g][?g][?g][?
g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@
gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@g][?g][?g][?g][?g][?g][?
g][?g][?hM_@hM_@hM_@hM_@hM_@hM_@hM_@hM_@g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?
g][?g][?g][?g][?g][?g][?gMO<gMO<gMO<gMO<gMO<gMO<gMO<gMO<gMW>gMW>gMW>gMW>gMW>gMW>
gMW>gMW>fmO<fmO<fmO<fmO<fmO<fmO<003Dd=KDd=KDd=KDd=KDd=KDd=KDd=KDd=K@cm7Ui>J`[k69
R8[RhN>6QHM6ADOBdM?Ee=KCd]AKFUb[ZZcPgn5KFUa^KFoOg^3?c]3BdM?BdM?Ee=KBdM?@cm5PGf5Z
JF]cLWA=C4jIV9[FeMO9b<[2`L?>cLoEe=KBdM=EE5K=c<hU92IcLWC3`/CJfM_Og^3Hf=k?cmGDe=[B
d]RATINf][cEeM_CdmWDe=[De=[De=[De=[De=[De=[De=[De=[EeM_EeM_De=[De=[CdmWCdmWBd]SB
d]SEeM_EeM_EeM_EeM_EeM_EeM_EeM_EeM_De=[De=[De=[De=[De=[De=[De=[De=[DdmcDdmcDdmcD
dmcDdmcDdmcDdmcDdmcEeM_EeM_EeM_EeM_EeM_EeM_EeM_EeM_Fe=[Fe=[Fe=[Fe=[GeM_GeM_He]cH
e]cGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_He]cHe]cHe]cH
e]cHe]cHe]cHe]cHe]cGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_Ge]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_HemWHemWHemWH
emWHemWHemWHemWHemWGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SIe]SIe]SIe]SIe]SIe]SIe]SIe]SIe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SIemOIemOIemOIemOIemOIemOIemOIemOJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOI
emOIemOIemOIemOIemOHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KIemOIemOIemOIemOIemOIemOIemOI
emOJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIemKIemKIemKIemKIemKIemKIemKIemKKe]GKe]GKe]GK
e]GKe]GKe]GKe]GKe]GIemOIemOIemOIemOIemOIemOIemOIemOKe]GKe]GKe]GKe]GKe]GKe]GKe]GK
e]GLemCLemCLemCLemCLemCLemCLemCLemCKe]GKe]GKe]GKe]GKe]GKe]GKe]GKe]GHdMCId]GJdmKK
e=OKe=OJdmKId]GId]GIf=CKf=CJem?Ke]?Ke]?NemCQf=GQf=GPfmSMf=GKe]?Ke]?Ke]?Ke]?Ie=7G
d/oFe=CJe]GJe]GIeMCJeM;LemCMfMCNf=?Sg=WLeM;Gd/oLemCKf=CFdloEd/kGe];Jem?Jem?Jem?I
e];Ie];HeM7HeM7HeM7Gd]?Ke]OMf=WLemSGd]?Dcm3Ed=7HdmCDd]7Edm;Gdm;Gdm;Ie=?Le=CLe=CN
e=CGd/oGd/oHdm3Ie=7JeM;Ke]?Ke]?LemCFe<[Ed/[Ge<cJf=3Mf]GIfM?Ge];Hem?Cd<_Cd<_Cd<_E
d/kHe=?IeMCGd]?FdM;LeM[DcM;Ab/oHdMCKeMKHd]?Gd]7Ke]GCeLWCeLWDe/[BdlWAd/WBdl[EeLoH
f=;Je]7Dd<_Ccl[IeM3Lf=?IeM3IeM3MfMCJdm3HdLkHdLkKe=7Of=GNemCJdm3Ec/_FdloFdloFdloG
e=3HeM7Jem?Kf=CLfMGMf<oLelkJeLcIe<_Ke/gLelkLelkKe/gOg<kNflgLfL_KelcKe/gLelkLe/oM
em3IelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgI
elgIelgIelgIelgIelgIe<_Ie<_JeLcJeLcJeLcKe/gKe/gKe/gMf<oMf<oLelkLelkKe/gKe/gJeLcJ
eLcKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gJeLcJeLcJeLcJ
eLcJeLcJeLcJeLcJeLcKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gK
e/gJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcMf<oMf<oMf<oMf<oMf<oMf<oMf<oMf<oJe/_Je/_Je/_J
e/_Je/_Je/_Je/_Je/_Je/_KelcKelcKelcLf<gLf<gLf<gMfLkKelcKelcKelcKelcKelcKelcKelcK
elcHelgHelgIelgIelgKe/gMe/gMe/gMe/gJe/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_KelcKelcKelcK
elcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcMfLkMfLkMfLkMfLkMfLkMfLkMfLkM
fLkJe/_Je/_KelcKelcLf<gLf<gLf<gLf<gMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkNf/oNf/oNf/oN
f/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oPf/gPf/gPf/gPf/gPf/gPf/gPf/gP
f/gPf/gPf/gPf/gPf/gPf/gPf/gPf/gPf/gPf/oPf/oPf/oPf/oPf/oPf/oPf/oPf/oPf/oPf/oPf/oP
f/oPf/oPf/oPf/oPf/oOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcPf/gPf/gPf/gPf/gPf/gPf/gPf/gP
f/gPf/gPf/gPf/gPf/gPf/gPf/gPf/gPf/gOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcO
fLcOfLcOfLcOfLcOfLcLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WMel[Mel[Mel[Mel[Mel[MelX00=C@
e]C@e]C@e]C@e]C@e]C@e]C@e]C@e/k=cmgLg/;1`n3OhI^JW<?2a9FDUVQWJMSGfLK5ahn>T7]jO:JU
YmKEen3OhHR7RN3OhMcKg@810l2o`N[Yjlk=cmcKgM7@d]CCeM;AdmcKgMSGfC4`<S0_<D=2A3He=l;1
`jBSYDU8BP000A<B53hm?lg<c];Adm7Aem?CfMOGgF5QIkJf_=3@e]7AemCDf]CDf]CDf]CDf]CDf]CD
f]CDf]CDf]CDf]GEfmGEfmCDf]CDf]?CfM?CfM;Bf=;Bf=GEfmGEfmGEfmGEfmGEfmGEfmGEfmGEfmCD
f]CDf]CDf]CDf]CDf]CDf]CDf]CDf]CCg=CCg=CCg=CCg=CCg=CCg=CCg=CCg=GEfmGEfmGEfmGEfmGE
fmGEfmGEfmGEfmKDf]KDf]KDf]KDf]OEfmOEfmSFg=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOE
fmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=OEfmOEfmOEfmOEfmOE
fmOEfmOEfmOEfmOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOE
fmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMOFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=WFf=WFf=WFf=WFf=WFf=WFf=WFf=WFf=OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWG
emWGemWGemWGem[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemSFe]SFe]SFe]SFe]SF
e]SFe]SFe]SFe]WGemWGemWGemWGemWGemWGemWGemWGem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemWG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]_FeM_FeM_FeM_FeM_FeM_FeM_FeM_FeMWGemWGemWGemWGemWG
emWGemWGemWGem_FeM_FeM_FeM_FeM_FeM_FeM_FeM_FeMcGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=[E
e=[Ee=[Ee=[Ee=[Ee=[Ee=[Ee=[Ee=cFemcFemcFem_Ee]_Ee][DeM[DeMWCe=CEdM?Dd=CCcmGBc]GB
c]G@cMG@cMK?c=CAcMCAcMCAcMKCcm[GdmcIeMcIeMcIeMSDdmWEe=WFd]KCcmG@cMKAc]SDcmWEd=SE
d=?@bm?@bmSEd=[Gd]GEcmGEcm[Je=CAc=GBcMKCc]SEd=[Gd]_HdmgJeMgJeMKCcmSEdM_He=cIeMcI
eMgJe]kKemoLf=cIe=cIe=_Hdm_Gd]cFdM_Ed=cCcmcCcmSFc=SFc=OEbmGCbM?Aam;@a]7?aM3>a=_I
c^GSf=gKdLo>a=;AamGDb/o>a<c:`]WKb=OHb=CEaM;Ba=3@`/c<`<S8_<C3^L?0^<6o]L6o]L2n/kNe
ZZb[WJZZVZn_Wjf]WK>cXkbk[LK5]lo=`]CBb=OEbmOEbmoMdm[Hc][Hc]gKdMcJd=OEbmKDb]_Icn3J
dm_Ec]G?b=;<aMG?b=[DcMoId^;LeMgJeM_HdmWFdMKCc]GBcMCAc=GBcMGBcMC>amK@bM[DcMkHdN;L
eN?Me^;LeN3JdmKBamOCb=SCb][Ec=_Ec]cFdMcFdMcFdMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWG
cMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWDbmWDbm[Ec=[Ec=[E
c=_FcM_FcM_FcMgHcmcGc]cGc]cGc]_FcM[Ec=[Ec=[Ec=_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_F
cM_FcM_FcM_FcM_FcM_FcM_FcM_FcM[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=_FcM_FcM_FcM_FcM_F
cM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=cG
c]cGc]cGc]cGc]cGc]cGc]cGc]cGc][Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm_Gc=_Gc=_G
c=cHcMcHcMcHcM_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=SGcMSGcMWGcMWGcM_FcMgFcMgFcMgFcM[F
bm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_G
c=_Gc=_Gc=_Gc=cHcMcHcMcHcMcHcMcHcMcHcMcHcMcHcM[Fbm[Fbm_Gc=_Gc=cHcMcHcMcHcMcHcMgI
c]gIc]gIc]gIc]gIc]gIc]gIc]gIc]kJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJ
cmkJcmkJcmkJcn3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3J
cn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3JcmoIc=oIc=oIc=oIc=oI
c=oIc=oIc=oIc>3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcMkH
bmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmcFbMcFbMcFbMcFbMcF
bMcFbMcFbMcFbMgGb]gGb]gGb]gGb]gGb]gGbP00e=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3FemKHcLc>
hn;Th=oQe=?EGUeOg=_Mh^7Sf]WK=cHhRHR:emKH_KbnYjJX`L32Y:>U?C`naLC62`X<dm;Dc/g?g]gO
Ogj051<E7A`N0P43?ci0_kk00001Z:NYfm[LY:>UGEaNf]WK0`84@d94VIRJ0001b/W;jNSZe=CJdm?I
6a/Q/[:hhN7Wc<cBc/kDgMgSe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJdm?Idm?I
dm?Idm?IeMGKeMGKeMGKeMGKeMGKeMGKeMGKeMGKe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=?Le=?L
e=?Le=?Le=?Le=?Le=?Le=?LeMGKeMGKeMGKeMGKeMGKeMGKeMGKeMGKe]CJe]CJe]CJe]CJemGKemGK
f=KLf=KLemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKf=KLf=KL
f=KLf=KLf=KLf=KLf=KLf=KLemGKemGKemGKemGKemGKemGKemGKemGKemKHemKHemKHemKHemKHemKH
emKHemKHemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKH
emKHemKHfMKHfMKHfMKHfMKHfMKHfMKHfMKHfMKHemKHemKHemKHemKHemKHemKHemKHemKHfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGf=KFf=KF
f=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KF
f=KFf=KFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEfmKEfmKE
fmKEfmKEfmKEfmKEfmKEfmKEf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFfmKEfmKEfmKEfmKEfmKEfmKE
fmKEfmKEfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBem;Aem;A
em;Aem;Aem;Af=?BfMCCf]GDc<o=c]7?dmCBe]OEfmWHgm_JhMgLhMgLgM_JfmWHfMOFf=KEfMOFf=KE
e]CCe=;Af]KAfMG@fMG@f]KAf]OBg=WDg]_FgmcGg=gCfM[@f=W?fmcBf]_Ae]O=e]O=fM[@g=[@fmW?
f]S>f=K<e]C:eM?9dm77dm77fMO<emG:e=;7dm76dLo4c/c1b/RmalFjc/focLbnblZlb/Nib/Bgal6d
aknba[ja_;VZ^kRY^;FV];6R/:fN[:VJZJJGZ:FFSHanWYf?RHQjL6mQNgY/Ph=cMgMWM7ATKW5GJfiD
IVU@HFA;G5i8EUM3D54mBd`hATPbB4XdBT`fADP_>chT=cXP@dLZDUHiFUI3EU8oEE4nFeM5JVEFNWEV
Qh5dSHMjZZVK[ZfO]kJX`L2balJhb/Vkd]73f]W;eM76f=C9g=S=g][?gMW>f]K;fMG:f=C9eM?9eM?9
e]C:f=K<f]S>g]cBhMoEhn7GgMOBg=KAfmG@fM?>e]3;dlg8dL_6clW4fMC;f]G<g=K?gMOBgMOBfmCA
fM;?f=3@fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=
fMO=fMO=fMO=fMO=fMO=fMO=fMC;fMC;f]G<f]G<f]G<fmK=fmK=fmK=g=O>g=O>fmK=fmK=fmK=f]G<
f]G<f]G<fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=f]G<f]G<
f]G<f]G<f]G<f]G<f]G<f]G<fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=
fmK=fmK=f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]K;f]K;
f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;fmO<fmO<g=S=g=S=g=S=fmO<fmO<fmO<fmO<fmO<fmO<
fmO<fmO<f=O=f=O=fMO=fMO=fmK=gMK=gMK=gMK=f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;fmO<fmO<
fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<g=S=g=S=g=S=g=S=g=S=g=S=
g=S=g=S=f]K;f]K;fmO<fmO<g=S=g=S=g=S=g=S=gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>
gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>gmW<gmW<gmW<gmW<gmW<gmW<
gmW<gmW<h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?gmW>gmW>
gmW>gmW>gmW>gmW>gmW>gmW>gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<
gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;
g]S;g]S;g]S;g]S;g]S;g]S;g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9gMO:gMO:gMO:gMO:gMO:gMO:
003Dd=KDd=KDd=KDd=KDd=KDd=KDd=KDd=KHemWAd=;:bL_DdmGAd=;Ui>I3@TASHVC6aLOLfmf7QXP0
0061P8;NgMo>cLoYj>[:bL_:bL/40`F][:jUY:KThnF6QHN`[k7HemW@cm4[:Rbm_;iCDUBh]kWAd=;B
dM<M71kMg=jMW9hd<cDK6QbIV9[Og^2o_/1UIF/000Bf][c>c]CCdmWLg>;MgN?9bLoDe=[De=[De=[D
e=[De=[De=[De=[De=[De=[De=[De=[De=[CdmWCdmWCdmWCdmWEeM_EeM_EeM_EeM_EeM_EeM_EeM_E
eM_De=[De=[De=[De=[De=[De=[De=[De=[DdmcDdmcDdmcDdmcDdmcDdmcDdmcDdmcEeM_EeM_EeM_E
eM_EeM_EeM_EeM_EeM_Fe=[Fe=[Fe=[Fe=[GeM_GeM_He]cHe]cGeM_GeM_GeM_GeM_GeM_GeM_GeM_G
eM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_He]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cGeM_GeM_GeM_G
eM_GeM_GeM_GeM_GeM_Ge]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGeM_GeM_GeM_GeM_GeM_GeM_GeM_G
eM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_Ge]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SIe]SIe]SIe]SIe]SIe]SIe]SIe]SI
e]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOI
emOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOI
emOIemOIemOIemOIemOIemOIemOIemOIemOHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KH
e]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KIemKIemKIemKIemKIemKIemKIemKI
emKHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GKe]GKe]GKe]GKe]GKe]GKe]GKe]GKe]GHe]GHe]GHe]GH
e]GHe]GHe]GHe]GHe]GKe]GKe]GKe]GKe]GKe]GKe]GKe]GKe]GKe]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?K
e]?JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;Qg=WOf]ONfMKLemCLemCLemCLemCMf=GAem;Aem;Cem;D
eM7Ce=3Cd/k@cl_Ac/[BdLgAd<cBdLgDdloHem?JfMGJfMGIf=CMf<oEdlWAclGEdlWFe<cBd<S;b<?4
a;k7bko6b[k4b;c4a[Zn`;Bi^jni^Jfi^Jfd/J>c/::`[In/ZI^XYINTXI>RWi6PWHnGUX:BTGf<RgN9
R7B7QW:2PFekNVIeM61ZJEAYJ5=YIU5VHdiUH4]TGDURFdMQFTIIE3mHDciED3]BCCQ>BCA;AS58@bi7
@Re7B3Q:Bc/_;adQ8@lk>RI0?b/b<Adg=1lo@RTl?RPi>bDf=b<c=20_;adZ:QXV9QHV9a<U9a4R90hM
80LN8@L^<AM;Cc9SIdYXI4aOFd=GDc]GDSeQFdQ]IeAdKEafKeiHF4IRHU1aLEmlO6Z3Pg6:RWRDU8:N
WXbj^:K2`:k=bkWCdKoDd/3Bd;kBd;kCdKoPg]?OgM;Ng=7KfLkGeL[CdLK?cL;<b[oLe]7KeM3Hd/gF
d<_Fd<_IdlkOfMCTg]WIdlcIdlcJe<oJe<oJdm3Kdm?Jd];Jd];IelgIelgIelgIelgIelgIelgIelgI
elgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIe<_Ie<_JeLcJ
eLcJeLcKe/gKe/gKe/gKe/gKe/gKe/gKe/gJeLcJeLcJeLcJeLcKe/gKe/gKe/gKe/gKe/gKe/gKe/gK
e/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcKe/gKe/gKe/gK
e/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gJeLcJeLcJeLcJeLcJeLcJeLcJeLcJ
eLcIe<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Je/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_IeL[Je/_Je/_J
e/_KelcKelcKelcLf<gKelcKelcKelcKelcKelcKelcKelcKelcHelgHelgIelgIelgKe/gMe/gMe/gM
e/gJe/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_KelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcK
elcKelcKelcKelcKelcLf<gLf<gLf<gLf<gLf<gLf<gLf<gLf<gJe/_Je/_KelcKelcLf<gLf<gLf<gL
f<gMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkM
fLkMfLkMfLkMfLkMfLkOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcPf/gPf/gPf/gPf/gPf/gPf/gPf/gP
f/gPf/oPf/oPf/oPf/oPf/oPf/oPf/oPf/oOfLkOfLkOfLkOfLkOfLkOfLkOfLkOfLkOfLcOfLcOfLcO
fLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcO
fLcNf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Le/WLe/WLe/WL
e/WLe/WLe/WLe/WLe/WMel[Mel[Mel[Mel[Mel[MelX00=C@e]C@e]C@e]C@e]C@e]C@e]C@e]C@e/G4
a^GTi^GTi/2o`MSGfMKEemoNh;fl_VETIUEDE/o>d>WXj]3?dKNf^>CSiL[9bmGDe[6`/P000HJ5Qj2O
XKNf^8j=Sjn^/=;Adn7PhRTX:^3OhM3?dFETI]WHf];Adg9aLk>b]>?Ri4e<C[Zi^l_:c5ACEA8A4i>C
VNGUjnCTj/c<d/?3bMgMhlK6c>7QimCDf]CDf]CDf]CDf]CDf]CDf]CDf]CDf]?CfM?CfM?CfM?CfMCD
f]CDf]CDf]CDf]GEfmGEfmGEfmGEfmGEfmGEfmGEfmGEfmCDf]CDf]CDf]CDf]CDf]CDf]CDf]CDf]CC
g=CCg=CCg=CCg=CCg=CCg=CCg=CCg=GEfmGEfmGEfmGEfmGEfmGEfmGEfmGEfmKDf]KDf]KDf]KDf]OE
fmOEfmSFg=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSF
g=SFg=SFg=SFg=SFg=SFg=SFg=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmKE
emKEemKEemKEemKEemKEemKEemKEemOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=WFf=WFf=WFf=WFf=WFf=WFf=WFf=WFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=SF
e]SFe]SFe]SFe]SFe]SFe]SFe]SFe]WGemWGemWGemWGemWGemWGemWGemWGemSFe]SFe]SFe]SFe]SF
e]SFe]SFe]SFe]WGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemOE
eMOEeMOEeMOEeMOEeMOEeMOEeMOEeMSFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]OEeMOEeMOEeMOEeMOE
eMOEeMOEeMOEeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMOEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=_F
eM_FeM_FeM_FeM_FeM_FeM_FeM_FeMOFd]OFd]OFd]OFd]OFd]OFd]OFd]OFd]_FeM_FeM_FeM_FeM_F
eM_FeM_FeM_FeM[Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed]WEd=WEd=WEd=WEd=WEd=WEd=WEd=WEd=_G
d][FdMWEd=OCc]KBcMGAc=GAc=GAc=?HcmCId=KId=KId=SId=[Hd=WGcmWGcmgKdmSFc]7?al[8`<?1
^Kbj/[FcZk2^YZ2KS9:?P8Z7NH^9OXV8OWUjLFEVGEMIDdaB?dmE@U=GA59D@Dm??De=>di<>Te;>Da6
<da6<d]5<TY4<DU3<4Q2;dQ2;dM1;TQ4;4I2:TA0:4M3:d]7;da8<4U5;DE1:DQ7:dQ7:dU6:TQ4:4M3
9dQ19TM09DPo94M2:DM2:DI1:4E09d<n9D8m944l8d4l8c/l;2DV5Pd=01XI1CTf8CHc7R/W3cDa6B/X
6RXW6BPT6BPS6RPS6RHP6B<M5R0J5AhL4AXH3A@B1a@C1B0P43Ti:EIFA6UYEfAPAfIRBFYVCW5]EGA_
FViXEF1JAe==>U=D@5aMBFEVDVIWDf=TD69SCfEVDVQYEEiMBFASCfi]FG]jIXb;Mj:QSKZiYL[9]LG3
/LW7]M3>_=OE`m_IamgKbMgKbMgKbM_FcM_FcM_FcMSCb]G@amG@amSCb]_FcMSCb]OBbMK@bMK@bmSB
cM_DdMgFdmoGemSFc=SFc=SFc=SFc=SFc=SFc=SFc=SFc=SFc=SFc=SFc=SFc=SFc=SFc=SFc=SFc=SF
c=SFc=SFc=SFc=SFc=SFc=SFc=SFc=WDbmWDbm[Ec=[Ec=[Ec=_FcM_FcM_FcM[Ec=[Ec=[Ec=[Ec=[E
c=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[E
c=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[E
c=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=WDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbm[F
bm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[FbmWEb]WEb]WEb][Fbm[Fbm_Gc=_Gc=_Gc=[Fbm[Fbm[Fbm[Fbm[F
bm[Fbm[Fbm[FbmOFc=OFc=SFc=SFc=[Ec=cEc=cEc=cEc=[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm_G
c=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_G
c=_Gc=_Gc=_Gc=[Fbm[Fbm_Gc=_Gc=cHcMcHcMcHcMcHcMgIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]cH
cMcHcMcHcMcHcMcHcMcHcMcHcMcHcMcHcMcHcMcHcMcHcMcHcMcHcMcHcMcHcMkHbmkHbmkHbmkHbmkH
bmkHbmkHbmkHbn3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3JcmkH
cMkHcMkHcMkHcMkHcMkHcMkHcMkHcMoIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=kHbmkHbmkHbmkHbmkH
bmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmgGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gG
b]gGb]gGb]gGb]gGb]gGb]gGb]gGb]cFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcF
bMcFb@00e=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3Fg]gOb/W;d]7Cg=_MgMcNclk@d<oAgmkPf=OIcLc>
LW5c=C@fXj:Tclk@fMSJemKHe=?EOgj00001FeYL^kZlfm[L/:naV9NIW9^M<C0bGeiPb<O9alK8CDa>
i>?Ug=_M];>efMSJclk@TI2B<S4c:bX/WijPc<_=_ko5eMGK^KVofMWOi^K/eMGKg]kT`<36e=CJe=CJ
e=CJe=CJe=CJe=CJe=CJe=CJdm?Idm?Idm?Idm?Ie=CJe=CJe=CJe=CJeMGKeMGKeMGKeMGKeMGKeMGK
eMGKeMGKe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=?Le=?Le=?Le=?Le=?Le=?Le=?Le=?LeMGKeMGK
eMGKeMGKeMGKeMGKeMGKeMGKe]CJe]CJe]CJe]CJemGKemGKf=KLf=KLemGKemGKemGKemGKemGKemGK
emGKemGKemGKemGKemGKemGKemGKemGKemGKemGKf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLemGKemGK
emGKemGKemGKemGKemGKemGKemKHemKHemKHemKHemKHemKHemKHemKHemGKemGKemGKemGKemGKemGK
emGKemGKemGKemGKemGKemGKemGKemGKemGKemGKe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHfMKHfMKHfMKHfMKHfMKHfMKH
fMKHfMKHemKHemKHemKHemKHemKHemKHemKHemKHf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFfMOGfMOGfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGemGEemGEemGEemGEemGEemGEemGEemGEf=KFf=KF
f=KFf=KFf=KFf=KFf=KFf=KFemGEemGEemGEemGEemGEemGEemGEemGEf=KEf=KEf=KEf=KEf=KEf=KE
f=KEf=KEemGDemGDemGDemGDemGDemGDemGDemGDfmKEfmKEfmKEfmKEfmKEfmKEfmKEfmKEemKBemKB
emKBemKBemKBemKBemKBemKBfmKEfmKEfmKEfmKEfmKEfmKEfmKEfmKEf]GBf]GBf]GBf]GBf]GBf]GB
f]GBf]GBfMG@fMG@fMG@fMG@fMG@fMG@fMG@fMG@d/o7dm38e]?;fMK>g=WAgM[Bg]_Cg]_CdmK7cm;3
bl^ma<Bf_[f_^[NY][>U];6STXaoRXAgOWQ[KfULHE]>DT`oAT0c?SP[CDLd@CdZ?3XX?cl_?3``:2TO
5AP?2a0782D@:bdI<c@P=SDQ>3@Q@3TVAS`ZAcd[BD@[B4<ZAd8YAD0W@chU@SdT@C`S@3/R>CDI>CDI
>cLK?c/OA40TAd<WAd<WAT8V@d4SA40SA40SAT0SB40SB40SBSlSBSlSA3dRA3dRA3dRAChSAChSASlT
ASlTAd0U=cT]4a<52PX0:2HD>cLT=c0L=2`E>S<J<2TP;bPO;BHM;RHO;RDQ;RDQ:b8O:1lL71PC7ATD
7Q/C9R<K>SP^E597IVAIKF]PK6YBKfeEMG=KO7UTOWYWNGERKFUGI61>JVYHM7ARNg]YNWYXN7QVMgMU
MWITM7ARMgIRLg9NJfYFH5m;EEA0CD`hBdXfBTTeJfMDM71MPgm/Ui>0ZZJC^[JSaL6^blNdaL:dcLZl
emC6fmS:f]O9emC6e]?5e]?5i>7Ch]oAgm_@g=O>f]G<fM?<fM?<fM?>f=K<f=K<f=K<f=K<f=K<f=K<
f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<fMC;fMC;
f]G<f]G<f]G<fmK=fmK=fmK=fMC;fMC;fMC;fMC;f]G<f]G<f]G<fmK=f]G<f]G<f]G<f]G<f]G<f]G<
f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<
f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<
f]G<f]G<fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;fMG:fMG:
fMG:fMG:f]K;f]K;f]K;fmO<f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;emK<emK<f=K<f=K<f]G<g=G<
g=G<g=G<f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<
fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<f]K;f]K;fmO<fmO<g=S=g=S=
g=S=g=S=gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=
g=S=g=S=g=S=g=S=g=S=g=S=g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;h=[=h=[=h=[=h=[=h=[=h=[=
h=[=h=[=h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?g]S=g]S=g]S=g]S=g]S=g]S=g]S=g]S=gmW<gmW<
gmW<gmW<gmW<gmW<gmW<gmW<g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;
g]S;g]S;gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:g=K9g=K9
g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9003Dd=KDd=KDd=KDd=KDd=KDd=KDd=KD
d=K3`/Cem?Jn_KoHemWMg=k:bL_Kf]cGe]SGe]S;b/cMg=k;b/bAT99LFef4PhG9b<[:bL_XinWGe]QG
EUQ?CU33`/CDdmG9b<ZRXJ=IF5[LfmgLfmgdloG4`lFf]KOMg=k:bL]dLgEcLWANGEo<blgCd]CEe=KV
iNOIfMo[jo7UiN_7alg@d=K:b]3Kfn7Jf^3De=[De=[De=[De=[De=[De=[De=[De=[Bd]SBd]SCdmWC
dmWDe=[De=[EeM_EeM_EeM_EeM_EeM_EeM_EeM_EeM_EeM_EeM_De=[De=[De=[De=[De=[De=[De=[D
e=[DdmcDdmcDdmcDdmcDdmcDdmcDdmcDdmcEeM_EeM_EeM_EeM_EeM_EeM_EeM_EeM_Fe=[Fe=[Fe=[F
e=[GeM_GeM_He]cHe]cGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_G
eM_He]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_Ge]SGe]SGe]SG
e]SGe]SGe]SGe]SGe]SGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_G
eM_FeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SGe]SGe]SIe]SIe]SIe]SIe]SIe]SIe]SIe]SIe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KIemOIemOIemOIemOIemOIemOIemOIemOHe]KHe]KHe]KH
e]KHe]KHe]KHe]KHe]KIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOI
emOFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KFe=CFe=CFe=CF
e=CFe=CFe=CFe=CFe=CHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?F
e=?Ke]GKe]GKe]GKe]GKe]GKe]GKe]GKe]GFe]3Fe]3Fe]3Fe]3Fe]3Fe]3Fe]3Fe]3Ke]GKe]GKe]GK
e]GKe]GKe]GKe]GKe]GIe=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7HeLgHeLgHeLgHeLgHeLgHeLgHeLgH
eLgLf]3Lf]3KfLoIelgDd/S>c<;7aK_4`[R/[IVRXhnDTgn3Ofa`K5URG4UGDCiCC3UEBcUBB3I?AC==
@c5<@S1:@2i7?B]4>RPi<a`f<A`h=24i>BL^;R0I7A4A5PdF7Q@S9Pda<ATl>R90>R=4?2E>@B]DAS1G
AS5:A2M9@bI7@BA4?R51>ahm=aXk=APj=1M3?255?R=8@BI8@BI7@2E6?bA7@2E8@BI>BRe@BRe@BReC
BbiEBRiFBbmGBbmGBbm<@RY<@RY<@RY<@RY=@b]=@b]=@b]=@b/`<BP@3`DM6a0m>R`m=RDo=B=:?bU2
=b4d<1dc;adb;Q`c;Qld;b0c;B0a:ah^:1dO7A<T8QLY9a`b<B=5A3IMGDe[JeU/K5YcMEmbM5icM61d
MF5hN6IlO6b0P722PW9[Je]eMFElO6anOVj1PG64Q7B1PG5kNf]cLEmfM69jN6IlNVQiMfE_KE]RH4iI
EdE6A2a6A2a7ABe:B31?CCEGECeNG4ARH4QkNVJ8Qg>KVXJ/ZiNj^JG6aK7BdKgKf/K@c[cBd;kEd/?G
e<GHeLOGdlSEdLKCclCGeL_GeL_GeL_GeL_GeL_GeL_GeL_GeL_GeL_GeL_GeL_GeL_GeL_GeL_GeL_G
eL_GeL_GeL_GeL_GeL_GeL_GeL_GeL_GeL_Ie<_Ie<_JeLcJeLcJeLcKe/gKe/gKe/gHdl[Hdl[Hdl[I
e<_JeLcJeLcJeLcKe/gIe<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_I
e<_JeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcIe<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_I
e<_Ie<_Ie<_Ie<_Ie<_JeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJ
eLcJe/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_He<WHe<WIeL[IeL[IeL[Je/_Je/_Je/_IeL[IeL[IeL[I
eL[IeL[IeL[IeL[IeL[FeL_FeL_GeL_GeL_Ie<_Ke<_Ke<_Ke<_Je/_Je/_Je/_Je/_Je/_Je/_Je/_J
e/_KelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcJe/_Je/_Je/_J
e/_Je/_Je/_Je/_Je/_Je/_Je/_KelcKelcLf<gLf<gLf<gLf<gMfLkMfLkMfLkMfLkMfLkMfLkMfLkM
fLkKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcMel[Mel[Mel[M
el[Mel[Mel[Mel[Mel[Pf/gPf/gPf/gPf/gPf/gPf/gPf/gPf/gPf/oPf/oPf/oPf/oPf/oPf/oPf/oP
f/oMelcMelcMelcMelcMelcMelcMelcMelcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcMel[Mel[Mel[M
el[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Le/WLe/WLe/WLe/WLe/WLe/WLe/WL
e/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WKeLSKeLSKeLSK
eLSKeLSKeLP00=C@e]C@e]C@e]C@e]C@e]C@e]C@e]C@e]KEelC3aNOVj=KEem[Ifn7Ph/[9bmgLg]7@
d]SGfMgLg/c;cMcKgNGTi[bk_Lc;cL?2a9RGVJ>RY8N6R:^Z[=[Ifm[IfmGDe]oNh<K5amGDe/k=cgIe
MjRWZK6`/ZJUYlK5al;1`mSGfM7@d]OFf=cKgLk=cmGDe]?CfKbl`]3@e]gMhm?CfMcLh/k>e=GEfmCD
f]CDf]CDf]CDf]CDf]CDf]CDf]CDf];Bf=;Bf=?CfM?CfMCDf]CDf]GEfmGEfmGEfmGEfmGEfmGEfmGE
fmGEfmGEfmGEfmCDf]CDf]CDf]CDf]CDf]CDf]CDf]CDf]CCg=CCg=CCg=CCg=CCg=CCg=CCg=CCg=GE
fmGEfmGEfmGEfmGEfmGEfmGEfmGEfmKDf]KDf]KDf]KDf]OEfmOEfmSFg=SFg=OEfmOEfmOEfmOEfmOE
fmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=OE
fmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OEfmOEfmOEfmOEfmOE
fmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmGDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=WFf=WFf=WFf=WFf=WF
f=WFf=WFf=WFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMWG
emWGemWGemWGemWGemWGemWGemWGemOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMWGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemKDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=SF
e]SFe]SFe]SFe]SFe]SFe]SFe]SFe]KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=OEe=OEe=OEe=OEe=OE
e=OEe=OEe=OEe=KDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdm_FeM_FeM_FeM_FeM_FeM_FeM_FeM_FeMKF
d=KFd=KFd=KFd=KFd=KFd=KFd=KFd=_FeM_FeM_FeM_FeM_FeM_FeM_FeM_FeMWDdMWDdMWDdMWDdMWD
dMWDdMWDdMWDdMSEcMSEcMSEcMSEcMSEcMSEcMSEcMSEcM;@aLc:_l6o]:n]XYRFRh5oM6i/HF9PEEME
?EAB>U5==De9<De7<559<UA<=EI>=e95;dm2;4/n:4Tl9TLj94@g8D4d7Sha6cXe73`h840m:3Ti9b8S
4`L;00P>0aLO5C8a5d0l8dU4:dY0:4Xn9U92:eM5;UM2;4]69da7:4a7:4a7:4e8:De8:Di9:Ti9:Ta5
;519<5A==5A==55:<E19<59;<UE>=E5;;U5;;U=;;U=;;UI;;eM;;eM;;eM;;eM;<eM;<eI:<UE9<EA8
<5=7;e=7;e96;R0O6``912XW7dM1=SD^7d0f95I;=dDh8S`l7S/k7C/j7Sdl83ln93lm9Chl93`j8S0`
7S<d83<d83<e7cm1:e=F?F5TBVAWCFU^FFmdGgIjIgb0KGn2LX23M8:5MX>5NHV8NXj=Oi2?PH^:O8V8
NXN6N7elKW5`HWYhIWQfI7MeHgUgIG]iIgUgIG=aGfe[FF1OAEUH?Ti=<dA3:Cln940o9DA3:DQ7;C/k
8d51:DQ8<4i>=UIF?VATC7EeGH:2JYbKQZFTSk>bW/?1[lo=^mKCa=WFamWFb=OEbmOEbmOEbmOEbmOE
bmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmWD
bmWDbm[Ec=[Ec=[Ec=_FcM_FcM_FcMOBbMSCb]SCb]WDbmWDbm[Ec=[Ec=_FcMWDbmWDbmWDbmWDbmWD
bmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbm[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=WD
bmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbm[Ec=[Ec=[Ec=[Ec=[E
c=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[FbmSD
bMSDbMSDbMWEb]WEb][Fbm[Fbm[FbmWEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]KEbmKEbmOEbmOEbmWD
bm_Dbm_Dbm_Dbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_G
c=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm_Gc=_Gc=cH
cMcHcMcHcMcHcMgIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_G
c=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb^3JcN3JcN3JcN3JcN3J
cN3JcN3JcN3JcN3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3JcmgGc=gGc=gGc=gGc=gGc=gGc=gGc=gGc=oI
c=oIc=oIc=oIc=oIc=oIc=oIc=oIc=gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gG
b]gGb]gGb]gGb]cFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcF
bMcFbMcFbMcFbMcFbMcFbMcFbMcFbM_Eb=_Eb=_Eb=_Eb=_Eb=_Eb000e/oBe/oBe/oBe/oBe/oBe/oB
e/oBe/oBem?Iem?Iem?Iem?If=CJf=CJf=CJfMGKe]CJe]CJe]CJe]CJe]CJe]CJe]CJe]CJd]3FfmWO
d<kD_;[0^[RnZJN]FUQN0@0500043P`BQ8:8_kg3]K>id]3Fg=[PcL_Ae]CJe]CJe]CJe]CJe]CJe]CJ
e]CJe]CJe=;He=;He=;He=;He=;He=;He=;He=;Hdm?Idm?Idm?Idm?Ie=CJe=CJe=CJeMGKdm?Idm?I
dm?Idm?Ie=CJe=CJe=CJeMGKd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];H
d];Hd];He=CJe=CJe=CJeMGKeMGKeMGKe]KLe]KLe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe=?EeMCF
eMCFeMCFe]GGe]GGe]GGemKHe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGemKHemKHemKHemKHemKHemKH
emKHemKHe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGemKHemKH
emKHemKHemKHemKHemKHemKHe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFf=KFf=KF
f=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KEf=KEf=KEf=KEf=KEf=KE
f=KEf=KEf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KE
f=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KE
f=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]GAe]GA
e]GAe]GAe]GAe]GAe]GAe]GAfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKC
fmKCfmKCfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAe]7>e]7>
f=C?f]OBgM_Cg=gCfM_?emW=e=3?e];AfMGDf]GBfmCAf]C?g=??gMC@d=?:dmC;eMK<fMW=fMK8cLRi
^KFS[:JCShA^OW=MK69:I5Y2GeDmFE0eED`aED`aGTl_Fdh^FT`_F4d_F4``Ed`aETdbET`dDDL_>c0J
@3PQBd8^GEI2@3XWFeA3CDTgBDPc@T0^AT<d@3`a9B4F2`P09R@B<2lJCTT`CTT`CdP_DDL_DDL_DdL_
DdL_E4H_EDTaEd/cF4`dEd/cE4P`E4P`Ed/cFdlgF4ldEdhcEdhcFE0eFe8gFe8gFE0eETdbDDXfE4`e
ETlfFU4fG54eG58dG54aFe0`FU4fD4L/DdTaEddeDTLaDdPbEDXfCT<_5A8=5Q48@ST[DD<`ASPQDdH/
DTH^BT0XCd<[BClWB3dWB40YB3l[@c`Y@S`YAT0]=SPU>CTW>CTW>cTW@cl]CDTgDd`kDDXiEEY5FEi9
HVMBJg1KMGYUOH9]PXMbQHYeQhIlS8^1TY67UYF;UIB:Ti:8TY67TI26RH9iQh1gR85hRHEjRXQmQXAi
Ng]]LW9TOGY/MgAUKfeKIFA@FeY5CThf?d0V=CHL@SdX?cXU?c/S@CdU?SXQ>cPL@ChRCDX^@T4WCdhd
G5]1Hf98JfY@NWUOSXecWIb2/jnL_[ZWc<Rfdlnmdljoe<k1fM?6g]S;f=;5fM?6f]C9f]C9fM;9fM;9
g=C=g]K?cLO0fmG>em;9d<_2em?8g=S=fMG:fmO<e]K8emK8emK8f]O9g=K9g=K9gmO:gmO:fmC;fM;9
f]?:gmS?h=W@fmC;f]?:gMK=fMK8fMK8fMK8fMK8fMK8fMK8fMK8fMK8f=?:f=?:f=?:f=?:f=?:f=?:
f=?:f=?:em?8f=C9fMG:f]K;f]K;f]K;fMG:fMG:f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;fMG:fMG:
fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:
fMG:fMG:em?8f=C9fMG:f]K;f]K;f]K;f]K;fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:
fMG:fMG:fMG:fMG:fMG:fMG:fmG8fmG8fmG8fmG8fmG8fmG8fmG8fmG8f]O9f]O9f]O9f]O9f]O9f]O9
f]O9f]O9f]O9f]O9f]O9f]O9f]O9f]O9f]O9f]O9gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:g=K9g=K9
g=K9g=K9g=K9g=K9g=K9g=K9gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:
gMO:gMO:fmS:fmS:fmS:fmS:fmS:fmS:fmS:fmS:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gmW<gmW<
gmW<gmW<gmW<gmW<gmW<gmW<gm_9gm_9gm_9gm_9gm_9gm_9gm_9gm_9g]S;g]S;g]S;g]S;gmW<gmW<
gmW<h=[=gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gm_9gm_9gm_9gm_9gm_9gm_9gm_9gm_9gm_9gm_9
gm_9gm_9gm_9gm_9gm_9gm_9gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7g=S6g=S6g=S6g=S6g=S6g=S6
g=S6g=S6gMW7gMW7g=S6fmO5fmO5f]K4f]K4fMG3fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5
fmO5fmO5fmO5fmO5003Fcm;Fcm;Fcm;Fcm;Fcm;Fcm;Fcm;Fcm;Fd]SGdmWGdmWGdmWHe=[He=[He=[H
e=[EdmWEdmWEdmWEdmWEdmWEdmWEdmWEdmW@c]CFe=[EdmWBd=KHe]cQgnGGeM_5`lWBd=Jl^/3Th^SQ
gnG0_/C>c=;Fe=[@c]CEdmWEdmWEdmWEdmWEdmWEdmWEdmWEdmWDd]SDd]SDd]SDd]SDd]SDd]SDd]SD
d]SBd]SCdmWCdmWCdmWDe=[De=[De=[De=[Bd]SCdmWCdmWCdmWDe=[De=[De=[De=[Bd]SBd]SBd]SB
d]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SCdmWDe=[De=[De=[EeM_EeM_EeM_F
e]cFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMODdmGEe=KEe=KEe=KFeMOFeMOFeMOGe]SFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGG
eMGGeMGGeMGGeMGGeMGGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGe=KGe=KGe=KGe=KGe=KGe=KGe=KG
e=KGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCG
eMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCG
eMCFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?FeM7FeM7FeM7FeM7FeM7FeM7FeM7FeM7JeM;JeM;JeM;J
eM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7I
e=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Qg=WMf=GIeM3Ed/gDdLcCd<_Bd<S@c/KJf=SHe]GGdm;E
d/kEdLcGdL[Gd/WJe<WNg];@cl6h]jVRWi2>RWQjM65XHDeKE41[GTAQE3YJCC=JCC=JCC=HC31FBRiH
C31IBbiIBbiGBbmFBRiFBc1DBS9EBc=EBc=HD3U8@2U8?b]LED5XHTmKE4=_JeUYIE=OGTYPGTaTHE=J
ET/R7Q<M6P`k>BM5A31@C3A@BS=?BC9ABC9DBC=EBSAJCCMKCSQDBS9GCCEJD3QJD3QICcMJD3QMDc]P
ESiID3EHCcAGCS=HCcAJDCIID3EGCS=DBc1BC3ECCCIGD3MKDCULDcQNDcMMDcENDcEOES]EC35HCSIL
DSYGC3IHCCMICSY@AC4=2PDG4PU:@C=ICSYA@baJCC=EBC5=@b]@ARi<@RY;@2Y<A2e:@bm7@2e7@Bi;
AC8h>RLl?R]0@2i4@S1:B3IDD3iFDT1DCCa=CSYADSiGF4ANGd]UIU9[K5Q^Ke]`LEemOG63PgN<S82E
UHVJVXjOWi>SXiNUYIVRWIBLUhjDTXNAShB@T8B=Sh>8Rgb1QWN5QGV3PgF1PG=nOfmhNVM/KUYNHD]D
Ed58A34n>RLh=B0m>b=1?bLo?R@m?28n?B4i>1hm?290?bE1@2I3@RQ7ARa=C39AD3I<BS9HESiYIU5j
MV>:QW>KUhF/Z9Jh/jC8a;;=bKOEd<7JeLKKeLSKeL[Le/_Le/_Pfm;TgmKOf]7IeL[MfLkLf<gFd/OF
dlGEeLWDe<SEdlSGdlSGdlSIdlSIdlSKd/SJeLcGd/WHdl[LelkKe/gGd/WFdLSIe<_Fd/OGdlSGdlSH
e<WIeL[Je/_KelcKelcGd/WGd/WGd/WGd/WGd/WGd/WGd/WGd/WIeL[Je/_KelcKelcLf<gKelcJe/_J
e/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[I
eL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[GdlSHe<WIeL[Je/_Je/_Je/_Je/_I
eL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[KeLSKeLSKeLSK
eLSKeLSKeLSKeLSKeLSJelWJelWJelWJelWJelWJelWJelWJelWJelWJelWJelWJelWJelWJelWJelWJ
elWMel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Le/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WMel[Mel[Mel[M
el[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Kf<[Kf<[Kf<[Kf<[Kf<[Kf<[Kf<[K
f<[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf/SNf/SNf/SN
f/SNf/SNf/SNf/SNf/SMel[Nf<_Nf<_Nf<_OfLcOfLcOfLcOfLcMel[Mel[Mel[Mel[Mel[Mel[Mel[M
el[Nf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SMfLOMfLOMfLOM
fLOMfLOMfLOMfLOMfLOLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KMfLOLf<KLf<KKelGKelGJe/CJe/CJ
e/CKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelD00=K?d]K?d]K?d]K?d]K?
d]K?d]K?d]K?d]KBf=KBf=KBf=OCfMOCfMSDf]SDf]SDf]GCfMGCfMGCfMGCfMGCfMGCfMGCfMGCfMOE
fmCBf=GCfM[Hg]KDf]3>e=SFg>OUjnOUjmCBf=kLh]GCfLW7cMCBf=KDf]SFg=GCfMGCfMGCfMGCfMGC
fMGCfMGCfMGCfMCBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=;Bf=;Bf=;Bf=?CfM?CfMCDf]CDf]CDf];B
f=;Bf=;Bf=?CfM?CfMCDf]CDf]CDf];Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;B
f=;Bf=;Bf=;Bf=?CfM?CfMCDf]CDf]CDf]GEfmGEfmGEfmKEemKEemKEemKEemKEemKEemKEemKEemCC
eMGDe]GDe]GDe]KEemKEemKEemOFf=KEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKE
emKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKE
emKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemGDe]GDe]GDe]GDe]GD
e]GDe]GDe]GDe]KEemKEemKEemKEemKEemKEemKEemKEemGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMOE
eMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEe=OEe=OEe=OEe=OE
e=OEe=OEe=OEe=ODe]ODe]ODe]ODe]ODe]ODe]ODe]ODe]OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OE
e=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OE
e=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=KDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKE
dMKEdMKEdMKEdMKEdMKEdMKEdMKEdM[Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][E
d][Ed][Ed][Ed]WDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdM3<
am;>bMGAc=WDdMgHeMkIf=_FeMWDdl[8b<g;b]?Bc][Hd=_Ic];B`/G3/KZiYI>=NXEoK79[Ef5JAUYB
>eU>>5M==EE;<eM9;5A6:EE7:U]=<5e?<UY<;eY<;ei@<eE9;EI9;eM<<EY>=UaB>UeE?V1G@f5HA5iG
@eI?>da5<W5[F6iZF7IaHX9oL8>0LGIfI8:2LXJ4NGIdJQ`J43dk<5mOCfMWEFEQCV=OC65KB5eGA5]D
@E]A?e]A?e]A?e]D>EaE>UeF>eaE>UYC>5YC>5]D>EeF>e]D>eUB>EM@=eQA>5UB>EUB>EM@=eE>=E==
=UE?>5MB>E]D>eiE>UmF>f5F>V5F>V9K@5UB=e]D>eiG?UUA>UYB>eYA?Di5<@H601XH3Tm8>EaA?EA8
<5aA=UM==EA==5E;<e57;dm7<59:<e19=Da6<de7=4m;>3Xl:D12;dA6<dU9=e5??EQFA5YFA5EA?e9>
>eA@?EMC@5]GA5iJAf5MBV9NBf=OC6IUEfe/GWMfJ860LXZ9Ni:APiZIRj2OTK>cYJf]Wj>VUijQTYZO
T9FLSi2GRXbCQXZ>PhZ>Ph^?Q8fAQHfBPhZ?P8F;NX67MX5oKFi/FUME@dM6<Sdl9cTh8c`l9492:T90
:40n9Slm9D4o9dA2:TA2:T0n9Sdk8cln8Shm8Chm8d0o9DE3:di;=UIC?UaIA6]YDGAbFXB1K9FBOJJR
SkJbX<>o[L_6]l_8^/_8^/k;_MGBa=WFb=ODa]CA`mCA`mGEbMGEbMGEbMKDbMSDbMOCb=WCb=WCb=[H
c]KDb]GCbMSFc=SFc=GCbMGCbMWGcMGCb=KDbMKDbMKDbMOEb]OEb]OEb]OEb][Ec=[Ec=[Ec=[Ec=[E
c=[Ec=WDbmWDbmWEb][Fbm_Gc=_Gc=_Gc=[FbmWEb]SDbM[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[FbmWE
b]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WE
b]WEb]WEb]WEb]OCb=OCb=WEb]WEb][Fbm[FbmWEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WE
b]WEb]WEb]WEb]WEb]WEb]WEb]WEb]_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=[GbM[GbM[GbM[GbM[G
bM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbMgGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]cF
bMcFbMcFbMcFbMcFbMcFbMcFbMcFbMgGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gG
b]gGb]gGb]gGb]_Hb]_Hb]_Hb]_Hb]_Hb]_Hb]_Hb]_Hb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]kH
bmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkJb=kJb=kJb=kJb=kJb=kJb=kJb=kJb=gGb]gGb]gGb]kHbmkH
bmoIc=oIc=oIc=gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]kJb=kJb=kJb=kJb=kJb=kJb=kJb=kJb=kJ
b=kJb=kJb=kJb=kJb=kJb=kJb=kJb=gIamgIamgIamgIamgIamgIamgIamgIamcHa]cHa]cHa]cHa]cH
a]cHa]cHa]cHa]cHa]cHa]cHa]_GaM_GaM_GaM[Fa=[Fa=_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_G
aM_GaM_GaM_GaM_GaM_Ga@00e/oBe/oBe/oBe/oBe/oBe/oBe/oBe/oBe];He];He];He];Hem?Iem?I
f=CJf=CJeM?IeM?IeM?IeM?IeM?IeM?IeM?IeM?If=KLc/cBc/cBf=KLfMOMc/cBb/S>d<kD`;k4aL?9
cL_AdLoEfMOMfMOMclgCd<kDeM?IeM?IeM?IeM?IeM?IeM?IeM?IeM?Ie=;He=;He=;He=;He=;He=;H
e=;He=;Hd];Hd];Hd];Hd];Hdm?Idm?Ie=CJe=CJd];Hd];Hd];Hd];Hdm?Idm?Ie=CJe=CJd];Hd];H
d];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hdm?Idm?Idm?Ie=CJe=CJe=CJ
eMGKeMGKe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe=?EeMCFeMCFeMCFe]GGe]GGe]GGemKHe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGE
emGEemGEemGEemGEemGEemGEemGDemGDemGDemGDemGDemGDemGDemGDemGEemGEemGEemGEemGEemGE
emGEemGEemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGD
emGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGD
emGDemGDe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]GAe]GAe]GAe]GAe]GAe]GAe]GAe]GAf]GBf]GB
f]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBfMCAfMCAfMCAfMCAfMCAfMCA
fMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAg=[Bf]S@fMG@f=?@fmCAf];Bf=3Af<g?h=oKf=SB
clg5`/2e[jnMUYF0MgMOI6=9H5DjFe0eEDX_DTL/E4T^EdX`F4``F4``G4d/Fd`/GTl_HU<cH50cG4`_
G4/`HE0eFDdeG50hH5DoJ5e9KFA@LV]HMg1MNG9QKFMDK6ICE50nQX9`M75RRhYlShj0U9:7QhMgV9N9
VIN=QX9m6AD@IVAJQhIhRXYjQhMeQ8AbP7i/N7ITLFeKJV=BHea;H5Q7GUU0GEPoFUDlEe8iEU4hF5<j
FeHmGEPoGULnG5DlFU<jFU<jFe@kGEHmGEHmG5DlEE4iEU8jF5<jFUDlGULnHUQ0HeU1IEU1Hea1Fe@i
GULnGePoFU8kGEDnFU4mBT4]1`L18R0FDd`mEdhjDdL_G54fF4hfGULnEe0gDd`cDd/dE4hgDdhiDD/h
D4`iE50m?40]@4@aATPeB4XgCdlmFEM5FEM5Ee=1FeE2G5I3GEM4GeU6H5Y7HE]8HE]8HUa9EeM7Fe];
HF5AIfMGK6aLLg=SNGUYOWi^TiJ6TiV8UYb;VZ6BWZFFVjBGUInBTI^>UIfCTi^ASiN=SYJ<SYJ<TIV>
U9bAUIfBYjJHWij@SHemLW9RE5A2@d@`@T<_B4Te@d4Y@3hV@T0XBDL_CD/cC4XbBDL_AdD]Bd`/ADHV
?CdO>c/M?SdQ@d8XATD[AdH/AdLYAdHZB4L[BTT_DU0hGUa4KFYEMgAOUI>1UI>1YjFC^kRY`Kj_bLJh
f=G7h]oAdM;8d]?9e=?9eMC:emG;f]G<f]G<g=G<eM?;dLo7d<k6dm79e=;:d]38e=;:fMO?f=K<f=K<
emG;emG;e]C:eM?9eM?9eM?9fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;f=C9f=C9fMG:fMG:fMG:f=C9
em?8e];7fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9
f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9e];7em?8f=C9fMG:fMG:fMG:
fMG:f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9f]C7f]C7
f]C7f]C7f]C7f]C7f]C7f]C7fMK8fMK8fMK8fMK8fMK8fMK8fMK8fMK8fMK8fMK8fMK8fMK8fMK8fMK8
fMK8fMK8gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:fmG8fmG8fmG8fmG8fmG8fmG8fmG8fmG8gMO:gMO:
gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:fmS:fmS:fmS:fmS:fmS:fmS:
fmS:fmS:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g][8g][8
g][8g][8g][8g][8g][8g][8gMO:gMO:gMO:gMO:g]S;g]S;gmW<gmW<gMO:gMO:gMO:gMO:gMO:gMO:
gMO:gMO:g][8g][8g][8g][8g][8g][8g][8g][8g][8g][8g][8g][8g][8g][8g][8g][8gMW7gMW7
gMW7gMW7gMW7gMW7gMW7gMW7fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5
fmO5fmO5f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4003Fcm;Fcm;Fcm;F
cm;Fcm;Fcm;Fcm;Fcm;EdMOEdMOFd]SFd]SFd]SGdmWGdmWGdmWDd]SDd]SDd]SDd]SDd]SDd]SDd]SD
d]SJf=kEdmW?cM??cM?Dd]SJf=kLf^3KfMoCdMONg>;EdmWCdMOIemgBd=K@c]CFe=[Dd]SDd]SDd]SD
d]SDd]SDd]SDd]SDd]SDd]SDd]SDd]SDd]SDd]SDd]SDd]SDd]SAdMOAdMOBd]SBd]SBd]SCdmWCdmWC
dmWAdMOAdMOBd]SBd]SBd]SCdmWCdmWCdmWBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SB
d]SBd]SBd]SBd]SBd]SBd]SBd]SCdmWCdmWCdmWDe=[De=[De=[FeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMODdmGEe=KEe=KEe=KFeMOFeMOFeMOGe]SFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOEe=KEe=KEe=KE
e=KEe=KEe=KEe=KEe=KFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMODdmGDdmGDdmGD
dmGDdmGDdmGDdmGDdmGFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMODe=CDe=CDe=CDe=CDe=CDe=CDe=CD
e=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=?Fe=?Fe=?F
e=?Fe=?Fe=?Fe=?Fe=?Fe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?F
e=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?F
e=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Edm;Edm;Edm;Edm;Edm;Edm;Edm;E
dm;Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7I
e=7Ie=7Ie=7Ie=7Ie=7Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3H
dm3IeloFe<cCd<SEclSId<cLdloOdm7Odm7;bKjf/ZNETX=iMF=UHTeIECa>Bbm8A2MKCC1JC2mJC2mK
CC1KCC5HC31EBBeBARYKCbeICB]JCBeMCc9MCc=KC39NCcETE3eWG4QYGdeaIeEgKeioN6N6Og29PgJ<
QWV3Off5P75WI5FHUhV0OW>LW92JVHnMWYBCThFRXINMVYF3P7`J5a>5PWfMW9:KVhfMWi>MWi>MWI6G
Uh^?SH:6PWMkMfaeLFIYI4mUH4]NFDAIE3mHDciJED1MF4=PFdILESmIDcaGDCYGDCYJE3eMEd1OFD9O
FD9EE3YHE3]IECeKECiOEd1QFD9UFTAVFdERGT9LF3aNFD1OFT5KECiOFD9JDcm6?b/41P0Y:1iHDdAK
DSiJD3QPEcaECSEMF3mJDcYDCcICCCIEDCUED3]@C3U?CSYCDSi0AS=5BCI5BCI7BCI>CSaGEdELFTQI
EdEMEdAMEdAMEdANF4EOFDIPFTMPFTMQFdQNG4YOGD]QGdeQGdeQGdeSHDmVI59YIeESJ5=VKEQ`MV=k
Pg:6SGj<UXJ>V8^>V8^KY9ZJXiVIXYRGX9JEWYBEWIJFWYNHX9VLVi6TXiVYZ9jSXiNATH=eMFMIFTY7
B3Q<BCA8AC19AS5>BcI?C3M;B3=:Ac9>BcI6AbE2@b4n?am1@B=8B2Y>CC5?CS9?CSA>Cbm:Bb]2@R@j
>Q`f=ATh=adn?B=4@RXn?RHj>BA;BSEIF4AKFDMfLfBQWY2f/jG2a[_5a[c7b;k;b/3>c<;@c/CCc/GD
clK7al73`kg3`kg7al79bL?9bL?<c<KBd/cAd<KAd<KAd<KBdLOCd/SCd/SDdlWDdlWEd<OEd<OEd<OF
dLSFdLSGd/WGd/WGd/WHe<WHe<WIeL[IeL[IeL[IeL[He<WGdlSIeL[IeL[IeL[IeL[IeL[IeL[IeL[I
eL[He<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WH
e<WHe<WHe<WHe<WHe<WFd/OFd/OHe<WIeL[IeL[IeL[He<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WH
e<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WJe<OJe<OJe<OJe<OJe<OJe<OJe<OJe<OIe/SIe/SIe/SI
e/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SLe/WLe/WLe/WLe/WLe/WLe/WLe/WL
e/WKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WL
e/WLe/WLe/WLe/WLe/WJelWJelWJelWJelWJelWJelWJelWJelWLe/WLe/WLe/WLe/WLe/WLe/WLe/WL
e/WMel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[MfLOMfLOMfLOMfLOMfLOMfLOMfLOMfLOLe/WLe/WMel[M
el[Mel[Nf<_Nf<_Nf<_Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[MfLOMfLOMfLOMfLOMfLOMfLOMfLOM
fLOMfLOMfLOMfLOMfLOMfLOMfLOMfLOMfLOLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KKelGKelGKelGK
elGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGJe/CJe/CJe/CJe/CJe/CJe/CJe/CJ
e/CJe/CJe/CJe/CJe/CJe/CJe/@00=K?d]K?d]K?d]K?d]K?d]K?d]K?d]K?d]GAemGAemGAemGAemKB
f=KBf=OCfMOCfMCBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf<k<d][Hg]gKhM7?eLW7cLk<d]?Aem;@e/[8
c]OEfl[8c/g;dM;@e/c:d=SFg=gKhMCBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=CB
f=CBf=CBf=CBf=7Aem7Aem7Aem7Aem;Bf=;Bf=?CfM?CfM7Aem7Aem7Aem7Aem;Bf=;Bf=?CfM?CfM;B
f=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=?CfM?C
fM?CfMCDf]CDf]KEemKEemKEemKEemKEemKEemKEemKEemCCeMGDe]GDe]GDe]KEemKEemKEemOFf=KE
emKEemKEemKEemKEemKEemKEemKEemGDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]KEemKEemKEemKEemKE
emKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemGDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]KE
emKEemKEemKEemKEemKEemKEemKEemCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMKEemKEemKEemKEemKE
emKEemKEemKEemCDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KD
e=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKD
dmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKD
dmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKD
dmKDdmKDdmKDdmGCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GDd=GDd=GDd=GDd=GDd=GDd=GDd=GDd=WD
dMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMSCd=SCd=SCd=SCd=SC
d=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd<O8_m3>a][Hc^;Ndn3JcmC;_/:gZK>XVWae
HFiWDeaF?e59<U16;UA;<5aA=UmD>EM8:5M8:5Q8:eM9;5Q<<5]>=5eB=eiC>5I=;5=::EE;;EeB=fAH
@6ULAW1RCgMYEgYbHGifIH=jK8V1M8b6NI2:Oi6=PY:=Q92=Oi6@PWIeIj6QUHN8OZ2QUibOUY^NUJ6P
UZf[Xj6NVWYfMB@P7iVFTZBRVZ:QUj6WW:>YWZR/XJR/XJNXWZ>RV9bKTIVGSHj;O8J3M7UfIfeZFfAQ
DUiKC5UFAeICA5iH@EYD?EI@>EI@>EUC?5eG@61J@f5KA5QG?EQG?EYF?U]G?eiG@f5HA6=IAfEKBF=O
@eiJ?V9MA65L@emI@VEOB5iG@dHo:`0202//8U]HBEiG@f=L@fIOA59==5UE?5YE?5IA>5A@>5IB>UAA
?4i=>Dm>>U9A?DI<>DM=>TQ<>DI:=de??5MGAEYJB5QHAUaHAEaHAEaHAEaHAEeIAUiJAf1LBF1LBF5N
BF=PBf=PBf9OBV5NBF5NBF=PBfERCEYNAEYMAeUNBEeQCV5WEVI]GVieJ79hKGf6NHF>PI2HSIVQUYjV
W:2WX::YXZ>ZXjNWXJNWXJVZXK2aZ;Ff[:NYWH:4N65SEeYF@e1<>Da8=Dm;>4m;>4]7=4i:=eMC@4e>
;TU::TE59dA49TA39d919cdl8STh7SXk6cdn7Slo8D108T0o8cln940o9D90:4E7:STk7Sho9C/j9CHe
8F=QCj6NSkNdY[6dZk6dZkFf[KNh[kbj/[nl]<6n]/:o]kBh/[6e[k:f/;Nk]KVm]kVm]k^o^L34_/6o
]l?1^LG3^lS6_/_9`Lg;`m3>a]7?amC?a]G@amKAb=OBbMSCb]WDbm[Ec=_FcMOCb=SDbMWEb]_Gc=_G
c=_Gc=_Gc=[FbmSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMOCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OC
b=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=GAa]KBamOCb=SDbMSD
bMSDbMSDbMOCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=WC
a]WCa]WCa]WCa]WCa]WCa]WCa]WCa]SEamSEamSEamSEamSEamSEamSEamSEamSEamSEamSEamSEamSE
amSEamSEamSEamcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbM[Dam[Dam[Dam[Dam[Dam[Dam[Dam[DamcF
bMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbM[GbM[GbM[GbM[GbM[G
bM[GbM[GbM[GbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMgGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gI
amgIamgIamgIamgIamgIamgIamgIamcFbMcFbMcFbMcFbMgGb]gGb]kHbmkHbmgGb]gGb]gGb]gGb]gG
b]gGb]gGb]gGb]gIamgIamgIamgIamgIamgIamgIamgIamgIamgIamgIamgIamgIamgIamgIamgIamcH
a]cHa]cHa]cHa]cHa]cHa]cHa]cHa][Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=_GaM_GaM_G
aMcHa]cHa]cHa]WE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE``00e/oBe/oB
e/oBe/oBe/oBe/oBe/oBe/oBe=3Fe=3FeM7GeM7Ge];He];He];He];Hdm7Gdm7Gdm7Gdm7Gdm7Gdm7G
dm7Gdm7G`/36dLoEg=[PfmWOemGKf=KLfmWOf]SNcL_AfMOMc/cBfMOMemGKc<[@f=KLcL_Adm7Gdm7G
dm7Gdm7Gdm7Gdm7Gdm7Gdm7Ge=;He=;He=;He=;He=;He=;He=;He=;Hd=3Fd=3FdM7GdM7Gd];Hd];H
d];Hd];Hd=3Fd=3FdM7GdM7Gd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];H
d];Hd];Hd];Hd];Hd];Hd];HdM7Gd];Hd];Hd];Hdm?Idm?Idm?Ie=CJe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe=?EeMCFeMCFeMCFe]GGe]GGe]GGemKHe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe=?Ee=?E
e=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGdm;Ddm;D
dm;Ddm;Ddm;Ddm;Ddm;Ddm;De]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?BeM?B
eM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?B
eM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?B
eM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?Be=;Ae=;Ae=;Ae=;Ae=;Ae=;A
e=;Ae=;Ae=??e=??e=??e=??e=??e=??e=??e=??f=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@
f=?@f=?@f=?@f=?@f=?@f=?@em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?
em;?em;?f][Df]S@e=;7b<Ff/ZbITh]dLfY?GE@iGeHeGU@fG54cFThbFDX`FDL`ET@]ED</HU<cH54a
Fdd`EDT]DTL/DDL_DdPbDd/dFeHgF58eFe@iJ619MFaHOG=RPgQZRGeaRX9eSHEhTXYmUHn4Ui:9V9>:
UiB<UiB<UYB9UYJ:PX9fXjBJT9>:XZFLX:BNVinIYjRO/k>]YZBSLFm_<S0`XZ2OYZJPZZ^RY:^TYZfV
Z:nX[;2Z[k6[[[2Z[jnY[ZjX[ZbRYjFKW9Z@THn5QH=iMgE[JVQNHEmEIF1;HEa7FeI1FE@oFeI1GUU4
HEa7HUe8F5ToFUToFELoFeLoG5M2GeQ5HeU8I5Y9Gea0G5TmH5a3Ge]2GUY2IF59GEQ3@SdX0080:b`R
De11DD`gGULnIUm4DdheGUY1GEPoF5@kEU8jEU@lDU4lCTdiC4diD54m@T/gAT`iAT`iAd/hBdllE5I3
EUI4DU90F5U5EeQ4EUM3EUM3EUM3EeQ4FEY6FU]7FELoFeU1GUa4Gee5GUa4Gee5HEm7Hf59I6E;HV9:
Fee7EeQ4DeA4DUE6E5E;EEU>FF5@HVYIKgIWO8=fQhf2TIJ=Vj2GXJFO/[>a[Zn[ZJZVZjfW];J`]kZa
Z:bQUIV>K6QEEe=0Ad<`B4@aBTHcAd<`BTHcDDdjADDWADDWAD@XAD@ZAD@ZA48Z@T0X@3dX?3`N@40R
@T4U@T4U?C`R=cDM<c4I<BlGAdXZ>S`N?T0S>3TO=3<NK6YHZJJG[Z^LYjbSZZfTZjjU[ZnV[k2W/[2X
];6Y]K:ZZ[2[Z:jYZJnZ[[B_/;Ja[K>^[K>^/KNb];F/]KJ]][N^^KZa^kbc_Kje_l2g`<6hb/FlblJm
c<Nnc/W0d<_2dlk5e<o6eM37dlo4e=35e];7em?8fMG:fMG:fMG:fMG:f=C9f=C9f=C9f=C9f=C9f=C9
f=C9f=C9em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8
em?8em?8em?8em?8em?8em?8eM76e];7em?8f=C9f=C9f=C9em?8em?8em?8em?8em?8em?8em?8em?8
em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6f=G7f=G7
f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7fmG8fmG8fmG8fmG8fmG8fmG8
fmG8fmG8f]C7f]C7f]C7f]C7f]C7f]C7f]C7f]C7fmG8fmG8fmG8fmG8fmG8fmG8fmG8fmG8fmG8fmG8
fmG8fmG8fmG8fmG8fmG8fmG8fMK8fMK8fMK8fMK8fMK8fMK8fMK8fMK8fmG8fmG8fmG8fmG8fmG8fmG8
fmG8fmG8g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=S6g=S6g=S6g=S6g=S6g=S6g=S6g=S6fmG8fmG8
g=K9g=K9gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:g=S6g=S6g=S6g=S6g=S6g=S6
g=S6g=S6g=S6g=S6g=S6g=S6g=S6g=S6g=S6g=S6fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5f]K4f]K4
f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4fmO5fmO5g=S6g=S6gMW7fMG3fMG3fMG3fMG3fMG3fMG3
fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3003Fcm;Fcm;Fcm;Fcm;Fcm;Fcm;Fcm;Fcm;Dd=KDd=KEdMOE
dMOEdMOFd]SFd]SFd]SCdMOCdMOCdMOCdMOCdMOCdMOCdMOCdMOMfn7CdMO<b]3=bm7AcmGBd=KBd=KC
dMOBd=KFe=[8a/cGeM_Dd]S<b]3OgN?;bLoCdMOCdMOCdMOCdMOCdMOCdMOCdMOCdMODd]SDd]SDd]SD
d]SDd]SDd]SDd]SDd]S@d=K@d=KAdMOAdMOAdMOBd]SBd]SBd]S@d=K@d=KAdMOAdMOAdMOBd]SBd]SB
d]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SAdMOAdMOBd]SB
d]SBd]SCdmWCdmWCdmWFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMODdmGEe=KEe=KEe=KFeMOFeMOFeMOG
e]SFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMODdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMODdmGDdmGDdmGDdmGDdmGDdmGDdmGD
dmGFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOCdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?E
dm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Ee=3Ee=3Ee=3E
e=3Ee=3Ee=3Ee=3Ee=3Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;E
dm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;E
dm;Edm;Edm;Edm;Edm;Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7DdloDdloDdloDdloDdloDdloDdloD
dloHdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Gd/oGd/oGd/oG
d/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oBd/bl^[:HUX]hM69QGDEHDSEGDBiI
DBaHCBMHCBMIBRUGB2QHABYLABmPB3ATC3YIBRYIBbiJC31IC39FC3AECCIECSYGD3aTHDEOG41RGTIa
K5MoN6N6OW69P7J;PWVBRWfES8:HTXNKUXfOVI:OW9BOViJNViJMWI6MWI6<SH>ZZj:MX9NX[:J]/J^S
Yj:XZJ2g][:/ZZU^Jfdo?3jYYjJ[ZZJf]jj//jj[/ZfZ/:^Y[jZ[[jZ^[j^_/:b`/Jf_ZZN]Z:F/YjBZ
YJ:VXIjLUiB>RHJ4Oga_JUEZIE1SGTUOFTEOFTERGDQTGdYUH4]IFciIFT1IEcmIET5LET=NETEPEdUS
F4YJEc]HECULF3mLF3mKEcmSGdMKET4n>B@0100Z:b56@c@l=b9>AbiMFCeED3MWHdYOFd9JESeHE3aG
ECeCDSe?CSY=CSY@DCdlAC50BCE4BSM4BSM:CS]@DSm>D3e9BCM>Dci=DSe<DCa;D3];D3]<DCa=DSe>
DciCDCUFE3aJF41MFd=MFd=NG4AQGdMRH4QNGD5PGdERH4QQH4aLG4aIF4YFED]EE4YCF4=EFDIGFTYJ
GDiQHeM_L6IoP7N;S8>AU9:RYJ>_/[2`]:na]Jnf^[Bi_[Fg_;>JUX=iMF9MFDIGDd1HE45CCca?BcQB
CS]=C31=C39=C39;BC58ARi6@bi5@Bi5@Bi2@BE3@RI2@BM0?bDm>b<l>B@m>RDo?2Lk?a`e>1Q3ABM5
ARa:BCB7QW:i]ZN[Z9VZ[ZRZ[ZR/[ZR/[ZR^[ZR`[JR`[JRa[JRZ/:^X[ZVY[jZ^]:n^]:nZ/:^X[ZVZ
/:^a/J^`/:Z`/:Z`/:Z`/:Z`/:Z`/:Z`/:Zf/JRg/ZVi]:^l]jjn^K31_;?3_[G4_kK=bKk>b[o@c<7B
c/?Dd<GEdLKEdLKEdLKHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WGdlSGdlSGdlSGdlSGdlSGdlSGdlSG
dlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSEdLKEdLKGdlSH
e<WHe<WHe<WGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSG
dlSIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKHeLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOH
eLOHeLOHeLOHeLOHeLOKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSJe<OJe<OJe<OJe<OJe<OJe<OJe<OJ
e<OKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSIe/SIe/SIe/SI
e/SIe/SIe/SIe/SIe/SKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSLe/WLe/WLe/WLe/WLe/WLe/WLe/WL
e/WLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KKeLSKeLSLe/WLe/WLe/WMel[Mel[Mel[Mel[Mel[Mel[M
el[Mel[Mel[Mel[Mel[Lf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KL
f<KKelGKelGKelGKelGKelGKelGKelGKelGJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CIeL?Je/CJe/CK
elGKelGLf<KMfLOMfLOIeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL<00=C>
cmC>cmC>cmG?d=G?d=K@dMK@dMK@dM;?dM;?dM;?dM?@d]?@d]CAdmCAdmCAdmGAemGAemGAemGAemGA
emGAemGAemGAem?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=CAdmCAdmGBe=GBe=KCeMKCeMKCeMKCeM?B
e=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=;@e];@e]?Aem?AemCB
f=CBf=CBf=CBf=?AemCBf=CBf=CBf=GCfMGCfMGCfMKDf]?Aem?Aem?Aem?Aem?Aem?Aem?Aem?Aem?B
e=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?AemCBf=CBf=CBf=GCfMGCfMGCfMKDf]CCeMCCeMCCeMCCeMCC
eMCCeMCCeMCCeM?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?CdmCDe=CDe=CDe=GEeMGEeMGEeMKFe]KD
e=KDe=KDe=KDe=KDe=KDe=KDe=KDe=?CdmCDe=CDe=CDe=GEeMGEeMGEeMKFe]CDe=CDe=CDe=CDe=CD
e=CDe=CDe=CDe=?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?CdmKD
e=KDe=KDe=KDe=KDe=KDe=KDe=KDe=?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?CdmCDe=CDe=CDe=CDe=CD
e=CDe=CDe=CDe=KDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmWDdmWDdmWDdmWDdmWDdmWDdmWDdmWDdmSC
d]SCd]SCd]SCd]SCd]SCd]SCd]SCd]WDdmWDdmWDdmWDdmWDdmWDdmWDdmWDdmOBdMOBdMOBdMOBdMOB
dMOBdMOBdMOBdMSCd]SCd]SCd]SCd]SCd]SCd]SCd]SCd]GDd=GDd=GDd=GDd=GDd=GDd=GDd=GDd=SC
d=SCd=SCd=SCd=SCd=SCd=SCd=SCd=GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]CCcmCCcmCCcmCCcmCC
cmCCcmCCcmCCcmG@cMG@cMG@cMKAc]KAc]OBcmOBcmOBcmSEcMSEcMSEcMSEcMSEcMSEcMSEcMSEcMCE
c=CEc=KDc=KDc=ODc=ODc=WCc=WCc=WCc=WCc=WCc=WCc=WCc=WCc=WCc=WCc=[Ac][Ed]3Bc=?JdlcD
b/W:`=3;`[ZaYh9fGWEYDFAH@5Y<=EU9<UY:<e]9<UY8<F1;;ee;;Ua:;EU9;5U::UM::UE;:EE;:Ee=
<5U;;Ua><F5E>FEH?VAI?VEK@fYPB6eWE79[FWUeHh9mKXN4MHZ9Nhb:Ohb<P9>CQiJFRYZISibKTIjL
U:2MV:BQW:NTX:6UVYRKTYBGSZf_ZJBVX;Be/Jb]ZjRYYjV[YK^m]jnaZf=UGda>B:b^Z:BVX:FWXJBX
XjN[YZ^_ZZjb[K2d[jnc[Zfa[:^_ZZn`[;2a[K:c[k:c[k2a[Jb]ZJNXY:BUXIbKTHn?PgemKfe]FfET
Cf9SBFASAfEUAeAF@5EG@EQG@UMF@EQE@5]F@EaG@UiIA5YIAE]JAUIE@De<>4]:=Te<>4U8=40o:adH
2BLR4c@`7Sdi9T=0:dY8<5AC>EaK@EaK?eEF?5AD?59C?dm??dM7>D93>DA5>cQ0=CY2=d17>TI:?TU>
?da??da??de>?U=@=5IE>eUJ@5AH?deC?4M@>dMC?D]F@UAG?U=F?E=F?5IG?E]J?UiN@6=Q@fESAE]M
AeaNB5ePBUeOBeYNBeEKB59HAe1FADIB@4]EA4iHAe1HAeAGAeUJBV5RDVQXF6abHGQnKHN<OI6ERI^L
TZ>TVj^[YJn^ZZV`ZH6:OEUUCe1L@5AP@UMPAEENA5ELAe]C@UMA?U==>Tm:=DY8<4U7;dM8;TM8;TU6
:TI39d8n9Clk8Sdi8C/f8CLb7C@^6cPd64I1:3Lc6bXV4h>0LInNT:NVW:b]XjR[XZV/Xj^]Yjj_Zjn`
[:j_[Jf^[:f][J^^YJ^^YJ^^YJ^^YJ^^YJ^^YJ^^YJ^^YJb_YZb_YZb_YZb_YZb_YZb_YZb_YZb_YZVa
YjZ_YZZ_YZjaZ;6dZkFf[KFf[KJd[;Nk/;Rl/KVm/[^o];c0]Kk2]ko3^<34^LG9_/G9_/O;`<_<`/o>
a=7@a]?AamCBb=G?b=G?b=KAb=KBamODa]SEa]SFa=WHa=[DbMWCb=SBaMWDaMcEa]cEa=[C`]OA_]WC
a]WCa]WCa]WCa]WCa]WCa]WCa]WCa]SBaMSBaMSBaMWCa]WCa][Dam[Dam[DamWCa]WCa]WCa]WCa]WC
a]WCa]WCa]WCa][Dam[Dam[Dam[Dam[Dam[Dam[Dam[DamWCa]WCa]WCa]WCa]WCa]WCa]WCa]WCa]SD
`]SD`]SD`]WE`mWE`mWE`m[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=_GaM_GaM_GaM_GaM_G
aM_GaM_GaM_GaMWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mgFaMgFaMgFaMgFaMgFaMgFaMgFaMgFaM_D
`m_D`m_D`mcEa=cEa=gFaMgFaMgFaM[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=_GaM_GaM_GaM_GaM_G
aM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaMcHa]cHa]cHa]cHa]cHa]cHa]cHa]cHa]gF
aMgFaMgFaMgFaMgFaMgFaMgFaMgFaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaN3Jan3Jan3Jan3Jan3J
an3Jan3Jan3JamkHaMkHaMkHaMkHaMkHaMkHaMkHaMkHaMcEa=cEa=cEa=cEa=cEa=cEa=cEa=cEa=cF
`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`m_E`]_E`]_E`]_E`]_E
`]_E`]_E`]_E`]_D`m_D`m_D`m_D`m_D`m_D``00e<k?e<k?e<k?eLo@eLo@eLo@e]3Ae]3Ad/oAd/oA
d/oAdm3Bdm3Be=7Ce=7Ce=7CeM7GeM7GeM7GeM7GeM7GeM7GeM7GeM7Gdm;Ddm;Ddm;Ddm;Ddm;Ddm;D
dm;Ddm;De=7Ce=7CeM;DeM;DeM;De]?Ee]?Ee]?Edm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;D
dm;Ddm;Ddm;Ddm;Ddm;Ddm;Dd]3Fd]3Fdm7Gdm7Gdm7Ge=;He=;He=;Hdm7Gdm7Ge=;He=;He=;HeM?I
eM?IeM?Idm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm7Gdm7G
e=;He=;He=;HeM?IeM?IeM?Ie=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Edm;Ddm;Ddm;Ddm;Ddm;Ddm;D
dm;Ddm;Ddm?Cdm?Ce=CDe=CDe=CDeMGEeMGEeMGEe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDdm?Cdm?C
e=CDe=CDe=CDeMGEeMGEeMGEe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Ce]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Ce=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe]CCe]CCe]CCe]CCe]CCe]CC
e]CCe]CCfMCCfMCCfMCCfMCCfMCCfMCCfMCCfMCCf=?Bf=?Bf=?Bf=?Bf=?Bf=?Bf=?Bf=?BfMCCfMCC
fMCCfMCCfMCCfMCCfMCCfMCCem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Af=?Bf=?Bf=?Bf=?Bf=?Bf=?B
f=?Bf=?BeMC@eMC@eMC@eMC@eMC@eMC@eMC@eMC@f=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@eM?BeM?B
eM?BeM?BeM?BeM?BeM?BeM?Be=??e=??e=??e=??e=??e=??e=??e=??eM3=eM3=eM3=e]7>e]7>em;?
em;?em;?f=G=f=G=f=G=f=G=f=G=f=G=f=G=f=G=e=G<e=G<e]C<e]C<emC<emC<fM?<fM?<fM?<fM?<
fM?<fM?<fM?<fM?<fM?<fM?<e/g9g]SCdLo7eMO;cM31[:bJRhEbH5I4H5DjFDhcDTL/DTD[F4T_G4dc
GdhdGD`bGdd`GT`_GD/^FTX]EdXZF4/[F4d]FDh^GU0cGDlbGe<gJ5a0KF97KF=;LFM?MfaFNgASOGUW
Pgm]RHIgShanTY63Ti>7U9B8V9Z>VY^AWYnEX:6HXJ:IXj>MYZFQZJRTYJROVijEU9N>ZZbVW9fIZ:VU
WYnMVIZHTiF?X::LWInIIVQRDeE?WInITYB>UYRBTiJDUiZHWj:PYjZX[[6_/[Fc];Ne]KRf/;6_/[>a
/kBb];Fc/kBb/K:`[k2^[Jj/[k2WZZ^RXZ6GUiJ8R8QfNGQTJ6MBH5i6E5M1EUQ2F5Y4FUU4G5U4FeQ3
GEQ3GEQ3G5]7GUe9FeY6E5<oDe8nF5M3EeI2DU4mAD0aBTDfD4`jDDdjDDhiDDlgDe4iEUDkE5DkCdlg
CTdhCDhjBT/kA4@f@44g@d@j<CL/=3X_>Shc?T8f@dHgAdLiB4TiB4TiDDdkEU90FEI7F5Q8E5E5E5E5
EEQ9FEa=Fe];Fe];GE]9H5a:HUi;If9=JFA?K6EAH618H618GF17G5i8F5Y6DeQ3D5A1C58oB54mBDll
BDllCE4nDeE2FEU7Gee;HEm=E5I3FUa9HF9BIFQIKFmSN7U_PHEjR8^2Y::JS8b0K6aJEUU0EeTlGUe3
G5Q0DdhiGEI3FU<oEE0kDDdeCTXbCDT`C4/aC4/_@T4W?chT?3/Q>SPP>CHQ=c@O=30M<RhK<BdD>3@L
<c0KA4<_S8alYjJHXj:HY:>IYjZQZJbSZjfW[JnY[Zn[[Zn][Jj/[:f[ZjjUZjjUZjjUZjjUZjjUZjjU
ZjjUZjjU[:nV[:nV[:nV[:nV[:nV[:nV[:nV[:nVZ;2VZJjUZ:fT[:nV[k:Y/[>Z/[>Z/k6Y/;BY/KFZ
/KFZ/kN/];R]]KV^][Z_][Z_^Kfb^[jc^knd_l2f`/6ga<>ia/BjalFkclW2d<[3dLc3d/k3dm32e=72
eM?1eM?1em?8e];7f=;5fM?6fmK7gMK5fmC3fM;1fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6f=;5f=;5
f=;5fM?6fM?6fM?6f]C7f]C7fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6f]C7f]C7f]C7f]C7f]C7f]C7
f]C7f]C7fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6f=C2f=C2f=C2fMG3fMG3fMG3f]K4f]K4f]K4f]K4
f]K4f]K4f]K4f]K4f]K4f]K4fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fMG3fMG3fMG3fMG3fMG3fMG3
fMG3fMG3gMK5gMK5gMK5gMK5gMK5gMK5gMK5gMK5fmC3fmC3fmC3g=G4g=G4gMK5gMK5gMK5f]K4f]K4
f]K4f]K4f]K4f]K4f]K4f]K4fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5
fmO5fmO5g=S6g=S6g=S6g=S6g=S6g=S6g=S6g=S6gMK5gMK5gMK5gMK5gMK5gMK5gMK5gMK5fmO5fmO5
fmO5fmO5fmO5fmO5fmO5fmO5gmW6gmW6gmW6gmW6gmW6gmW6gmW6gmW6g]S5g]S5g]S5g]S5g]S5g]S5
g]S5g]S5g=G4g=G4g=G4g=G4g=G4g=G4g=G4g=G4g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3
g=K3g=K3g=K3g=K3g=K3g=K3fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmC3fmC3fmC3fmC3fmC3fmC3
003CcLkDc/oDc/oDc/oEcm3Ecm3Ecm3Ecm3Bcm7Bcm7Bcm7Cd=;Cd=;DdM?DdM?DdM?EdMOEdMOEdMOE
dMOEdMOEdMOEdMOEdMOCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CDdM?DdM?DdM?Ed]CEd]CEd]CFdmGF
dmGCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CBd=KBd=KBd=KC
dMOCdMOCdMODd]SDd]SCdMOCdMOCdMODd]SDd]SEdmWEdmWEdmWCdMOCdMOCdMOCdMOCdMOCdMOCdMOC
dMOCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCdMOCdMOCdMODd]SDd]SEdmWEdmWEdmWDdmGDdmGDdmGD
dmGDdmGDdmGDdmGDdmGCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCdm?Cdm?Cdm?De=CDe=CEeMGEeMGE
eMGFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CCdm?Cdm?Cdm?De=CDe=CEeMGEeMGEeMGDe=CDe=CDe=CD
e=CDe=CDe=CDe=CDe=CCdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Fe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CCdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?De=CDe=CDe=CD
e=CDe=CDe=CDe=CDe=CFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Ie=?Ie=?Ie=?Ie=?Ie=?Ie=?Ie=?I
e=?Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Ie=?Ie=?Ie=?Ie=?Ie=?Ie=?Ie=?Ie=?Gd]7Gd]7Gd]7G
d]7Gd]7Gd]7Gd]7Gd]7Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3E
e=3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;DdloDdloDdloD
dloDdloDdloDdloDdloEd<gEd<gEd<gFdLkFdLkGd/oGd/oGd/oHeLgHeLgHeLgHeLgHeLgHeLgHeLgH
eLgDeLcDeLcFe<cFe<cGe<cGe<cIdlcIdlcIdlcIdlcIdlcIdlcIdlcIdlcIdlcIdlcIcLOUg=>l]ZVI
V8B3PFUOFciBBRa>ABAICc5FC2iEBbeHCBmMCc9MCc9KBbiGAbYNC2mMBbiJBReIBBaIBbiJCc5MDSAN
E3IVFSiUFCeZGdAdJDihKUIhL5UlM5f1N6B6PW29QG><RGZASWnDThFGUh^JVXjKVY2MWYBOX9JRXiZS
Y9^TY9jUY:2XYj>ZZJF^/JRTYijMWiV`/ZbPXIfZZjVPXInKVi^KW9ROX9bWZ:B;S8QoP7bYZZJJViNT
YJ6RYJ>UZ:JZ[J^`/k6d]kFf^KNf^KNf^KNd]K>d]K>e][Bf]kFg^;Jg^;Jh^KNh^KNc];:e][:h^;:g
]Jf^[J>OWI:<Rgf1OVmWJeQUIeAOHDiJFTQIEdEIEdEMFDMOFdUFEd=JFdMJFdMEET9CE41FEd=HFDEG
F4ACCSmDCd1FDT1GDd5GDd1GE3mGE3mGE3mADCU<BcI9BSI:BSQ8BCU1A3E1@cM2AS/h>c8j?C@o@3I1
@cM6ASY8AcU9B3Y:BSY<ACaABT5ECTEDD4EBCT=BCd5EDTAHEDMGED]GED]IEDYJET]NF4]RFdaTGDiU
GTmRHdUQHTQNGdEJGDAFFD=DEd5AET5AET5DFDABE41@DSiEET9MGTYVIE5WIU9XI55RHDePGTaLG4YK
G4aIGdiJHE9MIeMQJUejMfmhM6UXHeAED3]BC3EPECmPDceCAC9HDciED3]@C3A<B2m9ABa8ABU8ABU8
ARPj>R8h>20e=Add<ahd<alc<Qh`;Q`^;1Xa;aL[:1<c<Qi/JURHV8R^[InTY9RUY9ZVZYnWZZ6Z[JB/
[ZR^[j^^[j^][Zb/[J^[[ZF[[ZF[[ZF[[ZF[[ZF[[ZF[[ZF[[ZF/[jJ/[jJ/[jJ/[jJ/[jJ/[jJ/[jJ/
[jJW[jFX[JBW[:>Z[JB/[jJ_/:N_/:N_[JF[[jB[[jB//:F//:F]/JJ]/JJ]/JJ^/ZN_/jR`]:V`]:Vc
]:Zf]J^g]Zbi]jfi]jg1_[K2`;K3`KO5`kS7aK[9b;[:bK_;bk_=bl7=bl3@c<7Bcl7HdlCKe<GJdl;J
d/7Hd/GHd/GHd/GHd/GHd/GHd/GHd/GHd/GGdLCHd/GHd/GHd/GIdlKIdlKIdlKIdlKHd/GHd/GHd/GH
d/GHd/GHd/GHd/GHd/GJe<OJe<OJe<OJe<OJe<OJe<OJe<OJe<OIdlKIdlKIdlKIdlKIdlKIdlKIdlKI
dlKHe<;He<;He<;IeL?IeL?IeL?Je/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CKelGKelGKelGK
elGKelGKelGKelGKelGIeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?Me/GMe/GMe/GMe/GMe/GMe/GMe/GM
e/GKe<?Ke<?Ke<?LeLCLeLCMe/GMe/GMe/GJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CKelGKelGKelGK
elGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGLf<KLf<KLf<KLf<KLf<KLf<KLf<KL
f<KMe/GMe/GMe/GMe/GMe/GMe/GMe/GMe/GKelGKelGKelGKelGKelGKelGKelGKelGMelCMelCMelCM
elCMelCMelCMelCMelCNf<GNf<GNf<GNf<GNf<GNf<GNf<GNf<GLeLCLeLCLeLCLeLCLeLCLeLCLeLCL
eLCLe/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Je<7Je<7Je<7J
e<7Je<7Je<7Je<7Je<7Jdl;Jdl;Jdl;Jdl;Jdl;Jdl800=?=c]?=c]?=c]C>cmC>cmG?d=G?d=G?d=;?
dM;?dM;?dM?@d]?@d]CAdmCAdmCAdmC@e]C@e]C@e]C@e]C@e]C@e]C@e]C@e];Adm;Adm;Adm;Adm;A
dm;Adm;Adm;Adm?@d]?@d]CAdmCAdmGBe=GBe=GBe=GBe=;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;A
dm;Adm;Adm;Adm;Adm;Adm;Adm;Adm7?eM7?eM;@e];@e]?Aem?Aem?Aem?Aem;@e]?Aem?Aem?AemCB
f=CBf=CBf=GCfM?Aem?Aem?Aem?Aem?Aem?Aem?Aem?Aem?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=;@
e]?Aem?Aem?AemCBf=CBf=CBf=GCfMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeM?Be=?Be=?Be=?Be=?B
e=?Be=?Be=?Be=;Bd]?Cdm?Cdm?CdmCDe=CDe=CDe=GEeMKDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=;B
d]?Cdm?Cdm?CdmCDe=CDe=CDe=GEeMCDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?CdmKDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?CdmCDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=KDdmKDdmKDdmKDdmKD
dmKDdmKDdmKDdmWDdmWDdmWDdmWDdmWDdmWDdmWDdmWDdmOBdMOBdMOBdMOBdMOBdMOBdMOBdMOBdMWD
dmWDdmWDdmWDdmWDdmWDdmWDdmWDdmOBdMOBdMOBdMOBdMOBdMOBdMOBdMOBdMOBdMOBdMOBdMOBdMOB
dMOBdMOBdMOBdMCCcmCCcmCCcmCCcmCCcmCCcmCCcmCCcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmCB
dMCBdMCBdMCBdMCBdMCBdMCBdMCBdM?Bc]?Bc]?Bc]?Bc]?Bc]?Bc]?Bc]?Bc]G@cMG@cMG@cMKAc]KA
c]OBcmOBcmOBcmODc=ODc=ODc=ODc=ODc=ODc=ODc=ODc=?Dbm?DbmGCbmGCbmKCbmKCbmSBbmSBbmSB
bmSBbmSBbmSBbmSBbmSBbmSBbmSBbmO=`mW@`i::NEiG?U=;;D@l5e9886aQ=F1G=UiE=5eD<eiC<emB
<U]>;UI79e528UM8:5I6:EM7:UM9;5U=<EmC=fAI?VQM@W9WC79VCWE[DgicGH5iHWmhI89kJ8EoK8^6
Mh^8NHn<OI:APiJFRYZJSYbMTijOUIbPUIjQV:2SVZ6SWJ6RWZ:SWjBUXjJWYJb`ZZFYXj2TW[Jj]JNZ
Z;>f]:b^[ZV[ZkBh/jfa[;^o^[Jj]K6e/;c0^jnc[[c0^kRj^[Vk^k^m_K^m_K^m_KVk^kJh^;Fg]kJh
^;Jh^;Fg]kFg]kJh^;Rj^[Zl_;^m_K:d]K>e][Jf][Vj^;^j][Zg/[Ba[:n]YHfBPh66Mg5dIF=SEEYJ
C5YIBeaKCF1MCeIFA5UIAe]KBEUIAeEE@e9B@59B@55A?d]9=d]9=da:>4m=>e=A?eEC@EIE@EED@5=D
@4e>>TY:>4Y;>dI9>T95=T14>4A8?454>d95?4A5?4A5>dM7>dU7?4Y9>dY9>e5?A5ABAeQEAeQEAUID
@UAB@5ED@5IE@EEGBeIHC5IIBUUIBe]KBeaLBUmMBf1NC5UMA5MK@UAG@DmE?TaC?TaB?d]D@4aE@DY>
>dQ<>DQ<>D]??51D@EMIAUUKB5QJAemOCeYKBeEHB55IB4eGAdEB@T5A@49B@DA?ADYDB4aCATY=?DY:
>59>>eQA?UYA?E9?>Tm<=d]9<DQ4:dA09d8o8d8n8T8n8CDg8C<e7c0a7Bh_6bh^72`/72TY6BLW5bX[
5b0Q3CXj:8Z:NYVHRZ^ZW:FUVJ^[WjBXWJJZWjV/Xj^^YJf_ZJf^ZZf^ZZb]ZJ^^YJ^^YJ^^YJ^^YJ^^
YJ^^YJ^^YJ^^YJb_YZb_YZb_YZb_YZb_YZb_YZb_YZb_YZR`YZR]Y:N/XjZ]Y:b_YZn`Yjj_YZj/Y:b`
YJb`YJb`YJb`YJb`YJb`YJb`YJb`YJfaYZjbYjjbYk2aYk:aYk>bZ;BbZ;BbZ;>aYkBbZ;JdZ[Rf[;^i
[kfk/;nm//2n/kbm/kjm/l71]LW5^]7;_]O@`MW@`]S?`MSBaMSBaMSBaMSBaMSBaMSBaMSBaMSBaMOA
a=OAa=OAa=SBaMSBaMWCa]WCa]WCa]SBaMSBaMSBaMSBaMSBaMSBaMSBaMSBaMWCa]WCa]WCa]WCa]WC
a]WCa]WCa]WCa]WCa]WCa]WCa]WCa]WCa]WCa]WCa]WCa]SD`]SD`]SD`]WE`mWE`mWE`m[Fa=[Fa=WE
`mWE`mWE`mWE`mWE`mWE`mWE`mWE`m[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=WE`mWE`mWE`mWE`mWE
`mWE`mWE`mWE`mcEa=cEa=cEa=cEa=cEa=cEa=cEa=cEa=_D`m_D`m_D`mcEa=cEa=gFaMgFaMgFaM[F
a=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_G
aM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaMgFaMgFaMgFaMgFaMgFaMgFaMgFaMgFaM_G
aM_GaM_GaM_GaM_GaM_GaM_GaM_GaMcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mgGa=gGa=gGa=gGa=gG
a=gGa=gGa=gGa=cEa=cEa=cEa=cEa=cEa=cEa=cEa=cEa=_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E
`]_E`]_E`]_E`]_E`]_E`]_E`]_E`][D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[C`][C`][C`][C`][C
`][C`P00d/c=dlg>dlg>dlg>e<k?e<k?e<k?eLo@d/oAd/oAd/oAdm3Bdm3Be=7Ce=7Ce=7Ce=3Fe=3F
e=3Fe=3Fe=3Fe=3Fe=3Fe=3Fd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cdm3Bdm3Bdm3Be=7Ce=7Ce=7C
eM;DeM;Dd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7CdLoEdLoE
dLoEd]3Fd]3Fd]3Fdm7Gdm7Gd]3Fd]3Fd]3Fdm7Gdm7Ge=;He=;He=;Hdm7Gdm7Gdm7Gdm7Gdm7Gdm7G
dm7Gdm7Gdm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Dd]3Fd]3Fd]3Fdm7Gdm7Ge=;He=;He=;He=?Ee=?E
e=?Ee=?Ee=?Ee=?Ee=?Ee=?Edm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Dd];Bd];Bd];Bdm?Cdm?Ce=CD
e=CDe=CDeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?Cd];Bd];Bd];Bdm?Cdm?Ce=CDe=CDe=CDdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?CeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?Bf=?Bf=?Bf=?Bf=?Bf=?Bf=?B
f=?Bf=?Bem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Af=?Bf=?Bf=?Bf=?Bf=?Bf=?Bf=?Bf=?Bem;Aem;A
em;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Ae=??e=??e=??e=??e=??e=??
e=??e=??em;?em;?em;?em;?em;?em;?em;?em;?e=;Ae=;Ae=;Ae=;Ae=;Ae=;Ae=;Ae=;Adm;>dm;>
dm;>dm;>dm;>dm;>dm;>dm;>eM3=eM3=eM3=e]7>e]7>em;?em;?em;?emC<emC<emC<emC<emC<emC<
emC<emC<dmC;dmC;eM?;eM?;e]?;e]?;f=;;f=;;f=;;f=;;f=;;f=;;f=;;f=;;f=;;f=;;eLc2`KRZ
KfECCd<[IeXjIeXdHE<YH5<WEdh]ETd/ED`[ET/[F4/[EdXZEdPXEDHVDD8RD4<SDdDXETX^GU4gIEU1
JV18KfA>MfaFMFeFNg=LPW]WQX1]QX1]QX9`RXIdRXMhS8UkSXeoTi66V9R<VibBWj2GWj:IWZ6HX:>J
XZBNXjFOXZ>OXjBRYJJTYjNWY:^TWZBOW::M];VgYjbZ]KZi/;Be[k>d^[nm[[>a^l2n_/?1`<G3]kbj
/KJd_L;0][Rh]kVi^K^k^kfm_;jn_;jn^kfm^[bl^;fl]kbk]KZi];Vh];Vh][^j^;fl^Kjm_;o3^Kc0
]KVj][Ri^KRj^[Zj_;Zj^kVi[;:WWjFJSi>8O81eL75WJ6MMH5mEG5]AFEY:FU];GEi>GEi>FU];DeA4
Ce10CDhnDE4oCdlmCDdkCThlCdloD510CdloCDdmEUI6CTloBDXjATTj@dHg?D4e?4<f@4Lj>Cdg>Cdg
>Che>che?d0f@D<gATHjAdLkB4dhBDhiBe0kBE4jB50iAe0fAe0fAe0f@U91@U90AE=1AE@oB5A0BEDo
BEDoBeDnC5I5B5A2A4lo?d`l?DXl>dTm>T/n?4e0@De1@Dm3@U14@Dm3?Ta0?Ta0@Dm3@E95AE16?D]0
?4Xo?4a1>T]0<TPl=4/m>553:Da2:TU0=E17@EI=?4a1<S`_>D4`CE10Ad`gB4XfADPb@T@^@40X?SdS
?CTP?3PO<S@P;c4M:bdJ:BXJ9bPH92@F8B4C7QhB6Q/;7Ql?CTloX:2BVi^=Y:BHY::GZjVNXjNKYJVM
Yj^PZZfT[:nV[JnY[:jX[:fYZjjUZjjUZjjUZjjUZjjUZjjUZjjUZjjU[:nV[:nV[:nV[:nV[:nV[:nV
[:nV[:nVZK6WZZnVZJjUZjjU[K2W/;6X[k2W/:jV[[:W[[:W[[:W[K6V[K6V[K6V[;2U[;2U[[:W[k>X
[k>X/K:X/k:X/k:X];:X];:XZjZP[:^Q[ZfS/K2V];>Y]kF]^KN_^[R`[[>Z/KB[]kR^`KndblNleLg0
fM33fM32f=;5f=;5f=;5f=;5f=;5f=;5f=;5f=;5e]33em74em74em74f=;5f=;5f=;5fM?6f=;5f=;5
f=;5f=;5f=;5f=;5f=;5f=;5fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6
fM?6fM?6f=C2f=C2f=C2fMG3fMG3fMG3f]K4f]K4fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3f]K4f]K4
f]K4f]K4f]K4f]K4f]K4f]K4fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3g=G4g=G4g=G4g=G4g=G4g=G4
g=G4g=G4fmC3fmC3fmC3g=G4g=G4gMK5gMK5gMK5f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4fmO5fmO5
fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5
fmO5fmO5gMK5gMK5gMK5gMK5gMK5gMK5gMK5gMK5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5g=K3g=K3
g=K3g=K3g=K3g=K3g=K3g=K3gMO4gMO4gMO4gMO4gMO4gMO4gMO4gMO4g=G4g=G4g=G4g=G4g=G4g=G4
g=G4g=G4fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2f]C1f]C1
f]C1f]C1f]C1f]C1f]C1f]C1f]?2f]?2f]?2f]?2f]?2f]?2003Bc<gBc<gBc<gCcLkCcLkDc/oDc/oD
c/oBcm7Bcm7Bcm7Cd=;Cd=;DdM?DdM?DdM?CcmGCcmGCcmGCcmGCcmGCcmGCcmGCcmGAd=;Ad=;Ad=;A
d=;Ad=;Ad=;Ad=;Ad=;Bcm7Cd=;Cd=;Cd=;DdM?DdM?DdM?DdM?Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;A
d=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;@c]CAcmGAcmGAcmGBd=KBd=KBd=KBd=KBd=KBd=KBd=KB
d=KCdMOCdMOCdMODd]SCdMOCdMOCdMOCdMOCdMOCdMOCdMOCdMOCd]CCd]CCd]CCd]CCd]CCd]CCd]CC
d]CBd=KBd=KBd=KBd=KCdMOCdMOCdMODd]SDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGCd]CCd]CCd]CC
d]CCd]CCd]CCd]CCd]CBd];Bd];Bd];Bd];Cdm?Cdm?Cdm?De=CEdm?Edm?Edm?Edm?Edm?Edm?Edm?E
dm?Bd];Bd];Bd];Bd];Cdm?Cdm?Cdm?De=CCdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?E
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Edm;Edm;Edm;E
dm;Edm;Edm;Edm;Edm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;FdM3FdM3FdM3FdM3FdM3FdM3FdM3F
dM3Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7FdM3FdM3FdM3F
dM3FdM3FdM3FdM3FdM3Cd/kCd/kCd/kCd/kCd/kCd/kCd/kCd/kFdLkFdLkFdLkFdLkFdLkFdLkFdLkF
dLkCdM3CdM3CdM3CdM3CdM3CdM3CdM3CdM3BdLgBdLgBdLgBdLgBdLgBdLgBdLgBdLgEd<gEd<gEd<gF
dLkFdLkGd/oGd/oGd/oFdl_Fdl_Fdl_Fdl_Fdl_Fdl_Fdl_Fdl_Bdl[Bdl[Dd/[Dd/[Ed/[Ed/[GdL[G
dL[GdL[GdL[GdL[GdL[GdL[GdL[GdL[GdL[Fe<Vn^:]`IUE;?BMEA2YGABIKBRUJBRICBB]BB2Y@ARQ?
A2IA@bIBA2MEABQGAbY>@B5AA2ADBB]LD3ATF41ZGdUaIU9eJUIdKEUeKUYlMF:6P6f;QgF;QWN<RGZ@
SGj;RWb>SGnCTHJHV8bKW9:PXIRQY9^RYIbPY9jRYZ2TZ::UZJBUZ:JUZ:JXZZZZ[:bUZjJQYj:PYJ>g
_;ZX[Jbf^[^b][Nb][Nj_kj_];>h_Kbh_Kc1a/F`]KBe^[Vi_[fh^[^h^[^j_;fk_Kjk_Kjk_Kjk_Kjk
_Kji_Kjh_;ff^[^e^KZd^;Ve^KZf^[^g^kbi`L6i_[ng_;fh_;fh_;fi^kbi^;Zf]KNe_;F_]ZnW[ZNO
XifDUY22Q7i`L6YRHUaPHE5KG4aIFTYLGDeJFd]DEDE>Ccm<CCe>CSa>CSa=CC]=CCe<Bce=C3i>C45?
CD9CDdE;Bce2ACI0@c@j?c0e?2lf?C0k@SD/=S0/=bl^=Rl_>2hd?38k@CI0AcY3BSdmBC<oBSI0C3Pn
CS`mCchkDCljDD8jDD8cDDHeD4HfDTDiDdHiDdDiDd<jDD8jDD92EU4mDdhiCdXdBdL_AdD^AT@/ATH]
AdL`BTXdCTheDE4bCThZBDPVATDYBDP]CD`_CDhWADHT@T<S@T4M?3TF=C8L?3LXB4<REE4LBdPTCTd`
DU8Q?3T871L<714U<bL^>BT`>RXc>bXe>bPd>2Da<al^;a/];1LZ;Q/V:ATS9QHP8a@N81@K7A4G60hD
5@/<4@8U:Q]YK5fY[9fVYYRUYIVYYibYYibQYIVSYi^VZYjY[J:[[ZF/[jJ/[ZR[[JN[[ZF[[ZF[[ZF[
[ZF[[ZF[[ZF[[ZF[[ZF/[jJ/[jJ/[jJ/[jJ/[jJ/[jJ/[jJ/[jJZ/ZRZ[jJY[ZF]/:N_/ZVb/jZa/ZVb
/:R]/JJ]/JJ]/JJ]/JJ//:F//:F//:F//:F]/JJ]/JJ^/ZN`/JNb/JNb/JNc/JNc/JN][J6^[J>`[jFc
/JVf]:bh]K2j]k:k^;B]]J^^]Zbf^K32`KO=bKkGc/CKd/GMdLGGdLCGdLCGdLCGdLCGdLCGdLCGdLCG
dLCFd<?Fd<?Fd<?GdLCGdLCHd/GHd/GHd/GGdLCGdLCGdLCGdLCGdLCGdLCGdLCGdLCHd/GHd/GHd/GH
d/GHd/GHd/GHd/GHd/GIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKHe<;He<;He<;IeL?IeL?IeL?Je/CJ
e/CHe<;He<;He<;He<;He<;He<;He<;He<;IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?I
eL?IeL?IeL?IeL?IeL?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?LeLCLeLCMe/GMe/GM
e/GJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGK
elGKelGKelGKelGKelGJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CMe/GMe/GMe/GMe/GMe/GMe/GMe/GM
e/GKelGKelGKelGKelGKelGKelGKelGKelGLe/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?L
e/?Le/?Le/?Le/?Le/?LeLCLeLCLeLCLeLCLeLCLeLCLeLCLeLCJe<7Je<7Je<7Je<7Je<7Je<7Je<7J
e<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Idl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3Id/7Id/7Id/7I
d/7Id/7Id/400=;<cM;<cM;<cM?=c]?=c]?=c]C>cmC>cm;?dM;?dM;?dM?@d]?@d]CAdmCAdmCAdm??
eM??eM??eM??eM??eM??eM??eM??eM7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d];?dM;?dM?@d]?@d]?@
d]CAdmCAdmCAdm7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]3>
e=3>e=7?eM7?eM7?eM;@e];@e];@e]7?eM7?eM;@e];@e];@e]?Aem?Aem?Aem?Aem?Aem?Aem?Aem?A
em?Aem?Aem?Aem?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=7?eM7?eM;@e];@e];@e]?Aem?Aem?AemCC
eMCCeMCCeMCCeMCCeMCCeMCCeMCCeM?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=7AdM7AdM;Bd];Bd];B
d]?Cdm?Cdm?CdmCBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]7AdM7AdM;Bd];Bd];Bd]?Cdm?Cdm?Cdm;B
d];Bd];Bd];Bd];Bd];Bd];Bd];Bd]?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?CdmCBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm;B
d];Bd];Bd];Bd];Bd];Bd];Bd];Bd]CBdMCBdMCBdMCBdMCBdMCBdMCBdMCBdMOBdMOBdMOBdMOBdMOB
dMOBdMOBdMOBdMKAd=KAd=KAd=KAd=KAd=KAd=KAd=KAd=OBdMOBdMOBdMOBdMOBdMOBdMOBdMOBdMOB
dMOBdMOBdMOBdMOBdMOBdMOBdMOBdMKAd=KAd=KAd=KAd=KAd=KAd=KAd=KAd=?Bc]?Bc]?Bc]?Bc]?B
c]?Bc]?Bc]?Bc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=;A
cM;AcM;AcM;AcM;AcM;AcM;AcM;AcMG@cMG@cMG@cMKAc]KAc]OBcmOBcmOBcmKCbmKCbmKCbmKCbmKC
bmKCbmKCbmKCbm;Cb];Cb]CBb]CBb]GBb]GBb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]GG
bl_9_Y^BQGEUEEY3<dXe85M5;UM7<515:Tm4:De29d`o9Ddn94ho9E919eA3:E=79EE::UaA<f=H?FYP
B71UDG=YEgE[FWMaGWQbGgmhIhR4LXb9NXb9Nh^:O8n>P8n>P9:@QINGRiZKTInPUinRVJ2RW9jRW::V
X:FYXjN[YZR[ZJR[ZJV[Zj^][Jj`/JR_ZZB[Z:>ZYkVo_ZZ_/;Jk_;:g^[>h^kNm_;Bj^KVo_[6g]/36
aK6g][k4`kNm_;fo`;fo`;fo`;bn_k^m_[Zl_KVk_;Rj^kJk_;Jk_;Fj^kFj^kFj^kJk_;Jk_;Nl_K2k
^K6i^;6i^KFj^kNl_KRl_KRi_KFf^[Bk][>j]K:i];6g/Zfa[9nSWXf>RWioNg9eIVAWF5QKC5MJBeMJ
Be5DADa?@4Y=?T=5<DI8=DQ:=dM8>4I6>4M7>d]:@51?ADi=@dA5>cdo<cTm<C@k;S4h:c<m;CU3<bPh
<BLg<2He;BPe;B/i;S8n<SM3=ca6>T1;@Ca;@c]<B3U>C3M@DS=AERm@FBa@F2Q<ERU>ERY?Eba@ERe?
EBa?Dbe=DRa=D2M7C2I6BbA4BR11BQe1BAi1Bai2C1m2Ca4j@a8mAQE0BAM5CAQ7CaU:DQU=E1]?EQ];
EaU9EAi<Eb5<EADnA`L/=0HZ<14e>a9:Ba=6BA]4CA/kAPXP:`0630071@hH4PlP5A@U61/Y7B4^82D^
8BDZ6b8U5AhQ4AhT4a/P4ALL3ADI3A@H3A8F2`hA20/>1@L=0R`b9fmcIhnAQIfMTIfMTJZYVjBSUJ2U
UZ:WV:FYWJR/X:^_Y:b_YZ^^YJ^]Yj^^YJ^^YJ^^YJ^^YJ^^YJ^^YJ^^YJ^^YJb_YZb_YZb_YZb_YZb_
YZb_YZb_YZb_YZR`YZV^YJV^YJb_YZnbZK>dZk:cZ[>aZJb`YJb`YJb`YJb`YJb`YJb`YJb`YJb`YJ^_
Y:b`YJb`YJn`Y[6`Y[:aYk>aYk>aYjnaYK2bY[6bZ;>dZkJf/;Rg/kZh]k^i^;2k/k>k];Vn]L?4^lg;
`MO>a=[@a]c@a=OAa=OAa=OAa=OAa=OAa=OAa=OAa=OAa=K@`mK@`mK@`mOAa=OAa=OAa=SBaMSBaMOA
a=OAa=OAa=OAa=OAa=OAa=OAa=OAa=SBaMSBaMSBaMSBaMSBaMSBaMSBaMSBaMWCa]WCa]WCa]WCa]WC
a]WCa]WCa]WCa]SD`]SD`]SD`]WE`mWE`mWE`m[Fa=[Fa=SD`]SD`]SD`]SD`]SD`]SD`]SD`]SD`]WE
`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`m_D`m_D`m_D`m_D`m_D
`m_D`m_D`m_D`m_D`m_D`m_D`mcEa=cEa=gFaMgFaMgFaM[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=_G
aM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM[Fa=[Fa=[Fa=[Fa=[F
a=[Fa=[Fa=[Fa=gFaMgFaMgFaMgFaMgFaMgFaMgFaMgFaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaMgG
a=gGa=gGa=gGa=gGa=gGa=gGa=gGa=cF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcEa=cEa=cEa=cEa=cE
a=cEa=cEa=cEa=[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`MWC
`=WC`=WC`=WC`=WC`=WC`=WC`=WC`=WB`MWB`MWB`MWB`MWB`MWB`@00dL_<d/c=d/c=d/c=dlg>dlg>
dlg>e<k?d/oAd/oAd/oAdm3Bdm3Be=7Ce=7Ce=7CdloEdloEdloEdloEdloEdloEdloEdloEdM3BdM3B
dM3BdM3BdM3BdM3BdM3BdM3Bd/oAd/oAd/oAdm3Bdm3Bdm3Be=7Ce=7CdM3BdM3BdM3BdM3BdM3BdM3B
dM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3Bd<kDd<kDd<kDdLoEdLoEdLoEd]3Fd]3FdLoEdLoE
dLoEd]3Fd]3Fdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm;Ddm;Ddm;Ddm;Ddm;Ddm;D
dm;Ddm;DdLoEdLoEdLoEd]3Fd]3Fdm7Gdm7Gdm7Ge=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Edm;Ddm;D
dm;Ddm;Ddm;Ddm;Ddm;Ddm;DdM7AdM7AdM7Ad];Bd];Bdm?Cdm?Cdm?Ce=;Be=;Be=;Be=;Be=;Be=;B
e=;Be=;BdM7AdM7AdM7Ad];Bd];Bdm?Cdm?Cdm?Cd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Ce=;Be=;Be=;Be=;Be=;Be=;B
e=;Be=;Bdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Be=;Ae=;A
e=;Ae=;Ae=;Ae=;Ae=;Ae=;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Ae]7@e]7@e]7@e]7@e]7@e]7@
e]7@e]7@em;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Ae]7@e]7@
e]7@e]7@e]7@e]7@e]7@e]7@dm;>dm;>dm;>dm;>dm;>dm;>dm;>dm;>e]7>e]7>e]7>e]7>e]7>e]7>
e]7>e]7>dm7@dm7@dm7@dm7@dm7@dm7@dm7@dm7@d]7=d]7=d]7=d]7=d]7=d]7=d]7=d]7=eM3=eM3=
eM3=e]7>e]7>em;?em;?em;?e]?;e]?;e]?;e]?;e]?;e]?;e]?;e]?;d]?:d]?:e=;:e=;:eM;:eM;:
em7:em7:em7:em7:em7:em7:em7:em7:em7:em7:b<k3dm?7clJlbkV^Z9:6OfMKHdho>BHG?c<K@3@L
@SHNACLPBCTRCCdVDd4ZET@]Edd[Fe0`HePjJUm4KfA>M6UEMF]JMVaKOWQUOWMVPWi/RHIgSHYlRHQj
RHMlRXYnTHn4U9B8VIV=W9fCWZ6HWZ6HVinIVYjHX:NPXZRSYJ^VYZ^YYZ^ZYjb[ZZj_[K6bYJbYXJRU
XJRU]kflYjb]];Vj/KJi/[Nj[kFd/[Rg][bkZ:j]^l70[kFd`/S7/KNf];Fi];Fi]KJj]kRl^;Vm^KZn
^[^o^[^o]KZm]KZm][^n][^n]kbo^;g0^;g0^Kk1/[fj/;^h[kNf[[Je/KJg/kNh/[Jg/KBh/kbi/;Vf
/;Nd/KRe/kRf/;>aYZVWWj2NSI21MgY[HfIGGF1AFei?EEQ9D5=4Ce93BD/gC4hkCU0mBDXj@d<g@D0f
AD@jBTQ0BDY0@D8h>c`b=c/_<cX]<ST/=3h^>dDe9c`d9SPa8S@]8C8Y8C8W93@Y:3T/;3X^8Rda82`b
6R/d52/j3R`o2B]30BQ402I602A002E102M002Q10BLo0RLm02Dk02<i1B/g1R/i1Rdk1Rln2C532SE6
3CM:3SU<4DAD44AD4dYI75ET:6=b<Fil<g:0<W5o75M[95mb>723AgV;>fYh8dmL7DAB9TaH13Hl43e8
63a<4R`m11@U00LD20`A51HF01D;1AXA42<J6RXO8BdQ8RXO7bHI7B4E51/<4AP93QD83A@73A<83148
2@h51P/20@T09blTGVAIHfMKOh5eR8QlXZ6CWIZ<WjBEXJJGYJVMZ:bPZZjSZjjUZjjUZjjUZjjUZjjU
ZjjUZjjUZjjUZjjUZjjUZjjU[:nV[:nV[:nV[:nV[:nV[:nV[:nV[:nVYjnUZ:fTYjbS[:nV[k:Y/kB[
/kB[/k6Y[;2U[;2U[K6V[K6V[K6V[[:W[[:W[[:WZjnTZjnT[;2U[k2V/K2V/[6W];:X];:X[k6U/;:V
/[>Y/kB[][J`^;Nc^KNf^[Rh]L2h]knh^/:ha<Flc<[0eLc2e/c2el_1em74em74em74em74em74em74
em74em74eLo2e]33e]33e]33em74em74em74f=;5em74em74em74em74em74em74em74em74f=;5f=;5
f=;5f=;5f=;5f=;5f=;5f=;5fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6f=C2f=C2f=C2fMG3fMG3fMG3
f]K4f]K4f=C2f=C2f=C2f=C2f=C2f=C2f=C2f=C2fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3
fMG3fMG3fMG3fMG3fMG3fMG3fmC3fmC3fmC3fmC3fmC3fmC3fmC3fmC3fmC3fmC3fmC3g=G4g=G4gMK5
gMK5gMK5f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5
fmO5fmO5fmO5fmO5fmO5fmO5f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4gMK5gMK5gMK5gMK5gMK5gMK5
gMK5gMK5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5gMO4gMO4gMO4gMO4gMO4gMO4gMO4gMO4g=K3g=K3
g=K3g=K3g=K3g=K3g=K3g=K3g=G4g=G4g=G4g=G4g=G4g=G4g=G4g=G4f]C1f]C1f]C1f]C1f]C1f]C1
f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1fM?0fM?0fM?0fM?0fM?0fM?0fM?0fM?0fM;1fM;1
fM;1fM;1fM;1fM;1003Dc/oDc/oDc/oDc/oDc/oDc/oDc/oDc/oBcm7Bcm7Cd=;Cd=;Cd=;DdM?DdM?D
dM?Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Bcm7Bcm7Cd=;C
d=;Cd=;DdM?DdM?DdM?Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;DdM?DdM?DdM?DdM?DdM?DdM?DdM?D
dM?Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;@cm7@cm7@cm7Ad=;Ad=;BdM?BdM?BdM?BdM?BdM?BdM?B
dM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;A
d=;CdM7CdM7Dd];Dd];Dd];Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?E
dm?Edm?Edm?Edm?Edm?Edm?Dd];Dd];CdM7CdM7Bd=3Bd=3AcloCdM7CdM7Dd];Dd];Dd];Edm?Edm?E
dm?Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Dd];Dd];Dd];D
d];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];D
d];CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM3CdM3CdM3CdM3CdM3CdM3CdM3CdM3Gd/oGd/oGd/oG
d/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oG
d/oGd/oFdLkFdLkEd<gEd<gFdLkFdLkGd/oFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkF
dLkFdLkFdLkFdLkFdLkEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gE
d<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gAd<cAd<cCd<cDdLgEd<gFdLkHdLkHdLkGdL[GdL[GdL[G
dL[GdL[GdL[GdL[GdL[GdL[GdL[GdL[GdL[GdL[GdL[GdL[GdL[Fd<WFd<WFd<WFd<WFd<WFd<WFd<WF
d<WGdL[AblC?bL;Dc/OGdL[:a;f]Yj2EShQJDCe>AC51=R8i;QXm;aa4=B98>BI9>RMJC3IMD3YRECmV
FdEXHT]_Je=gLe]kNF5eMFMiNF]oOg63PgF6QWR9RG^?Sh6DU8JFThFEThRGUHZJVHnKW9:OX9NOXYVQ
XifUXj>VY:BXYZJZZ:R]Zj^_[Jfa[jnb/;2]/jj[/:jZ[jf//K2a][Fc]kRb][N`/kNa][Fa][Fa][Fa
][Fb]kJd^KRe^[Vf^kZd^KRd^KRd^KRe^[Ve^[Ve^[Ve^[Ve^[Vd^KRd^KRd^KRd^KRd^KRd^KRd^KRd
^KRa][Fa][Fa][Fa][Fb]kJc^;Ne^[Vf^kZc][Zc][Zc][Zb]KVb]KVb]KVb]KVb]KVTZYnEVi1mQ7MS
JUe@EdQ8D3m9DD1<E4=DDD9@Dd=5CclgA3Hc@38i@cLn@CPk?3<a?c<a>bld>C0k?CLc>C@Q;2TB8b0<
8R015b8262<46RD46RD56bH77BP;8B`>92l29C82:3@6:cT8;cd;<T4<=4H<=dP==dXA@U8DAeLICEdK
DV4KE6<JEF@JEfDLFFLOEV<PEf@QF6LQF6LRF6TQEfPQEVXPEFTADV4CDF4FDF4KDf@PF6TRGFdQGflN
GfhkKg`6>TL`I755NXM@QI91MX=8Oh`oMX<lL7LeK74;>ShI=S/01`h410X:4aH03P`15AX36Q`061PV
@d0M>C<=8QX95Ph>5`d>5A801@800P083``63@X00P000P073P/<3`0V:ATm?Ri0@C56ASIHF4Q/JEYc
L661Q7F9S7fFVHZSYYN[[Yn^/J:]/:6[[YnX[:2Z[Z:[[jBZ[JBY[:>YZjF/[ZR^[j^Z[:JYZjFZ[:J/
[ZR][jV][jV/[ZRZ[:JZ[Z:]/JF`]:Ra]JV_/jN^/ZJ]/JF^/ZJY[:>Y[:>Z[JBZ[JB[[ZF[[ZF/[jJ/
[jJ[[jB]/JJ_/jR_/jR]/JJ//:F]/JJ^/ZN][ZZ_/:bc]Jnb]:ja]:^h_;69SH:WZj2X[Z>i^jo1_Znj
/Z7NdlGEbKoEbL?Ld<kGd;oGd;oGd;oGd;oHdL3HdL3HdL3Id/7HdL3HdL3HdL3HdL3HdL3HdL3HdL3H
dL3Id/7Id/7Id/7Id/7Id/7Id/7Id/7Id/7HdL3HdL3HdL3Id/7Id/7Id/7Jdl;Jdl;Jdl;Jdl;Jdl;I
d/7HdL3HdL3Gd;oGd;oId/7Id/7Id/7Jdl;Jdl;Jdl;Ke<?Ke<?Idl3Idl3Idl3Idl3Idl3Idl3Idl3I
dl3Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;Je<7Je<7Je<7J
e<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7KeL;KeL;Le/?Le/?Le/?KeL;KeL;KeL;KeL;KeL;KeL;KeL;K
eL;Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?KeL;KeL;Le/?L
e/?Le/?MelCMelCMelCLe/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?L
e/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?KeL;KeL;KeL;K
eL;KeL;KeL;KeL;KeL;JeL3JeL3JeL3JeL3JeL3JeL3JeL3JeL3Idl3Idl3Je<7KeL;KeL;Je<7Idl3I
dl3Je<7Idl3Hd[oHd[oHd[oHd[oIdl3Je<7KdKoKdKoKdKoKdKoKdKoKdKl00=C>cmC>cmC>cmC>cmC>
cmC>cmC>cmC>cm;?dM;?dM;?dM?@d]?@d]?@d]CAdmCAdm;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM?@
d]?@d]?@d]?@d]?@d]?@d]?@d]?@d];?dM;?dM;?dM?@d]?@d]?@d]CAdmCAdm?@d]?@d]?@d]?@d]?@
d]?@d]?@d]?@d]CAdmCAdmCAdmCAdmCAdmCAdmCAdmCAdm7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]3?
dM3?dM3?dM7@d]7@d];Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;A
dm;Adm;Adm;Adm7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]?AdM?AdM?AdMCBd]CBd]GCdmGCdmGCdmGC
dmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmCBd]CBd]CBd]?AdM?A
dM;@d=;@d=;@d=?AdM?AdM?AdMCBd]CBd]GCdmGCdmGCdmCBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]GC
dmGCdmGCdmGCdmGCdmGCdmGCdmGCdmCBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CB
d]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?A
d=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=OBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOB
cmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmKAc]KAc]G@cMG@cMKAc]KAc]OBcmKA
c]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]G@cMG@cMG@cMG@cMG@
cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cM7@
c=7@c=?@c=CAcMG@cMG@cMSAc]SAc]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OA
b]OAb]OAb]OAb]K@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMOAb]C>am;<aMC>amSBbmSBbm7;a<_5_/_4
/K6WUHMmJfAHATi0;T<e8d0`7ch^7EI9<ee@>VIKAFiVCg9/EG5]EFeYDFQVCWQhJWUiJgYjK7YjK7Yj
K7inL8F5Mh^;OIJFR9JFRYJFRYFFS9BHSIFHSiFJTIFITj6QXJ:RXZBTY:JVYZRXZ:^[Zjf][Jf][Jbb
[JV^[:N/ZZV^[Jfb/K2d]K2d]Jnb]Zfb/Jnd/k:g][Bi^;Jk^[Jk^[Fj^KBi^;Bi^;Bi^;Bi^;Bi^;Bi
^;Bi^;>h]k>h]k2e];2e];2e];6f]K:g][>h]k>h]k>h]k6f]K6f]K2e];2e];2e];2e];6f]K:g][>g
^;>g^;>g^;>g^;>g^;>g^;>g^;>g^;Bh/ZZ^Z9VNUHF;P75gK5eTEdaCAT=:>dU7?4]=@DM>@Ci8>cY4
>3a2=cXk<CDc:Bdg:Rlg;30h;R/b;AdX9Q8T8aDa<R=2@b9:ERI>FRUAGB]CGb]CGb]CGbaDH2eEHBMA
GBQBGbUCH2QCHRMDHRMCI2ABI2ABI1E8F1M;FaY>GQQ?GQA=G11;FPi;F@i;F@e7D`e7D`i7EPi7EPi6
E`i6E`e5F0a4EaaHJ1]CI29FIbeOLCEWNC=WN2aTMBQTM3a`OA14DCEYMSmdPDAiQT1ePU:7U5:7U4Mk
PSidNaQ8CQ8_=0073P@42Q@M800E4`0A4`0B500A4BU4@@`S7`0A3@050P060@040`0510030P010087
1PT>3@@9200101`P3Blc83do;3Tk:3Lg9D10;TY8=TY8=Ta?@5AGB69UEW=fIhF8NI>FQifPTJ:UUZJZ
WZV]XJb`Y:b`YJ^^YJV/XjV[YJV[YK6c[JnaZjf_ZJb^Z:b^Z:b^Z:^]YjZ/YZNZXJZ]Y:jaZ:nbZJja
Z:jaZ:nbZK6dZj^^YJ^^YJ^^YJ^^YJ^^YJb_YZb_YZb_YZ^_Y:faYZncZ:jbYjfaYZb`YJb`YJjbYjVZ
YZf^Z[Bf/;6c[JR[XZ6UVUmSF71dJG1gJ7aoKhF4L8b5L/NmZm35]mG:`]W?b=K?_]O@_mO@_mO@_mSA
`=SA`=SA`=SA`=O@_mO@_mO@_mO@_mO@_mO@_mO@_mO@_mWB`MWB`MWB`MWB`MWB`MWB`MWB`MWB`MO@
_mSA`=SA`=SA`=WB`MWB`MWB`M[C`][C`][C`]WB`MWB`MSA`=SA`=O@_mO@_mWB`MWB`MWB`MWB`M[C
`][C`]_D`m_D`mWC`=WC`=WC`=WC`=WC`=WC`=WC`=WC`=[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M_E
`]_E`]_E`]_E`]_E`]_E`]_E`]_E`][D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M_E`]_E
`]_E`]cF`mcF`m_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]cF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF
`mcF`mcF`mcF`mcF`mcF`mcF`mcF`m_E`]_E`]_E`]cF`mcF`mcF`mgGa=gGa=cF`mcF`mcF`mcF`mcF
`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF
`mcF`mcF`mcF`mcF`mcF`mcF`mcF`m_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`][E`=[E`=[E`=[E`=[E
`=[E`=[E`=[E`=WC`=WC`=[D`M_E`]_E`][D`MWC`=WC`=[D`MWC`=SB_mSB_mSB_mSB_mWC`=[D`M[@
_][@_][@_][@_][@_][@_P00dlg>dlg>dlg>dlg>dlg>dlg>dlg>dlg>d/oAd/oAd/oAd/oAdm3Bdm3B
dm3Be=7Cd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bd/oAd/oA
d/oAd/oAdm3Bdm3Bdm3Be=7Cdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Be=7Ce=7Ce=7Ce=7Ce=7Ce=7C
e=7Ce=7CdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3Bd<oAd<oAd<oAdM3BdM3Bd]7Cd]7Cd]7Cd]7Cd]7C
d]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7CdM3BdM3BdM3BdM3BdM3BdM3B
dM3BdM3Bdm7Adm7Adm7Adm7Ae=;Be=;BeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?C
eM?CeM?CeM?CeM?CeM?CeM?Ce=;Be=;Be=;Bdm7Adm7Ad]3@d]3@d]3@dm7Adm7Adm7Adm7Ae=;Be=;B
eM?CeM?Ce=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;BeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?Ce=;Be=;B
e=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;B
e=;Be=;Bdm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7@dm7@dm7@dm7@dm7@dm7@dm7@dm7@em;?em;?
em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?
em;?em;?em;?e]7>eM3=eM3=eM3=eM3=e]7>em;?e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>
e]7>e]7>e]7>e]7>e]7>e]7>e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<
e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<d<o;dM3<dm3<dm3<eM3=eM3=em3=em3=e]39e]39
e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39
e]39e]39em7:em7:e]39dlg6dL_4dlg6f=;;gMO@f=70f=2odl^jb/2_]JRHTXEeKEi>E4DeCT<_C44]
Bd8^E4/gHU]7LVeHOgYUQX5/LG1RM7=UN7MYOGa^PH1bQhIhSXeoTi:4RXenRXb0RXj2S925SI>8SYJ<
TIV?TiZCVYnNVYnNW:6PWjBSXJJUXjRWYJZYYZ^ZZJnZYjbZY:VWY:VXYjb[ZZj_[;2a[K2dZJj][;6`
/KJe]KZi]kbk][^j];Vh/kRg];Vh/kRg/kRg/[Nf/[Nf/KJe/KJe/;FdZZn^Zk2_[;6`[K:a[[>b[kBc
/;Fd/KJe/;Fd/;Fd[kBc[[>b[K:a[[>b[[>b[kBc/KFf/KFf/KFf/KFf/KFf/KFf/KFf/KFf];Ne[[6_
XjNRUi^FQ8R2JVmVBe17=c`c?Shh@D<m@DHm?4@j>D4f?40e>SX^=C<X:c<X:C4W8bdW6BLU2R4S0b<X
2C<j549:038n03I203a80Si:0Ce903]703Y603Y613I21SQ423U72Ce:2cm?341A2d5B2d5B6DmP7E=T
7UIW85QY7UUY75QX7EUY7EUY861[861[85m]85m]85i^7ee]7E]]75Y/8UIW4D=E3ce?74MJ8TeP64IH
3d5C4TIG:5eZ3T=@<6Eb=FYg=V]h?G9oCX>@DXNDChB>C8:9=FE[5C8i214J2PdB7b/]0a/K01<D01<C
01<C?eAE1QPI21@D1``=30h?00000P820@410000000000000@4100009RXG<SHS>cdZ=cTV=SHT>SXX
?C/Y>3HT=CHV>3TY?Sl_BDXjEUM7I6EEL75QN7UYRXn0TIJ7VYn@XZJJYZZOZJfR[:nV[[6X[:nVZjjU
ZJbSZ:^RYjZQZ:^RZZfTZjjU[[2Z[k6[/;:/[k6[[JnYZjfW[:jX[JnY[K2W[K2W[K2W[K2W[:nV[:nV
[:nV[:nV[;2U[[:W[k>X[[:W[;2UZjnT[;2U[[:W[k2//kB`^;Zd];J`ZJbSW:2ECe=8Ee]@EEi:FEi9
GEe5K6M>^k>Le<Zhf]73elk4e/nne/nne/nnem2oem2of=70f=70f=70em2oem2oem2oem2oem2oem2o
em2oem2of=70f=70f=70f=70f=70f=70f=70f=70em2oem2of=70f=70f=70fM;1fM;1fM;1fM;1fM;1
fM;1f=70f=70f=70em2oem2of=70f=70fM;1fM;1f]?2f]?2f]?2f]?2f=:of=:of=:of=:of=:of=:o
f=:of=:ofM?0fM?0fM?0fM?0fM?0fM?0fM?0fM?0f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1fM?0fM?0
fM?0fM?0fM?0fM?0fM?0fM?0fM?0f]C1f]C1f]C1fmG2fmG2fmG2fmG2f]C1f]C1f]C1f]C1f]C1f]C1
f]C1f]C1g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3fmG2fmG2
fmG2fmG2g=K3g=K3g=K3gMO4g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3
g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3f]C1f]C1
f]C1f]C1f]C1f]C1f]C1f]C1f]G0f]G0f]G0f]G0f]G0f]G0f]G0f]G0f=:ofM?0f]C1f]C1f]C1f]C1
fM?0f=:ofM?0fM?0f=:oem6nem6nf=:ofM?0fM?0f]2nf]2nf]2nf]2nf]2nf]2n003CcLkCcLkCcLkC
cLkCcLkCcLkCcLkCcLkAc]3Ac]3Bcm7Bcm7Bcm7Cd=;Cd=;Cd=;Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7B
cm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Ac]3Ac]3Bcm7Bcm7Bcm7Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;C
d=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;A
d=;@cm7@cm7@cm7Ad=;Ad=;BdM?BdM?BdM?Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;A
d=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Bd=3Bd=3CdM7CdM7CdM7Dd];Dd];D
d];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];CdM7CdM7CdM7C
dM7CdM7CdM7CdM7CdM7Bd=3Bd=3CdM7CdM7CdM7Dd];Dd];Dd];CdM7CdM7CdM7CdM7CdM7CdM7CdM7C
dM7Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7C
dM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3B
d=3Bd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkF
dLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkEd<gDclcDclcEd<gFdLkF
dLkEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gDclcDclcDclcD
clcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcD
clc@cl_@cl_Bcl_Cd<cDclcEd<gGd<gGd<gFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WF
d<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WAblCEclSGdL[EclS?bL;<a[o=al3@
b/??b[_Cc[oKe<GPelWNeLOEb[c5^Zbk[Z2ITH27Ofi_IeIOEdIMETESG4]ZHe9]IUEcLVAgMVQmO6j2
PG>5Q7J5Q7J3PWB3PWB6Rgb7Rgn8S828SX>:TXN>UXbAVY2DW9FCW9VDWIZEWY^HXIjJXj2LYJ:NYjBO
Z:FV[:NSZ:JPYJ>OY:>QYZFTZ:VX[:fZ[K6W[:^Y[Zf//K2_];>b]kJc^;Nc^;Nb]kJb]kJb]kJa][F`
]KB_];>^/k:^/k:]/[6X[JbX[JbY[ZfZ[jjZ[jj[/:n[/:n//K2^/k:]/[6//K2//K2//K2]/[6^/k:_
];>]/[6]/[6^/k:^/k:^/k:^/k:_];>_];>i^kbc]KJ/[ZjVZ:RKWYb4R8=TJ6==DD`i?3Xi?3Xh?3Le
>C<d>C0f>C0g>2hf=bdT;2DJ9R0B9B8D;BlG>d4D@Td:?d`0>TT?DV4BEF@FFFPGFVTFFFPDEfHCEVDC
EVDRFVDRG6PUGf/VHG0YIGD[IgLZJ7X[JG/UH70WHg<ZIWH/J7P/J7P/J7P/JWX]Jg/XKGLXKGLXK7TX
K7TWJWTUJ7LSIGLRI7HKBed0;Cl072l09ST4;3l09CP09cT3<dDCBUL9@4d[H6dcJ7DgK7U5NHI7NhQ5
NHI:PHY=Q8e8NH4H=Ch=5Ql<3QHL:2`051@77ad261H05A=<Fed01@P21`X000<400D71@D30@471@D;
2@T2000200091`LU8b<Z;aXa=R4h>RHh>RHl?BU0@Bdo?RXi>2@m?Rhk?2`i>RXh>BTk?2a0@C56AcM:
Bc]GFdQOHU9]L61lOg29RgnEUh^PXINVYifVZYjWZinX[:2X[:2WZinWZinX[:2Y[J6ZZjN/[JV/[JV[
[:RZZjNYZZJZZjN/[JV_/ZV_/ZV^/JR^/JR]/:N/[jJ/[jJ/[jJ//:F^/ZN^/ZN]/JJ[[jB[[jB]/JJ_
/jRc]k:c]k:d^;:`]:j[/:NW[J9LHUMPIU]TKUMSJE1OHDAZITVk]9WGckSKe<7Cc;gFckkFckkFckkF
ckkGd;oGd;oHdL3HdL3Gd;oGd;oGd;oGd;oGd;oGd;oGd;oGd;oHdL3HdL3HdL3HdL3HdL3HdL3HdL3H
dL3Gd;oGd;oGd;oHdL3HdL3HdL3Id/7Id/7HdL3HdL3HdL3HdL3HdL3HdL3Gd;oGd;oHdL3HdL3HdL3I
d/7Id/7Id/7Jdl;Jdl;Hd[oHd[oHd[oHd[oHd[oHd[oHd[oHd[oIdl3Idl3Idl3Idl3Idl3Idl3Idl3I
dl3Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Idl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3J
e<7Je<7KeL;KeL;KeL;Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7KeL;KeL;KeL;KeL;KeL;KeL;KeL;K
eL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;Je<7Je<7KeL;KeL;KeL;Le/?Le/?Le/?KeL;KeL;KeL;K
eL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;K
eL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7JeL3JeL3JeL3J
eL3JeL3JeL3JeL3JeL3Hd[oHd[oIdl3Je<7Je<7Idl3Hd[oHd[oIdl3Hd[oGdKkGdKkGdKkGdKkHd[oI
dl3Jd;kJd;kJd;kJd;kJd;kJd;h00=;<cM;<cM;<cM;<cM;<cM;<cM;<cM;<cM7>d=7>d=7>d=7>d=;?
dM;?dM?@d]?@d];?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM7>
d=7>d=7>d=7>d=;?dM;?dM?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@
d]?@d]?@d]?@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]3?dM3?dM3?dM7@d]7@d];Adm;Adm;Adm7@
d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@
d]7@d]7@d]7@d];@d=;@d=;@d=?AdM?AdM?AdMCBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CB
d]CBd]CBd]CBd]CBd]CBd]CBd]CBd]?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM;@d=;@d=;@d=?AdM?A
dM?AdMCBd]CBd]?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdMCBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]?A
dM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?A
dM?AdM?AdM?AdM;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cmKA
c]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KA
c]KAc]KAc]KAc]KAc]G@cMC?c=C?c=C?c=C?c=G@cMKAc]G@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@
cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMC?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?
c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c<o>b]3?bm;?bm;?bmC?c=C?c=K?c=O@cMK@
bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@
bMK@bMK@bMK@bLo9`]7;a=?=a]K@bMOAb]K@bMG?b=?=a][GbMGBa=3:_Lg7^];:_MW@`n3Gb^CKc]OB
`l[5][^dYJZSU9ZCQ8N0LG9[G6AMCVMTEVUVF6i[GGEbI7aiJh5nL8F2M8J3MHb?P8b>PXV=PHV=PXV?
Q8ZBR8fERhnFShnITi2JU9:LUYBNV9NQViVSWI^UWibVX::XXj2UXijSXIbQX9bQX9nSY:>WZ:JY[JJ[
ZZJ[ZZJ[ZZN/ZjV^[Jfb/K2e];:g][2e];2e]:nd/jjc/Zfb/Jba/:^`[j^`[jV^[JV^[JR][:R][:N/
ZjJ[ZZJ[ZZJ[ZZZ_[ZZ_[ZZ_[ZZ_[Z^`[jfb/Jnd/jnd/jba/:ba/:ba/:fb/Jfb/Jjc/Zjc/Znd/kBe
^K2a]Jna/[2b/Z^][IJIUgEhMUaPFcLl>SDj>3@i=c8h<ble<2Xa;2D`:2D`:14S90lV:18a=1a3BbUJ
I2]TLb9PL1EGJBARM2ESMBITMRESMB=QLb=QLbESMBMUMbUWLRUWLRMVM2EVM2EVMB5SMB1RM1eQM2e]
Obi^P2i^P2a/ORYXNRMUMbITMRMUMbAYLbAYLbAXMBAXMB=VMB5TLb1RM1mQLaY<GP4a@`0T=``dAaQ0
Da<nDAA4EQmAHaUCGa==FBMNJcEZMd5ePUR9UdamRdYiQd=iQ4AlQdUjQ0d/=@074@0230hJ800<3PPP
7P4G5@<C4U=NG0D:2@/92@@000P20`X300L000X301L@3AXC41@=2QL@3B<L6C0e838g8SDg8cHh93Tj
9S/l:3Pg8c4`73/k:CXj:3Ph9SPh9STi9c`l:Shn;410;S<e8CTk9d94<De??5UJBVIVF7=cIG]kKi6F
QiJKS9fRTj:WV:BYVZJ[W:V^WjbaXZ>UWjJXXZV[YJZ/YZZ/YZ^]Yjf_ZK2b[:nbZJnbZJjaZ:jaZ:f`
Yjb_YZb_YZb_YZb`YJfaYZfaYZb`YJ^_Y:b`YJjbYk6eZ[2f/Jne/:fd[JR_Z:R`YZJ^XeEMDU9JCfA_
EFI]DV=UAfUUB;F_T]7:/MK?_<k7]]G>_MG>_MK?_]K?_]K?_]O@_mO@_mO@_mK?_]K?_]K?_]K?_]K?
_]K?_]K?_]K?_]O@_mO@_mO@_mO@_mO@_mO@_mO@_mO@_mK?_]K?_]O@_mO@_mO@_mSA`=SA`=SA`=O@
_mO@_mO@_mO@_mO@_mO@_mSA`=SA`=O@_mO@_mSA`=SA`=WB`MWB`MWB`MWB`MOA_]OA_]OA_]OA_]OA
_]OA_]OA_]OA_]SB_mSB_mSB_mSB_mSB_mSB_mSB_mSB_m[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`MSB
_mSB_mSB_mSB_mSB_mSB_mSB_mSB_mSB_mWC`=WC`=WC`=[D`M[D`M[D`M_E`][D`M[D`M[D`M[D`M[D
`M[D`M[D`M[D`M_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`][D
`M[D`M[D`M[D`M_E`]_E`]cF`mcF`m_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E
`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`][D
`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[E`=[E`=[E`=[E`=[E`=[E`=[E`=[E`=OA_]SB_mWC`=WC`=WC
`=WC`=SB_mOA_]SB_mSB_mOA_]K@_MK@_MOA_]SB_mSB_mW?_MW?_MW?_MW?_MW?_MW?_@00d/c=d/c=
d/c=d/c=d/c=d/c=d/c=d/c=d<g?d<g?dLk@dLk@dLk@d/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oA
d/oAd/oAdLk@dLk@dLk@dLk@dLk@dLk@dLk@dLk@d<g?d<g?dLk@dLk@dLk@d/oAd/oAd/oAdm3Bdm3B
dm3Bdm3Bdm3Bdm3Bdm3Bdm3Bd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAdM3BdM3BdM3BdM3BdM3BdM3B
dM3BdM3Bd<oAd<oAd<oAdM3BdM3Bd]7Cd]7Cd]7Cd<oAd<oAd<oAd<oAd<oAd<oAd<oAd<oAd<oAd<oA
d<oAd<oAd<oAd<oAd<oAd<oAdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdLo?dLo?d]3@d]3@dm7Adm7A
dm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Ad]3@d]3@
d]3@dm7Adm7Ae=;Be=;Be=;BdLo?dLo?d]3@d]3@dm7Adm7Adm7Adm7Ad]3@d]3@d]3@d]3@d]3@d]3@
d]3@d]3@dm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Ad]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@
d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@dLo?dLo?dLo?dLo?dLo?dLo?
dLo?dLo?dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=
eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=e<o<dlk;dlk;e<o<
eM3=eM3=e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<dlk;dlk;
dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;
dlk;dlk;clk:clk:dLk:d/o;dlk;e<o<e/o<e/o<eLo8eLo8eLo8eLo8eLo8eLo8eLo8eLo8eLo8eLo8
eLo8eLo8eLo8eLo8eLo8eLo8e]39e]39e]39e]39e]39e]39e]39e]39fM?<eLo8dL_4d/c5eLo8f=;;
f=;;em7:d]35dm76eM?8f=C9f=;7eLo4d/Vod<NmcLZlc/^mclbne<k1e<bobl>f_[FX]:^NT8YmRH=f
PG]^OGMZOGMZPWa_QX1cR89ePh9dPh5fPX9fPh9hQHIlR8^2SI27TI>=T9JATINBTiVDUI^FUifHVZ2K
Vj6LW::MWZBOWZ>QWJ:PVj2OVYnNVinPWj>TXZFYYZ^ZY:VXXjRWXZNVY:VXZ:f/[K:a/;Fd[K:a[K:a
[;6`[;6`Zk2_ZZn^ZZn^ZJj]ZZn^ZZn^ZJj]Yjb[YZ^ZYJZYY:VXXjRWZ:f/Z:f/Yjb[Z:f/ZJj]ZZn^
Zk2_[;6`Zk2^[;6_[;6_[K:`[[>a[[>a[kBb[kBb[k6b[k6b/[Bd]KNg/;>aVIfHMg]fG61K=S`g=3Xe
=3Xe=3/h:cHd72`[4BLU2bHS1bXd5Ca57deH85ER7UUX8f5a:FUk;Vj0;VUi;fYj;VUi;FQh:fIf;6Mg
;fYj<Vem9FAb96Ec9FId96Mf96Ih8FIg7fAg7fAg9FUl9VYm9f]n9fUl9VEi9FAh9fAh:FIj9V]e9faf
9f]h9f]h9VUh9FQg96Ih8fEg8e]/5deN6D]M;Ee_>6Qj<F=e:f5b;VIg;VYf7e]W7EMS;V=`?G5nGXnM
Cgj<EX>AAgj;B82;BGb63Rhi000:008;1Q@J01HJ01DB0AHD6BHTOhF0HUmJK6IOJfIMMW1UOgU^PWaa
PG]`Q7icThf2UHn4KVQM?3H[<cTR<SPQ<cHP=STS>S`V>cdW>STT=SDP<C8N<c@P=CHR=cPT>S/W?3dY
?Sl[?d0/=STS=cXT>3XV>3XV>S`Y?d0`ATLgC4dmEee<HFMFKgETOH=bRHmnUI^:XJNFZJnNZZjS[K6V
/;BY/;BY[[:W[;2UZjnTZjnT[K2W[K2W[K2W[K2W[:nV[:nV[:nV[:nVZZjSZjnT[;2UZjnTZjnT[K6V
/;BY];R]/KNb/[Rc/KRa[KB]Zk>YX:RM@4Pm;SH[BE<lE5Y1FE/nHEe0[jR=clN`fM:oe<fneLjmeLjm
eLjmeLjme/nne/nnem2oem2oe/nne/nne/nne/nne/nne/nne/nne/nnem2oem2oem2oem2oem2oem2o
em2oem2oe/nne/nne/nnem2oem2oem2of=70f=70e/nne/nne/nnem2oem2oem2of=70f=70em2oem2o
em2of=70f=70fM;1fM;1fM;1em6nem6nem6nem6nem6nem6nem6nem6nf=:of=:of=:of=:of=:of=:o
f=:of=:ofM?0fM?0fM?0fM?0fM?0fM?0fM?0fM?0f=:of=:of=:of=:of=:of=:of=:of=:of=:of=:o
f=:ofM?0fM?0f]C1f]C1f]C1fM?0fM?0fM?0fM?0fM?0fM?0fM?0fM?0f]C1f]C1f]C1f]C1f]C1f]C1
f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1fM?0fM?0f]C1f]C1f]C1fmG2fmG2fmG2f]C1f]C1
f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1
f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1fM?0fM?0fM?0fM?0fM?0fM?0fM?0fM?0f]G0f]G0
f]G0f]G0f]G0f]G0f]G0f]G0em6nf=:of=:ofM?0fM?0f=:of=:oem6nf=:oem6ne]2me]2me]2me]2m
em6nf=:ofLnmfLnmfLnmfLnmfLnmfLnm003Bc<gBc<gBc<gBc<gBc<gBc<gBc<gBc<g@cLo@cLo@cLoA
c]3Ac]3Ac]3Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3A
c]3@cLo@cLo@cLoAc]3Ac]3Ac]3Bcm7Bcm7Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Bcm7Bcm7Bcm7B
cm7Bcm7Bcm7Bcm7Bcm7Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;@cm7@cm7@cm7Ad=;Ad=;BdM?BdM?B
dM?@cm7@cm7@cm7@cm7@cm7@cm7@cm7@cm7@cm7@cm7@cm7@cm7@cm7@cm7@cm7@cm7Ad=;Ad=;Ad=;A
d=;Ad=;Ad=;Ad=;Ad=;AcloAcloAcloBd=3Bd=3CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7C
dM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7Bd=3Bd=3Bd=3CdM7CdM7Dd];Dd];Dd];AcloAcloAcloB
d=3Bd=3CdM7CdM7CdM7Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3CdM7CdM7CdM7CdM7CdM7CdM7CdM7C
dM7Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3B
d=3Bd=3Bd=3Bd=3Bd=3AcloAcloAcloAcloAcloAcloAcloAcloAclkAclkAclkAclkAclkAclkAclkA
clkEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gE
d<gEd<gEd<gEd<gEd<gEd<gDclcCc/_Cc/_Cc/_Cc/_DclcEd<gDclcDclcDclcDclcDclcDclcDclcD
clcDclcDclcDclcDclcDclcDclcDclcDclcCc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_C
c/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_?c/[?c/[Ac/[Bcl_Cc/_Cc/_FclcF
clcEclSEclSEclSEclSEclSEclSEclSEclSEclSEclSEclSEclSEclSEclSEclSEclSFd<WFd<WFd<WF
d<WFd<WFd<WFd<WFd<WKeLkGdL[CcLKAblCBc<GCcLKCcLKBc<GFeL_DdlW@clG>c<;?b/7BcLCHdLSL
eLc>c/;?cL;?cL;Bc/?Fd<GId<KLd/SLd/SLe/W@b[fo^Jb_ZIbRW8nGTHB>R7^9PgJ@RWf?RGj=Qgb<
Qgj<RX2@SHFDTXZGU8nCUHnDUY2EUi6HVYBJW9JLWYRNX9ZOXI^JX9^LXInMXZ2LXJ2IWYfIWIjLX:6O
XZJUZZVTZJRSZ:NSZ:NUZZVW[:^Z[jj//K2Z[jjZ[jjZ[jjZ[jjY[ZfY[ZfY[ZfY[ZfY[ZfY[ZfX[JbX
[JbW[:^VZjZVZjZUZZVW[:^W[:^UZZVTZJRTZJRSZ:NTZJRTZJRW[:ZW[:ZX[J^Y[ZbZ[jf[/:j[/:j/
/Jnc]KF`/[:^/Jn[[jZRYZ6=TH]aMFmMHUTh@3D`>2hZ<BXW<2dM;2hA:Rh8;C49<cP?@UHKDfHSGW4J
G6hDEVPJFfXWHg<]J7PUI78WIW@YJ7HYJ7HXIgDWIW@YJ7HZJGLSHW0RHg4TIG@UIgTUJW/VJWdVJghV
JglLI7HNIWPRIgXSIgXUIgXXIg/[JWh`KH4TI6lUIG0UI78VIG<UHg<UHg<THW@SHG<TIgHUHg</IgLh
L84nMXLgLX8]Jg/VJGPjN8<VHVhFD5`WGV/gJgQJRIM:MhEMRYQ:PHi=Qi=BQY8YBE@01a<;3aX341P4
7b<03@d771Xf@Cj^/JS4`K?>akK?b[GJe[kBb[WEcKcBb[W@b;OFc[g4_:^2NVTk<b8e>b@b>24d=b4g
>R@l?RPm?bU0?bY0?bXf=B4g=R8h=b<i>2@j>BDj>BDj>BDj>BDo@RTo@RTn@2Xk?BLg>2@g=bDi>BLk
>bT_=B8g?BY2B3E=Dd1HGT]UJeQeNfR1QgB@UHJFVhbNXiBSZ9VVZibVZibW[9fX[Ij[[ZF[[ZF[[ZF[
[ZF[[ZF/[jJ/[jJ/[jJY[J:Z[Z>Z[Z>Z[Z>[[jB^/ZNb]Z^f^Znb^KBc^[Fd_;Fa^K:a^[2S[J4jA3PP
:Qhf?bY6C3EADCUMF3n^YXoBb;KNeLOHd<?DcKcDcKcEc[gEc[gFckkFckkFckkFckkEc[gEc[gEc[gE
c[gEc[gEc[gEc[gEc[gFckkFckkFckkFckkFckkFckkFckkFckkEc[gFckkFckkFckkGd;oGd;oGd;oH
dL3Ec[gEc[gFckkFckkGd;oGd;oHdL3HdL3Gd;oGd;oGd;oGd;oHdL3HdL3HdL3Id/7Fd;gFd;gFd;gF
d;gFd;gFd;gFd;gFd;gHd[oHd[oHd[oHd[oHd[oHd[oHd[oHd[oIdl3Idl3Idl3Idl3Idl3Idl3Idl3I
dl3Hd[oHd[oHd[oHd[oHd[oHd[oHd[oHd[oHd[oHd[oHd[oIdl3Idl3Idl3Je<7Je<7Idl3Idl3Idl3I
dl3Idl3Idl3Idl3Idl3Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7J
e<7Idl3Idl3Idl3Je<7Je<7Je<7KeL;KeL;Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7J
e<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7J
e<7Idl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3JeL3JeL3JeL3JeL3JeL3JeL3JeL3JeL3GdKkGdKkHd[oI
dl3Idl3Hd[oGdKkGdKkGdKkGdKkFd;gEckcEckcFd;gGdKkGdKkHc[cHc[cHc[cHc[cHc[cHc[`00=7;
c=7;c=7;c=7;c=7;c=7;c=7;c=7;c=3=cm3=cm3=cm3=cm7>d=7>d=;?dM;?dM;?dM;?dM;?dM;?dM;?
dM;?dM;?dM;?dM7>d=7>d=7>d=7>d=7>d=7>d=7>d=7>d=3=cm3=cm3=cm3=cm7>d=7>d=;?dM;?dM?@
d]?@d]?@d]?@d]?@d]?@d]?@d]?@d];?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM7@d]7@d]7@d]7@d]7@
d]7@d]7@d]7@d]3?dM3?dM3?dM7@d]7@d];Adm;Adm;Adm3?dM3?dM3?dM3?dM3?dM3?dM3?dM3?dM3?
dM3?dM3?dM3?dM3?dM3?dM3?dM3?dM7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7?cm7?cm7?cm;@d=;@
d=;@d=?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM7?
cm;@d=;@d=?AdM?AdMCBd]CBd]GCdm7?cm7?cm7?cm;@d=;@d=;@d=?AdM?AdM;@d=;@d=;@d=;@d=;@
d=;@d=;@d=;@d=?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@
d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=7?cm7?cm7?cm7?cm7?
cm7?cm7?cm7?cm7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]G@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@
cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMC?c=?>bm?>bm?>
bm?>bmC?c=G@cMC?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=?>
bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>
bm?>bm?>bm?>blk=bLo>b]7>b]7>b]?>bm?>bmG>bmK?c=G?b=G?b=G?b=G?b=G?b=G?b=G?b=G?b=G?
b=G?b=G?b=G?b=G?b=G?b=G?b=G?b=K@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bLg7`=7;a=G?b=SBbmSB
bmOAb]K@bMK@bL_<`lg>aM;@b=;@b=;?am;<aM3:`m;:`lg<`/o>a=7?aM;=a=7:`M;9`=?8`=G:`]3:
_M3:_M7;_]G?`]OAa=G?`/k8^lS2]K^bYKN]XjjUVjNNUInHSiZDSIRBRiRBSIBDSYFESiNGTIVITibL
UYjNV:2PVZ6QViRNVI^PWYfRX9bQX9ZOWYVMWY^OX9jQYJ>XYjBYZ:FZZJJ[ZZN/ZjR][:R][:R][:R]
[:R][:R][:R][:V^[JV^[JV^[JV^[JN/ZjN/ZjR][:R][:R][:R][:R][:R][:R][:J[ZZBYZ::WYYnT
XijSXYfRXIfRXJ6WXZ6WXZ:XXj>YY:BZYJF[YZJ/YjJ/YibOWI>GTXJ:QG]oNG1dKV5VGE1FBdA:?c]5
=B`e:1`U6a@O70dP8`TY;`lj@aU<EQAAJaMJLAQNMAIPLQmUMRY[NRiYNBiRLQUQJaeUKb9ZM2A/MR=[
MB5YLb1XLR1XLRYYMbYXN2QYN2EWNBAVNB1TMamRMaaQMB1ZO25[OB9ZO29WNQmSMR1RMB=RMRISMbYX
Lb]YM2aYMbeZN2eYNBeYNBaWNR]VNAiWMBAYN2]/Nc9`P3MeQCQiR3=hQbefQ3ilQbYXLaUCGbiULS]_
O5V8UTEbP62;VT1jQT^5TEV=VCmQKPTE8AHJ9@09400J7`0@4PhS8D=<BKRg[N7JbMOB^Lg9[=;@[]G<
^<o6/]?:]]kE`M?:]Z>JQV9IACH]6C]1:3Pn9CLk8SHj8CHi83@g7SHf7SPh83Th93Th93Pg8cTh93Th
93Xi9CXi9C/j9SHi7cPk8SXm93/m9cXl9SXk9c/k:Cdm:cPo:SU0:cPo:S@k9S4h8cHm:417<TYA?5IL
BF9XEG=iIXF;N9BJQj2VTjR^VjfcX:V/XjV/XjZ]Y:Z]Y:^^YJ^^YJb_YZb_YZN[X:V]XZV]XZZ^Xj^_
Y:jbYkBh[KRl/Jje/:je/:jf[jfe[[:k/JZdZ4A>@RXd:3<l:4A9=4i=>5]E?ZjUTM77]][Aa=78_mC=
_=C=_=G>_MG>_MG>_MK?_]K?_]K?_]G>_MG>_MG>_MG>_MG>_MG>_MG>_MG>_MK?_]K?_]K?_]K?_]K?
_]K?_]K?_]K?_]G>_MG>_MK?_]K?_]K?_]O@_mO@_mO@_mG>_MG>_MG>_MK?_]O@_mO@_mSA`=SA`=K?
_]O@_mO@_mO@_mSA`=SA`=SA`=SA`=K@_MK@_MK@_MK@_MK@_MK@_MK@_MK@_MOA_]OA_]OA_]OA_]OA
_]OA_]OA_]OA_]WC`=WC`=WC`=WC`=WC`=WC`=WC`=WC`=OA_]OA_]OA_]OA_]OA_]OA_]OA_]OA_]OA
_]SB_mSB_mSB_mWC`=WC`=WC`=[D`MWC`=WC`=WC`=WC`=WC`=WC`=WC`=WC`=[D`M[D`M[D`M[D`M[D
`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`MWC`=WC`=WC`=WC`=[D`M[D`M_E`]_E`][D
`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D
`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`MWC`=WC`=WC`=WC`=WC`=WC`=WC`=WC`=[E
`=[E`=[E`=[E`=[E`=[E`=[E`=[E`=K@_MOA_]SB_mSB_mSB_mSB_mOA_]K@_MOA_]OA_]K@_MG?_=G?
_=K@_MOA_]OA_]S>_=S>_=S>_=S>_=S>_=S>_000d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;clg=clg=
clg=clg=d<k>d<k>dLo?dLo?d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@dlg>dlg>dlg>dlg>dlg>dlg>
dlg>dlg>d<k>d<k>d<k>dLo?dLo?dLo?d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@dLo?dLo?
dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d]3@d]3@dm7Adm7Adm7Ae=;B
e=;Be=;Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAdLk@dLk@
dLk@d/oAd/oAdm3Bdm3Bdm3Bd]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@
d]3@d]3@dm7@dm7@dm7@dm7@dm7@dm7@dm7@dm7@dm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7A
dm7Adm7Adm7Adm7Adm7Adm7Ad]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@dm7Adm7Adm7Adm7Adm7Adm7A
dm7Adm7Ad]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?
d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?eM3?eM3?eM3?eM3?eM3?eM3?
eM3?eM3?e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=
eM3=eM3=eM3=eM3=eM3=eM3=e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<
e<o<e<o<dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dm38dm38
dm38dm38dm38dm38dm38dm38d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:e<k7e<k7e<k7eLo8eLo8eLo8
e]39e]39eLo8eLo8eLo8eLo8eLo8eLo8eLo8eLo8eM37eM37eM37eM37eM37eM37eM37eM37eM37eM37
eM37eM37eM37eM37eM37eM37e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6
e<o6e<o6e]?4cLZld/g4fM?<dLk6d<g5d]77c/g3e<k1dlg0dlg0dlg2eLk5e<g4dl_4dLW2eLfldl^j
d/Vkd/Vkd/Vld<Jlbl6ga[bb^[BY^[BY^K>X][2U/jfR/:ZO[ZRM[JNLZjNLZjNLZZJKZJFJZJFJZJFJ
ZZJKZZJKZZbV/;://[B^[k6[[JnYZjfWYZRRWj6KWj:I^KbcXjJMVijE]KR_VYfDR8^2^[fd/[F/UYV@
NgieYJROWJ2GVIbCWZ6HY:NN^;:]]JnZ^kNb[ZZUZ:FP[ZjXZJVS/k>]^[:[`;Ra/ZbU]k6Z/ZnWZZNO
][>[/[2X[;2UU9R=OH5fUYZ>C5=65Qd@>D8eW:FH[:BGAdHl0Q0:01`M12df3Si@6e5X6U5/8F5c8F5c
8V9d96Af9FEg9fMi:6Qj:6Qj9fMi:FUk:f]m;6an;6an:VYl:6Qj9VIh:6Mk9fIj9VEi9VEi9VEi:6Mk
:VUm:fYn9VQk9VQk9FMj9FMj9FMj96Ii96Ii96Ii:fIi:fIi:fIi:fIi:fIi:fIi:fIi:fIi;6Yl:VQj
<6]n>gF8@G^>@7R;?7B7?G:6@GJ:<6Ym34II>fQmCVf4GGbCCgbA@X2BB8JH?WV9DXFEE7j;8d1>01<N
1A4K3AHO01/K00`:IVMM`<:_aLnha]>kblnld<VjeLJme<Rnd<NjeM31`l>aNgeY>D4Z<c`R=3DQ=3DQ
<c@P<c@P=3DQ=3DQ=SLS=SLS=3LN=3LN<cHM<cHM=3LN=3LN=STP=STP=SLS=SLS=cPT=cPT>3TU>CXV
>CXV>CXV>3TU>3TU=cPT=cPT=cPT=cPT>3TU>CXV?SdY@D0/AdHbDE0lGUe9L6mKPh9^ShijUiZ:X:>C
ZjjN[k:S[:jRZ:ZNYjRNZ:VOZjjUZ:^RYjVS[:jX]KJb^[^i^KZh][Ne/[BX^KZ`]KV^XjJM_/:l[kJ_
CeE@9R`W<ChTCU<hBTHZGe4j[Yf:f<^mc/NnblS3e<jke<jke<jkd/bidL^hd/bie]2mfM?0e<fneLjo
e/o0e/o0e/o0eLjoe<fne<fneL^ie/bjf<jlfLnmfLnmfLnmfm6og=;0f<jlf<jlf<jlf<jlf<jlf<jl
f<jlf<jlfm32clBfe/^mh]O9g=73f<fogM;4gM;4fLnmf<jlf<jlf<jlfLnmfm6ogM?1gmG3fLnmfLnm
fLnmfLnmfLnmfLnmfLnmfLnmg=;0fm6ofm6of]2nf]2nfLnmfLnmf<jlfm32fm32f/o1f/o1fLk0f<fo
f<foelbnf/o1f/o1f/o1f/o1fLk0fLk0fLk0fLk0f<jlfLnmfLnmfLnmf]2nf]2nf]2nfm6of]2nf]2n
f]2nf]2nfm6ofm6ofm6og=;0g=;0g=;0g=;0g=;0g=;0g=;0g=;0g=;0fm6ofm6ofm6og=;0g=;0g=;0
gM?1gM?1gMC0gMC0gMC0gMC0gMC0gMC0gMC0gMC0g=;0g=;0g=;0g=;0g=;0fm6ofm6ofm6ogMC0g=>o
fm:nfm:nfm:nfm:ng=>ogMC0fm:nfm:nfm:ng=>og=>og=>ogMC0gMC0g=>og=>og=>og=>og=>og=>o
g=>og=>og=>og=>og=>og=>og=>og=>og=>og=>ofm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nfM2lfM2l
fM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2leljjeljjf<nkf<nkfM2lfM2l
003@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_?cLg?cLg?cLg?cLg@c/k@c/kAcloAcloBd=3Bd=3Bd=3B
d=3Bd=3Bd=3Bd=3Bd=3CcLkCcLkCcLkCcLkCcLkCcLkCcLkCcLk@c/k@c/k@c/kAcloAcloAcloBd=3B
d=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3AcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloA
cloAcloAcloAcloAcloBd=3Bd=3Bd=3CdM7CdM7CdM7Dd];Dd];Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;C
d=;Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Ac]3Ac]3Ac]3Bcm7Bcm7Bcm7Cd=;Cd=;Bd=3Bd=3Bd=3B
d=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3CdM3CdM3CdM3CdM3CdM3CdM3CdM3C
dM3CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7Bd=3Bd=3Bd=3B
d=3Bd=3Bd=3Bd=3Bd=3CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3B
d=3Bd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oB
d<oBd<oBd<oBd<oBd<oEd<oEd<oEd<oEd<oEd<oEd<oEd<oEd<oDclcDclcDclcDclcDclcDclcDclcD
clcEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gDclcDclcDclcD
clcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcCc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_C
c/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cd<SCd<SCd<SCd<SCd<SCd<SCd<SCd<SAc<WAc<WAc<WA
c<WAc<WAc<WAc<WAc<WCcLKDc/ODc/ODc/OEclSEclSEclSFd<WEclSEclSEclSEclSEclSEclSEclSE
clSEd<OEd<OEd<OEd<OEd<OEd<OEd<OEd<OEd<OEd<OEd<OEd<OEd<OEd<OEd<OEd<OCc/GCc/GCc/GC
c/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/G?c;k7a;K8a;W:aKc5`kW9akgAclGB
d<G@c/??cL;=bl7=bl7=b/;=bLC=bLC=bLCGd/?Ecl;Dc/7CcL;Bc<7Ab/7@b<7?al3BclO@cLG>bl?=
b/;=b/;>bl?=b/;=b/;5`k_4`[[3`KW0_[Jo_KFm^k>l^[:l^[:`/Jfh^KFo`;bn_k^j^kNd]K6YZZJN
Wi^8RXBQXifd][35al6Z[:I=CdTb=2iiNgG<c/R_/J^:S8JFV99/KVQUIf6BU8k5al77`[o>blNl^KG0
_k^j^KFRXinLX9^3Qh9mNGBSWiZa[JRi][6l^KC1_[W8aL2`/:ZMW9:7QWa=CTB6RWn2R7eUJV5]MF]_
MfeJH5/P:bP57AdB=c/JB5<REVLZHgTWH7TRHW@SHgDSHgDTI7HVIWPWIgTWIgTXJ7XVIWPWIgTZJW`[
Jgd[JgdZJW`XJ7XWIgTXIg/XIg/WIWXVIGTWIWXXIg/ZJGd[JWhVJ7/VJ7/VJ7/UIgXUIgXUIgXTIWTT
IWTYIgTYIgTYIgTYIgTYIgTYIgTYIgTYIgT/JW`ZJ7X`JghjMHQ1Nhi0N8/lM8LkLhHjLXDcKX4@BUe4
KhA[QimnUZiRRImBQi];QYU3NhaDQiMIPY4[BeP46RD04AX64Q`030l551INHUfd]ZZi`k:c_jf/[j3:
a;WIcL?DbkkFc/7FdL:ZZYQKGDTX<1T]=Ahd=B4c=20c=20c=20c=20d=B4e=R8f=b<d=R0c=Alc=Alc
=Alc=Ald=R0e=b4f>28f=b<f=b<f=b<g>2@g>2@h>BDh>BDi>RHj>bLi>RHh>BDf=b<f=b<f=b<f=b<f
=b<k>RHk>RHj>BDh=b<j>BE0?b]8Ac=>CCULH4eWJeQhNf^6RGZCUXNPXYJ][j>g^:j`]:V//:FXZj:X
ZZB/[ZRa/Zje][:f]kFd^:fk_[Fl`KRY[JNf_KJ[/ZeAF5<F7a`M;AHk@b`l>R9EBC6UUh7Lc[cGcl;A
cL;=akC>b;G@b[O@b[O?bKK@b[OBc;WEckcCc;gDcKkFcl3Gd<7HdL;HdL;Gd<7Gd<7Jd;kLd/3Ld/3I
ckgDb[SBb;KDb[SGcK_Db[SDb[SDb[SDb[SEbkWEbkWEbkWEbkWQe/SLdL?Oe<KLdL?Cb;[Gc;kKd<;@
aKOIckkGcKcFc;_Db[WDb[WDb[WEbk[Ebk[OeLCNe<?Mdl;KdL3Jd;oHc[gGcKcFc;_GcK_Hc[cIckgJ
d;kKdKoMdl7Ne<;Ne<;Ebk[Fc;_GcKcIckkJd;oLd/7Mdl;Ne<?Jd;oJd;oJd;oIckkIckkIckkIckkI
ckkHc[cHc[cIckgIckgIckgJd;kJd;kJd;kIckgJd;kJd;kJd;kKdKoKdKoKdKoKdKoLd/3Ld/3Ld/3L
d/3Ld/3Ld/3Ld/3Ld/3Jd;kKdKoKdKoKdKoLd/3Ld/3Ld/3Mdl7Me<3Me<3Me<3Me<3Me<3Me<3Me<3M
e<3Ld/3Ld/3Ld/3Ld/3KdKoKdKoKdKoKdKoMe<3LdkoKd[kKd[kKd[kKd[kLdkoMe<3JdKgKd[kKd[kK
d[kLdkoLdkoLdkoMe<3LdkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoL
dkoJdKgJdKgJdKgJdKgJdKgJdKgJdKgJdKgId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cI
d;cId;cId;cId;cId;cGc[[Gc[[Hck_Hck_Hck_Id;`00=3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:blo=
cLo=cLo=cLo=cM3>c]3>c]7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm?=c]?=c]?=c]?=c]?=
c]?=c]?=c]?=c]3>c]3>c]3>c]7?cm7?cm7?cm;@d=;@d=7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?
cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm;@d=;@d=;@d=;@d=?A
dM?AdM?AdMCBd]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]7>d=7>d=7>d=7>d=7>d=7>d=7>d=7>d=3=
cm7>d=7>d=7>d=;?dM;?dM;?dM;?dM7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm;@d=;@d=;@d=;@d=;@
d=;@d=;@d=;@d=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?A
dM?AdM?AdM?AdM?AdM?AdM?AdM?AdM;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=?AdM?AdM?AdM?AdM?A
dM?AdM?AdM?AdM7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?
c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]C?c]C?c]C?c]C?c]C?
c]C?c]C?c]C?c]C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?
c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>
bm?>bm?>bm?>bm;=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];?
am;?am;?am;?am;?am;?am;?am;?am7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM?=a]?=a]C>amC>amC>
amG?b=G?b=G?b=C>amC>amC>amC>amC>amC>amC>amC>amC?a]C?a]C?a]C?a]C?a]C?a]C?a]C?a]C?
a]C?a]C?a]C?a]C?a]C?a]C?a]C?a]?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>
aM?>aM?>aM?>aM7=`]GBa=[GbM[GbMODa]KCaMGBa=;?`M;Aam;Aam7?am3=b=3=b=3=bM7>b];>cLg;
`<g;`<c:`<[7_lW6_/W5`<c8`lk9a/O4_l?0^knl]knl]l?0^lO4_lS5`<O4_l32_;o1^kk0^[fo^K^m
]kVk]KRj];Rj];fn_<C5`lW:b<O8a/G6a<72`;Vj^;2a[k6b[Zf^Z[Jg/kVj]XF6PSPi=DU:AZ>TX7]l
N6e^JVMXI9nPW9ZKUi^LV;2a[LW:a[bj^Lo=c:FVY:Z]Zi2CTEEJF5=HERL^:cXk=i:CSl72_[bm^JNX
Y:f^Z/O8a;jo^knm/kNd[5UGCfIXHVEYI6M]J:2WY9>LVAde>`h[<Q<j@R9CGB=JIbAPL2QUNBAPMREU
MbEUMbEUMbIVN2IVN2MWNBMWNBMWNBEUMbIVN2QXNRYZO2][OBYZO2UYNbQXNRUXO2UXO2QWNbQWNbQW
NbUXO2YYOB]ZORIXNbIXNbIXNbIXNbEWNREWNREWNRAVNBUWNBUWNBUWNBUWNBUWNBUWNBUWNBUWNBUY
NbYXNRm]Oc]fRD1jSCegRSadQcadQc5/OcAbQ11:GDA]PhbR^ib]agB@Z5b5Vd^5V49jRe23TeF0SbmB
H0LS;P0C7@0B7@0C6@`P9BL/;DiBCD]FC4MEBTM<@ijHTM37^/_3]]?>_lO4]H:2L3/m:BDZ5C0g8S8d
834c7c4c7c4c7c4c7c8d83<e8C@f8S<e7c8d7S8d7S8d7S8d7S<e7c@f83Dg8CDf8SDf8SHg8cHg8cHg
8cLh93Lh93Lh93Xk9cTj9SPi9CHg8c@e8C@e8C@e8C@e8Chm:Chm:C`k9cTh93Lf8SPg8c`k9cln:SLi
9Ci0;4U;>5EFAV9SDg=cIHF5Mi:BQYJJSYnSUjb`Y;Fi[[Rk/[Fh[k6c[Jj`ZZ^`YjbdZ[Jm]ZN^ZJZd
[Zff/f=^JaHQ7aLX6SA0;SPi9Di6;ifANM[=]mgA_m79^=OA_]SB_mWC`=OA_]C>^m;<^M?=^]C>^l_4
/lc5]<k7]]39^=7:^M;;^];;^];;^/[3/<o8]MG>^mO@_MK?_=G>^mO@_M[C`=_D`M[C`=[C`=[C`=[C
`=WB_mWB_mWB_l_3//o7]]G=_=38]lc4/mgEa>GMc=O?_]W>`=W>`=W>`=W>`=_@`]cA`mkCaMoDa]G:
_=K;_MK;_MK;_MO<_]O<_]S=_mS=_mgC`MgC`McB`=_A_m[@_]W?_MW?_MS>_=_A`=_A`=_A`=_A`=_A
`=_A`=_A`=_A`=W?_]W?_]W?_]W?_]W?_]W?_]W?_]W?_]S>_=S>_=S>_=W?_MW?_M[@_][@_][@_]W?
_MW?_MW?_M[@_][@_]_A_m_A_m_A_m_A_m_A_m_A_m_A_m_A_m_A_m_A_m_A_m[@_][@_]_A_m_A_m_A
_mcB`=cB`=cB`=cC_mcC_mcC_mcC_mcC_mcC_mcC_mcC_m_A_m_A_m_A_m_A_m_A_m_A_m_A_m_A_mcC
_mcC_m_B_][A_M[A_M_B_]cC_mcC_m[A_M[A_M_B_]_B_]_B_]cC_mcC_mcC_m_B_]_B_]_B_]_B_]_B
_]_B_]_B_]_B_]_B_]_B_]_B_]_B_]_B_]_B_]_B_]_B_][A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_MW@
_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=O>^]O>^]O>^]S?^mS?
^mS?^`00d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;clg=clg=clg=clg=d<k>d<k>dLo?dLo?dLo?dLo?
dLo?dLo?dLo?dLo?dLo?dLo?dlg>dlg>dlg>dlg>dlg>dlg>dlg>dlg>d<k>d<k>d<k>dLo?dLo?dLo?
d]3@d]3@dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?
dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d]3@d]3@d]3@dm7Adm7Adm7Ad/oAd/oAd/oAd/oAd/oAd/oA
d/oAd/oAdLk@dLk@dLk@dLk@dLk@dLk@dLk@dLk@d<g?d<g?d<g?dLk@dLk@d/oAd/oAd/oAdLo?dLo?
dLo?dLo?dLo?dLo?dLo?dLo?d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3?d]3?d]3?d]3?d]3?d]3?
d]3?d]3?d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@
d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@dLo?dLo?dLo?dLo?dLo?dLo?
dLo?dLo?dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>
dLo>dLo>dLo>dLo>dLo>dLo>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o<e<o<e<o<e<o<e<o<e<o<
e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<dlk;dlk;
dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;d/g:d/g:d/g:d/g:d/g:d/g:
d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/o7d/o7d/o7d/o7d/o7d/o7d/o7d/o7dLc9dLc9
dLc9dLc9dLc9dLc9dLc9dLc9dlg6dlg6dlg6e<k7e<k7e<k7eLo8eLo8e<k7e<k7e<k7e<k7e<k7e<k7
e<k7e<k7e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6dlk5dlk5
dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5b<Jld<c1aL:c/[2N[ZZG[ZZH
/JZK]ZnP];N^]kZa^[bf_;jh_;fi_;fk_;fk_Kjl_[nf`<6h`/>j`L6k_kjj_kjj`/2oaL?2_l2l^[^g
]KJb]KJb^[^g_[nk_[nk_Kjj_L6l_/:m_l>n_l>n`<Bo`<Bo_l>n_l>n`;jm`l70`Knn_;Zi_;Zi`Knn
`l70`;jma<>o`/6mbl[6alK2ZJRTU9>?Z:NSb<O3eMC@YjJRK6]WOgijPX5mWYfI][Fa_;^g_;nmc]7?
][Vg/kRfT9NDFf9OEf1M@4U6@4I1TiVD^/2k[K6/Si>>UIJB]kRd^KZf^KJ^aL>kWYfI[K:`/;RhTinQ
NHR;>4I<33M8549C7EAS85a/6ea[75i`8V9d8F5c9fMi9fMi9fMi9fMi:6Qj:6Qj:6Qj:6Qj9FEg9VIh
:6Qj:FUk:VYl:f]m:VYl:VYl:VUm:VUm:VUm:FQl:VUm:VUm:VUm:fYn9fUl9fUl9VQk9VQk9VQk9FMj
9FMj9FMj:6Qj:6Qj:6Qj:6Qj:6Qj:6Qj:6Qj:6Qj:6Qj:6Qj<6j0>GN9?gZ=?7J9>WB7>gF8:FUk<g>5
3DMJ>V5gVJ[4[;G@OY:[GWjEC8BEA7Z;CH2@EX>A?fUf8DAB6CU68Sm=:E9K?5EO51dV1@/@00X:1A@@
5Q`GVIBAclZkc/Vjd/o0[ZjLGEm<;c4N;c<P=3PU<38O<38O;c4N;c4N<38O<C<P<S@Q<S@Q<C8N<C8N
<34M<34M<C8N<S<O<c@P<c@P=3DQ=3DQ=CHR=CHR=CHR=CHR=CHR=CHR=cPT=cPT=CHR=3DQ<c@P<c@P
=3DQ=3DQ<C0L<c8N=C@P=SDQ=cHR>CPT?C`X@3l[>C`V>C`V>C/W>C/W>cdZ@T<cC4dmDeA4HFADLWEU
RhioWj:CZZbP[k2V/[>Y]KJ//;R^Zk>Y/k^dZ;:/Y:jX[;NdLGai2AHD1aP?8BdQ9bdL?3TTQ7YR`kRM
cL6Y`;>M_kZU`;^V`;^V`;^V_kZU`KbWaL2[bLB_c/VdclZedLbgd/fhd/fhd/fhd/fhd/fhdLZfd/^g
eLjjf=6mfM:neLjjc/NcbL:^d/^gdLZfdLZfdLZfd<Ved<Ved<Ved<Veg=G1fM:ngMK2fmC0d/^geLjj
em2lc<Fad/Nid/Nid/NidlRje<VkeLZleLZle/^mfLk0fLk0fLk0fLk0f/o1f/o1f/o1f/o1fM2lf<nk
eljje/fie<^gdlZfd/VedLRdf]2nf]2nfLnmfLnmf<jlelfkelfke/bjf<jlf<jlf<jlf<jlfLnmfLnm
fLnmfLnmelfkf<jlf<jlf<jlfLnmfLnmfLnmf]2nfLnmfLnmfLnmfLnmf]2nf]2nfm6ofm6ofm6ofm6o
fm6ofm6ofm6ofm6ofm6ofm6of]2nf]2nf]2nfm6ofm6ofm6og=;0g=;0fm:nfm:nfm:nfm:nfm:nfm:n
fm:nfm:nf]2nf]2nf]2nfm6ofm6ofm6ofm6ofm6og=>ofm:nf]6mf]6mf]6mf]6mfm:ng=>of]6mf]6m
f]6mfm:nfm:nfm:ng=>og=>ofm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:n
fm:nfm:nf]6mf]6mf]6mf]6mf]6mf]6mf]6mf]6mfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2l
fM2lfM2lfM2lfM2lfM2lfM2le/fie/fieljjeljjf<nkf<nk003@b/_@b/_@b/_@b/_@b/_@b/_@b/_@
b/_?cLg?cLg?cLg?cLg@c/k@c/kAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloCcLkCcLkCcLkC
cLkCcLkCcLkCcLkCcLk@c/k@c/k@c/kAcloAcloAcloBd=3Bd=3AcloAcloAcloAcloAcloAcloAcloA
cloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloA
cloBd=3Bd=3CdM7CdM7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3A
c]3?c<k@cLo@cLo@cLoAc]3Ac]3Ac]3Bcm7AcloAcloAcloAcloAcloAcloAcloAcloBd=3Bd=3Bd=3B
d=3Bd=3Bd=3Bd=3Bd=3Bd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3B
d=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3B
d=3Bd=3Bd=3Bd=3Bd=3AcloAcloAcloAcloAcloAcloAcloAcloAclkAclkAclkAclkAclkAclkAclkA
clkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkDclkDclkDclkD
clkDclkDclkDclkDclkDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcD
clcDclcDclcDclcDclcDclcDclcDclcDclcBcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[B
cL[BcL[BcL[BcL[BcL[Ac<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WA
c<WAc/KAc/KAc/KAc/KAc/KAc/KAc/KAc/K@blS@blS@blS@blS@blS@blS@blS@blSBc<GBc<GCcLKC
cLKCcLKDc/ODc/ODc/OCcLKCcLKCcLKCcLKCcLKCcLKCcLKCcLKCc/GCc/GCc/GCc/GCc/GCc/GCc/GC
c/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCB
cLCBcLCBcLCBcLCBcLCAc/K<b[nPWXa^K5AUHDQeKeR;Q76VW8^UZIj//:Fe^:nk_KNk_KNj^kNi^[Ji
^[Rh^k:i_;>k_[Fk_KNj^kNh^KFi^[Ri^[Rm_kVj_;Jg^K>g^K>j_;Jk_KNi^kFg^K>d^;:e^K>f^[Bh
_;Jh_;Jh_;Jg^kFg^kG2_k_4`Kg2_k^m^[Jm^[K3`;c6`ko5`[jm^[Fm^[G6`kk6`kjl^KC1_[W3`;^d
/Jba[ZVi][6[Z:>o_;Nc/:_5`[g<bLBn^kJ]/Jb^/Zfj_[Vna;nf_KRU[:NBW9J?VI=oQh2JXY^KXY^L
X9ZLX9ZRY9jb/ZbUYInSYYfEVI>@VIImRhYcQX]MM7`gDEdO>TP8?e@GDVHLFflFFf`HGVlQIWLWJWT[
K7/XJ7XXJ7XYJG/YJG/YJG/YJG/YJG/YJG/VIWPWIgTXJ7XZJW`[Jgd[Jgd/K7h/K7h[JWh[JWh[JWh[
JWh[JWh[JWhZJGdZJGdWJG`WJG`WJG`WJG`VJ7/VJ7/UIgXUIgXXJ7XXJ7XXJ7XXJ7XXJ7XXJ7XXJ7XX
J7XUIgTVJ7X_Kh4jN8XlNX`jMHPiM8LlMXTXJW`bM8H<AeX/DfVDYKn]]]6:VkETPiYCQiQ=PI9?PY9I
RYYFPi51K7]1JWUEOha:NhENOX/Y>DH02Q@041H<7QlU;BbXYZG;bkW>c[c5aK>;SGY1@c0]<20e>2PY
;1`]<20/;al/;al/;al/;al]<20^<B4_<R8`<Ad_<1`_<1`_<1`_<1``<Ada<Qhb<ald=B4d=B4c=20c
=20c=20c=20c=20c=20c=20b<alb<alb<alc=20d=B4e=R8f=b<b<Ade=20g=R8g=R8f=B4f=B4g=R8h
=b<k?RDj?B@h>b8f>28e=R8g>2@k>bTn?R`g>BE1@bm>D3aKGDYZJe]oP72HV8ZZZYb_]JZX/:Fb^[2c
_;:X/j^/][1bOWP02080100650TA6@PU9a5OFT6GSW>VVh2JSWJDT7RETGVGTg^JUWjPW8BYYHfd/9Rl
^:2_Zi>_Zi>_Zi>_Zi>^ZY:]ZI6/Z92[Yhnk]ine/IVc[iNm^J7>b[;Je[kLf<3IeKgAcKGBc[KDd;SF
d[[He;cJe[kLf<3MfL7<b;2o^j?9aJgLf<3Gdk_?bk?Bc[KDd;SPe/COeL?Ne<;Mdl7KdKoIckgHc[cG
cK_KdKoKdKoIckgGcK_EbkWCbKOBb;KAakGIdK[IdK[Jd[_KdkcLe;gNe[oNe[oOel3Db[SDb[SEbkWF
c;[Hc[cIckgJd;kJd;kGcK_GcK_GcK_Hc[cHc[cIckgIckgIckgGcK_GcK_GcK_Hc[cHc[cIckgIckgI
ckgHc[cHc[cIckgIckgIckgJd;kJd;kJd;kJd;kJd;kJd;kJd;kJd;kJd;kJd;kJd;kIckgIckgJd;kJ
d;kJd;kKdKoKdKoKdKoJdKgJdKgJdKgJdKgJdKgJdKgJdKgJdKgIckgIckgIckgJd;kKdKoKdKoKdKoL
d/3Kd[kKd[kJdKgId;cId;cJdKgKd[kKd[kId;cId;cJdKgJdKgJdKgKd[kKd[kKd[kJdKgJdKgJdKgJ
dKgJdKgJdKgJdKgJdKgJdKgJdKgJdKgJdKgJdKgJdKgJdKgJdKgId;cId;cId;cId;cId;cId;cId;cI
d;cHck_Hck_Hck_Hck_Hck_Hck_Hck_Hck_Hck_Hck_Hck_Hck_Hck_Hck_Hck_Hck_FcKWFcKWFcKWG
c[[Gc[[Gc[X00=3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:blo=cLo=cLo=cLo=cM3>c]3>c]7?cm7?cm3>
c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]?=c]?=c]?=c]?=c]?=c]?=c]?=c]?=c]3>c]3>c]3>c]7?cm7?
cm7?cm;@d=;@d=3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?
cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm3>c]3>c]7?cm7?cm7?cm;@d=;@d=;@d=7>d=7>d=7>d=7>d=7>
d=7>d=7>d=7>d=3=cm3=cm3=cm3=cm3=cm3=cm3=cm3=clo<c/o<c/o<c]3=cm3=cm7>d=7>d=7>d=3>
c]3>c]3>c]3>c]3>c]3>c]3>c]3>c];@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=7?c]7?c]7?c]7?c]7?
c]7?c]7?c]7?c]7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm;@
d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm3>c]3>c]3>c]3>c]3>
c]3>c]3>c]3>c]3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>
cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cMC?c=C?c=C?c=C?c=C?
c=C?c=C?c=C?c=?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm;=
b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=b]7<bM7<bM7<bM7<bM7<
bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7>a]7>a]7>a]7>a]7>a]7>a]7>a]7>a]3;
b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=;<aM;<aM;<aM?=a]?=a]?=a]C>amC>am?=a]?=a]?=a]?=a]?=
a]?=a]?=a]?=a]?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM;=
a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=KBcMOEbZ:QS69QAEQE
=VMPAGebG9Z>O9nOTJRXV[>cYkVh[[Zi[kRf[[Rf[[Vf/L32][fo/k^l/[Zk/[Zk/[Zj];Ng/KFd/;:a
YkBcZKNf[;Zi[kVh[[Rg[KFdZ[>bZ:b`YJfaYZjbYjjbYjfaYZ^_Y:V]XZN[X9jMTj>RV:FTVZ>RV::Q
Uj:QUijMTiRGSInOTi2@Q8j>PY2@Q8R8O8R8O92@Q9:BQWmoLhn?Ph61MHN7NfYZGWMgJh61MGAdJ8>4
NW5bJ7n3N8^AQYZPUIJNTg5iKVMaIE9LCeYTEeAMD6AXG6]]HFQXG75_I6QTFEIUGCm?B5AYIS5<D2M8
DAe4DQ0lCBQEJPi9GB1MLAmQM1QNKb9XNBM/NbQYN2i/O2UYNbUYNbUYNbYZO2YZO2][OB][OBa/ORYZ
O2YZO2YZO2][OBa/ORa/ORe]Obe]Oba[Oba[Obe/P2e/P2e/P2a[Ob]ZORYYOBQZOBQZOBMYO2MYO2MY
O2IXNbIXNbIXNbMYNbMYNbMYNbMYNbMYNbMYNbMYNbMYNbEWNBMYNbi`PSQhRS]iRcMeQcQcQSagRRa^
P31eQQ5?HB5<HHFI/ZFbc9N]aVj@YeV<W5F8V4j1TE64U4f0T3AWMbmRLTQkRdQoQUUoRcA9F0023`0:
4P8G6BXg=I2DSiNIQIjPS8b>NUQJAbd^7Rd`83@g:2HY6RX`7bT_7RT_7RP^7BT_7RX`7b/a82`b8Bl_
7Bh^72h^72d]6bh^72l_7C0`7S4a7c<d83<d838c7c8c7c8c7c4b7S4b7S4b7S0a7C0a7C0a7C0a7C8c
7c<d83Df8SHg8cLf8STh93/j9S/j9STh93Pg8cTh93Xi9C<g6S<f73@g7CDh7cHi83Pj93Tj9SXk9blc
6S<g7SPk9CXm9ci0;4Q:=eMIAV=UDWEhJ7^1L8fBPj:YW:F^XJ^cZ8:<P1LP5PdH41<M4AXR4BX]5dI7
;FQTB79[DVaQBfeYDFeYDFeYDFaXD6m[DgIbFWmkHhF1JHZ6KHZ6KHZ6KHV5K8R4JhJ2JHB0Ih=oITi<
=4=1:C`j8TE3:eeK@gMeGHJ4K8Z8L9NEOIVGOibJPZ6OQjJTS:^YTJj/U;2^UYVHOXV8KYbKPKnnY<G4
Z/70Y/c;/MWH_/[2Zl_3[<k6[m79/]C<]MK>]mO?^=S@^M79/];:/mC<]MK>]mWA^]_C_=gE_]kF_m;:
/m;:/m;:/m?;]=C<]MC<]MG=]]G=]]kE`MgD`=gD`=cC_m_B_][A_M[A_M[A_MK=^MK=^MK=^MO>^]S?
^mW@_=W@_=[A_MO=^mO=^mO=^mO=^mS>_=S>_=S>_=W?_MS>_=S>_=S>_=S>_=W?_MW?_M[@_][@_][@
_][@_][@_][@_][@_][@_][@_][@_]W?_MW?_MW?_M[@_][@_][@_]_A_m_A_mW@_=W@_=W@_=W@_=W@
_=W@_=W@_=W@_=S>_=S>_=W?_MW?_M[@_]_A_mcB`=cB`=_B_][A_MW@_=W@_=W@_=W@_=[A_M_B_]W@
_=W@_=W@_=[A_M[A_M[A_M_B_]_B_][A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A
_M[A_M[A_M[A_MW@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=S?^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mS?
^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mG<^=K=^MK=^MK=^MO>^]O>^P00d<[;d<[;d<[;d<[;d<[;d<[;
d<[;d<[;clg=clg=clg=clg=d<k>d<k>dLo?dLo?d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>dlg>dlg>
dlg>dlg>dlg>dlg>dlg>dlg>d<k>d<k>d<k>dLo?dLo?dLo?d]3@d]3@d<k>d<k>d<k>d<k>d<k>d<k>
d<k>d<k>dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d<k>d<k>
d<k>dLo?dLo?dLo?d]3@d]3@dLk@dLk@dLk@dLk@dLk@dLk@dLk@dLk@d<g?d<g?d<g?d<g?d<g?d<g?
d<g?d<g?clc>clc>clc>d<g?d<g?d<g?dLk@dLk@d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>d]3@d]3@
d]3@d]3@d]3@d]3@d]3@d]3@dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo?dLo?dLo?dLo?dLo?dLo?
dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@dLo?dLo?
dLo?dLo?dLo?dLo?dLo?dLo?d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k=d<k=d<k=d<k=d<k=d<k=
d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=dlk=dlk=
dlk=dlk=dlk=dlk=dlk=dlk=e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<dlk;dlk;dlk;dlk;dlk;dlk;
dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:
d/g:d/g:d/g:d/g:d/g:d/g:d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8
d<_8d<_8d<g5d<g5d<g5d<g5d<g5d<g5d<g5d<g5cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7dL_4d/c5
d/c5d/c5dlg6dlg6dlg6e<k7d/c5d/c5d/c5d/c5d/c5d/c5d/c5d/c5d/g4d/g4d/g4d/g4d/g4d/g4
d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4dLc3dLc3dLc3dLc3dLc3dLc3dLc3dLc3dLc3dLc3
dLc3dLc3dLc3dLc3dLc3dLc3`Kjjdm76YjJAJVQ9G5XgGeLiHEDmMFICLG5ONGUWPH5aQ8AdPh9dPX1e
QH=hR8IkKVmOI6AFFEU;EEE9EeM;FEQ>EeE=De59EUE7H5mAK6]MLW5SLG1RKFaNJfYLJfYLJ6QJJFUK
JVYLJf]MJVYLJ6QJIVIHI6AFIVIFK6aLKViNK6aLJf]KJf]KIVIFH61@IFECI6ABK6aJMWITLg=QI6AB
HF5?JVYHJf]IJ6QFEUI4KViLGem=IfMEK6aJI6ABKViNHfADFU];JFaLKW5QF5i=ADdl=Cd/?TTeEUm;
GF=@If]HHV9@FeM5K6EDJfACD6]Q8T4j5cXf234d9eQR;69c:fMm:fV17eMX;fYj9fQg86=b:Fim9fYi
8V1`;FUi:6Qj:FUk:VYl:f]m;6an;Feo;Vj0;Vj0;Feo;Feo;Feo;6an;6an;Feo;Vj0;Vj0;6]o;Fb0
;Vf1;Vf1;Vf1;6]o:fYn:FQl:6Ym:6Ym:6Ym9fUl9fUl9fUl9VQk9VQk9fUk9fUk9fUk9fUk9fUk9fUk
9fUk9fUk8VMh9FYk;g63=gV;>GV;=WB6=WB6?7N:;g63;W>46EMY6TMLJhFMSj>lU[G<J9>XF8VIEhZJ
CX6ABgn@@GN86e=T2d=D8Ea/BXV=EhF=DF]i00`K00LB00d?;chjKWE^CeM0EUi7B4dh;S8O:B`L;C0Q
<30R<S8V:2dN:2dN:2dN9b`M:2dN:BhO:RlP:c0Q;BdK;BdK;BdK;2`J;BdK;RhL;blM<30N<S<O<S<O
<S<O<C8N<C8N<34M<34M;c0L<34M<34M;c0L<34M<34M<S<O<c@P=3DQ:RTE;B`H;bhJ<2lK<2lK<C0L
<c8N=C@P<cDG<cDH<S@G<c@J=3DK=CDM=SDP=C@O=CTL>SdS@4<Y@4<Z?3lV=cTS=3DQ<c@P?3hXC4di
E5I2KW1MN7aYOhEdMGY[:c8S9B/P7RDF9B/H;cDL=3TN?3dSAD0[@S/X?SXQ?SXQ?CTP>SHM=c<J=c<J
>CDL>cLN>CHJ>CHJ>CHJ>CHJ>3DI=c@H=S<G=C8F@D0V>3LM;B`B:2L=;2/A<S4G>3LM>STO<c8H=3<I
=cHL>STO?C`R@3lU@d8XA4<Y?chR<C0D>cXNCD``C4/_BDP/DE0dEeHjLF]>M6iANWAGPG]NR89USXQ[
TH]^The`WiUlXYaoYj64[JN:]:jA^[BG_kVL`[bOc<F/cLJ]clR_dlbce/nffM:ig=FlgMJmdLRddLRd
d/Ved/Ved/VedlZfdlZfdlZfeLbheLbhe/fieljjf<nkfM2lfM2lf]6me/bje/bjelfkelfkelfkf<jl
f<jlf<jlelfkelfkf<jlf<jlfLnmfLnmfLnmfLnmfLnmfLnmfLnmfLnmfLnmfLnmfLnmfLnmf<jlfLnm
fLnmfLnmf]2nf]2nf]2nfm6of<nkf<nkf<nkf<nkf<nkf<nkf<nkf<nkelfkelfkf<jlfLnmf]2nfm6o
g=;0g=;0f]6mf]6mfM2lf<nkf<nkfM2lf]6mf]6mf<nkfM2lfM2lfM2lf]6mf]6mf]6mfm:nfM2lfM2l
fM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lf<nkf<nkf<nkf<nkf<nkf<nk
f<nkf<nkeljjeljjeljjeljjeljjeljjeljjeljjeljjeljjeljjeljjeljjeljjeljjeljjeLbheLbh
e/fie/fie/fieljj003@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_?cLg?cLg?cLg?cLg@c/k@c/kAcloA
clo@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/kCcLkCcLkCcLkCcLkCcLkCcLkCcLkCcLk@c/k@c/k@c/kA
cloAcloAcloBd=3Bd=3@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/kAcloAcloAcloAcloAcloAcloAcloA
cloAcloAcloAcloAcloAcloAcloAcloAclo@c/k@c/k@c/k@c/kAcloAcloBd=3Bd=3Ac]3Ac]3Ac]3A
c]3Ac]3Ac]3Ac]3Ac]3@cLo@cLo@cLo@cLo@cLo@cLo@cLo@cLo>blg?c<k?c<k?c<k@cLo@cLo@cLoA
c]3@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/kBd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3AclkAclkAclkA
clkAclkAclkAclkAclkAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloA
cloBd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3AcloAcloAcloAcloAcloAcloAcloAclo@c/k@c/k@c/k@
c/k@c/k@c/k@c/k@c/k@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@
c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gDclcDclcDclcD
clcDclcDclcDclcDclcCc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_C
c/_Ac<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<W@blS@blS@blS@
blS@blS@blS@blS@blS@blS@blS@blS@blS@blS@blS@blS@blS@cLG@cLG@cLG@cLG@cLG@cLG@cLG@
cLG?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/OAblCAblCBc<GBc<GBc<GCcLKCcLKCcLKBc<GBc<GBc<GB
c<GBc<GBc<GBc<GBc<GBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCB
cLCAc<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?3`;cIelbZZY9V
ID=GE2iDCBaCARaUET=DDCaIET5NFTMNFTQKEdELEdQQG4eWHEAMGD]>CS`l?2`e=BDi>2Xm>c0l>Rlh
=R]3?beBCSaTH4i]JEM/J5IYIE=XI59ZIUARH4iTHU1XIUAZJ5I[JEM[JEMYIeEXIUAVIUAXJ5IVIUAR
HU1RHU1WIeEYJEMWIeEQHdeYJeEUIe5OHD]TIU1UIe5SIDmXJUAMGdUCECm6B39[KEMGFD==CcUEEd5N
H4YVI59eLf5GEdE]KE]QHe0l@2eHG4U@E453CCIGGdQFG4ENH4YPGdYQG4MZHdmME40D>2`MA3`WDTlS
EUT]J78<CV0QIghCGGLYGV/fKG`ZIgDQHW0^KghWJ7LTH70fL8<XJ7XYJG/ZJW`[Jgd]KGl^KX0_Kh4_
Kh4_Kh4_Kh4^KX0]KGl]KGl]KGl^KX0^KX0]K80^KH4_KX8_KX8^KH4]K80[JWhYJ7`XJWdXJWdXJWdX
JWdWJG`WJG`VJ7/VJ7/UJW/UJW/UJW/UJW/UJW/UJW/UJW/UJW/RIgPUJW/_LH<gNH/iNH/fM8HfM8Hk
NH/`LX@/LH8KFfdC@UMGLh]jTZZ=[lIHRYi?P91HRIUCQYIDR9U;Pi@RG6l;AUTQGg4nPH9CPhUbSI/D
:CP372H04Q@dASmCFe4d?B<g?bPX;aXV:QLc=RH/;b0X:1`k>blX;AhW;1dW;1dW;1dW;1dX;AhY;QlZ
;b0];Ad/;1`/;1`/;1`/;1`];Ad^;Qh_;alb<alb<ala<Qha<Qh`<Ad_<1`_<1`_<1`b<ala<Qh`<Ad_
<1`_<1``<Ad`<Ada<Qhd<alf=B4g=R8f=B4e=20d<alf=B4h=b<g>A/e=aTc=APc=APe=Q`f=Qhg=alg
=alf>Qdf>Qdg>ahh>b4j?B@m@2M1@be4AS0n?2A6ARhg=alj?2Hh>RHk?BU3Ac@G6`PE5`/:3@0D6@@R
:0lM90TL7`HU910Z9Q@Y9@`]:A0a;A@b;QDa;A@`;1<`;1<`;1<^;0h^;0h_;@l`;Q0`;Q0`;Q0_;@l^
;0hT8`TX9`d/:a4/:a4Y:0hU90XT8`TU90X_;Q@_;Q@_;Q@^;A<^;A<];18];18/:a4_;a4Y:@/^;Q0c
<aD`<18i>A]4A2I1@B<g<Q4i=1<m>1M1?1]3?Qe5@1m6@B16@B14?ai6@B18@b9;ARE>BBQAC2]CCReD
Cbi>AbiCC3=LECaXHDQeKUF1NV6:PfZ?R6nVWXNYXHZ`Z96h/9W0^:79`J[?ak3Bb[?Dc;GEcKKEcKKF
c[OHd;WIdK[IdK[Jd[_Fc;[Fc;[Fc;[GcK_GcK_Hc[cHc[cHc[cGcK_GcK_Hc[cHc[cHc[cIckgIckgI
ckgIckgIckgIckgIckgIckgIckgIckgIckgHc[cHc[cIckgIckgIckgJd;kJd;kJd;kHck_Hck_Hck_H
ck_Hck_Hck_Hck_Hck_GcK_GcK_Hc[cIckgJd;kKdKoLd/3Ld/3JdKgJdKgId;cHck_Hck_Id;cJdKgJ
dKgHck_Hck_Id;cId;cId;cJdKgJdKgJdKgId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cI
d;cId;cId;cId;cId;cHck_Hck_Hck_Hck_Hck_Hck_Hck_Hck_Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[G
c[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Ec;SEc;SEc;SFcKWFcKWFcKT00<k9b<k9b<o:bLo:bLo:
bM3;b]3;b]3;b]3:bm7;c=7;c=7;c=;<cM;<cM;<cM?=c]C>cmC>cmC>cmC>cmC>cmC>cmC>cmC>cm3>
c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3:bm7;c=7;c=7;c=;<cM;<cM;<cM?=c]7?cm7?cm7?cm7?cm7?
cm7?cm7?cm7?cm3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c/o=cLo=cLo=cLo=cM3>c]3>c]7?cm7?cm7?
cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm3>c]3>c]3>c]7?cm7?cm7?cm;@d=;@d=7?cm7?cm7?cm7?cm7?
cm7?cm7?cm7?cm3>c]3>c]3>c]7?cm7?cm7?cm;@d=;@d=7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]C?
c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]?>cM?>cM?>cMC?c]C?c]C?c]G@cmG@cmC?c]C?c]C?c]C?c]C?
c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]C?
c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]C?c]3>cM3>cM3>cM3>cM3>
cM3>cM3>cM3>cM;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=?>
bm?>bm?>bm?>bm?>bm?>bm?>bm?>bmCAbMCAbMCAbMCAbMCAbMCAbMCAbMCAbMC?c=C?c=C?c=C?c=C?
c=C?c=C?c=C?c=?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bmgJd]3=aLk;`m7>a/k;`m;?amODc=;?am3=
aM3=aM3=aM3=aM3=aM3=aM3=aM3=aM;?am;?am;?am;?am;?am;?am;?am;?amG>bmC=b]C=b]?<bM;;
b=7:am7:am39a/k>`/k>`/k>`/k>`/o?`lo?`lo?`lo?`m7;a=7;a=7;a=3:`m3:`lo9`/o9`/o9`]K=
a=K=a=K=a=K=a=K=a=G<`mG<`mG<`mGD`=;B`/o=aLo>b/o@c/g>b/[;`/K8_=;;`]C=a=G>aMG>aM?<
`m7:`M7:`M7:`MO9`mC8`]?7`M?7`M?9`]G;a=G=a]O?b=G7b=K9amK9amG:a]G;a=?;a=;;`];;`/o@
amOEcM7?am7>a/g7`=C>an3HdLNo^=C@_];<^KVbWVAJ@UY=<emA=5i<;EA38V5A>V9B>f1B>emC>eiD
?5mH?f9MA6EQB6ILDU14>4Dh:4e2;U17<d@n:cPh:3/k;DA6<4Y==5UK?F9UAF9S@EYK>eQG>eiJ@EeI
@F=OAVUUC6]XC6UWBFQVAfUXAV]ZB6MPCFMPCFMPCFMPC6MPC6QQCFQRBfQRBfaTEfaTEfaUEV]TEFYS
DVQQD6IOCVEOC5mJ@E1:<e5==F1MB5eJADI5<D4o;Da<>ViTDfMQBV5O@5]P>EMO=e1H>TaB?d]?A4YL
=dUA<U9>=V1FAEiLDTEECQi7@P<m>0m;EaIDGaeMJ1mQK1eRK1aSKB1XLRE]MbYYMba[NBi]Nbi]Nbi]
Nbi]Nc1_OC9aObI`PR1XNRQ`PS9gRRM/Ob9VNBU[OR]]P2a^P2a^P2e_PBi`PRi`PRmaPc1bQ31bQ2aa
PRebPbicQ2]`PBM/OBEZNbM/OBY_P35/P2aYOBEWNR=WNREYO2U[ORi[ObmZORYZO2MYNbMYNbQZO2M/
OBI[O29XNAmUMR]ZN2m^O3QePcaiQcagQSYcPS]dPcefQCQgS2aWNR]RL@e1CS1OKD=aPTYjS5>2V5>:
TeJ;V5:4UU63Udn1UCY/ORQLJB]OJe68Udn0SUAnRbQ8D`0D6`0H73aCEA`d=0TA2Q8L41lY6BD`72L`
6bP^6b/a82hc92DZ6bH[72P]7RT^7b/`8B/`8B/`8B/`8B/Y5b/Y5b`Z62`Z62`Z62d[6Bd[6Bd[6BT^
7b`a8Rdb8bd`8B`/7RXZ72d/7Rl^82X`7BP^6bL]6RP^6bT_72X`7BT_72L]6Rh/6Rh/6Rl]6c0^734_
7C8`7S<a7c<a7cHe83@f838c7c0`7S0^73D_73/d840h8C`i93`h9C`h9C`h9Chi940k8TDl8DLl848o
8dA09d<o9T4m9D8m:3lj9C@^6bHP3@/E1@lG1QXK2bHR42`U52dW52`Y52d/5c0/4c0/4c4]538^5C8^
5C<_5S<_5S@`5cXf7CLc6S@`5c@`5cDa63Da63@`5c<_5S4`5S8`638`638_6S4]6Rl[62dY5b/W5BT[
5BX/5R`^62h`6S0b730b730b730b72h]4c<b63Pg7CDd6Rl^52h]4c@c6C/j83Lg6CHf63De5c@d5S<c
5C@d5S@d5S@d5S@e5CDf5SDf5SDf5SDf5S@e5C<d53<d538d5bd_4R`^43<d53Tg63Th5S`j640n6clm
6d4o7DE38DY89U1>;5EC<EUG=E]I=g1[BWMbDH9mG8^6II>>KIfHMjNRPJjYR;^cUKJ`TlC2Y=;A]M7@
]]??]m_B_]_@_=C<]MS@^McD_MoG`=oG`=cD_MO?^=C<]McA^mW>^=O<]]S=]m[?^MgB_=gB_=cA^mW>
^=W>^=W>^]S>_=W?_]K=_mC;_];9_>;E_mcA^mO<]]?;]=;>]]?A^MCD_=KF_]K=^MK=^MK=^MO>^]O>
^]S?^mS?^mS?^mW>^=W>^=W>^=[?^M_@^]_@^]cA^mcA^m[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?
^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?
^M[?^M[?^M[?^MW>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=S=
]mS=]mS=]mS=]mS=]mS=]`00c/W8c/W8cl[9cl[9cl[9d<_:d<_:d<_:d<[;dL_<dL_<dL_<d/c=d/c=
d/c=dlg>e<k?e<k?e<k?e<k?e<k?e<k?e<k?e<k?d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<[;dL_<
dL_<dL_<d/c=d/c=d/c=dlg>dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d<k>d<k>d<k>d<k>d<k>d<k>
d<k>d<k>clg=clg=clg=clg=d<k>d<k>dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d<k>d<k>
d<k>d<k>dLo?dLo?d]3@d]3@dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d<k>d<k>d<k>d<k>dLo?dLo?
d]3@d]3@dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>dlk=dlk=
dlk=dlk=e<o>e<o>eM3?eM3?e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>
e<o>e<o>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>
e<o>e<o>e<o>e<o>e<o>e<o>d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d/g<d/g<d/g<d/g<d/g<d/g<
d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;e=79e=79
e=79e=79e=79e=79e=79e=79e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<dlk;dlk;dlk;dlk;dlk;dlk;
dlk;dlk;dm38dLk6dLk6dm38dm38dLk6d<g5clc4d<g5d<g5d<g5d<g5d<g5d<g5d<g5d<g5dLk6dLk6
dLk6dLk6dLk6dLk6dLk6dLk6clS5d<W6d<W6d<W6dL[7dL[7d/_8d/_8c/c4clg5clg5d<k6dLo7dLo7
d]38d]38d/k9dLg8dLg8dLg8dLg8dLg8dLg8dLg8dL_4dL_4dL_4dL_4d/c5d/c5d/c5d/c5b/ZjbLRj
b<FmbLK2cL[6dLg8dLo5clk0b/Rmc<ZocL_0c/c1c/c1c/c1c/c1clg2d/k3dlo4e=35eM76e];7dm76
dm76d]35b/BobLG0b/K1blS0c/c2dM36e=C8e]K:_kfcdm77c/c2aL2gem37em37c<>jf]78cl^ic/Nf
]ZnKGeM0DdP]F4X^G4`_FDXZD48[DdD^ETXbET`dETlfEe0gF5<jFeHmGUA3GU90GeA0GU<oDT/hBdPi
F5Y>K75XJ6UPF5Y>C4hkCU0jEeLoGE]3H5]6HE]8E50mEe=0FeM4G5U4FeQ3EeDmEE<kE58jGUU4GUY2
GUY2GUY2GUY2GUY1GUY1GUY1FELoFUQ0G5Y2GUa4Gei4Gei4Gei4Gei4IVE9FEPlEeHlGEe5F5]2BD/e
ATTcD58nDDhoDDlmDe8nDeDoDU@nCU4kC4hjC4hjATPZDe8hH5Y7EeA6>d4l8SPf7DA69EQK8EEU8eYY
9ei]9Um^8ei]8f1^9FAb:FQf;fMh<FUj<f]l<f]l<f]l<f]l=Fen=fn0<W66;Fb1<g:7>GF;=W26=6j4
>G:8>767<fj2<fj2<fj2=6n3=G24=W65=W65=g:6<g24=G:6=G:6<g24;fb0;FYn;V]o<Fj2<Vf1;6]o
9FUl96Ul9FYm9f]n:fYn;FQl;762:Fio9fam:6en;762:g629Vam8FMh7f9a9VMf<760>WR8>gV9>GF5
=720<Vem;G279fIj;FQh4DIC;f1^?FinAGN;D86GChNBDXVFCXBEDXNLFHfTChBIAG^<CHBC@Wn=Agj=
G8VFB6af<e1G=e1DDVU[4BTY3A@?5QlE82TL92hM9BhJ9R`K9b/O:BdR9b`M9b`M:2dN:BhO:BhO:BhO
:2dN:2dN:bdJ:bdJ:bdJ:bdJ:bdJ:bdJ:bdJ:bdJ9BXK:2dN:RlP;2lP;2`N;2`N;bhP<S4S:c4N:S0M
:2hK:2hK:S0M:c4N:S0M:BlL;BlL;BlL;S0M;S0M;c4N;c4N<38O<38O<C<M<S@N<c@P<c@P<c8M=C8M
>CDM>cLO=c@O>3DP>CPS>cXU>cXU?C/S?CTQ?3PO>CLO>SPP>SPP>3DP>CDR>3@Q;b/I8al=2Q@34QP7
7Qh<:RHD<BXG<B`G<RdH<RlJ>CHJ>SLK>cPL?S/O@ChRA44UAT<WB4DY@d0T@ChR?c`P?c`P@ChR@d0T
@d0T@SlS@d8X@T4W@3hV?c`W?CXU?3PU>cLT>cLU>STT>STT>STT>STT>CPS>CPS>CPS>CPS>3LM?3/Q
?SdS?3/Q>3LM>3LM>cXP@3lU?SdQ?C`P?3/O>cXN>STM>cXN>cXN?3/O?CdO?CdO?ShP?ShP?ShP?CdO
?3`N?3`N=3PK<38E;S0C=3@F>3HG=C<D=S@B>3HD=3<A=C@B=SDC>3LE>STG?3/I?SdK?chL>3LE>cXH
?SdK?chL?SdK?chL@T4OAD@RAT8V@ChRAdP^Ce8iD58lH5m;N75POWIUXYf8ZZF@]k:M`[fXb/F`clZe
dljie]6ldLVbe/jgg=BmgMFnfm>lelnheLffe<beh]S0h=Jng]>mg=6mf]2nfLnnfLk0f<fod/F_e/Vc
f/nih=Foh=S1fmFneM6id<bdeljjeljjeljjeljjf<nkf<nkfM2lfM2lf/nif/nif/nif/nif/nifm2j
fm2jfm2jf/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/ni
f/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nifLjhfLjhfLjhfLjhfLjhfLjh
fLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhf<fgf<fgf<fgf<fgf<fgf<fg003>bLS>bLS?b/W?
b/W?b/W@bl[@bl[@bl[@b/_AblcAblcAblcBc<gBc<gBc<gCcLkCcLkCcLkCcLkCcLkCcLkCcLkCcLkC
cLk?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg@b/_AblcAblcAblcBc<gBc<gBc<gCcLk@c/k@c/k@c/k@
c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/k?cLg?cLg?cLg?cLg@c/k@c/kAcloA
clo@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/k?cLg?cLg@c/k@c/kAcloAcloAcloAclo@c/k@c/k@c/k@
c/k@c/k@c/k@c/k@c/k?cLg?cLg@c/k@c/kAcloAcloAcloAclo@c/g@c/g@c/g@c/g@c/g@c/g@c/g@
c/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gBcLcBcLcCc/gCc/gDclkDclkDclkDclkCc/gCc/gCc/gC
c/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@
c/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/gCc/g@c/g@c/g@c/g@
c/g@c/g@c/g@c/g@c/gBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcB
cLcBcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[Cd<SCd<SCd<SCd<SCd<SCd<SCd<SCd<SCc/_Cc/_Cc/_C
c/_Cc/_Cc/_Cc/_Cc/_BcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[=b/;Cd<S@cLG=b/;Cd<S@cLG;b<3@
cLG@cLG@cLG@cLG@cLG@cLG@cLG@cLG@cLGAc/KAc/KAc/KAc/KAc/KAc/KAc/KAc/KAblKAblKAblKB
c<OBc<OBc<OCcLSCcLS<b<?<b<?<b<?=bLC=bLC=bLC=bLC=bLC:al?:al?:al?:al?;b<C;b<C<bLG<
bLG>b/G>b/G>b/G>b/G>b/G?blK?blK?blKDd/OCc/G@b/?BbLGDc<GHclKIdLCId/7@dlC?d/??d/?>
dL;=d<7=d<7<cl3;c[o9bKO:b[S=cK_>c[c>c[c<c;[:b[S8b;KBdl[@dLS=c/C9b/37bKg6bK[7b[_7
b[_Mf/c7a;KJe<O<a[W1^Jc=a;O7_[7Id<?IeL?Dd;jm]jAUG4QBB31@ABYDB2aHBRi>@B]BABmEBSAG
C3IECCIDC3EABcABC3EEBC5MDCUSEcmJDS]@C3UBETYWLF]jR8IFFUm8CDho@ce3Ac];C3a=BS]9@cI8
@3=8ACI:AcQ=BS]ACT1BCd5@CCm;B3Y7A3I5ABe7Abm:BS9>CSICDc]GEcmJFT9LG4AJGTEKGdIMHDQO
HdYQIDaRITeRITeRITePH4iIFdQCED9>DD58CCi3B3U2BCa5C3m0B3i5BDA8AdU7@dU8@dA;BCmBDCaI
FSYVFD=?BCHf>BXR<bXI=CDL@TLYEF8gIW@gJG/gJG/fJW/fJW/eJg`dK7dfKWlgKh0gK80iKX8kL8@k
L8@iKX8iKX8kL8@mLXHeKX@fKhDgKH@eJh8hK8<mKhHlKXDhJ80fKH8fKH8gKX<hKh@hKh@iL8DjLHHj
LHHgL8DhLHHhLHHfKh@dKH8bJh0bJh0cK84aKX8[KH0VJghTK7hUKGlWK7lYJgh[J7`YKh0UJg`RJ7TU
Jg`ZL84[LH8WKGhRJ7TUJg`YKWl^Lh@hNXa2PYA5QIM4PY@oOHl^M8`YK84]Jgd;A5<TF6D`Hg<lKX1:
OI5@R9=@RIQ9PIA8PIMARZ==Qie5PYI>S9i2RIM8RIMQUZ=RS9Q]S9E`RY1XOh4771hB61LH7aXO9adQ
:QdQ:1TP91PP91TR9A`T:AXT:AXT:AXT:AXT:AXS:1TR9aPQ9QLT:QTT:QTT:QTT:QTT:QTT:QTS:APS
:APP9AHR9aPU:Q/X:a`Z:Q`[:ad_;R0a<28Z<1lX;QdV;1/V;1/X;QdY;ahX;QdW;A`X;Q/X;Q/X;Q/X
;Q/X;Q/X;Q/X;Q/X;Q/[;1P^;a/a<add=1`c<a/_<QT_<QT`<aXa=1/d=ahg>R4j?B@k?BLh>RHc>2<`
=24g>B<h>R@f=b<c=20c<b4c<b<[:a/R8Q89500E6`PT9A4b;1Tg<1`i<a`i=Adg=Ae1?B51?B53?b=6
@RI;Ab]@C31EDCEHE3QLF3aIECUFDSIEDCEFDSIFDSIDD3ACCc=AD3IAD3I@CcE@CSIACSUBCcYDD3eE
DCiED3]DCcYCCSUBCCQAC3MAC3MAC3MBCCQ=Bc==Bc=<BS9;BC5;BC5;BC5<BS9<BS9=C39=C39;BS1:
BBm:BBm:BBm;BS1;BS1=C31>CC5?CS9?CS9?CS9?CS9>CC5=C315B2i0@bU1@RQ5AbY8B2Y6A2I3@B95
@bA1?b10?Qlo?Ahn?1dl>Q/k>AXj>1Ti=aPb=ADc=QHc=QHa=1@^<A4]<10]<10^<A4h=Qh/;aHU:a@F
70T32@082`0H5P/L5@`M6`T]:aU3@BmHETAYIeEiMfF9QgFDTX2aZiBk]Ik7`J[<aZo;aJk<aZoAbkCG
dK[Ec;7Ebk?Ebk?Eb[CFbkGGc;SHcKWIcK_]glWXf/CPdkgIc;KDbK?DbK?EcKKHd;WGc[[Gc[[Hck_H
ck_Id;cId;cId;cId;cJckWJckWJckWJckWJckWIc[SIc[SIc[SJckWJckWJckWJckWJckWJckWJckWJ
ckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJ
ckWJckWJckWJckWJckWIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SI
c[SHcKOHcKOHcKOHcKOHcKOHcKL00<k9b<k9b<o:bLo:bLo:bM3;b]3;b]3;b]3:bm7;c=7;c=7;c=;<
cM;<cM;<cM?=c]?=c]?=c]?=c]?=c]?=c]?=c]?=c]?=c/o=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cM3:
bm7;c=7;c=7;c=;<cM;<cM;<cM?=c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>
c]3>c]3>c]3>c/o=cLo=cLo=cLo=cM3>c]3>c]7?cm7?cm3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c/o=
cLo=cLo=cM3>c]3>c]3>c]7?cm7?cm3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c/o=cLo=cLo=cM3>c]3>
c]3>c]7?cm7?cm3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM;=
c=;=c=;=c=?>cM?>cM?>cMC?c]C?c]?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>
cM?>cM?>cM?>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>
cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM;=c=;=c=;=c=;=c=;=
c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=b];=b];=b];=b];=b];=b];=b];=b]?@
b=?@b=?@b=?@b=?@b=?@b=?@b=?@b=?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm;=b];=b];=b];=b];=
b];=b];=b];=b/g:`]GBb/c9`LK3^m7>a]?@b<g:`]?@b=3=aM3=aM3=aM3=aM3=aM3=aM3=aM3=aM3=
aM3=aM3=aM3=aM3=aM3=aM3=aM3=aM;<am;<am7;a]7;a]3:aLo9a<o9a<k8`m?>bm;=b];=b]7<bM3;
b<o:alo:alo:al[9aL_:a/_:a/_:a/c;alc;alc;alg<b<_8`l_8`l_8`l_8`l_8`l_8`l_8`l_8`lg:
`/k8`M36_m35_M?7_M78^m39^]39^=3=_lo<_/k;_Lo<_]3=_m3=_lo<_/k;_M3>_=3>_=7?_MC@_]C@
_]G>_MC=_=C=_<_9_l_9_lc:`<o;`=3=_m?=`=C?`=C?`<g9]g9^G:jZV;VbXHMoK[^cX^CJbMcB`Lk9
^/O3/KB]W6EOC5I?>e9:<e=9<EE;<eE==UM?>5UA>UQ@>EA<=E59<Ti8<Di8<EI;;EA9:di39dM1:TU:
>TeDCdIEF3]>EQ/V;R0[;b`d<c@l<S<g:bl_8C4^83Pb9cHg9cHf:3Ti:d10=4E4>TI4?40m>3/h<cTn
;c]0<Ci3=496>TI:?TY>@deAATmCB4aCD4eDDDeDDDeCDTaBDD]@DDY?D4U>CcTkASTkAS@e@bT/>R@Y
>2L[?BH]?R@Z?A/Z<ahX>QdO?Q/D>B0G<S@]<Ta8=E]K=fAKCSXn<a4Y8@Td<AYBEb]WLc1ZOBiTNbmW
NRmWNReWNS1ZOCA^PCI`PcE_PS=^PBmYO35[OS=]P39/Oc5[OS5[OS=]P3A^PCQaQcefS3Q^QC5WOSU]
Q3a`QcQZPC=UO3QaQSQaQSUbQcYcR3YcR3]dRCaeRSaeRSUdR3YeRCYeRCUdR3MbQSE`Q3A_PcA_Pc1]
PBY/ObI[ORE]ObM_PBY_PR]]P2i[ObAZNbAZNbE[O2M/OBU^Oba^P2a^P2a^P2I[OR=WNR1TMbEWNS=e
R4>2UTZ7VdN4V4:9Y3QlTcIdQQ17EREIIC9SLCe^OT]kSEN=V5N>WDf5V4Z2Ve6<YTf:Y4B7WTV<XCb9
VCf4TTf7TeR5T7bMYX^UZgb@UA<V:ALL7A/Q820W820X7B0V6b0T6B0R720Q7B4V5b4V5b8W628W628W
624V5b4V5b0U5R4Y624Y624Y624Y620X5b0X5b0X5b0X5b8W62<X6BDZ6bP[72`/7Rd]7c0_8C8a8b/a
82P^7BD[6RD[6RL]72T_7RT_7RP^7BL`72L`72H_6bH_6bH_6bH_6bH_6bH_6b/[6Bd^6S8b6S8b6Rlb
6B`b6bTb7BPc7c0f7c<g7S@h7cDh7c@g8Bhe82Pb8BD_8S<h8c@i930e82/_72T/72T/72@W61`O40`E
01`Q32h]63Td7clg848k8T0k8Shk7d0l7d4m844m84<o8TM39Ta8:e1<;e=?<V5M@5mK?UiJ?F1L?fAP
@fMSAVQTAfQTAfERAVISAfMSBVQTBfQTC6MRCFIQC6EOC6MPC6MPC6ENBVENBVENBVIOBfMPC6QQCFES
Bf5OAeiLA5iLA61NAV5OAf1NAUeK@f5OAf1NAUmMAEiLA5iLA5iLA5iLA5mMAEiOAEmPAV1QAf1QAf5R
B61QAf1QAemPAUQKAEEH?eII@5iOAF1RAEiM@EiL?UmM?e]J?UYI?EUH?5IE>EAC=e5@=4m><Ti=<DI;
;TM<;dM<;dI;;TE:;DA9;4A9;4E:;CTl9SHk9S8k9alZ6P8<000200@300@0008400H8014C1aHH31HH
31PJ3QlQ5BLY7Bh[5SXg8Ti;=V=PBgYgHYBAO:fZUKjkY]C?]]G@]mK?]]G>]MO=]MW>^=gB_>3E_m73
[MG7/MW<]]c?^MkA^moB_>3C_N7D_]S?^mS?^mS?^mS?^mW@_=W@_=[A_M[A_M_@^]_@^][?^M[?^MW>
^=S=]mS=]mS=]mW>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>
^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=S=]mS=]mS=]mS=]mS=
]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mO<]]O<]]O<]]O<]]O<]]O<]P00c/W8c/W8
cl[9cl[9cl[9d<_:d<_:d<_:d<[;dL_<dL_<dL_<d/c=d/c=d/c=dlg>d/c=d/c=d/c=d/c=d/c=d/c=
d/c=d/c=c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<d<[;dL_<dL_<dL_<d/c=d/c=d/c=dlg>clg=clg=
clg=clg=clg=clg=clg=clg=d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>clg=clg=clg=clg=d<k>d<k>
dLo?dLo?clg=clg=clg=clg=clg=clg=clg=clg=c/c<c/c<clg=clg=d<k>d<k>d<k>d<k>clg=clg=
clg=clg=clg=clg=clg=clg=c/c<c/c<clg=clg=d<k>d<k>d<k>d<k>clg<clg<clg<clg<clg<clg<
clg<clg<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<dLc;dLc;d/g<d/g<dlk=dlk=dlk=dlk=d/g<d/g<
d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<clg<clg<clg<clg<clg<clg<
clg<clg<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d<k=d<k=
d<k=d<k=d<k=d<k=d<k=d<k=d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<
d/g<d/g<dLc9dLc9dLc9dLc9dLc9dLc9dLc9dLc9d/o7d/o7d/o7d/o7d/o7d/o7d/o7d/o7d/g:d/g:
d/g:d/g:d/g:d/g:d/g:d/g:dLc9dLc9dLc9dLc9dLc9dLc9dLc9dLc9cL[2dm38d<g5c<W1d/o7emC<
dm38d<g5clc4clc4clc4clc4clc4clc4clc4clc4clc4clc4clc4clc4clc4clc4clc4clc4clW2clW2
clW2c/S1c/S1c/S1c/S1c/S1cLO2cLO2cLO2c/S3c/S3c/S3c/S3c/S3c<W4blS3blS3blS3b/O2b/O2
b/O2b/O2d<k4clg3clg3clg3c/c2c/c2c/c2cL_1c/W0e<_2f<c2g<k2g<o1f<o2dm32dM73d<W0clRo
clRodL[1e<g4e<g4dL[1c/Nnd/o1d<fod<Zmd<RkdLRkeLVmel^oflg1cLFnd<Jod<Nnd<Fmcl>ic;jb
akV]aKFYUI>1<BlMJfMENgMUDT/jRH5`[ZJEXi^:YjBEXYf>VIF3HUi<J69?IV1=HEY7H5U6CDHbCDHb
C4DaBD8^AChZA3dYB3l[BT4]Ed`^CT<W@c`S@Sh[ATU0>dM96bdh00lQ00/C0a8E41dK7BXR9S0T;38W
=cXaA4Dl?DDj?4@j?4<l@4E3@dQ7@DA8>Se2=3Hn=C]6=3Y5<SQ5<3E4;C91:bm1:Be0:2`o6R586R58
6R196Am861i95Q]851Q84aM730Y53a1:3Pi:1`Q410M42@];1`a;0@I500df00/o0092000j2P4c9B0e
A4@hDePh;CHc9chj8dm>9VIW:75i96mm9FYn:6In:fak;6el;g1o<gB3=WN6>7J6=WB4<g61=7:2=WB4
>7J6>7J6=gF5=gF5>7J6>WR8=g:5@7^>=g64<F]n?gN:@7F9=V]o>Fb0>gJ6?7N7?7N7?GR8?WV9?gZ:
?gZ:@7^;?7R8?7R8>gN7>gN7>gN7>GF5=W:2=G61<Fb0;V]o:F]n:6f0:g23<7:5<g24=G24:Fio;G:3
<G>5<G63;Feo;F]m<Vf0=W64<W:4;Vj0:VQj:VQj>GB7BXBGCHNJBH6D<WF>:6Ml:61a23Y6959J;UUR
<EUU<eeZ:UUQ;UiZ:EU[9e]b<fZ5<Vn9:f^3:fj39W>39Vam<V]j@fmlN9RSSjV`RijU=4M<5Q/L61hM
6b8K6b<H728G7B4F7AlI7QlK724B7B8C7R<D82DF8BHG8BHG8BHG8BHG8BPI8BPI8BPI8BPI8BPI8BPI
8BPI8BPI9R/L9R/L9R/L:B`M;2`N;RhP;bhP;bhP:BhO9R/L8bPI8RLH92TJ9R/L9R/L9R/L9BhJ9BhJ
9BhJ9BhJ9BhJ92dI92dI92dI;2hK;BhJ;blG;RhF:bdG9RhM8c4U8c</9S0O:2hK:BdD:2/A9RT@82LB
7BLF6RLI8bTB9B/D8bPC7R<>7R8?7b8B71l?5aX:4QX38bT@=SHN?cXQ@c`QAd0UAT8U@ShQAClRA3hQ
A3hQ@cdPA3hQAT0SB48UBD<VCDLZCTP[DT`_FE<fHee0K6I9LF]>Lfe@MG5DMg=GNWIJO7MNO7ION79K
M6eILFYFM6eIM6eILfaHLV]GLV]GLV]GLV]GLV]GMW=NLFiIKFYEKFYELFiILVmJL6eHK6UDLFiIL6eH
KfaGKV]FKFYEKV]FKV]FKV]FJVeDJfiEK6mFKG1GKG1GKG1GKG1GKG1GIfUEHfEAI6MAJVaFKViFJV]A
JFQ>JVU=K6]AK6]AJfY@JVU?J6M=IfI<IVE;IVE;G6=8FV56F5m4EUe2DeXoDEPmCeHkCE@iADXe@T/g
AU90=d@f51lG00L40@<30P012@`33a894aH=3Q4810L000<000<01@P04Q824Q8251@46AT98B4A:RXJ
<C4Q=CDUFeY5Lg9MV9In^KFMc<J_d/Zcc/J_c<:ZfLjhf/nifLjhelbfelZdf<^eg<nih=>meljjeljj
f<nkf<nkf<nkfM2lfM2lfM2lf/nif/nif/nifLjhfLjhf<fgf<fgelbffLjhfLjhfLjhfLjhfLjhfLjh
fLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjh
fLjhfLjhfLjhfLjhfLjhfLjhf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fg
f<fgf<fgelbfelbfelbfelbfelbfelbf003>bLS>bLS?b/W?b/W?b/W@bl[@bl[@bl[@b/_AblcAblcA
blcBc<gBc<gBc<gCcLkBc<gBc<gBc<gBc<gBc<gBc<gBc<gBc<g>c<c>c<c>c<c>c<c>c<c>c<c>c<c>
c<c@b/_AblcAblcAblcBc<gBc<gBc<gCcLk?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg@c/k@c/k@c/k@
c/k@c/k@c/k@c/k@c/k?cLg?cLg?cLg?cLg@c/k@c/kAcloAclo?cLg?cLg?cLg?cLg?cLg?cLg?cLg?
cLg>c<c>c<c>c<c?cLg?cLg@c/k@c/k@c/k?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg>c<c>c<c>c<c?
cLg?cLg@c/k@c/k@c/k?cLc?cLc?cLc?cLc?cLc?cLc?cLc?cLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcB
cLcAc<_Ac<_Ac<_BcLcBcLcCc/gCc/gCc/gBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcB
cLcBcLcBcLcBcLcBcLc?cLc?cLc?cLc?cLc?cLc?cLc?cLc?cLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcB
cLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLc@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/gBcLcBcLcBcLcB
cLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcAc<WAc<WAc<WAc<WAc<WAc<WAc<WA
c<WBclOBclOBclOBclOBclOBclOBclOBclOBcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[Ac<WAc<WAc<WA
c<WAc<WAc<WAc<WAc<W<bL7>bl?Ge<cCd<S4`KW<bL7Ed/[9a[k?c<C?c<C?c<C?c<C?c<C?c<C?c<C?
c<C>bl?>bl?>bl?>bl?>bl?>bl?>bl?>bl?@bl;Ac<?Ac<?BcLCCc/GCc/GDclKDclK@bL3@bL3Ab/7B
bl;Bbl;Cc<?DcLCDcLCAcL;@c<7?bl3=bKk<b;g:a[_9aK[8a;W<a[W;aKS:a;O9`kK8`[G6`;?5_k;5
_k;9`KC;`[C>`K7=_jg4^ZVh]jV_]jb[^;2^/Zb[[jVX[:JVZZBSYj6MXI^BUY2:SXQ/M6eZLFYWJfEU
If5VIV1YIV5]JFAbK6MkN7AkN7AkMg9iLfigKFI`IEe[GUIVFE5LG4he=BLo?S0n?Bm4@C=ECd9;ACQJ
E4M;B3U7A3E:AcPU8Q<d<B8b;b0X9AHV8a@b;Q/c;a`d;Q/c;AXd;AXf;a`m<b51=bDm=Ahm=R93?2]9
Aca6BdXe?dTF:S`05c400a@011874QXQ;C<h@dM0BU4nADhj@4/kADli@Tlg?e0d>dl`=50Z;D`T9TTO
84HC6dXB6DX@5dP>54T;44L834H62TD524D015@00eH00eP015/015d00f000Ul00F0006820VH31FT0
16X116`21fh11Fh00V/01UT02F4015l0050514@L7T0`=cXh@S4N?44VC50`HVPaKgLYJgHPI74XIWPf
Kh@cLG`eLghhM80jMX8lMX8jM80kLWliL7doLgm1MH53Mh=4N8A4N8A4N8A6NXI9OHTkKga6NXLnKge0
Kge@Ohe9MX@kJ7I;MXE?OHQ@OXU@OXUAOhYBP8]CPHaCPHaDPXe@PH]?P8Y>OhU?P8Y?P8Y>OhU:NhE7
N88iKX<cK84^Jgl/Jgl_KX8dLHDiLXLmLXL_Kh4bLX@eLhDeKh8aJG``IGTeJ7`kKH50MhI4N8Q3MhM3
MXI;OXiFQiMAOi13LH8OFVhMDf@ZFVHI@4PiG611H6<fE5TaCeA4If];KgM4JgY3KX=@P9QAQii5PIM2
PID_M8L`L88lL85@NHR5X[2AZ[B?YJ]>HFP>51<>5A0?5`d?60/A60TC5`/C5``D5`hB5`PC60TE6P/G
70dH7@hI7PlI7PlI7PlK814K814L8A8L8A8M8Q<M8Q<N8a@N8a@P9AHN8a@M8Q<P8a@T91HT91HT8aDS
8Q@N8a@J7a0G70dF6``G70dJ7a0K814K814L8PlL8PlL8PlM8a0M8a0M8a0M8a0M8a0T9Q8U9a4W9@dV
8`hP8A4J8A`F92XC9c8I:20L9QTO90lP8@LQ80@N8@PK8@hI8a<M80HR9@/S9PdQ90/R90hV9a<V9a<R
8`lG80D]<QLo?RA5?R=7?b9<A2M;ARM4@B9:ABI:ABI9A2E9A2E8@bA7@R=6@B96@B96@B96@B97@R=<
AbQBCBiHDcAKESMLEcQTH4=YIDQaKE5jMUZ1O6>4OVN4OVN4OVN2OFR2OFR2OFR2OFR1O6MoNVEmN6=l
Mf9oNfQkMfAhM65hM65kMfAmNFIkMfAhM65lN6IkMfEjMVAiMF=iMF=iMF=iMF=jMVAeMf5eMf5gNF=h
NVAiNfEiNfEiNfEiNfEgNfQbMV=bM61fN6AgNF=dM5aaLEUdLUYeMEeeMEeeMEeeMEeeMEeeMEeeMEee
MEecMei`M5]^LUU^LUU^LUU^LUU/L5MZKUE`MUmTKEQTL5iDHE<T;bL01040004200<00@000@010P02
0`410P020`482@L>3`d20`020`061`0A4PPL7A<Q8QPO81HL7A<K8A0K8@hP914/;QY6AC5/JEBFTGb`
[9C4`:S;ajoDc[OHd[_Jd[_Hd;WKd;[LdK_FcKWFcKWFcKWGc[[Gc[[Hck_Hck_Hck_Ic[SIc[SIc[SI
c[SHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOH
cKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOGc;KGc;KGc;KG
c;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KFbkGFbkGFbkGFbkGFbkGFbkD00<k9
b<k9b<o:bLo:bLo:bM3;b]3;b]3;b]3:bm7;c=7;c=7;c=;<cM;<cM;<cM?=c];<cM;<cM;<cM;<cM;<
cM;<cM;<cM;<cLg;blg;blg;blg;blg;blg;blg;blg;bm3:bm7;c=7;c=7;c=;<cM;<cM;<cM?=c/o=
cLo=cLo=cLo=cLo=cLo=cLo=cLo=cM3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c/o=cLo=cLo=cLo=cM3>
c]3>c]7?cm7?clo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLk<c<k<c<k<c<k<c<o=cLo=cLo=cM3>c/o=
cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLk<c<k<c<k<c<k<c<o=cLo=cLo=cM3>c/o=c<o=c<o=c<o=c<o=
c<o=c<o=c<o=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=7<bm7<bm7<bm7<bm;=c=;=c=;=c=?>cM;=
c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c<o=c<o=c<o=c<o=c<o=
c<o=c<o=c<o=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=3>
cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=
c=;=c=;=c=;=c=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=;?am;?am;?am;?am;?am;?am;?am;?am;=
b];=b];=b];=b];=b];=b];=b];=b]3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3=aLS5_MKCblG2^YND
S:NTW<o<a<W6_/k;`lk;`lk;`lk;`lk;`lk;`lk;`lk;`lg:`/g:`/g:`/g:`/g:`/g:`/g:`/g:`]3;
`]3;`/o:`Lk9`<c7_/_6_L[5_<W4^lk8^lg7^/_5^<S2]LFo//:l[l2j[Kni[;^dXkZcX[N`WkB]W;6Z
VJjWUZ^TTjZSTYZCP9VBOiN@OIF>Ni><NI6:Mhn8MHj7M8V2Kh^0K8QkIH9eGgE_G6M^HEmaJUeeLeii
ME]fLUUdL5MbKUA_Jd]VHSeHE39=B@`[;0XX:@HR8`<L7P<H6P8E60HE60LF6@4B3`4B3`HC4@XE4Q0G
4Q@J5APL5Q/M5adQ5R4U6QLK41`M4cPg;CLf;2`Z83lm<c@a8S@a8T4n<2<R53@c9Bl^82HT6BPV6bLV
4RXY5Bl[638/6CD^6cL`7Cdc8D0f92h[7C4]8SXh;TI5@Cm3B2XdAA`[AAT]C0829P439@hA<2<YAS8j
F2lhFR<YDQTNB`lHA10HA`lFB0/?B@H8B@81B@00BP00C000DP00E000E`00F`01GP01H`01I@02J008
M`0:NP4;O@<<P@D=QPH=R0L=S0L=S0<:Q@<:Q@@<Q`P@S0PAT0@@SP@?S`HAT@02OP07P006M@01H0D>
DQ`XDRdlC2m1@SYOKC]RL45XMTI]NdA[NDA[NTedPeV0SdMdOdYgPTegPdifPTidP4mePEEhQEYmRUml
QF9oR6B1RVJ3S6J3S6N4SFZ7T6b9TVj=UWRGX72=UWF@VXFPZW29TemhPWbBWHVLY8ZMYHZMYH^NYXbO
YhfPZ8fPZ8fPZ8ZQZHVPZ8ROYhVPZ8^RZXVPZ8BKXh2GWd=dRSe_QCE/PC5ZOc9[P3Q_Q3i`QT1aQcA_
PS9/Oc=[OSQ[Oce_PdEbQdQcR4QaQdUePTmkR5=mRTmiQUImRej3TEEjR4Q[NCa/OT1]NeIkPdMTJ6Mo
OFj1OVAfMF5cLV1eMVAmPEafPUEfQV27WF2?Y5B9WDn7VTb7Vdj3V5V4UfnAXIVd`YBZ]HjSZeidNQLN
6ADN51@M41<M31@M2AHL2aHJ3QHJ3a<H2A@I2QDJ2aHK31LL3ALL3ALL3AHK31XJ3Q/K3a`L41dM4AhN
4QlO4b0P524Q5AdR4aXO41TN3a`O424Q4b8R528Q4b0O4AXN4QLK3a8F2Q4E2A<G2aHJ3QLK3aPL41dO
31dO31dO31hP3AlQ3QlQ3R0R3b0R3ahT3B8U32LU3BLS424P5QPN9@lM<`/O?QHX:A`X8RDX62dY434[
3S0/42l/5b`^6bd]3c<c5CHf63@c5c@c6CLf73Hd738`61hV23@h6dE4:4M194Lo8Da49Ta79TM28D]3
9Da49Ti6:4m7:Dm7:Di6:4a49TY29518:Ti6:4]39DY294]39Da49T]39DY294i9:U9<;eYD=f=L@FeV
BgE^EG]cG7mgH7elIgmnJH>2KHN6LHR7LXR7LXJ5L8F4KhJ2KhB0KH=oK8=oK8B0KHJ2KhJ2KhJ2KhN2
LhJ1LXF0LHAoL8AoL8AoL8F0LHF0LH22KX63Kh:4L8B6LXF7LhF7LhF7LhF7LhN:NX64M7j2Kh>5LXB5
LH63KH60Jh>2KHB3KXB3KXB3KX>2KH>2KH:1K8:1K8:1K7YlIWQjI7QjI7]mIgn1Jh:4KX:4KX22K7Ml
HFM`EVahHVQcHcHo=@871@000@h83@H31@L41PL41PD210800@800@800@@10`D81PX=2a0C4A@G5A8E
4``?3@D81P440P0500HC1AXT5bL^7bT_7RLY5R<T428Q3D13:UiQB8b<M;BbV/_7[m3<]=3:/m38/MG<
^=G<^=G<^=G<^=K=^MK=^MK=^MO>^]O<]]S=]mS=]mS=]mS=]mS=]mW>^=W>^=S=]mS=]mS=]mS=]mS=
]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=
]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mO<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<
]]O<]]O<]]O<]]K;]MK;]MK;]MK;]MK;]MK;]@00c/W8c/W8cl[9cl[9cl[9d<_:d<_:d<_:d<[;dL_<
dL_<dL_<d/c=d/c=d/c=dlg>dL_<dL_<dL_<dL_<dL_<dL_<dL_<dL_<cL_;cL_;cL_;cL_;cL_;cL_;
cL_;cL_;d<[;dL_<dL_<dL_<d/c=d/c=d/c=dlg>c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<d<k>d<k>
d<k>d<k>d<k>d<k>d<k>d<k>clg=clg=clg=clg=d<k>d<k>dLo?dLo?c/c<c/c<c/c<c/c<c/c<c/c<
c/c<c/c<cL_;c/c<c/c<c/c<clg=clg=clg=clg=c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<cL_;c/c<
c/c<c/c<clg=clg=clg=clg=c/c;c/c;c/c;c/c;c/c;c/c;c/c;c/c;dLc;dLc;dLc;dLc;dLc;dLc;
dLc;dLc;d<_:dLc;dLc;dLc;d/g<d/g<d/g<d/g<dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;
dLc;dLc;dLc;dLc;dLc;dLc;c/c;c/c;c/c;c/c;c/c;c/c;c/c;c/c;dLc;dLc;dLc;dLc;dLc;dLc;
dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d/g<d/g<
d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d<_8d<_8d<_8d<_8d<_8d<_8
d<_8d<_8dLk6dLk6dLk6dLk6dLk6dLk6dLk6dLk6dLc9dLc9dLc9dLc9dLc9dLc9dLc9dLc9d<_8d<_8
d<_8d<_8d<_8d<_8d<_8d<_8f=G=a<6ic/_3[JZRJFINPh1hbLJnc/_3c/_3c/_3c/_3c/_3c/_3c/_3
c/_3c/_3cL[2cL[2cL[2cL[2cL[2cL[2cL[2cL[2bLBkal:ia;nf_kZa^[F/]K2W/ZfT/:^RWi^9W9R6
UY:0Sh]iQX9`OWYXNGESMG5OL6MCKfIBJf9>Iei:HeY6GeI2Fe8nFU4mFe0jFTliF4dgEDXdDTLaD4D_
CT<]CD8/D4T`DTH^D4<YC40XA40]?dTm?EIB?V1P;V1L;f5M<fEQ>feY@G=_?W1/=FMS:eeI<VMZ<6EX
;emS:UUM:59G9deB94Q>94I<7T0o6C/j4S4^2bPU1b0L1A/F1ATD1aPD3aL=2Q881``33a@;30l63Pl6
7QlF51D<6QL87a`=<c8T7Qd?<BlT;BdQ:b/O<c8X;RlK<S<O>CPT?SXW@C/X@S/XA3XXAc/Y@Chi=C8]
=C8^>STk<38l5b0d2aTf421450a14@]040do30do10Hl004l00A51`aA00A;0PMB1@UH1@IN10=Q1@5X
2PA_3`Qg0PQc0`Qe10Qh1@Qk1PMo20V32@R62@R600j800n:0Q2>116C1Q6G1Q2I1a2M1a2M1Q>E00f?
00b@1Q>G1ABI00nG012H1aNO2A2S3QFP3AF@3QUk8S1hB5R6HGF>Igb;?VIhEGJ9LHVKPI2SNXJHKWf=
LX>@OI2MOY^TPIjWPijXPibVPiVTS9jYUjVdX[:nZ[2k[;:m[kG0/KO2/[S3];[5]kg8^Ko:]/79_/WA
];g6^/?<b<oHZ:ffU9VR][_4b<G>b<G>bLK?bLK?b/O@blSAc<WBc<WBcLcEbl[Cbl[Cc<_Dc/gFcLcE
alK?`/7:C7R?AGB:>ff3=FYo=FYo>Vb2?fj4@Vj5?7B7=fb0=FQl@G25EH2EH8VOI8VOGhBJJhnILYJP
LYFOJhjHLI6LNi^VNiVTL8jIBgJ5DGN3IXB9DVQVK7eiM81jMGmiNXAnKG]iLh:4Igb4HGb:KXnRLYb_
J9RZHiNXDhNNDh:HGHFHN9JYX;[8TjVeT:F]K8:8;CD^:S@X:38R9C0L9RlJ:2hK9bdL9R/L8RLH8RLH
8bPI8bPI8bPI8RLH8BHG82DF8alD920E9B4F9b<H:2@I:RHK:bLL;2PM9BXK8RLH8BHG9BPI:b/M;BdO
;B`N:RTK92PL82@H720D6QhB720D7b<G8BDI8BDI:BLE:RPF:bTG;2XH;B/I;R`J;R`J;bdK9R`C;2lF
=38J=S8P<2dY8bTf62E54BA?6Rdd8bl_<S@X?cTRAcdOB3dQAChU@ChY?C`J@d8PAD<T@ClP?S`N?S/O
>cPL=S<G8RX<>3`OBTPZB4<TB3hPCTDTCTLVAd<PAChMB44PC4DTCdPWDDXYD4TXCTLVC4DTD4TXCTLV
C4DTCDHUD4TXDT/ZDT/ZDT/ZC4LXBdHWBT@WBdDXCTL/Dd`cF54hFe<lJVaFKg5KMgUSOh5[QHMaR8Yd
R8YdQhUcS8QeS8QeS8QeS8QeS8QeSHUfSh]hT8aiT8]lT8]lSXUjSHQiSHQiSHQiSXUjSXUjRXaiRhej
SHmlSY1mSi5nT99oT99oT99oR8enQ8MgPXEeR8YgRhejRhahSXehTI1kSXmkSXmkSHijRhahRHYfR8Ue
QXMcQXMcRhYfRHQdQhIbRHQdS8]gSXeiS8]gRHQdSI9eOHAYQY1iR9:1CUI;2@d80P012@<80P030P03
0P030P030`041P872@D:2PH;1PL;30dA4A8F3a0D20T=0`@81@H:20T=00`300l40a4610h20P`020h0
4QD571h;6b487bD<:RhE>C`SE5@lNgUQYZ::`[jVe<^ge<^ge<^ge<^geLbheLbheLbhe/fie/^eelbf
elbff<fgf<fgfLjhfLjhf/nif<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fg
f<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgelbfelbf
elbfelbfelbfelbfelbfelbfelbfelbfelbfelbfelbfelbfelbfelbfe/^ee/^ee/^ee/^ee/^ee/^e
003?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?bL[?bL[@b/_@b/_AblcAblcAblcAblcBc<gBc<gBc<gB
c<gBc<gBc<gBc<gBc<g@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@bl[@bl[@bl[@bl[@bl[@bl[@bl[@
bl[?b/W?b/W@bl[@bl[Ac<_Ac<_Ac<_Ac<_@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/k?cLg?cLg?cLg?
cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg?
cLg=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLgBcLcBcLcBcLcB
cLcBcLcBcLcBcLcBcLc@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[BcLcBcLcBcLcBcLcBcLcBcLcBcLcB
cLcBcLcAc<_?b/W@bl[Ac<_BcLc@bl[>bLSBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcB
cLcBcLcBcLcBcLcBcLcAc<_Ac<_Ac<_Ac<_BcLcBcLcBcLcCc/g?b/W?b/W@bl[@bl[Ac<_Ac<_Ac<_A
c<_BcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLc@blS@blS@blS@
blS@blS@blS@blS@blSBcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[Bc<GBc<GBc<GBc<GBc<GBc<GBc<GB
c<GKc/cIcL_Ec<W@bLK<alC<bLG=c<S?c/[<a/7?bLCAblKBc<OBc<O@b/G@b/G@b/G?cL?Cd<S@cLFe
/JamN7F7PWo5`;o9a<?:aL;:aL;;al;>bl?@c/C@c/?<bkg9bKWBbkc?b;W;a;G5_Znm]ZNbZibVWi2N
UhRERWB=PVb1MV1hKEMbIe5^HdeYGTQUFTANDceMDSaLDC]JCcUGC3IEBSACB39CB39@@S1@@S1?@Bm?
@Bm>@2i=?be=?be<?Ra6>S15>bY5>RA6?R58?R17?216>253=Am5=25:>25<>b15>Qld>B@V@CPQD5@Q
GFTDDUdHEV4NG6LOGV`PGfdPGVhNGfhOH6lXHg8WHFdTGVXXGf`_HfldIW8cIW0dIFl_IWD[HW4/Hg0_
IW</HVdRFF8QF64XGfPXCehTBeXOAE4H?dPE>d0E>cdF?3`I?S`I>3LG<c<E<2`I<2/P=B`X>RdZ>bd/
?2/jAc4`>RhZ<R/^=bXa>b@a>1dd=2@m=30_<d/@4c8823HB4Th=3U851dh22Dh22Td00T`00U800U/0
068006P006`30fl51G402GL01gL01WP01G/01X0028H02HT02hd02i<039@23IL12iP02YL02IL02YP2
2i/03Z@03jD14ZP15JX25Z/05Z/05JX05JX44jD35:D45JH05JH05jL06:P06:P06JT45ZT06;805k0>
9ZQ4D:RZZmNj^lVm`L9lO8:c/kVl_<;4a<Zk^l64Q8Zg]kg4a<[2aL[2aL[2aL[3a/_4alc4alc5b<g5
b<g7alg7alg8b<k9bLo:b]3;bm7<c=;<c=;>d]O:c]?5bLkFfN7=cmVj_<JJW:O9bmKAc<g@c/kAc]3B
c]?Dd=KEdMOFdM[DdM[Bd<oFe=?FdloAc/[Fd/gLf=?AcLS1^kAYRiQ?LGiCMX=>LGi7KGU@N8A<M81>
MX92LGUBOHICMgm]RI25VZ9oTYV3UYf3Uib5UiR6V9V6V9V5UiR8VY^7VIYmSi1aPhAaQ85]PGa]OWYb
P7YhQGemR81mQWakPgV3R7mmQGimS8QdS8b?[;61WjZ1WJioVZicVjMgVZMkUj:DZ[FncmRDY:^:VZ26
UiY5CT@Y<2<b=24h=Qhj=Qe2?RDd<QX`;aXe<Qdf<ahh=B0i=R4j=b8j=b8j=b8j=b8j>20j>20j>20j
>20j>20j>20j>20j>20m?20n?B4l>alj>Adm?211@2@m?20f=AT_<aX_<aXa=1/b=A`e=Adh=Qhi=ali
=alh=a/h=a/h=a/i>1`i>1`i>1`i>1`i>1`i>2<l>Qa0?AM2?aTj?2HZ<cHE9dH87e4Q<chb>C94?R59
@1]2?A`o>b95?RE<@2A6@2=3?B10>Qe0>Qe3?B13?B10>Qdm=aXe>1Pn@B56AbM4ABE5@bA9ARM;B2U<
AbQ=B2U<AbQ;ARM:ABI9A2E9A2E9A2E:ABI<A2I<A2I=ABM=ABM>ARQ>ARQ?AbU?AbUABB]ABB]@B2Y?
AbU@B2YABB]CBbeECBm>BReACC1GDcINFSeXI4MeLEB2OV6;QfZFT7fITX6LUHBMUXNKU8FJTXFJTXFK
TXREUHFEUHFEU8JCTHJBT8FBT8JDTXRGU8bFV8FDUX>BU86DUHFHV8ZIVH^HV8bEUHV;RWb@Sh6FUHNG
UXRDThFAT8:AT8:CTXBBUHJAU8F@ThB@ThB@ThB@ThBAU8FBUHJCTh6CTh6CTh6CTh6CTh6CTh6CTh6C
Th6DTgjCUH6?UHB0RWY`NFl120431P@200000@000@0010800@000@021`D00P0?5Q<A5AH;3a0=4A8C
5aP=4A8010D00`@93@h01`@01`@01`@01`@020D020D02@H02@H93P`<4@lC6Q<J8QPN9aXR;1/^>BDk
Ac5[LeFFWWo0aJG9bZS1_ig5_IoEbZkReK_KeKS8`ZGLeK[Me[_Ab[7Jd[_Fc[O?ak3Kd;GJckCIc[?H
cK;HcK;HcK;Ic[?Ic[?HcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOH
cKOIc[?Ic[?Ic[?Ic[?Ic[?Ic[?Ic[?Ic[?Gc[?Gc[?Gc[?Gc[?Gc[?Gc[?Gc[?Gc[?Gc[?Gc[?Gc[?G
c[?Gc[?Gc[?Gc[?Gc[?FbkGFbkGFbkGFbkGFbkGFbkD00<o:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo9
b/o9b]3:bm3:bm7;c=7;c=7;c=7;c=7;c=7;c=7;c=7;c=7;c=7;c=7;c=7;c=3:bm3:bm3:bm3:bm3:
bm3:bm3:bm3:bm3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b/o:bLo:bM3;b]3;b]7<bm7<bm7<bm7<bm3>
c]3>c]3>c]3>c]3>c]3>c]3>c]3>c/k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<
c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<g;blg;blg;blg;blg;blg;blg;blg;blk<
c<k<c<k<c<k<c<k<c<k<c<k<c<k<c=7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm3;b]3;b]3;b]3;b]3;
b]3;b]3;b]3;b]7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm3;b/o:bLo:bM7<bm;=c=7<blo:bM7<
bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm3;b]7<bm7<bm7<bm;=
c=;=c=;=c=;=c<o:bLo:bM3;b]3;b]7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<
bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=7<bM7<bM7<bM7<bM7<
bM7<bM7<bM7<bM;<aM;<aM;<aM;<aM;<aM;<aM;<aM;<aM?7aMC8a]C;b=;;b=3;b<o<b<o<b<k=bLo;
a/k:aLg9a<c8`l_7`/c8`lk:aLo;a/S6_<?1]mCAbMSEcHj:QFAOG:6LVM3;b=O?b=;:`lW2^L2j[kJ`
XjZUUZ2KS9VEPhAjJH1fIGY`GgAZFFmUE6UOCV9HAeiD@fEJAUmD@5U>>UE:=UA9=EA9=E97<e15<De2
;Ta1;D]0;4Xo:dTn:TPm:DLl:4Ll:4Xl:TXl:TTk:DPj:4Li9dLi9dLi9dLi9dHi:d<g9D0e7cdf6d0i
7T8k8T@j:4@j:D@f:THg9d<e8cTb7bXc9Q`k>1M;DQEFIAQIIaQIIaQIIaUJJ1QKJQQKJQIIJ1EHIaiM
JaaKJA]II1eIIB=MJBMQKBUQK2QPJbYUMBMRLBMRLB]WLbiXM2eXLReXLC5ZLc9VLc=TLS5SKc9SJcEU
JCQYJce]KSm`KSYQJSYNJ3QLHSaLHCmNGd5MGCmJESiGDcE>A315@be0AC94@cE9?3E6>3U4@T14Cble
GQ0DA`L9B@`>G0H7G@02FP05FP08FP0;H@0:IP49KP87M0<6N@D6OPL8P0T:PP@?R0@?R08?R@8>S08?
T@<@U0HBV0LCV`8?V`<@W0DAW`@@WP<>WP8<W`@>X@H@X`0BZ@4DZ`<F[@<H[`<K/@<K/@4J/00I[`<D
ZP<DZP<G[08H[@8J[`8L/0<M/@8N/PHL/@4M^00J/a4[[D]H[[:dgL32cL;7aHB4R[^k`L?3bL[:d<71
ah^;TKnoaL[:d<S;d<S;d<S;d<W<dLW<dLW<dLW<dLW<dL_;dL_;dLc<d/g=dlk>e<o?eM3@e]3@e/[>
clW<d<?6b]7DfL_=eL32bZ2QZl_<e]GIg]GHh=CGgm?EgM;Dg=7Bg=;Afm;Afl_Cf/kFgLcDflW?e/oE
f]KLhLoEf/75bWBCW5UhPEioR5f1REUmQEb1RE9gOe1gOdmlP5MoQ51`MV^3RHZMXX^KXHjOXX^LWi6O
WY:PWi:PWi2NWI6OWY2NWHNEU7^9R8BETX:@SWj<R86<RHNARhfESXnFSi2DSXnBRHbCS8VGTgZ>SiJ^
]92Z]YB]_HnW^HFX]HJV/HfW/jFg`/?Bfj>`^:>a]iJV[4]DBRhe:3Hh9CTi8Cdi84E1:3Tg7cHe83Tf
8CXg8S/h8c`i93dj9C`i93`i93`i93/i8C/i8C/i8C/i8C/i8C/i8C/i8C/i8Cln8T0o8chm8C`k7cln
8T=29T0o8cPg6c4e734e73<f7C@g7SLg7cXh83Xh83/i8Cln8Sln8Shm8C`k7c/j7SXi7CTh73Pg6cTh
8cdk7D0m5d4n63Tk9BTb=A@VA@LND24c?S4h<D@n8DPo6T8m73lk8TDn9Da094I08d<m844k7T4k7T<m
84<m844k7Shh6c8e5Cdn7TA59DE394E394U69di9:Ti9:Te8:De8:D]69dY59TY59TY59TY59T]69de5
9di6:4i6:4i6:4i6:4i6:4m7:Dm7:E18:Tm7:Di6:4i6:4i6:4m7:E59:e9:;4m;;U1<;e1<;e1<;e5=
<5EA=5]G>UmK?V]WCg9]F7agHXN1KY6;N9ZCPZ>LSJVRTi2@OY>CPiNGQiVHRYZHSI^ISYfKTIjLTY^L
S9jOSj>TU:VYVj^[WjFUVI^JT9:AQhZ9Nhj=Oi:APiFDQYJEQiNFR9RGRIVHRYJIRYJIRYFHRIBGR9BG
R9FHRIJIRYJIRYZJR9ZJR9ZJR9ZJR9ZJR9ZJR9ZJR9ZJR9VHQ9RJQYFKRXN@PgIoM@D;1P@71@800001
000200D:200100030@481@0200/B3`020@<81`T>3@/@3`hC4Q4F5A8G5Q4F5@H?30D>2`@=2P8;204:
1`091P081@081@/?40P=30T>30lF3a4I3a0I31<M3ALQ42Pa73M1:TY@=eEH?VMVBWeiGHf7JY>;K[Vb
TKN`Sl[2Y<g5Z=C<[n?J_mW@]MG;/mC9[]C9[]C9[]C9[]G:[mK;/=S=/]S=/]S=]mS=]mS=]mS=]mS=
]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mW>/mW>/mW>/mW>/mW>/mW>/mW>/mW>/mO>
/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mK;]MK;]MK;]MK;]MK;
]MK;]@00cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9clW:clW:d<[;d<[;dL_<dL_<dL_<dL_<dL_<dL_<
dL_<dL_<dL_<dL_<dL_<dL_<d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<_:d<_:d<_:d<_:d<_:d<_:
d<_:d<_:cl[9cl[9d<_:d<_:dLc;dLc;dLc;dLc;clg=clg=clg=clg=clg=clg=clg=clg=c/c<c/c<
c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<
c/c<c/c<cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<dLc;dLc;
dLc;dLc;dLc;dLc;dLc;dLc;d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:dLc;dLc;dLc;dLc;dLc;dLc;
dLc;dLc;d<_:cl[9c/W8cl[9d/g<dlk=d/g<dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;
dLc;dLc;dLc;dLc;dLc;dLc;d<_:d<_:d<_:dLc;dLc;d/g<d/g<d/g<cl[9cl[9d<_:d<_:dLc;dLc;
dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;d<_8d<_8
d<_8d<_8d<_8d<_8d<_8d<_8dLc9dLc9dLc9dLc9dLc9dLc9dLc9dLc9d/c5d/c5d/c5d/c5d/c5d/c5
d/c5d/c5dl[6eLc8e/g9e]3;dlo:d/k9clc7cL[5dm79dm79d]38dLo7c/c4c<[2bLNoalFmfmO<b/Jk
dlk5f=?:QGmh?CLbIV1KVI>>ThMkS81dPWMYMfaNKF=BHeU7FU0nE4XhHeE2GU0mEdTfDT@aDD<`DD<`
D48_Cd4^ACXV@cPT@CHR@CHRA3TUACXVACXVACXV@cPT@cPT@cPT@cPT@cPT@SLS@SLS@SLSAcTWACLU
A3HT@S@R@S@R@cDSA3HTACLUA3HT@3DQ?3<O>S<O>S@Q=c8S<bhU;b/V;b<Q:b0L91`E7AdG5BHS43@j
2dAC2TmR5E]X4EMT3eER4UQU65i[6f5^6V1]5eeZ6F1Z65mY6EiX7EmZ8F=^9FE`9FE`9VA_8fAc8fAc
8f9`8f9`:VQc<Fih<Fih;VUc<fei<fei<fih=W1f>G5f>gAf?WIg?gQg@fj1@fn0AG1oBW5oC79nBVmg
A6Q^@F=Y?f5Q?EaU@5]YA61WA6=PAF9OB61/CF1k:39h2aES0`YW2Pmf0@Qg00Ac00Yf00ee0aIo0aB3
0a690`n=10fB1@jD1a2F216G1A6E112F112H0a2J1A:N1A>Q1AFT1QFW0Q>R11FT1QNX1QJY11BW11>Y
1QF[1aF]01>[01F]01R`0QZb0Abc01bc01^b01^b0a^a11bb11fc11ne1R6g1RBi22Jk2BNl2bBj0B:o
01jh536bDV:e_;kVbLcAb<g4Rh^A`/;8bLW?cloEalO=Ti>Ia/K<cloEcM3EcM3EcM3EcM3EcM3Ec<oD
c<oDc<oDd=3Fd=3FdM7Gd];Hd];Hdm?Ie=CJe=CJd=;BdmGEblg>d]CEcm3Dc<cB[Jfcd<oHa]3Jam3I
b]7Jc=7Jc]7Id=;Jd];Hd];HbmOQc=SRb=CN`LgG`loIb=CN`<cF/ko9NiFKK8V>KX^@FGMlEG=hJ8R=
FWf1AVU]G8:6G7n2CVU]Jgj1U:6SVjNYWj^[VJFUWZVVX:^XXJbYX:^XXjj[Xjj[W:NTTYfJUZBSTYjN
SYVGT9RGV9fKWj>NY:FQY:FQX:2JXJFPV:>QOY2AW:nfXKO3Z[k?XkC7V;S3V;BoZ;c7]lGAb=;L];g6
`LcD[KS0DEaB<S/^>CdZ?ShV?chTATD[?3`T?ClY?cdU?cdU@3hV@3hV@3hV?cdU?S`T?C/S?3XR?3XR
?3XR?3XR?3XR?3XR?3XR?3XR@T4W@T4W@3lU?SdS@D0VAD@Z@T4W>STO=3PO=3PO=STP=cXQ>CTQ?3XR
?C/S?C/S@3lU@3lU?chT?SdS?3/Q>cXP>STO>STO>STT?S`N@ChH@SlI>C/U:C8e52I51Qe?8C<n<CPa
A3hQB3lJ@SdL?c/RA3dTC40TAT0SA3hQ@S`O@S`O@cdP@cdP@C/N?cTL<C8B>c`LAD<TAD<TAT<TC4LX
CdX[CdX[CTTZCDPYC4LXBdHWBdHWBdHWBdHWC4LXCdLYCdLYCdLYCdLYCdLYCTHXCTHXCTHXCdLYCdLY
CTHXCDDWC4@VCDDWCDDWCTHXCDLZCTP[CdT/CTP[C4HYCDLZD4X]DT`_D4``EE4eGETmIV58L6YCNWAM
PgaXRX=_VIR4WIb8X9j<XIn=Wib=W9V;ViR:VYN9YJFEXj:DXJ2BXInDXZ2FXj6GXYnGX9fEWIb>W9^=
WIb>Wij@XZ6CXj:DXJ2BX9nAWJ2AW9n@Vij?Vij?Vij?Vij?W9n@WJ2AXJ6AXJ6AXJ6AXJ6AXJ6AXJ6A
XJ6AXJ6AX9n;Wj6>W::AT9V<OhQn2@l:1@L70P00004000<11``:00<10PT60``900800`h;00<02`l:
3a<>2@d8310;5a/F51PC1`/600H300H300H300L400L40PT60`X710/80@H9004400831`h;4APC4a/D
4Q/A4adA5B4E4Q`@3AH94aT89bTE@40XDU4gFePlBT@OFE<^JVA1L6Y7Tha[[ZJ8[jN9b/:TcL:WcL:W
c/>XclBYd<FZdlR]eLZ_e/^`f<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fg
f<fgf<fgf<fbf<fbf<fbf<fbf<fbf<fbf<fbf<fbe/fbe/fbe/fbe/fbe/fbe/fbe/fbe/fbe/fbe/fb
e/fbe/fbe/fbe/fbe/fbe/fbeLZdeLZdeLZdeLZdeLZdeLZd003>bLS>bLS>bLS>bLS>bLS>bLS>bLS>
bLS?bL[?bL[@b/_@b/_AblcAblcAblcAblcAblcAblcAblcAblcAblcAblcAblcAblc@b/_@b/_@b/_@
b/_@b/_@b/_@b/_@b/_@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[?b/W?b/W@bl[@bl[Ac<_Ac<_Ac<_A
c<_?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>
c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c=bl_=bl_=bl_=bl_=bl_=bl_=bl_=
bl_>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<cAc<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_@bl[@bl[@bl[@
bl[@bl[@bl[@bl[@bl[Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_?b/W>bLS=b<O?b/WBcLcCc/gCc/gB
cLcAc<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_@bl[@bl[@bl[@
bl[Ac<_Ac<_BcLcBcLc?b/W?b/W@bl[@bl[Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_A
c<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_@blS@blS@blS@blS@blS@blS@blS@blSAc<WAc<WAc<WA
c<WAc<WAc<WAc<WAc<WBc<GBc<GBc<GBc<GBc<GBc<GBc<GBc<GEcl[Dc/WBc<OBc<OBc<O?blK>b/G<
b<?5aKW8b;c=cL7Bd/KCdlO@d<C:b[k5aKW5_K2e[J2RVXfDRh5OETdf;BA9?cQBB45IBcUEAcE@@S1<
?R]<?R]<?R];?BY9>bQFB39BA2i=?bU;?BM<?RQ>@2Y?@B]?@B]7>bU6>RQ6>RQ6>RQ6>RQ6>RQ6>RQ5
>BM4>2I4>2I4>2I3=bE3=bE2=RA2=RA2=RA5>BM3=bE1=B=0=290=291=B=3=bE4>2I1=R8n=B4k<b8g
<B@^;28S8QhF5QH<3A4>2A8:1P`510P631497RH>=D<?BE`?DfXEFFHAEF8?Df0EEf8MGfXSI6dQHV/L
GFHLGfPMH6TPHf`RI6lRI6lRHVdNGF/KFVPPHG0SI78THg4RH6/UHV`aJG@bJg@_IVlgJW@gJW@kK7@n
KGE0L7I1L7A2LWA4LGA<LGm>Lh5CMX=HNhEHO8AHNH9FMWaCLgUKNW]ONh9TO8QXP8IUPWmQOh1RO8eS
NI`F:8d24Wd03HD84YD23I<039855IL76IH679T46IX259d14J024:@44ZP44ZP44ZH049l03j414:82
4ZD14ZP35:/25:d35Jh05jT26J/46Zl46K036:l25jl46K466[D06K<06k@07[L08;T18KX08KX08[X0
8KT48kX39;X49K/69kd7:;h8:Kl8:l48:l48:Kl09/808KXE=[EHJ;_0a^W=d=C=dLJ>SYC6a/c<c=;@
d=K8b<jGUig9bLo@d=K>dMK>dMK>dMK=d=G<cmC<cmC;c]?;c]?CdmWDe=[De=[EeM_EeM_Fe]cFe]cF
e]cHfMOMgMgBd];DdmGAd=;Cd]Jd/[SBd=K=e][@e]_Bem[Df=WIfMWLf]WOfm[PfmSFfm[HgMcFfm[C
emSCf=WDfMc;d]Foa/V4VYn7WJ:0UY]<IFU4Gf=eT9A/RHe4HFEXS8aZR8UMLW=lRH^S[Jf[/k:b^;NZ
/[6V[JZZ/Jj]];6_][>c^[Ng_[^c^[N[/ZnOZjfLYJRKXZFNXjBTZJR][Jf`[Zf_[Jb`[JVb]K>V[Zf1
T9>M[kJ^`<^kb]Z^_<jX`lfV_<NibMG3cMO7d=Zi`/cBfnFf`<YGHUPf?c8l@2e0@bY1@2I6AB/o?bM3
ABm2@2Q3@BU3@BU2@2Q2@2Q0?RHo?BDn?2@n?2@n?2@n?2@n?2@n?2@n?2@n?2@n?2A2@BM2@BM0?bDo
?RA2@BM6AB]2@BLj>Alg>b8g>b8i?2<i?2<l?2@n?2@o?BDo?BDk>R0k>R0l>b4l>b4m?28n?B<n?B<o
?R@l>bHo?Am2?aU3@1Xj?2HZ<cHE9dH77U0P<Sda>353?B18?aY1?1/n>R54?BA;?b=5?b94?R53?B12
?1m2?1m1>ai0>Qe0>Qdb<a<n?1e6A2E8ABI:ABI=B2UABB]@B2Y=B2U=B2U<AbQ;ARM;ARM;ARM<AbQ=
B2UABB]ABB]@B2Y@B2Y?AbU>ARQ>ARQ>ARQ?AbU?AbU>ARQ=ABM=ABM<A2I<A2I<A2I<AbQ?BR]BCBiC
CRmCCRmDCc1FDC9HDcA>C2Y?CB]@CBi@CBiACC1CCc=GDcMKEc][IdmbKUImN6>9Q6nDSW^OV8NXXI2^
YiRYZIVVYINSXYBQWiBQWiFTXYRVXi^XYIfUY9JRXI>QX9:SXYBXYiVZZI^XYiVTXiFQY9FQY9FPXiBO
XY>OXY>PXiBQY9FQY9FVYYJVYYJVYYJVYYJVYYJVYYJVYYJVYYJUXi6TYY>RYiRIXIJ5SHH;40h41PH2
00400@000@021`D0104:4a0B7AX030P44PhE7A<I8ALH81HC6a4E7A<G7aD?5`d32`422@H22@H120D0
1`@120D32PL530T63@X=4aP631432Pd73`l:4Q484@h53P/43PP6518751884a063@P52`0@504V:A0j
?1ll=Pe8@QU6?aPn=a1JDReTFcUaJ4Ji/8kBajcBajcBajcCb:gEbZoGc;7Ic[?JckCGc;KGc;KGc;KG
c;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KHcK;HcK;HcK;HcK;HcK;HcK;HcK;H
cK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;Eb[CEb[CEb[CE
b[CEb[CEb[@00<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<o9b/o9b]3:bm3:bm7;c=7;c=7;c=7;c=3:
bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3;b]3;b]3;b]3;b]3;
b]3;b]3;b]3;b/o:bLo:bM3;b]3;b]7<bm7<bm7<bm7<blk<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<g;
blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;
blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;blg;bm3;
b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;
b]3;b]3;b]3;b/o:bLk9b<g8alo:bM;=c=?>cM?>cM;=c=3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;
b]3;b]3;b]3;b]3;b]3;b]3;b]3;b/o:bLo:bM3;b]3;b]3;b]7<bm7<bm7<blo:bLo:bM3;b]3;b]7<
bm7<bm7<bm7<bm3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;
b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=7;a=7;a=7;a=7;a=7;
a=7;a=7;a=7;a=7>a/k;`l_8`<k8`M7;a=?=a]?=a];<aLo>`<W8^[jm[k>bY:NVV9VHRXb;OH>2M75Y
F6aSEEI=?dm6>D@k;T4g;Dm4?48g;eM6<E=2;Dln:Dhm:U0o;591;UA3<5A3<4Xl9TTk9DLi8dLi8dTk
9DXl9TPj94Li8dPl:TPl:TPl:THj:4Di9d<g9D<g9D<g9D@h9T<g9D8f944e8d0d8Slc8Chb83hb844g
9D4g9Cle8cle8cle8d0f944g9D8h9Shh9CLc8BhZ7b@Q71TI6@`?4`853@0020<44P003P002`095PPM
;10dA1A6F1E>HaQBGQYEGb1HHbQOJ2iTJc5UJbiSIRePHbeTIc1WK3=ZKc=YL2eTKB=II1Y?G1A9ER5L
IRUQK31VLCAWLCY[LdEcNdahOdeiP5aiP5mlPfB0QfZ4RVn9SgB=TGJ?TgR>TgZ?TGbATgjCU86EUX:G
UHFGUXFGUXJHUgjCRhBDThZFV8bGU8NHSH:FTGV>WG>6Y`LPV00AS`0BV`HHZ`4BZ00CYPDLZ0HNYP<P
Y`0JYP0EY`0BZP0C[`0D/00D/00C[P0CZP4DZ`4F[P<H/08H/`8J]0<K]@@K]`0I[@0K[`4L/P4L/P0K
/P4K]@8L]P@N^00T^P0U^`<X_P<[`08/`@8/`@4/`@0[`00Z_@0Z_@0Z_@0Z_@4Y_@8Z_P8Z_P8Z_P@]
_`0Z`@0U^A<i]EQ[_<;8jm3AeLo@aY>CVL_;dLo?eM3@e/W9ci^KXLg=dm7AeloBeloBelkAe/kAe/g@
eLg@eLc?e<c?e=CDf]GEfmGEfmGEfmGEfmKFg=KFg=KFg=?EeMWKfm3Bdm;DeLk?dm7Aek>c^M;Af]WJ
f=SIemWGe][Gdm[Ed][Dcm_Bc]_Bc]O>a=WCb=cEc=cFcmgIe=cIe=GBc/[9aIZ]/YJZ[i2TZFAjOf1f
NhVRYX>NXVF0Q7fLWHBPXGb@TIVUYkc1`[c1`;k3`[Zo_[6f];Jk^KVn_;Zo_Kk3`L76a;o4`[Vn_:Jb
^:F`]:N`]:fd]kJi_K^m_[^k^kRh^;Vj^;g2`Jjh^8JEV:6c^[C5c/?@g[G2d;3:dJo4c;o@fLOAflO@
f[S0cLoHiK:nbUMUFSI0<c]1;T54:cm09T93:C`o9TE8<T=2:4=2:4=2:4=2:4919d0o9Chm8cdl8Shl
93hl93hl93hl93hl93hl93hl93hl940n9T4o9clm9Cdk8d0n9TA2:T0n9STg7cTm93Tm93Xm93Xm93dm
9Clm9Clm9Clm9C/i8C/i8C`j8Sdk8chl93lm9Clm9D0n9S`k9Slm7d=06TA16c/m9b/d=aHXA`PODB0b
?C0g<4<m84Ln6D4l6chj8D<l8d/o8d<m84<m84<m848l7d0j7Cli73li740j7CLe5T908DY7:4Y7:4]6
9dm7:Dm7:E16:4a7:4a7:4]69d]69d]69d]69da7:4e8:E18:U18:U18:Tm7:Di6:4i6:4e59de59dm7
:Dm7:Dm7:Dm7:Di6:4e59da49Ta49U5::E=<:eE>;EA=;55::Dm89dm89dm89dm;:51<:E1<:Dm::De8
:Di9:U5;;UA><DY6:Tm;;eMB>F1K@V]UCWQaGHEnJXj7Li>AOibJR:VVUk>`XKJcYK>_Y:fYWZVTVj6P
TYnNT9nNT:>RU:RWVJZYVjRWVJBSUJBWV:BWV:>VUj:UUZ:UUZ>VUjBWV:BWV:RWVJRWVJRWVJRWVJRW
VJRWVJRWVJRWVJZXUZJWUjFYWIfUVhV@R`/@3`841@800`01000100030@060aPS82/i=A<T814R7RHa
9alZ81hY7bLb:2Td:R8]8a`W7A`W7ADP7A<N6`lJ5`/F4`PC40LB3`HA3PLB3`0;3`082P072@092`09
2@061P091`4>30020@041P4<40L>4@871@45010E02HZ4Dm97UI@9De77T8k54m88D8j5EQ@:lJmVm[?
]=[?]=[?]=[?]=_@]McA]]gB]mkC^=O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<
]]O<]]O<]]O<]]S=/]S=/]S=/]S=/]S=/]S=/]S=/]S=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]K=
/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]C9/mC9/mC9/mC9/mC9/mC9/`00cLS7cLS7cLS7cLS7cLS7cLS7
cLS7cLS7clW:clW:d<[;d<[;dL_<dL_<dL_<dL_<d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;
d<[;d<[;d<[;d<[;d<[;d<[;d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:cl[9cl[9d<_:d<_:dLc;dLc;
dLc;dLc;c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;
cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;
cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:
d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:cl[9c/W8cl[9d/g<dlk=
d/g<dLc;d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:cl[9cl[9
cl[9cl[9d<_:d<_:dLc;dLc;cl[9cl[9d<_:d<_:dLc;dLc;dLc;dLc;d<_:d<_:d<_:d<_:d<_:d<_:
d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8
d<_8d<_8d<_8d<_8d<_8d<_8dL_4dL_4dL_4dL_4dL_4dL_4dL_4dL_4clk4c/g3d<k4dm77em;9e/o6
clRob<6h/JZKXIZ;RH9cLfaMHU]<ETm0CDHgAd0aAS`ZBd4_@CLVC48aC44c@SHZCT8fCd<iDD0[CC`W
BCPSB3LTBCLVBcTXBcPYBcPYBS`YBC/XBS`YC3h[CT0]CCl/BS`YAcTV@SDU@cHV@cHV@C@T?c8R?c8R
@C@T@cHVACPXACPXA3LW@cHV@C@T@3<S?c8R?S4Q?C<Q?S@R?S@R?cDS?cDS?cDS?cDS?cDS=3@V:2TO
5aPD2P/?0P@<0@<>0@D@00HA0PXG0@LD00DB00TG11@T2B8b2B`j1c0o43U28D]B>F5VBg5eEGQkFG]k
GWimHH9nHX:1IHB5IXN:Hh>8FG^1CFig@FA^?5i[<emV=f5XA6Y_EgUoJHN<LXnDOYNKQYbQS9RJSIVK
TIZMU9fPUijQVj2SVj2SW9nSXJNRXZRSXjVTXZRSX:JQXJNRXjVTYZbWVJ>FX:BNYJBPYZFKXZNHV:BN
R9NWNXN]0B6R01JM01VY0Qfc01F/01JZ0R2]0R:Y12J_01n[01N[01B^01Nb01Vd01Vc01R_01J^01N_
01Za01bc0Aje01nf01nf022f01j^026a02:e026f026f026g0R>i12Bm02Vj02Zk02fn02o003710371
03300330032m032m02nl02jl02fk02fk02bj02bj03>k03;102jm5SniF6fn`/O^d<oHdM3<V9RNdM7G
dm?Id];HcLgCX:2Vd];Hdm?IdMCIdMCIdMCIdMCIdMCId=?Hd=?Hd=?HeMGKeMGKeMGKeMGKeMGKeMGK
eMGKeMGKd=GHeM[Md=CIem_Pd=?KcLoI/;:le]SSe]GGe]GGe]GGemKJemGKf=GNf=GNf=GNf]OIfmOL
f]WMf=OPd]CNbloJ`<KC]kk=[;k5V:^bWK2gT:J/S::XVK6gTJ^aS:J/RZR]Uk:fUJR]/Kc0c]?Fb<_?
b<c=`lO8aL[;b/o@c=7BbLk?bLk?b/o@alc=`/O8[;W1[;W1/;c2]l78`LO<aL[=`lK:_l?4^l2o_/K6
/;foS9fPYk_0]l[B`m?O^<KB//cB/LW?_]3GaM7Kb]KR[[[6]lODXkC1EVAI<Sla>44]@DD/?D0V?D0V
>3`S@TPa@d8XA4<YA4<Y@d8X@T4W@D0V?chT?SdS?S`T?S`T?S`T?S`T?S`T?S`T?S`T?S`T?cdU@3hV
?S`T?3XR?cdU@d4Y?cdU=cDM>CdT>CdT>SdT>SdT?3`T?S`T?S`T?S`T?S`T?S`T?S`T?C/S?C/S?3XR
?3XR?3XR>3LR?3XL@3dG@SlI>S`V:S<f5RQ721mA838m<3L`@cdPAchI@3/J?SXQ@c`SBShR@3XM@S`O
@S`O@C/N?SPK?CLJ?CLJ?cTL>3DF@d0QBdPYC4LXCDDWCTHXD4HXCD<UBTDVBTDVBD@UBD@UBTDVBTDV
C4LXC4LXCTHXCTHXCTHXCTHXCDDWCDDWCDDWCDDWCDDWCTHXCTHXCdLYCdLYCTHXCDDWC4@VCD@SCdHU
DDPWD4LVCTDTCD@SCD@SCTDTBdLTCDTVCTXWCdXYCTTZD4//Ddd`EDlbEe8cEU4bDdd`CdT/CDH[CdP_
E4ddF50iHf59KV]FOgaWSh]hW9R6YJ6?ZjJG[jZK[:^M[:^M[JbN[ZfO[jjP[:^MZ:NIY:>EYZVJYZVJ
YJRIY:NHY:NHYJRIYZVJYZVJZZVKZZVKZZVKZZVKZZVKZZVKZZVKZZVK[JZKYjNIYZZNX:RNRi:=2Pl>
0@860P030P<1004000@200T68S0/?4e9:3`g8SPc;Cdf8c</8c</;Shg;clh93@]8S8[:CTb7RdY6bXV
62LS52<O4b8N4b8N52<O5B@P1Q@C0a4@0a4@118A0a4@00`;00d<118A00/700<200@81`dD2PdA1PL3
3@d06A/7>c<;@CTA@CPB@CPBCTDP?cDCEdd[a[bJe<V^dlR]dlR]dlR]e<V^eLZ_e/^`elbae/^ee/^e
e/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^eelbaelbaelbaelbaelbaelba
elbaelbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbae<Vce<Vc
e<Vce<Vce<Vce<Vc003=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O?bL[?bL[@b/_@b/_AblcAblcAblcA
blc?bL[?bL[?bL[?bL[?bL[?bL[?bL[?bL[@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@bl[@bl[@bl[@
bl[@bl[@bl[@bl[@bl[?b/W?b/W@bl[@bl[Ac<_Ac<_Ac<_Ac<_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=
bl_<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[<
b/[<b/[<b/[<b/[<b/[=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_<b/[<b/[<b/[<b/[<b/[<b/[<b/[<
b/[?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[?b/W?b/W?b/W?
b/W?b/W?b/W?b/W?b/WAc<_@bl[?b/W?b/WAc<_BcLcAc<_?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?
b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W>bLS>bLS?b/W?b/W@bl[@bl[@bl[@bl[?b/W?b/W@bl[@
bl[Ac<_Ac<_Ac<_Ac<_?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?
b/W@blS@blS@blS@blS@blS@blS@blS@blS?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O@b/?@b/?@b/?@
b/?@b/?@b/?@b/?@b/?;c<;@clGCd/SEdlW>bL2j/jZOUXf:PGQPDd=GBSY;?Ri7>RY:?Be@@c=CASID
AcM:?b]HCCU@A39FBSQBACE1=2I8>be<?S9=?bU:>bQ8>BI8>2M:>RY<>bi=>c1<>Rm0=RDo=BA0=RE2
>2M4>RU4>RU2>2M0=RE1=2A2=BE2=BE0<b<m<20n<B53=RI7>RY5>2Q5>2Q4=bM4=bM4=bM3=RI3=RI3
=RHi<Qlj<b0m=R<o>2Do>2Dn=b@m=R<l=B8M9Q`D6aP83A000Pd000d00Q031a862a@02a<021802180
21D22aP13a/04QX04a/16AlS>Ci>HfEYOGidQH9hR864THV>Vi>CVYFFWIZGWijEWin?VYj:UIf7Tif7
TieHLgM>If]IKW1jRhjFXjFMYjNSZ:VZ[jjV[:NV[:NWZjJVZZFWZ:JXYZFWYJBWYJB][:R_[Jb`[Zf]
[ZbZZjVYZJV[Zj^^[ZjW[ZN][ZbaZjba[JRa/ZRV/;2AW[QjR;P0:JL07j<08:`08K@06:/07ZX:;K<=
<[87;K<19[007jd06k007kD18[L18kH08K407;407[<08;D28kP19[P29kT09kT09kT09[<0:;D0:[T0
:[T0:K/1:Kd3:kl5;L40;[X0<;`0<[h0=/40=l80=l80=/40=/40><00><00><00><00=l01=l03=l03
=l00>[P0>/80=l8JB;iJLL73ao3Ed=oGd]BKVj7De=[EeM_CdmW>c]BSXjWEeM_De=[BeM[BeM[BeM[B
eM[Ce]_Ce]_Ce]_Ce]_Fe]cEeM_EeM_EeM_EeM_EeM_EeM_EeM_>e]g@en3=e=gGgNS:d=fk`LjOY;?=
d^7Ae^G>eNK<dnO:dN[4cn_3c^k0c?2mb_2ebO:baO2Y`>fS^nVI]>J?[=n6Y=^2XMRS]L2FZ[FO/kj<
XZf3VJBBZkF=Y[24WjUlW:::YZf=X:R^^L7=dm[;c]K;cmC6b/o:d=O>e=_@e]g;dMS9cmK9cmK6c=?1
aljT]knT]KjV][f]^/:f`/Rma/Zm`lRk`/Fb_;bd`<2Y^kb=XZBX`LFdb]2od]Zgam>/blj_b/jcbLnl
cMK;fnNN[kbJ[KZ?Y;=CHePa?S0h@Be1Abhm@2Hk?R@e>B11Ac14@bM4@bM5A2Q5A2Q4@bM3@RI1@2A0
?b<m>b<m>b<m>b<m>b<m>b<m>b<m>b<m>b<o?2M0?BPn>bHl>B@o?2M3@2/o?2Lh=B0h?2<h?2<i?2<h
>b8j>R8l>R8l>R8l>R8i=R4i=R4i=R4h=B0h=B0h=B0g=1lg=1lc<Qdg=ALk>18m>Q@f>28W<3<C9D@6
7DlO<C`_=Rm2?1m6?AQ0>aXm>B13?2=:?R8n>1]0>Qe1>aho>A`l=QTj=1Ll=QTn>1/c<14n>aa9A2E<
A2I;@bE?ABM>A2I=@RA8@bA8@bA8@bA8@bA8@bA9A2E;ARM;ARM;@bE<A2I<A2I<A2I<A2I<A2I=ABM=
ABM:@RA;@bE<A2I=ABM>ARQ=ABM<A2I;@bE:@Am<@b5?ARA@AbE@AbEAB2ICBRQFCB]<ABA>AbI@BBQ?
AbU=ABQ<A2M<@bQ=A2U=ARE=ARE>AbI>ARQ>ARUABBaGCS=KDSM7ARY:BBe@Cc=HEceSHDUcLEV5PVfA
SWVDThFJVH^RXI>XYiVZZI^ZZI^YZ9ZYZ9ZXZibXZibWZY^VZIZVZIZWZY^XZibXZib]Zj2]Zj2]Zj2]
Zj2]Zj2]Zj2]Zj2]Zj2`[InYZI^WZj2QZ:6<Ti0:3Pl10PH200@30@020`442@L12PLP;RXlD4/^A3l^
AD0/@Ch[@3d/@Ch]@Sl/@ChY?S/[@3d^@d0Y?cXV?3LQ=c8M<bhJ<2/J<2/K<B`L<Rd`@CdY>SHT=C4S
=30M;RXA8Ql45A8040d<7A802@<000<00PX10@L20009200M7@]:@A]:@A]8?aY5>aUHCRaICRiYGSje
ZXc:_jC:_jC;`:G<`JK=`ZO?a:WAaZ_BajcFbkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGF
bkGFbkGFbkGFbkGFbkGGc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7E
c;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7DbK?DbK?DbK?DbK?DbK?DbK<00<g8alg8alg8alg8alg8
alg8alg8alg8alo9b/o9b]3:bm3:bm7;c=7;c=7;c=7;c<o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b]3:
bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b/o:bLo:bM3;b]3;b]7<
bm7<bm7<bm7<blg;blg;blg;blg;blg;blg;blg;blg;blc:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:
b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/g;blg;blg;blg;blg;
blg;blg;blg;blc:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/o:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bM3;
b]3;b]3;b]3;b]3;b]3;b]3;b]3;b/o:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bM;=c=7<blo:bM3;b]7<
bm;=c=3;b/k9b<o:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLk9
b<k9b<o:bLo:bLo:bM3;b]3;b]3;b/o:bLo:bM3;b]3;b]7<bm7<bm7<bm7<blo:bLo:bLo:bLo:bLo:
bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bM3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b<o:
alo:alo:alo:alo:alo:alo:alo:am3:`m3:`m3:`m3:`m3:`m3:`m3:`m3:`lG6_<W:`<o>a<_9_kJa
Z8j7OUiEC3hc:ei>?EU9>5=3<U=3<UE5=5E5=510;d/k:T8d8Ee??4i0;DDg9DXk:d`m;E=3=TPh:ddo
;4Xl:DPj:4Pi:DTi;4Xj;TTh;dPf;d0i:Shg:3df9clh:D8k;4@m;T@m;T<l;D<f:4@g:D<f:3lb93`_
8Cd`8T8e9dLj;3ha8clb93lb940c9D0c9D4d9T4d9T8e9cTb7c`e8Slh9D8k:4<l:D4j9chg93df8`PF
4PDA4@<:4`465@<55`<65@@64@853@083P0:404:4`@:5@@;50@;50@=4@8=4@0832Da<eQRHWElNGMn
MgQkLX:4N8n?PinHSj>KU:FOVZJQX:RSYJbX[[>`^KRg`GZ9Rf=aL6I`L8nEU:na/K>_[ZjVY[>ZYjbd
ZJbdZJfeZk2e[;Fh[kNi/kbl][fm]k:a/kJe^KZi_KRi_KJf_;:e^[Bf_[Jh`:nd]K>c^KFa]kNb/kNj
^:ni`iBTb7^;aP8^Z@0SY00U[@0T/P0MZ`<W/1Dl_1a5_`de]PH//P0T[P0R/P<U^0LZ^PHZ^0@X]0HX
^`PZ_@P]_`/``0Xb`@Td`@Td`@Pc`00/]P0^^0<a^`<`_@<__P@`_`Hb``Pda@<k`PDma0LoaPQ2b@M4
bPM4bPA3b@=2b011a@11a@92aPA2aPM2a`Y3b0a4b@a4b@11^013a050aQm>`UecaLC7lmOAi=cDfi^K
XMCDf]CDf]7Aelc<dZ>SZMCDf]?CfM3Cf=3Cf=7DfM7DfM;Ef]?Ffm?Ffm?FfmKFg=KFg=KFg=KFg=KF
g=GEfmGEfmGEflWCgLSBg<G>floHiK_4dZ:Z^hB<WKNndKK1gk2mgJFefYZ[eXZPd7jFc7B?b6j:aTih
`dQb_Cm]^c]Z^cEW^RmT^bmT_RmV`H^N[IV/^iZ__VIkRUE/Nh2JZ82JZ61kRF>3SW6=V7B8Ti^W/L?9
e<O<eLW>elC:dKS1b[k7d<39d[c5c[W2bk[3c;S1b[BmaYN/]9BY/IFX/9V[/ZBb^:bh_Zji_Jfh_:Ve
]JNf^9nd]HVRY:O2aZo7cKW>e[C7cjO6aj[7bjW1akG8d<_Mj9>V/h6HYgjHYU=SF30m;cU2;T98;ci1
9cTn8c@h7d57<4E4:4E4:4I5:DI5:DE4:4A39d=29T919C`j8S`j8S`j8S`j8S`j8S`j8S`j8S`j8T0m
:40m:3hk9S`i93ll9d=0:d0m:3Pe83Lk8SLk8SPk8SLj8CTi8C/i8C/i8C/i8Bh[5Rh[5Rl/5c4^6C8_
6S@a73Db7CDb7Bh]638`4SLd3SXg4C<e7b@]<14S@P@KCAla?2lf;d8l7dHm640k6Sdi848k8TXn8S`f
6Cli740j7Cli73/e63Tc5SXd5cdg6Rh[33`g64E08DU18d]18di49Tm49Te294M28dM28dM28dM28dM2
8dU49DY59T]69dU18dY294Y294]39D]39Da49Ta49Te59dLo8DQ08TY294a49Ta49Ta49T]39DY29599
9e=::5=::5589Ti58di58e179E999d]48di6:518:U18:di6:Da3:4]1:D]1:E999e=::5A;:U=::E57
:E56:U97:eA9;Da=;Dm@<59B=55A<dm><Tm><U9A=eED>U=BA65PDWEdIXR7NIJEQj2OTJZYVk2_XJZ]
WZV/WJR[W:R[W:R[W:R[W:V/WJZ]W[2^Xk2^Xk2^Xk2^Xk2^Xk2^Xk2^Xk2^Xk:_XJZZWZR/XJ>ZXhfD
T@/?40831`<01@8000830@H;2@081APW8cA8@b]2?C1:A2Hn?3=;BCM?CC18AS18ASeEDdALFT5IEdUS
GD9LESQBC2e7@B8l=Q/e;aLa:aD_:B@g;R0c:R@f;cA6?d5CC41ACCE6@Rdn>Q`^7@/K40@<30H84080
20@00B0M5DQ5=dLk5dHj64<g5D<f5VUL?8]mH9f?Llo1YLc1Y/g2Ylk3Z=35Z]?8[MK;/=S=/][?]=K;
]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MO</MO</MO</MO</MO<
/MO</MO</MO</MG</MG</MG</MG</MG</MG</MG</MG</MG</MG</MG</MG</MG</MG</MG</MG</M?8
/]?8/]?8/]?8/]?8/]?8/P00d<S8d<S8d<S8d<S8d<S8d<S8d<S8d<S8c/W8c/W8cl[9cl[9d<_:d<_:
d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:cl[9cl[9
cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9d<_:d<_:d<_:d<_:d<_:d<_:
d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;
d<[;d<[;d<[;d<[;d<[;d<[;c<[9c<[9c<[9c<[9c<[9c<[9c<[9c<[9c<[:c<[:c<[:c<[:c<[:c<[:
c<[:c<[:cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[7cl[7
cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7c/W6c/W6cl[7cl[7d<_8d<_8
d<_8d<_8cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7c/W6c/W6cl[7cl[7d<_8d<_8d<_8d<_8cl[7cl[7
cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7
cl[7cl[7c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/_3c/_3c/_3c/_3c/_3c/_3c/_3c/_3dLc3d<_2
d<_2dLc3d/g4d/g4cl[1cLRod<G1f]39h]O?^K2SKV=EBCl]DTLcET/eCT4aCT4aCT4aCT4aCT4aCD0`
CD0`CD0`Bch^BSd]BSd]BC`/BC`/BSd]BSd]Bch^AcXZB3/[BC`/B3/[ASTYASTYB3/[BSd]B3/[B3/[
B3/[AcXZASTYASTYACPXACPX@CTX@3PW@SPW@SPWA3LWB3TYBS/[Bc`/AcT]ASP/ACL[ACL[ACL[ACL[
ASP/AcT]@CT/>2lR@3DW@cPZB3hdL6YS:2HU4Q@E2@LC10HA20`G0P/E0009008=2@/F2@LC0`dG0`dG
0P`F0@/E0@/E0P`F0`dG0`dG0a0B<chlHVURLgEYMWEWOGY/OWaaNWQ^Q8=eQhEjSH^0UI>9WYbBYZ>K
[JZR/:bWZZNRZJJRYjJRZJZX[Jn_/KJe/kRi];Vj_;Zi_[bl_K^k^kRj_[Zo`ko4`ko5_[[0_;c2_[k4
_ko5_ko5_Kg3_Kg3_[k4`<36^;k;]KS0`/C5a<K6][c1//;?WkSBM9>d03>l02nm02_20B_40Rc11SBn
5TK49EO=0Sji03bg03Ze03Rc03Rc03Vd03^f0Cfh03fl03fl03jm03jm03jm03jm03nn03nn03k=03k=
03o<03o903o804360434043404O<04S=04W=0T[>1d_>2dc=34[<3T[<0dW<0d[:1T_:1Tc824c72Tg7
2Tk52Tk52e6l34g05Tc1=5NiGf^]^kgOcM;Qc]_S]:jW`/C<b]7U`lWPe]KVVYZVbM?U]/OQe=[Uc=3S
bL[VbloWb]7R`lSM_l7T`l3b/<;W[[oVZ[cUY;ORWK;OUjkLTj[JSjWHNICDL8[@IHC?FGk@?fg19efb
9F6c<G313e^k3ERl2e>n2e;12e?32e?31e;01E2l04o<04g<04c;04g<0e3;25G:3U_945k8KiBfQ9nc
UJR]NY6CF7b4IY>QKij/Dh::GXJ;KYBIFWZ0QInVYKJo^/C>[k>n][S3]Kfm/kfm/kfm/kfm];jn/kfm
[k^k[KViSjN]R:6URYjSTZFXWZf_XJf_X:ZZWjNWVZNYVZJXVjBXWjJ_Z;Bn[l?>Z<KAW/7>V[C2U[6o
W[c7Wkg8]mCMW;:mTj>_TIfYPWj3K6e[EeYAB50o?DL`=SlU>3hU@DD/@4<Z?D0W>SdT>SdT>chU>chU
>SdT>C`S?3/W>cXV>STU>CPT>CPT>cXV?3/W?C`X>STT>STT>STT>STT>STT>CPS>CPS>CPS>cXU>cXU
>cXU>STT>CPS>CPS>3LR>3LR<BlG<2hF<2hF<S0H=C<K=cDM=cDM=S@L=CHR:RLH9b4D;bdK=C/Z:CLf
4B=2015962Dc;Rl[@CPM@CPC>cHE>3LK?3PK@3LF?3XL>CLI=C<E=34E=C4H=S8I=S8J=C4I=S8E?CLJ
@S`OB40SBSlSBSlSC40TCD4UB40RB40RB40RB40RB40RB40RB40RB40RB40SBD4TBT8UBd<VBd<VBT8U
BD4TB40SAD8SAD8SB4<TB4<TBd<UCT@VCT@VCdDWC4@WBd<VBT8UBT8UBT8UBT8UBd<VC4@WAdDSAdDS
B4HTB4HTB4HTB4HTBDLUBDLUBD@SBTDTBTDTBTDTBTDTBTDTBTDTBTDTBTPZBdT[CD/]CT`^Cdd_CT`^
CD/]C4X/Ee<`D4/ZAdDWATD[C4diGf9BOX9fV9jC/[:R/K6Q[jjP[ZfO[J^P[J^Q[J^Q[J^QZ:^R[:nV
/KB[/KB[[[6X[:nV[K2W/;>Z[k:YZZbV[:fYYZJVR8N;0P082`LC000810T:1Ph>00X:00`;6b/Z@UME
DFMUAEeKBUmPBf1QC65RCV=TD6EVDVMXDfQYE6UZC6ALCfMODVYRE6aTE6aTDVYRD6QPCVINFVUQCEaD
>TU1;cdg<d4m>dU5=D909c@b9C4a72PX6bLW6RHV31PH31PH>dM7MX:2?3LN?SPKC4HSCdPQ?SD?Ac/I
Dd8W^jJ@f<Z^e/Z^e/V_eLZ_e/Zbe/^eelbfe/jgel^cel^cel^cel^cel^cel^cel^cel^celbaelba
elbaelbaelbaelbaelbaelbaelbaelbaelbaelbaelbaelbaelbaelbae/^`e/^`elbaf<fbf<fbelba
e/^`e/^`e<^`e<^`e<^`e<^`e<^`e<^`e<^`e<^`dlZ_dlZ_dlZ_dlZ_e<^`e<^`003@b<S@b<S@b<S@
b<S@b<S@b<S@b<S@b<S>bLS>bLS?b/W?b/W?b/W@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@
bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?
b/W?b/W?b/W?b/W?b/W@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@
bl[@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_<b/W<b/W<b/W<
b/W<b/W<b/W<b/W<b/W<b/[<b/[<b/[<b/[<b/[<b/[<b/[<b/[?b/W?b/W?b/W?b/W?b/W?b/W?b/W?
b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?
b/O?b/O?b/O?b/O?b/O>bLK>bLK?b/O?b/O?b/O@blS@blS@blS?b/O?b/O?b/O?b/O?b/O?b/O?b/O?
b/O>bLK>bLK?b/O?b/O?b/O@blS@blS@blS?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?
b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O>bLK>bLK>bLK>bLK>bLK>bLK>bLK>
bLK>bl?>bl?>bl?>bl?>bl?>bl?>bl?>bl?@bl;?b/7>bL3?b/7@bl;Ac<??b/7=b;o=`[kLd/^j[jMd
Jei>@cE6?2Y:?b]BAc5;?Ri;?Ri<?bm<?bm<?bm<?bm<?bm<?bm;?Ri;?Ri:?Be:?Be:?Be:?Be;?Ri;
?Ri8>b]9?2a:?Be9?2a7>RY6>BU8>b]:?Be8>b]8>b]7>RY7>RY6>BU6>BU5>2Q5>2Q1>BQ2>RU6?2]7
?Ba:?Be;?2a:>b]9>RY4=RY4=RY3=BU2=2Q2=2Q3=BU4=RY4=RY2=RXj;Am8>b]1=RQRFDmBCTTQ8b<;
41<=3aX421<331H33AL01@l02A<;3aX621<43QP33AL33AL231H231H33AL33AL43QP54Q@h@d5[LV]m
Og=oOW26PgF9Qgb7QG^7QWR9Qgb<RWn@SXBDTXRGU8bJUhnLV9>RWiZVXij[ZZJd]K>l_kfoa<?0aLBo
a<Fm_ko1`lC0`/>m_/:m_/;2`/S4a<[2`L[4a<[5aL_5aL_3`lW0`<Jn_/Bn_/C0`<JlaLnj`<O6b<W8
b<Rk_/>i`]2X^M>1V;P=@K<<?;8<>[L@>[/D?K/KB;//Fl@lK/hE>/@D>L<B=l4@=KlA=/0B=l4D>L<F
>lD=?L4=?L4>?/8??l<@@<@A@LDB@/HC@lL@?k<A@;@C@[DEAKDHBKLKC;PLCKTMCkTJDK@LDkHQE[LX
F[X_G;ddH;lgHL4iH[l`Fk8dGK8hHKHoIkY5KKm<Ll9AMlEDN/QWQ/E]SMAeU=n=XN:S[=k<eO^Z_>FJ
]nAoQjbO[]n>Xn6>X>66T/abP;F9WmU^S/m;Ola8NLm5M=11L/PmLKhgKKXfIl<gHlhUFKdUFKhRF;dO
E[hME[lKEKlJDl0HDl0EG<@=D[l<Cl8@D/T;C<H1A;h3Akh?E<T8ALD6@/@5?lL5?LX6?/d4?/d3?/X1
?<L0@L00@<40@L80AL@4B/D<D/LAFLPDG/QeWlUfU:mjSiMaQhaVQHiTS9QOR95>MGM=LgQIOH=ZRY2:
YZfQ^<2``LZU];f]^L>Z^KbW]K^R/[RS/kZT/kbQ/KfL[;RGYkB9YZn7Y:f8XZR<XZNCYZVIZJRIYZBG
XYm^PHAdQ8YlRI65U9fEYk:M]lFH^LR=]<:F_]29]<>6/L23[KZTb]JG][nAYk:8Vj>[ZZbKW9Z6Rh9e
O6eUJeQ@ED0k?b`a<b0m?bTm?bTo@B]1@be3ABm1@bdl?RPh>R@i>2@h=b<g=R8f=B4f=B4g=R8i>2@j
>BDm?2Lm?2Ll>bHk>RDj>B@i>2<h=b8h=b8h=b8h=b8h=b8g=R4g=R4f=B0f=B0e=1ld<QXc<ATb<1Pc
<ATe<a/f=1`e<a/c<AT`<AdM6P/A300G5@<R:1DO;B/@83d14TXH9C<^;b]1>1e1>1<k=QDh=a/l>1]0
=aHl>Q`i=aTf=1He<QHf<QTg<aXf<QXe<ATd<1<i=AQ0>Qe6?R56?R58?B59?R9;?b=8@298@298@298
@298@298@298@298@298@2=8@2=9@BA9@BA9@BA9@BA8@2=8@2=5@R=5@R=7@R=6@B98@29:@29:@29:
@299@BA9@BA8@2=7?b97?b98@2=9@BA9@BA7@R=7@R=8@bA8@bA8@bA8@bA8@bA8@bA7@R=7@R=8@bA8
@bA8@bA8@bA8@bA9A2E7ABM8ARQ:B2Y;BB]<BRa;BB]:B2Y9AbU3?Qe7A2EEDcEVI4adMF62QGFFVXjY
[J:ZZYb[Zif^[Z:a/JFb/JNc/ZRb/:Rb/:RX[:6Z[Z>//:F//:F[[jBZ[Z>[[jB//:FTYijVZJ2^/:ZX
ZJF6QXH510H:2@d000<00P000`022P<95PhY>31AI5]PMFaGKfELKFULKFULKFUKK6QKK6QKK6QKK6QK
K6QQMFURMVYOLfMDJ5a5FDdkCd<iCD4kCd=3Cd=SKf>2SX:8ThUkQWiYM6aKIEmBG5IAFUM=EU=>EeA?
F5E2BdPh@Ci:De1XLFi?B3A2?R92?Ai4?1Li<0Y:?QYIBR[1[i;Mck?Kck?Kck?JckCIcKGGcKGFbkGD
c;GGc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7G
c;7Gc;7Gc;7Gc;7Gc;7Fbk3Fbk3Gc;7HcK;HcK;Gc;7Fbk3Fbk3CbZoCbZoCbZoCbZoCbZoCbZoCbZoC
bZoBbJkCbZoCbZoCbZoDbk3Dbk000=38b=38b=38b=38b=38b=38b=38b=38b<k9b<k9b<k9b<o:bLo:
bLo:bM3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b/o:
bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bM3;b]3;b]3;b]3;b]3;
b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:
bm3:bm3:bm3:bm3:bm3:bm3:bm3:blc:bLc:bLc:bLc:bLc:bLc:bLc:bLc:bLc:b/c:b/c:b/c:b/c:
b/c:b/c:b/c:b/o:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:
alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alk9a/k9a/k9a/o:alo:
alo:am3;b=3;b<o:alo:alo:alo:alo:alo:alo:alo:alk9a/k9a/k9a/o:alo:alo:am3;b=3;b<o:
alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:
alo:alo:alo:alk9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k;`lk;`lk;`lk;`lk;`lk;`lk;`lk;`m3;
`/k9`<c7_/g8_lo:`M3;`]3;`/o:`M77`=?:`HZ0MS/b9Cdb94a2<DXn;515<DPk:dPk:dTl;4Xm;DXm
;D/n;T/n;T`o;d/n;T/n;T/n;T/n;T/n;T/n;T/n;T/n;TPk:dXm;D/n;TXm;DPk:dPk:dTl;4/n;TPk
:dPk:dPk:dLj:TLj:THi:DHi:DHi:C`d8clg9TDk:TTo;T`o;dho;d/l;4Xk:d@g:D@g:D<f:48e9d8e
9d<f:4@g:D@g:DLf:D8b8U10<4`o<H^2N3Hf<1`R8@8=4@`B7@0:504=5`4B6`0=5P<?6@LA6`474PD?
6@@>60@>60<=5`<=5`@>60@>60D?6@HC5Ce8AWAjMHR9OhV7O8n;P9BBR9BBR9>BQ9>AQY>AQY>AQi>A
QiBARIBARIB@Rhj;QY:?RYRHTZBSWjj_[KJi]k^m_Kfo_ko3a<?7b<?6b[g0aKVl`Kfoal;4c<?4c/C5
bLK7blO8c<S9cLO8c<O8c<W:c/_<d<;;e<;8cL_=c/k<c<O5blO8e[c2fInZaS5KZ2iFZ2mDZC5E[CEH
[SeQ[d]b]eZ3`T=E`49D_d5C_T1B_D5C_T=E`4EG`TIH`dEO_DEO_DMQ_dQR`4YT`T]U`deWaDeWaFAj
`VIla6QnaVb2bFn6bW>:cWJ>d7N?dHBOdXVQeHjUei>XfiV]gJ2`gj>ahJBchK_5ikg6iko8jLC<j/O?
kLcBkm7El];Fl]76e]KDj<_?ilW?i[[3gYf]fcUIY1=2Y14/PcmQaAY2/RA9^`TYU2M7ZbQ?^@`k[P1;
b@A?e05;d`15a017^P1?_`1:a@0oa`0lb@0mbP0nc00oc@0oc`10d011d`11d`15a@0m_`0k`P13b`96
c`E6b`e:bQMBd0I1aP@naP<kb0<jb`DkcPHmcP@lb`8ja`8m`P4l`@4k`P0n`P91`@A7`@M=_PUA_DEe
ZB]AM1D^?Qdc>Ba8Cb93C1Dd=ATc;BE6CbQ9DVN6SgNFWhJS[8fX/X>NZ8bU[iVb_9F]^I2Z^8jX^HnW
_H^T_XBO^WnI]fV=WGBGYGVIY7REW7^DUXFJV8RIUHFESU=]LeafO6Z1RGVAWH^V]9FfaI6hahNb`f^Q
^5V@YDj3Udf0T8Nc`9Ji`iF`^XJKXj2UY9jSXI^PUiZNTYNLSI2BQWioMFa]I4a<>T92<3Hf92d]6b/[
6Bl_7CDe8cTi9cDd83Dd83@c7c<b7S<b7S@c7cDd83Dd83`k9S`k9SXi93Th8cLf8CDd7c@c7S@c7S@c
7S@c7S@c7S@c7S<b7C<b7C<b7C<b7CLe7CDc6c@b6S@b6SDc6cDc6c<a6C8`63Lf8B8N31@=01LF0R@Z
5b8_;A8R?`@CBaTV=2l`;44h7D4h4cXe53Pg6c`h6clf5C`j73Tg6CLe5cHc5cLc6SLc6SHb6SDa6C8^
4CLc5S`h6d4k7T@l7d@l7dLl84Ll84Hn84Hn84Hn84Hn84Hn84Hn84Hn84Hn84Q08dLo8TLo8THn8DHn
8DLo8TLo8TQ08dA18TA18TE08D@o84Dm7dHl7THl7TDk7DLo8THn8DDm84Dm84Dm84Dm84Hn8DLo8TLo
8DLo8DLo8DLo8DLo8DLo8DLo8DLo8D@o84E08DE08DE08DI18TI18TI18TM28dA294E39DI49TM59dM5
9dM59dI49TI49UAA<VISA8F2IZ6QRJj_Vjj_Wj^^Wjb`Y:RZWZV[WjV[WjZ[XJ^/Xj^/Xj^[YJ^[YK6e
ZK2dZ:ncYk2dZ;>gZkFi[KJj[[Fi[K^o];Vm/[Rk/ZFXWgUlL`@700D80003014D1AhQ4RL/7Bhe9T1;
>eUVEV5aH5][FV5ZGF1YG5mXFeeVFE]TEeUREEMPDeIODUAMD5IODU=LCdM@@cU2=C<l;cQ1=3m8>dYB
@GEmK:>ZVk:iZZV`Xj2VVjBZWjbbYkBi/;:g[[:g[[:g[ZfbZJ:WWYfRVIfRVHN0Kg9[EfMPAEaE=4Y2
7E=88UQ:9[NYQM;4Ym;7ZMC8[=K;/=O</MG;/mG;/m;:/mK;/=K;/=K;/=K;/=K;/=K;/=K;/=K;/=K;
/=K;/=K;/=K;/=K;/=K;/=K;/=K;/=K;/=K;/=K;/=K;/=K;/=K;/=K;/=K;/=G:[mK;/=O</MO</MO<
/MO</MK;/=G:[m?:[m?:[m?:[m?:[m?:[m?:[m?:[m?:[m;9[];9[];9[]?:[m?:[mC;/000clO7clO7
clO7clO7clO7clO7clO7clO7cLS7cLS7c/W8c/W8cl[9cl[9cl[9cl[9d<_:d<_:d<_:d<_:d<_:d<_:
d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8
c/W8c/W8c/W8c/W8c/W8c/W8d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:
d<_:d<_:d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;blW8blW8
blW8blW8blW8blW8blW8blW8blW9blW9blW9blW9blW9blW9blW9blW9c/W8c/W8c/W8c/W8c/W8c/W8
c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6
c/W6c/W6c/W6c/W6c/W6c/W6cLS5cLS5c/W6c/W6cl[7cl[7cl[7cl[7c/W6c/W6c/W6c/W6c/W6c/W6
c/W6c/W6cLS5cLS5c/W6c/W6cl[7cl[7cl[7cl[7c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6
c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6cLS5cLS5cLS5cLS5cLS5cLS5
cLS5cLS5cL[2cL[2cL[2cL[2cL[2cL[2cL[2cL[2dLc3c/W0c<NncLRocl[1d<_2d<_2d<_2e<_2YijD
GeE;=B`O@SLYD4HeCT4aBSh/B3/[B3/[BC`/BSd]Bch^C3l_C3l_CD0`Bch^C3l_C3l_CD0`CD0`C3l_
C3l_Bch^BC`/Bch^C3l_C3l_BSd]BC`/BSd]Bch^B3/[B3/[B3/[B3/[B3/[B3/[B3/[B3/[>30O>S8Q
@CLVAC/ZBSd]CCh^CCh^CCh^B3/]AcX/AcX/AST[AST[AcX/AcX/B3/]CCPYDSd^D3h]HeI6ZJ>H<C8^
628R00hD1@lI00XD11DN2AhV0AHN014J110J00TC1Q0J1@lI10hH10hH10hH10hH1@lI1Q0J1Q8F@4Y:
NX1kSXn6SH^0TXj3UiF;VIJ>V9N9V9J;V9J;V9J<UiF;UiB<UiB<Ui>>U9F<TY>:TY:<UiNAXj:N/:j]
^[^i`<30^l31`/O8`/O:^ko4][Zo^kk6`/G=a/SBaLK:alS<b<W=bL[>b<W=b<W=b/_?c<gA_l[>a<_>
b/c=cL[<c<S=cl_FbLOJ^kcAWkGNW[7NWJkOXK3QXK7PX[;MZk_P]<GV/<3M/<3M/<3M/<3M/L7N/l?P
]<CQ]/KS]lSM^<WN^<WN^L[O^/_P^lcQ_<gR_LkS_/CQ_lGR`<KS`LOT`lWVaLcWa/gXa/gXc=?Tcm?U
dMKUeMSWf=WWfMWUfmWUfmWUf]KKfMGJfmKHfMCFfM;Ef]7DfM3CfM3Cj];Dkn7SfmOFe=WGbM?MU:_K
6TFV02je0bjM95OC0SS13D7:02NW8Dg:7E3?147703fi1dG71dG90d:j3U>j8VK97Uo;2TRn3T_;3T_;
34_;34[<34[<34[<34[<2T_<34c82DO32TG34DW65dc564k08UK1;F3804Ni04Fi04:k042m04:o0DBo
04>j04>h13_60S[70S[703_703k60DC30dS10dc0BGnl:E=n0A`a11PS8cY293a26Bh/:CT^9dA=7CY3
LI2ILY>LNYjVOj>[M9VQNIjVLiFUM9FXLYB[KI2ZJ8^/I8R/I8R`IXVdEHBIJiJYMZ2]M9RPLi:EOIFC
OYF=Nhj5BVY`DG1iEgN2GX2=IX^IJi6SI8jQFXFH:E]g5dYT3d5H6DUKJiBSU;C1WkG0Ri^WTijLV::L
VZ:HVYjCWIjDWj2GV9NCRX^9PH5aLG5QFUY:A4@d=cLW<C4Q<C4Q<C4Q=3<O=3<O<c8N<c8N<S4M<S4M
<S4M<c8N=SDP=SDP=C@O=3<N<c8M<S4L<C0K<C0K<c8M<c8M<c8M<c8M<c8M<S4L<S4L<S4L>3HN=S@L
=38J=C<K=S@L=S@L=C<K<c4I?3/V<BdK;2DD<RhK=S/V:3Hb4b4m0A566BHd;c0/@CPM@CPC>SDD>3LK
>cLJ?cHE>cTK>CLI=cDG=S<G=c<J>3@K=S8J=30H<BlA=C<E>cLJ?c/N@C/N@c/NA3`OAc`PA3`NA3`N
A3`NA3`NA3`NA3`NA3`NA3`NAclRAShQA3`O@c/N@c/NA3`OAShQAclR@ChO@ChO@chO@SdNA3`NAC/M
AC/MAC/MACdPA3`OA3`O@c/N@c/NA3`OA3`OACdPB3dQAc`PAc`PAc`PAc`PAS/OAS/OAS/O@S`O@S`O
@cdP@cdPA3hQAClRAClRAClR@T0R@T0R@d4S@d4SA48TA48TA48TA48T?3XLBDLYH5m3Ng]SSHijUiV6
XJ:BZ:^L[k>W[[:V[;2TZjnTZZfTZZfTZjfWZjfW]KRY/;>TZJbMYjZKYjZKYjZKXjJGX:>DUiV=TI>7
SY62PXEfKW5Q:bhN?D4^A4PeD4ljEeU3GEm9Fei8G69;HFUBH6YCFVA=I6I@I6I@HfE?HF==H69<Gf5;
GV1:GEm9H61>Hf=AIFECHf=AHF5?I6ABKFeKMWITNWaVPhE_RhahS8ajRXYhS8alTi>3VIR:ViZ<VYV;
UiJ8U9>5UYF7V9N9TY63RHQjUi21S8EdRH=/O7IIGeHeEdhXED/S/jMo`K>F`kRJbKjPc/>Wd/N/dlZ_
e<Zbd/^be/^_e/^_e/^_e/^_e/^_e/^_e/^_e/^_e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`
e/^`e/^`e/^`e/^`e/^`e/^`eLZ_eLZ_e/^`elbaelbae/^`eLZ_eLZ_dlZ_dlZ_dlZ_dlZ_dlZ_dlZ_
dlZ_dlZ_d/V^d/V^d/V^d/V^dlZ_dlZ_003?alO?alO?alO?alO?alO?alO?alO?alO=b<O=b<O=b<O>
bLS>bLS>bLS?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?
b/W>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS?b/W?b/W?b/W?
b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?bL[?bL[?bL[?bL[?bL[?bL[?bL[?
bL[?bL[?bL[?bL[?bL[?bL[?bL[?bL[?bL[;bLS;bLS;bLS;bLS;bLS;bLS;bLS;bLS;bLW;bLW;bLW;
bLW;bLW;bLW;bLW;bLW>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>
bLS>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK=b<G=b<G=b<G>
bLK>bLK>bLK?b/O?b/O>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK=b<G=b<G=b<G>bLK>bLK>bLK?b/O?
b/O>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>
bLK>bLK>bLK>bLK>bLK=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b/;=b/;=b/;=b/;=b/;=b/;=b/;=
b/;Ac<??b/7>bL3>bL3@bl;Ac<?@bl;?b/7;`[QVGU4j<BA8?c95>Ra4>B]@@cE5>2Q:?Be:?Be;?Ri<
?bm=@31>@C5>@C5?@S9<?bm<?bm>@C5>@C5>@C5>@C5<?bm<?bm9?2a<?bm>@C5>@C5=@31;?Ri;?Ri<
?bm:?Be:?Be:?Be:?Be:?Be:?Be:?Be:?Be0>2M0>2M3>BQ4>RU7>RY;?2a=?Ri>?bm:?Be9?2a9?2a8
>b]8>b]9?2a9?2a:?Be=>BQKAcI6=2=gJUZYXiPi>SHC71l02a<02Q@03AH>8BTG;3@87BD04QX24AX1
3AL641X53aT43QP43QP43QP43QP53aT641X74aU1BTejOgf>ShJ=Rh6BSHBFTh^HU8nEU8JDTXNDTXND
TXRCTHNCT8RBShNBSXVEUXbATXV=SXF=SHNFThnPWIVYYJB^ZZV[/:nc^;Nf^[^b][Na];Ri_<73a/_9
c=7:c<g;cLk<c/o:c<g7bL[5alS6b<W7bLZob<_5cLg6b/_7a/S<b<g>bM;:a];9`mC8b=[7aMS8a][=
amk>a]g9`mK;`mC?b=G9e<[9e<[:eL_:eL_;e/c=f<k>fLo?f]3=dlk=dlk=dlk<d/g<d/g<d/g<d/g<
d/gAfMSAfMSBf][Bf][Bf][Bf][Cfm_Cfm_Ee=SEe=SFeMWHeMOGeMGFe=CGdm;Fd]7Ff]_Ff]_Hf]_I
f]kKf]kNf]oNf]oQfn3EbmcJf>C;d=7Af=?@g>:U_N/]FKh7A=09?:X>Al80>Kl0=[d0<[0;?KD:@kh0
>k`4>[H=@/4@@l8BB;/XI<A2O]LiL=4KCkX8A[`8A[`7AK/7A;X7A;P6@kL5@[H5@[HF?/HC?LD??l<<
?/05?[T4A;@>DkXIH/@0A;`0@K`0?kd0?L00?[l0@;l0?kX0?[D0>L@1>LH2>/L2?LT4@<P7A/H7B/@8
CL8fJjXYD7d77cL04QdM;cXV>D4R<S4a>C8[@dlE;c]NNXEDM7mIOHMJPHY:MGi=N85>MXQEOI1GP9MA
O9M8LiA5LYQ=NZEFQK4mLhYBQIUOSIiJPXiBLWM@JVY=HUm9Fe@ZC58/CEHXC5HTBUHRBELOAeTG?e8=
=DP6:4D073H06C47:SiMOXj:Xk>HZKJ5TZ2GZZNN[:JQZZ2QXYROWYBPWYJNWIVFVINVYYJOWhnBTX:0
P71ZJUYADD4j>RX/;1`e=20e=20e=20e=20d<alc<Qhc<Qhb<Adb<A`b<A`c<Qdc<Qdc<Qdc<Qdd<ahd
<ahd<ahd<ahd<ahd<ahd<ahd<ahd<ahe=1lg=Ade<a/d<QXe<a/g=Adh=Qhg=Adf=1`j>20i<b0l=2=1
?2Lj?2PT;b`>7CL34DDJ9cD`<Be2>Ai1>1<j=A@g=QXk=aXn=A@i=aTh=QPf=1Hf<aLg<aXg<aXe<ATc
;aL_;a4e<aDj>1Xo>ai1>ai1>ai4?1m5?B13>ae3>ae3>ae3>ae3>ae3>ae3>ae3>ae4?1m3>ai1>Aa0
>1]0>1]1>Aa3>ai4?1ln>a`n>aa0>aa1?1e3>ae6?1i6?1i6?1i4?1m3>ai3>ai2>Qe2>Qe3>ai3>ai4
?1m4?1m4?1m3>ai3>ai2>Qe2>Qe1>Aa1>A`o>Aa0>Qe1>ai1>ai2?1m3?B14?R54?R50?R10?R10?R10
?R11?b51?b52@292@28k>Qhb<AD[;18_;aLj>BA9BSIRHU1eMFF<SgnCUXNMX96WZIf][j>^[jF[[:>Y
ZZ6KW8bDUHF:Rg^3Q7AnOfmjNf]cM6A^Kem/KEeSI5AQHe1RI55VJ5A@DSiXJeEdMf5^KeEbLeUfMeed
ME]_LUQ_LUQ`MEYaMU]gLeYgLeYhM5]iMEajMUekMeilN5mlN5n3OFZ2O6V2O6V4OV^8PVn<QW>>R7F>
R7F7QFf1OfMmNVEoO6N3Ofb2OVamNFMhM6:2OV^4P6f1OFYlN6F0O6V7Pg27Pg20O6UaKE]fLV26P6en
MeiHD3=>AB=@B22g[X?8^i_9_Yk>`jGAajWDbJgCbZoCbZoAbZoEbZkEbZkEbZkEbZkEbZkEbZkEbZkE
bZkEbZoEbZoEbZoEbZoEbZoEbZoEbZoEbZoEbZoEbZoEbZoEbZoEbZoEbZoEbZoEbZoDbJkEbZoFbk3F
bk3Fbk3Fbk3EbZoDbJkBbJkBbJkBbJkBbJkBbJkBbJkBbJkBbJkAb:gAb:gBbJkBbJkBbJkCbZl00<k6
a/k6a/k6a/k6a/k6a/k6a/k6a/k6a/c7a/g8alg8alg8alk9b<k9b<k9b<k9b<o:bLo:bLo:bLo:bLo:
bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLg8alg8alg8alg8alg8alg8alg8alg8alg8
alg8alg8alg8alg8alg8alg8alg8alo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:
bLo:bLo:bLo:bLo9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/[8
al[8al[8al[8al[8al[8al[8al[8al[8b<[8b<[8b<[8b<[8b<[8b<[8b<[8b<g8alg8alg8alg8alg8
alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8
aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLc7a<g8aLg8aLg8aLk9a/k9a/k9a/k9a/g8aLg8aLg8aLg8aLg8
aLg8aLg8aLg8aLc7a<g8aLg8aLg8aLk9a/k9a/k9a/k9a/g8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8
aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLc7a<c7a<c7a<c7a<c7
a<c7a<c7a<c7a<c9`Lc9`Lc9`Lc9`Lc9`Lc9`Lc9`Lc9`M3;`/o:`Lk9`<o:`M3;`]3;`/g8_l_6_JjV
VClg:RdT5eA;?T@i:chc9EI9>d`o<D`o;de0<4e0<4i1<Di1<Dm2<Tm2<U13<d`o;de0<4m2<U13<e13
<dm2<Te0<4`o;dXm;De0<513<e13<dm2<Te0<4`o;de0<4`o;d`o;d`o;d`o;de0<4e0<4e0<4e0<4e5
=4]3<T]1<4To;TTl;4/l;4`m;Ddn;TXn;4Tm:dTm:dPl:TPl:TTm:dTm:dXn;4Pi9UM8=Ch_77EXF8f4
NSTg=Q4E6P074@094`0<5Q8S;1`a>@XO9`0?60<?6@LA6`D?6@@>60@>60<=5`<=5`@>60@>60D?6@LC
6Ci7BWEjN8V9PhV7OHn9PY>@R9>?RY:APi:@QI2>Phn=Phf;PHb9PH^8P8Z6PHF6O8B5NhB5O8N5OHb8
Phj9QY29QXn8QHf?RIFGTIZKUiZKVIjOWJVYZK:b/[Je]kZl_;fo_l73`lC6a/K8b<W;blg?cm3Bd/G;
b/gCd/W=c/C8bLc=dLW9clG5blk=e]K>eMC<dmS=eN3BgN3Cfmg>e]_<e=k=e];?f=?@fM?@fMCAf]GB
fmGBfmKCg=KCg=SAh=SAh=O@gmO@gmK?g]G>gMC=g=C=g<_Db/cEblcDcLgEc/kEd<oFdM3Ge=7HeMSG
fmWHg=[IgM_Jg=_Kfm_Kfm[KfM[KfLkHglkHglkGh=7Gh]?Gh]CGiMKGiMOHi/_Ak/oHk<O@fM3FeL_D
f:RmhbmK]00f]QA;]0A1]@A5a@4n_1I<`@e2/A5=_`U=a00mbP0od`50d@M8cAiTeSIjiBUXf`Y5``13
b013b013b013a`13aP13aP14a014a04cc@<fdP0jd`0gc@0ha00o`P1Bb`=Se@A2d0<nd0<kd0Djd@Pk
d@Pkc@Tkb@Tja0Xo^0Tn]`Pk]`Pi/`Dg[@DgY`DhX0@hW1M6OQdmIQDX?@hL:1PY=R0c@R0`=b<];@`T
<00C7a/g@QHd?aHi@aLnA`L`>@Xe?PXc@Q4iBa<nD@`kD@@eC`HjF1A:JB9HNAmLL2USMS9UMBeGI1ln
Aa0V:`LH6`HC5@8O90<S:00T:P0S;00T<04V=00Q<@0I;0dP=@0G:`0K;`h/?EEcQ6n<VgN@X6^2TH:K
Uh>DT8RAQhnAQI2?PHZ:OXB8OHB9P7inK7YjJ7AdHV][FEiNC4m??Clo;CDe8cLf8SLf8SLf8SLf8SHe
8CDd83@c7c<b7S@c7SDd7cDd7cHe83Lf8CPg8STh8cTh8cDd7cHe83He83He83Lf8CLf8CLf8CLf8CLe
7CHd73Dc6cHd73Pf7STg7cTg7cLe7CXf7CXc7cle8chj8S<f820Z91<P>PhKCa/X=S0a;D8i7T4h4cXe
53Lf6SXf6Che53Le5cHd5SDc5CDb5SHb6CDa63<_5c0/52h^438b53Xh6Sdk7Clk7T4k7T4k7T8l7d4i
6d4i6d4i6d4i6d4i6d4i6d4i6d4i6d4i740h6d0h6clg6Slg6T0h6d0h6d4i73/h6C/h6Chi6Slj6d8j
74Dk7DDk7DHl7T8j7D8j7D4i740h6d0h6d4i748j7D8j7Cdi7Cdi7C`h73/g6cXf6SXf6STe6CTe6C`e
6S`e6Sdf6chg73lh7D0i7T4j7d8k83hl7Sdk7Cdk7Cdk7Cdk7Chl7Slm7d0n84E6;3/l8S4a6B/[4bLV
4BDT42TX534_7Cdn:Te>>VMXE7inK8f=OHn?OhZ9NhF4MW5cH6maGV]]FVU[F6U[F6QZEfIXEFAVDg1c
GFMYEFIXE6IXE6U[Ef5SCfEWDfU[EgAcGWAcGWMfHGUhHgQgHWMfHGakIX>2KGmkHh1lI89nIXB0J8N3
JhV5KH^7Khb8L8Z4LHJ0KHAnJhJ0KHZ4LH^5LXJ0KH5kJ8B2JXB2JXR5L8n<Mi6=NXj:N8j:N96=Ngij
Ih9nJh=oK85mJX1lJH5mJWmkJ7]gI7EdGgejIH^5LWaeHDm8;d<i6dHm6:fUOM_?[MW>[][?[mW?/MW?
/MG=/=?:[lo8[MG;[MG;[MG;[MG;[MG;[MG;[MG;[MG;[MG:[mG:[mG:[mG:[mG:[mG:[mG:[mG:[mG:
[mG:[mG:[mG:[mG:[mG:[mG:[mG:[mC9[]C9[]G:[mK;/=K;/=G:[mC9[]C9[];9[];9[];9[];9[];9
[];9[];9[];9[]78[M78[M78[M78[M;9[];9[P00c/K6c/K6c/K6c/K6c/K6c/K6c/K6c/K6c<O6c<O6
cLS7cLS7cLS7c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8
c/W8c/W8cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7c/W8c/W8
c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/S9c/S9c/S9c/S9c/S9c/S9
c/S9c/S9c/S9c/S9c/S9c/S9c/S9c/S9c/S9c/S9b/S7b/S7b/S7b/S7b/S7b/S7b/S7b/S7b/S8b/S8
b/S8b/S8b/S8b/S8b/S8b/S8cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7
cLS7cLS7cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5c<O4c<O4
cLS5cLS5cLS5c/W6c/W6c/W6cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5c<O4c<O4cLS5cLS5cLS5c/W6
c/W6c/W6cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5
cLS5cLS5cLS5cLS5cLS5cLS5c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<W1c<W1c<W1c<W1c<W1c<W1
c<W1c<W1cLRocLRocLRocl[1cl[1cLRob<>ja;nfMg1Q?3DV>C0RD4LiASX^Ac/_F4XnCT0dCT4aCT4a
CT4aCT4aCT4aCd8bCd8bCd8bC3l_CT4aD4<cDD@dDD@dD4<cCT4aC3l_Bch^CT4aDD@dDTDeD4<cCT4a
CD0`CD0`CD0`CT4aCT4aCd8bCd8bD4<cD4<cD4<cC4@cC4@cCT@cCD<bCT4aCd0`CSl_CCh^C40^C40^
Bcl]BSh/BSh/Bcl]C40^C40^ACdVCd@^A3TUH5I5IUeD:RDT4Q4J0`@B0@XD00LA2APQ52D^1QLP00TB
0@/E1@hH10hH0`dG0`dG0P`F0P`F0`dG0`dG10hH0@`D=3e1J6e/OGegP7eeRH=lSHV4S8N4S8]mS8Yo
RhUnRXQnRHMmQhAlQX=kQX9mPHEiPX=iPX=iQhEmRhR0SXR3ShJ3SHB1OGeaPX5gQ8=iPh5iQhEmShb7
Ti2<TXn;TYBDUiVIWZ2PYJNWZjf]/[Bd^K^k_/30]kbja<W8_/C3^<30`l[=_lK9^l?3cM;CcLgCb/[@
b/_?dM3De=3EdLgCdl_EeLgGcl_Ncl_Nd<cOd<cOd<cOd<cOd<cOcl_NeM;ReM;ReM;Re=7Qe=7Qe=7Q
dm3Pdm3Pd]GCdmKDe=KFeMOGe]SIemSLf=SNf=SNemGKf=KLemSLf=[KfM_LfM_KemcKemcJdm[Mdm[M
e=SMdmKNdmGMeMCNe=;Ne=;Nc=7Pcm?NdmCHh=gIfMSLa=GfEX;?34nl13j_03B`03o603Zo3TO22d6d
24Fk0dK303K603K=03C<03[52Dk75Uc>3dg903>j03_903_903c703c603g403c203g103g103S203c6
03g703[203Vk03jh1DVj2e2m2SVb2SJa2S>a33:`3S:^43:Z436V3bnP1cB;1c6:1bb61BN10b5h0Am^
01]U01]P01U9018d1a@T2A8O00hO014V0a@W0@lK018Q01@S010N01TW01d[0R@a01`Y1RTf4SQ443M5
2cM423M51cY:44IG7EQX:FEe6U]Z6EIT7E5N7DMD3R`g00dH004;0@H?00h@01DI01/P01hT02<[1bLd
2b@d21l_31`X11PS1R@_3cE1@6ehA7B0Bgb:Bgb:JHJ3EVaWCUU?EeY;FEM5BDXf>d4^>TDaA4H`?T0Z
=cTS<cDO=3HP=cTS>C/U>cdW=cHR>3LS>3LS>3LS=cHR=SDQ=3<O<S4M>3LR>3LR>3LR>3LR>CPS>CPS
>CPS>CPS=SDP=SDP=cHQ=cHQ>3LR>3LR>CPS>CPS>SPP>3HN=cDM=cDM>CLO>CLO=cDM=S@L>SHM>C8N
?38P?CLP<cHM8B`T5R8j41i?6bPf<C8^@STN@CPC>SDD=cHJ>SHI?C@C=C<E=38D<c4C=34E=C4H=30G
<BdE;RXB:R`><30B=SHH>cTK?3XL?CTL?cTL@3XM?cLI?cLI?cLI?cLI?cLI?cLI?cLI?cLI?SHI?SHI
?cLJ?cLJ?cLJ?cLJ?SHI?SHI>SLH>SLH?3LH?CPI?cLI@CLI@CLI@CLI@3PK?cLJ?SHI?SHI?SHI?SHI
?cLJ@3PK=C@H=C@H=3<G<c8F<S4E<C0D<C0D<2lC=c0E=c0E>34F>C8G>c@I?3DJ?CHK?SLL>SPJ>SPJ
>CLI>3HH>CLI>SPJ>cTK?3XL92L>8bH=9RT@<2lJ<c8M<C0K<2lK<S4M;RdC>STOCT`dHEm7KFYELFeJ
KVYGJfMDIFIBJ6UEK6eIKVmKKg1LLG9NM7EQMWMSKG1FJfiELG=MLW=OM7ARNGUYMGAVN7MYN7QVM7AR
MGESNg]YOG]YNGMUO7YXQ89`OGaXOGaXOgiZP7m[PX5]Ph9^Q8=_QHA`R8IdQhEcQXAbQhEcRHMeRHMe
R8IdQXAbU95lT8ehSHUfRhMdPgm]NgMUOWUZQX5bQh=`QX9_R8AaS8QeRhMdQh=`Pgm/Q81]SY1cRX]a
T8ehQGi[GUE1CdH[BClQYYehdlNUdLNUd/NWd/VXdlV[d/Z]dl^^dL^^e<Z/e<Z/e<Z/e<Z/e<Z/e<Z/
e<Z/e<Z/e<V^e<V^e<V^e<V^e<V^e<V^e<V^e<V^e<V^e<V^e<V^e<V^e<V^e<V^e<V^e<V^dlR]e<V^
eLZ_eLZ_eLZ_eLZ_e<V^dlR]dLR]dLR]dLR]dLR]dLR]dLR]dLR]dLR]d<N/d<N/dLR]dLR]d/V^d/V^
003>a/K>a/K>a/K>a/K>a/K>a/K>a/K>a/K<alK<alK<alK=b<O=b<O=b<O>bLS>bLS>bLS>bLS>bLS>
bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS=b<O=b<O=b<O=b<O=b<O=b<O=b<O=
b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>
bLS>bLS>bLS>bLS>bLS>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W>
b<W:b<O:b<O:b<O:b<O:b<O:b<O:b<O:b<O:b<S:b<S:b<S:b<S:b<S:b<S:b<S:b<S=b<O=b<O=b<O=
b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<G=b<G=b<G=b<G=b<G=b<G=b<G=
b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G<alC<alC<alC=b<G=b<G=b<G>bLK>bLK=b<G=b<G=b<G=
b<G=b<G=b<G=b<G=b<G<alC<alC<alC=b<G=b<G=b<G>bLK>bLK=b<G=b<G=b<G=b<G=b<G=b<G=b<G=
b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G<alC<alC<alC<
alC<alC<alC<alC<alC<bL7<bL7<bL7<bL7<bL7<bL7<bL7<bL7:aKc:aKc<akk>bL3>bL3:aKc4_kJo
^[50>BQ2>ba5?2i3>Ra7>bm@A3QA@cM4=Ba>@C5>@C5>@C5>@C5>@C5>@C5=@31=@31<?bm>@C5@@c=B
ACEBACE@@c=>@C5<?bm;?Ri>@C5BACECASIAA3A?@S9>@C5>@C5?@S9?@S9?@S9@@c=AA3AAA3ABACEB
ACE2>RU5?Ba:@2m>A3=AA3AB@c=@@C5>?bm@A39@A39?@c5>@S1>@S1?@c5@A39@A397@bY7@BY?Ac1?
ACA>@c/L51DG4Q/81A@32A@000T02A<85b003AH00P`01@l01Q433AL33AL231H12aD12aD231H33AL3
3AL010`Z<cMLHF1aL6ahMFf3OGJ7Pgj5P7f0Og60OW>1OgB1OgF2P7J2OgN2OgN3OgYdN6abM6Q^KfE`
KfEgLFYoMW:4NgN9OG^3P7:4PG>2Og5nNVmoNW62OGB0NW=jM6ebM7AfN7QjO7anP821Ph>4QXJ9Rh^<
SXjMX9j//JnX[ZfT[Zja_Kf^^[Z/^KO3c/c8e]c2d=K1cM72c];4cm?3cMC6c=O:d=g>dMG>dMG?d]K?
d]K?d]K>dMG=d=C=d=C:eL_;e/c;e/c;e/c<elg=f<k=f<k=f<kHe=WHe=[He=[HdmcHdMkHdN3Hd>7H
d>7He=WIeM[Ge][HemWFf=SEemODemGAe]CGf<oHf=;Kf=CLf=OOfM[RfMcSfMoVf^3Pg=OJeM;PeM7Y
fM;Ic]3<f?APSm<;DkP5@kl0@<X0A]T0?/l2?<<:@L00>;X0>;l4?kd6?/<7?<8;?k/CBkHMDkPJBkTB
?;L>>KP@>KP@>;H@=[8A=ZhA=J/A<jXA=:T2?9`4>i`7>9`9<YD?;i0E;hTH;H8E:gT0:Fd09F`086X0
7fT07fP27f@17Ed06eL04U404e804U804E8144h544T84T894Sh06dH02RD;524C72H02ah02B@15c04
5BX031/87bh011<06RP582h=:SP8:3DN?T/A=3h9;CL0:340:S82=Sd@AdhKEedQGfD>Ced5@dh7>dP@
=dD78S001AD000h<31`251D471`482407b@07bD172H152402a/03a803a<08bL6=S`ZIFhSIVl]Lh0i
OhaLNgXiD4/X<bTh>b]5A2lk?RDb>b4f@bTh>b8g>R4f>B0f>B0h>b8g>R4e>1lb=A`g=R8h=b<i>2@i
>2@g=R8e=20c<Qhb<Adi>2<h=b8h=b8h=b8g=R4f=B0f=B0f=B0f=B0f=B0f=B0g=R4h=b8h=b8i>2<i
>2<m>b<k>B4i=alh=Qhh=Qhh=Qhe<a/c<ATg=1Pe;QXi<1`m=b0f>B0R;BD@73@44T<L:CLa<Ri3>Qm1
>1<j=A@g=QXi=APm=1<c<A<b<18b<18c<1@d<1Lc;aH`;1@]:A4X:P`/;Q0d=1Hg=aTj>1Xk=aXk=aXn
>1/o=aTo=aTo=aTo=aTo=aTo=aTo=aTo=aTl=1Lm=APn=QTo=aXo=aXn=QTm=APl=1Lj=aPj=aPk=QLk
=QLl=1Hm<aDm<aDl<Q@m=APm=APl=1Lk<aHk<aHl=1Lm=APm=AP^<AL^<AL]<1H/;aD[;Q@Z;A<Y;18X
:a4c;1<c;1<d;A@f;aHg<1Li<QTj<aXj<aXh=QPg=ALf=1He<aDe<aDg=ALi=aTj>1Xn@BPb=A`W:Q4X
9a8];1Lg=R58AC1FDciWHdIYIDQ[Id]^JTiaK5=dKUMgLEYhLU]aLeeeMf5hNVAgNF=bM5i^L5Y^L5Y_
LE]cMeYcMUaiO6=eMV9`L61jN6edLVQlNG5iNFedM6QfMVZ0OW>1OgAnNVn0O768Q7V1PW:1PW:1PW:1
PW:1PW:1PW:2Pg>2Pg>0PVn2Q762Q761Pg1nP6enP6f1Pg25QgB9R7B3PVj3PVj9QgF;R7V6PgB4PG>7
Q7J6Q79nO6YmNfV4PW28QWB5Pg66Q7:;RGMlP5efN5YoOFF4OV]bJ5I/HD]NDcN_YXFi[H^i[hfm/i72
^IS8_Z3=aJOCbjkDc[7Dbj[Dbj[Dbj[Dbj[Dbj[Dbj[Dbj[Dbj[DbJkDbJkDbJkDbJkDbJkDbJkDbJkD
bJkDbJkDbJkDbJkDbJkDbJkDbJkDbJkDbJkCb:gDbJkEbZoEbZoEbZoEbZoDbJkCb:gAb:gAb:gAb:gA
b:gAb:gAb:gAb:gAb:g@ajc@ajcAb:gAb:gAb:gBbJh00<o8aLo8aLo8aLo8aLo8aLo8aLo8aLo8aLk8
`lk8`lk7a<o8aLo7am38bM38bM38bLg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8
alg8alg8alg8alc7a/c7a/c7a/g8alg8alk9b<k9b<k9b<g8alg8alg8alg8alg8alg8alg8alg8alg8
alg8alg8alg8alg8alg8alg8alg8alc7a/c7a/c7a/g8alg8alk9b<k9b<k9b<k9b<k9b<k9b<k9b<k9
b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k8
bLk8bLk8bLk8bLk8bLk8bLk8bLk8bLc7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<k7a<k7a<k7a<k7a<k7
a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<g8
aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLc7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<k7a<k7a<k7a<k7a<k7
a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k8
`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<o9`/o9`/o9`/o9`/o9
`/o9`/o9`/o9`/c;`LS7_M3>a<_9_/k;_Lo9_=WDaG5/GC0V54@j:4Y0;TPn;4e3<Da2<4Y0;U57=Di4
<Te3<De3<Da2<4a2<4i4<U16=598=Tlo>4e0>4e1=de1=d]2=Da3=Da5=4a5=4Pn;4To;DY0;Ta2<4i4
<U16=557=E98=U=7=E=7=EA8=UA8=U=7=E96=555<e14<UE7=EE7=EA6=5A6=5=5<e94<U53<E53<Di4
<Tm5<e57=E98=U=9=e98=U57=E16=4do>D]2=D]4<dY9=D=3<bl^:Q<@6@003@<35@444`444`064@09
4P0940073@0420<<6@8;608;604:5`095P095P085@0750L>5a4I84aBEgAiNVM/JVeaK823NWEhKgel
LWelLWimLgelLWakLGYiKgUhKWMfK6mfLC8i=20V8C4g<W=gLWIgLgYkMfm`K7ahIW]fIgMdIGAdI75d
IG5fIg=gJg=jKG5_Ig9`J7AbJWEcJgEcJgAbJW=aJG9`J71eM6ebLFicLW=iN7UoOX28QhjFUI^SX[Nm
_;Vn_Kc1`<?5aLS:b/o?cm?AdM?AdM3Bdlk?dlc=dLc<d/g<eLk=e/g<e/c;eM?EeM?Ee]?Ee]7Be/o?
eM7AemCCg=OFgmcMhMSIgMCEfM7Be]7Be];Cem;Cem;CelcCe/oDem;EfMOIf]_Jg=kKgMkIf]cGf=_L
f][KfM_Lf]cMfm[KfMKGeMKGeMSIelc<f=KFg=gJg=7Ce<kFhl_Mo9:]h3mOX1=3[0m0YP/mX@TlW0Tm
V`TnV0PnU@LnT`XnV0`nV0XjTPXiS`dkSa4mT0dhR@<^OaH[P14WN@dTM0XQK`TQK@LPJP8KH`0GG`XI
HPPGH0LFF`DEF0HEE0PFD@TGD@THD08E@P8E@P8E@P8E@P8E@P8E@P8E@P8E@P@D?P<C?@<D>`8C>P4C
>00C=P0B=@0A<P0E<@4C<00C;00A:00B900B8@4B7`4C7P0B7`8H900G8`0E8@LS;QPf@ATiA0d`>PPU
<`HS<@8T<@H[>@`eA10mB`hlC@TjBPXfC@0b@`Q4D00]=@`U;`4750003P003`0660<C80@J9@0I7`0F
70@F8@H?7@045`0340HN:P0P:RQIH`m4DA59FTElTDQlTd]mPcYHFCDk<3lj9D539Ce393Xo93hm:3Hl
8c<i83<g7S@g7SHi83Xj8S/k8c`j8S@e8C@e8CDf8SDf8SDf8S@e8C<d83<d83He83Lf8CPg8SPg8SPg
8SPg8SLf8CHe838a73<b7CDd7cHe83Lf8CLf8CHe83Dd7cDd7cDd7cDd7cDd7cDd7c@c7S8a738a73P_
8C/c73`g63Th5Rle7Qh/:PdR>08L@BDS>BT[:c4f6cLj4c`h5CXc63La53<`4C@e5C<d538c4c4a4bl^
4Rh]4Bd/4R`[4C4`5SDa63Ld63Pd63Xd5c/f5d0h6T8j73le5chd5Shd5Sdc5Cdc5C`b53`b53`b53hg
5Shg5Slg6D0h6T0h6c`c63L^4c8X42dY33Da53`f6Cde63`d5d0e6Cld63``53@a4SDb4cLd5CPe5SPe
5SHc53@a4S<`4Cdd6CD[4bhX4BlY5R<P4A8B110A1aTM4RdZ5BdZ5Bh[5S4^6C@a73Db7C@a734^6CDd
63Dd63@c5c8a5Bl^4Rh]4C0_4c<b5S<c6c/k8dQ8<5EE?EiNAVATC6YZDVe]EFm_Efi^EVi^EVi^EVi^
EVm_Eg1`F75aFG9`GW9`GW=aGgEcHGIdHWMeHgUgIGUgIGUgIGUgIGYhIW]iIgajJ7ajJ7ekJGekJGek
JGilJWmmJh1nK8:0KX>1KhB2L8F3LH>1KhB2L8B2L8B2L8F3LHF3LHF3LHF3LHJ8MHF7M8J6M8J6M8R6
M8^7MHb8MXf9Mhf;NHf;NHb:N8^9MhV7MHR6M8N5LhN5Lhf6Lhf6Lhf6Lhj7M8n8MI6:Mi:;N9><NHR8
L8J4K8B0Ig]fGGmhGE=;;T@i7K6URM;7Zm;7Zm?8[=?8[=C9[MC9[MC9[MC9[M?8[=?8[=?8[=?8[=?8
[=?8[=?8[=?8[=;7Zm;7Zm?8[=?8[=C9[MC9[MC9[MC9[M?8[=?8[=?8[=?8[=?8[=?8[=?8[=?8[=?8
[=?8[=?8[=?8[=?8[=?8[=?8[=?8[=;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7
Zm;7Z`00clS5clS5clS5clS5clS5clS5clS5clS5c/S3c/S3c/O4clS5clO7d<S9d<S9d<S9cLS7cLS7
cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7c<O6c<O6c<O6cLS7cLS7c/W8
c/W8c/W8cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7c<O6c<O6
c<O6cLS7cLS7c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8
c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/S9c/S9c/S9c/S9c/S9c/S9c/S9c/S9c<O4c<O4
c<O4c<O4c<O4c<O4c<O4c<O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4
c/O4c/O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5c<O4c<O4
c<O4c<O4c<O4c<O4c<O4c<O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4
c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/S1c/S1c/S1c/S1c/S1c/S1c/S1c/S1c/O4c/O4
c/O4c/O4c/O4c/O4c/O4c/O4clW2clW2clW2clW2clW2clW2clW2clW2c<_1bLRnc/c2bLNlbLJhc<Ji
]K2QGeY;D4HeG591FDlnDDLfE4XiDTPgC48aCdDdE4XiE4XiE4XiED/jED/jE4XiD4HeCD<bEdTmEdTm
ETTkDTLiD4DgCD8dBT0_BCl^DDLeDDLeD4HdD4HdD4HdD4HdD4HdCdDcE4PfE4PfEDTgEDTgEDTgE4Pf
DdLeDTHdF4XhF4XhF4XhEdTgETPfEDLeEDLeE4HdDdLeDdLeE4PfE4PfDdLeDdLeDTHdDDDcD44hCd8d
C4DaCDPcAD<a=34Y71HK204>1`PF0`@B004<000;00<>00HA00TC00TC00TG00TG00TG00TG00TG0@XH
0P/I0``J00<<0PXA=ce2HfQ[HFIUJViYN7YdJF]UKFmYKg5[LWA^LgE_LG=]KW1ZJF]UIVQR@4]96R8Q
4a/J8RPWEEYIFEiMIVQXHVATKVaTK6eTJf]UIfUSHfMQGfIOG6=NFf9MI6QSHVIQH6AOGF5LFUiIFEeH
FEeHFEeHEEYKCE9CBTm@DEIGEUiNDe]KCEEEBE5AJg1^PhR6UiZHVYfKXZ>Q/Jn^][Bc/Jn^alO7bLS:
bl[<c/gAdM3DeM?If=GNf]OPb/k?c=3Ac];Cc]7EcM3Ec<oDcLoGcm7I`/G9al[>cm;Fem[NfmkRf]gQ
eMSLdMCHfn7Vf=kSe]_Ne=OKe=GIemKJfMSJg=WKem_Ld]KGc];Ccm?DdmOHe][Kf=cMfMgNe][UfmkS
gMgMcm7A_lO>[;cCKhR`8d1c01UV01QT01MR01]T029W02M/02Y]0B]^12]`12]_0bUZ0bIX1RUY2R]Z
1RER01aI0AYJ01ME01AB01A@01I?01E=01=9011601A=019;019601540150018o0A8m0Q@m0a@o0a@o
0a@o0a@o0a@o0a@o0a@o0a@o11Dl11Dl0aDj0Q@i0QDh0A@e01<d01<d0aDb0QD`01@]01<X0A8U01<R
0Q<P0Q@O010M0QDR0ALS01HR1B4/4Blj3Rhi0B@^0QhY01d[024^1RTg2C9133M61cE60S=32cM>0311
145;02hf2b@^004@0@4C10PK21HX0aHS01TS01`Q0A/Q1ATT114O008E20PH2QDS00lK94iJ4TQC3daJ
<g61<6j0DX65AEmO?T8g?c`W?T0S=ShP=SXQ>cXU=C/T<cTR<SDO<SDO=CLQ>STT>STT>STT=CHR=CHR
=SLS=SLS=CHR=3DQ<c@P<S<O=CDM=CDM=SHN=cLO=cLO=SHN=CDM=CDM=CDM=CDM=CDM=CDM=SHN=cLO
=cLO>3PP=CDM=CDM=CDM=CDM=3@L<S8J<C4I<30H>38O>C@K>cTG>STG;c@O82`/4B8l1Qa5824f9RPX
;S<H=3L@=cDC=c0E<RhB<Bh?<34A;c0@;Rh@;Bd?;2/?:RT?:BP>:BL?:2H>;2/A=30G=c@H>3@G>C<F
>3<D>C@E>S8D>S8D>S8D>S8D>S8D>S8D>S8D>S8D=S4B=C0A=S0C=c4D=c0E=2dD;RL>:R<::BH:<RhB
=S8F=c0E>2lD>S4F>c0E>2dB<Bh?<Bh?<Rl@<Rl@<c0A=34B=C8C=S<D=BdF;2H?:RD@9bDC71/=2@/0
1@T03148<2dH;b`G;R/F;2TD:bPC:bPC;2TD;2TD92<7:BP<<2lC=cHJ?chRAdHZCdhbE5<gFEQ3GUe8
I6=>J6MBJFQCJVUDJVUDJfYELg9MLW5LLG1KLG1KL6mJLG1KLG1KLW5LM79PM79PMG=QMgESN7ITNGMU
NWQVNgUWO7YXO7YXOG]YOWaZOge[Oge[P7i/P7i/OWaZOge[P7i/PGm]PX1^Q89`QH=aQH=aQ89`Q89`
QH=aQH=aQH=aQXAbQXAbQXAbQXQeQXQeQhMeQXIdRHMeS8QfSHUgSXYhSH]iSH]iS8YhS8YhRhUgRXQf
RHMeRHMeT8YgShUfShUfSXQeShUfShUfT8YgTH]hShmgPX1XQ81WPGaSLFY?>c<F>c0D[:24d/N[d/N[
dlR/dlR/dlR/e<V]e<V]e<V]dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/d/N[d/N[dlR/dlR/dlR/e<V]
e<V]e<V]dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/d/N[d/N[
d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[003?b<G?b<G?b<G?b<G?b<G?b<G?b<G?
b<G>b<?>b<?>alC?b<G?alO@b<W@b<W@b<W=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=
b<O=b<O=b<O=b<O=b<O<alK<alK<alK=b<O=b<O>bLS>bLS>bLS=b<O=b<O=b<O=b<O=b<O=b<O=b<O=
b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O<alK<alK<alK=b<O=b<O>bLS>bLS>bLS>bLS>bLS>bLS>
bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>
bLS>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W<alC<alC<alC<alC<alC<alC<alC<alC>alC>alC>alC>
alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC<alC<alC<alC<alC<alC<alC<alC<
alC=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G<alC<alC<alC<alC<alC<alC<alC<alC>alC>alC>alC>
alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>
alC>b<7>b<7>b<7>b<7>b<7>b<7>b<7>b<7>alC>alC>alC>alC>alC>alC>alC>alC?bL;?bL;?bL;?
bL;?bL;?bL;?bL;?bL;:bKo9b;k<b/3:b;g9a[S<a[V;QWMBCCiSFTaYH59QF4YKDTARFD]RFD]ID49H
Cd5;@SA9@398?c5;@SA?ASQAB3Y?ASQ<@cE8?BU;@2a?@c5DB3IHBc]IC3aIC3iIC3iFC3YEBcUEBcUD
BSQDBSQCBCMBB3IBB3IEBCMFBSQGBcUHC3YHC3YHC3YGBcUFBSQKCC]JC3YJC3YIBcUHBSQHBSQGBCMG
BCMOCciNCSeMCCaLC3]KBcYKBcYKBcYKBcYJBCaGBCMEBSAECSEABSI5?38b:2PR61h410X30`T210`3
1@l51Q@31QD00Q@001401QL01AH011D00a@00a@01AH01QL121T731D62a@^<CUDFEaKGf1SJ6MZKF]H
G5MJGUmKGf1KGf1IGEiBEUM9CDho@d@i?ChD7b<64AD74QH94QHQ9b`Q9b`_<cP_<cPe>Chf>Slf>Slc
>Ch_>3`Z<cLT;c<Q;30K8RDM92LN9BPO9RTM92LH7b8D6ahA61/L92@C6a/=5AD@61PB6QXA6ATA6ATB
6QXk?cYSIf:1PWioP7b1P7bASXZETXj;R8BNWIVTXZ6[ZJRa[jne/[Bk^;[2_/?8a<W3b<W7c<g<dM;>
dmK>d]O=dMK=d=S=d=SDf=gCemcAeM[@e=W>d]O>d]O=dMK=dMK2blo6cm?=dmS?eM[Be]_Ae=WAe=WA
e=WCf=_?e=O:cm;;d=?@eMSBem[?e=O:cm:laLje_;n//JnKWiUnQXESKg/a@U`03C053CD12c<02c<0
3CL04Sd05d416TH06dL47DL67TP47DD46d477T@;8DD674004cP04c/04SX04SL04cL05CT05SP05CL0
5C@063d05S`05SX05CP05S@05S815S415c025C/25C/25C/25C/25C/25C/25C/25C/45S/45cX35ST2
5CH25CH15C@05C405C435c025Rl252/04bP14b@34b<3524452403a`152405R805R847RX99c828Rd0
5B005b8062<072T29C86;C/6<D02;cd0;3X;=T/0;Cd0>dD2<CT?:38000l<3B4J7c@G:c`36bL05R00
7B806b015b804Ah00A<E3Ah?4R404b8jHFliKGTcKWPoNhLlMX9<MWE4FeM0@CLn>RLh>b4_>1da=b0k
>RHa>B8`=Ql]<a`_<Q`c=Ale=b4g=R4g=R4d=R8d=R8d=R8c=B4b=20a<al_<Ad^<1`a=1Xb=A/c=Q`c
=Q`c=Q`c=Q`b=A/a=1Xc=Q`c=Q`b=A/b=A/b=A/c=Q`d=ade>1hc=Q`c=Q`b=A/b=A/`<aT^<AL/;aD[
;Q@^;QH`;a<c<Q0a<Q8Y;AXL9BP=73H45SlO8C<S:2HZ<1Lb<a4d<1<c;AHa;1<_;@h];@l];@l/:`l[
:PhZ:@lY9`lX9PhW90lQ80/W9`lb<1Pg=Q`i=QXh=1Pe<A@d<1<g<1Dg<1Dh<AHh<AHh<AHh<AHi<QLi
<QLd<1<c;a<d<1@d;aHe<1Lb;1D]9Q8Y8PhY:0ha<1Hg<aXe<APe<1Li<QTh<APe;QDa;Q8_;10]:Ph[
:0`Z9`/[:0`/:@d/:@d/:1DU910S8a4S8aDI6`l93@852P4:4@XT8@`V8`hW90lU8PdT8@`V8`h/:A@a
;QTk>R11@2I9B2iAD3IIF3iPGdEWITa/Je5WIU5ZJEA^KEQ`KeY`KeY`KeYbLEadLeigMV5fMF1eM5md
LeidLeidLeieM5meM5mhMVAhMVAiMfEjN6IkNFMmNfUmNfUnO6Z0OVb0OVb1Off1Off2P6j3PFn3PFn4
PW20OVb0OVb1Off2P6j3PFn4PW25Pg66Q7:5Pg66Q7:6Q7:6Q7:7QG>7QG>7QG>8QWB8RWN7RGJ8R7J7
QgF:R7J=RGN>RWR?RgV=RgV=RgV=RgV=RgV=RgV=RgV=RgV=RgVDSW^CSGZARgR@RWN?RGJ>R7F>R7F>
R7F8R71oOFF7PfZ6PFQjLeQSFci`IDVgZhoBaj_Baj_Baj_Cb:cCb:cCb:cDbJgDbJgCb:cCb:cCb:cC
b:cCb:cCb:cCb:cCb:cBaj_Baj_Baj_Cb:cCb:cCb:cDbJgDbJgCb:cCb:cCb:cCb:cCb:cCb:cCb:cC
b:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cBaj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_B
aj_Baj_Baj/00<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k8`lk8`lk7a<o8aLo7am38bM38bM38bLg8
alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alc7a/c7a/c7a/g8alg8
alk9b<k9b<k9b<g8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alc7
a/c7a/c7a/g8alg8alk9b<k9b<k9b<g8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8
alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alc7
a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7
a<k7a<k7a<k7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7
a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7
a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk7
a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`LO6_<W8_/[8_/k<`Lg:
_<_5^6eXFE=>?fALCfiVFFaTEg1XFh5iK8AlKgUaI7A/Gg5YG6QPDeiFBEUAA5UAA5UAA5M?@UA<?e]C
?5eE?V1E@F5F@UmC@Ei??e];?UU9?5E;>EE;>EI<>UM=>eM=>eQ>?5Q>?5U??EQ<>UU=>eY>?5]??Ea@
?Ua@?U]??E]??Ee??Ea>?5a>?5]=>eY<>UY<>UU;>EU;>F9B@F5A@5m??Ui>?Ei>?Em??V1@?f5A@5m=
?5]==e]==U]?=eY?>E=8>TLl=3ha;a/I61<C4`X92`812P002P003P004P004`D76@<55`435@014`00
4P004P0250435@012`001`hA6BLZ<R/^<bha=Bhb<b4U9R0V;B0V;AlU;1/Q:1@J8@`B6@@:4@053008
400<50<>5P043@03300330894P@94P486@496P8;6@8;6@4:60095P0850064PLA60H@5`@>5@<=508<
4`8<4`8<4`<=50<;2`@<30TA4@dE5@hC510E5QdQ8R/_<34d:dmBBFUZHFUZHFUWGg1]IG=`J71ZHfaZ
HWAbJWikMX9oNXB1OHR4Pi2<RiNCTYnVXjF[ZZfc/[Fj^k_0`l76bLK:cl[>dlO<clO<clO<clK;c/O<
cl[?d/oDem;Gf]7Hfm7Hfm7HfloEf/kDfLgCf]3Cfm;EgMGNh]GNh]7Jg/[Cel?<d;W2aZVb]YbUZH:>
TW5lNVI^IeQPEDA<@S@l>b0[<`DB8Pl<6``;6`P:70H;80HA9`PE;`HG<PDG=0@H<@HJ<`HJ<`@H<@PJ
<@`N=@PJ<@4C:P0D<00D<00D;`4F<@8G<P<H<`@I=0@I=08I>@8J>04I=`8H=0<H<`<I<PDJ<0DJ<04D
=`4D=`4D=`4D=`4D=`4D=`4D=`4D=`@E=P<D=@<E=08D<@8D<@4D;`4D;`4E;P<E;08E:P0C:04B9@8B
8`8B8P<C80<C800@7@8C800C800D804K9`HR;@0M:00B7@0G8@0H8`0K9P0Q;P<Y=@<]>P4^?00/>PPb
A@0/>@0e?PHe?A8/>0024aXN<C4gCQdgA`0L9`0G800L8@0D6@0D7P<I9@0=7P085@0?700M:TA^Ndai
QSiXM3QMICUIGc=GDCE7@3Xj;S/g93@g8B`f7c<h8cdk:Bdd7b/b7BX_6RX_6Rh`734b7S8c7c8c7c8d
8C8d8C8d8C4c830b7bh`7B`^6b/]6S4d6S8e6c<f73<f73<f73<f738e6c4d6Rlb630c6C4d6S8e6c8e
6c4d6S0c6C0c6C8e6c8e6c4d6S0c6Bha5b`_5BX]4bT/4RP]4R/]3bh_3bd]3bPY6A/Q9PhI=0HF>a`Q
<24X8bT_5Rha4C8^5C8[5bl[4bh/3RX/3bX[4BTZ42PX42LW3bHU42HU4BDT41lP32DV4Rd_6C@d73Le
7CHe6cHb6CDb5SDa6C@`63@`63@`63<_5c<_5c8^5S8^5Rl^52h]4bh/52l/5bl/5bdY5RTU4RDQ3b<U
3bX/5Rl^6Bd/5bh[5S8]634/5blX52PX42LW3bHV3RDU3B@T32@T32DU3BDU3BLW5b8S4b0P4Q`O414E
2@D;008:00TA1a/H0b<P2b/X4c0]63<`6cTf8DA1;4a9=5aM@f1QAfEVC6QYCfUZD6Y[DF]/DVe^E6QW
DfYYEFe/F6m^FW1_Fg9aGGIeHGUhI7IeHGIeHGIeHGIeHGMfHWQgHgYiIGYiIGajJ7ekJGekJGilJWmm
Jh1nK85oKH5oKH:0KX:0KX:0KX>1KhB2L8F3LHF3LHJ4LX:0KX:0KX>1KhB2L8F3LHF3LHJ4LXJ4LXN5
LhN5LhR6M8R6M8R6M8V7MHV7MHV7MHV;N8R:MhV9MhV9Mh^9Mhj:N8n;NI2<NXf;NHf;NHj<NXj<NXn=
Nhn=Ni2>O92>O9B@OY:>O92<NXj:N8b8MXZ6M8Z6M8Z6M8>3JhV7Khn;LXN2JHn8KK2XRl>hW<BhW=76
Z]76Z];7Zm;7Zm?8[=?8[=?8[=?8[=;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm76Z]76Z];7Zm;7Zm?8
[=?8[=?8[=?8[=;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm76
Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76ZP00c/O4c/O4c/O4c/O4c/O4c/O4
c/O4c/O4c/S3c/S3c/O4clS5clO7d<S9d<S9d<S9cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7
cLS7cLS7cLS7cLS7cLS7cLS7c<O6c<O6c<O6cLS7cLS7c/W8c/W8c/W8cLS7cLS7cLS7cLS7cLS7cLS7
cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7c<O6c<O6c<O6cLS7cLS7c/W8c/W8c/W8cLS7cLS7
cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7
cLS7cLS7cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c/O4c/O4
c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c<O4c<O4c<O4c<O4c<O4c<O4
c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c/O4c/O4
c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4
c/O4c/O4c/S1c/S1c/S1c/S1c/S1c/S1c/S1c/S1c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/S1c/S1
c/S1c/S1c/S1c/S1c/S1c/S1bLRnb/Vob/Rnd<k3c<Vk^[BWGEQ9FEA5IV9GMW9WOWY_RHEjW9R=WYZ?
T8b1RHEjTHf2RHEjOWY_MG5VK6QMHemDFEE:Ddm4Ee8mEU0mEe0mETllET`kETTiETLgEDDhEddkF4hl
F4hlFDlmFDlmFU0nFe4oFe4oG50nG50nGU90Ge=1Ge=1H5A2Ge=1Ge=1HUA2HE=1HE=1H590Ge4oGU0n
GU0nGU0nH50oGdlnGThmGDdlGThmGdlnHE50He=2Fd`iFT`fFD/eFTdgG4hkFD`lEDLkDD8iBTPn>3D]
7AXF1@840P0600081@0@2PDJ10@D0`<C0@4A000@000@0@4A0P8B0`<C0008000700081@H@0@@<008:
00@90087000:000:000;004<004<008=00<>00<>000:00PD00PE00@A000;00DB00HC0PDC00<G00<E
004D008C00<A00@A00HC00PB00<7008600<700H:0P/?214E3aPL4a`P8R/X8BPU8bXW:Rl];S4_;c0^
<c4`=cDd;BlS=3@X?ShbB4HkCDTnC4PmDde2FUA9BdXlDU53FUQ=G5Y@FUQ>FUM?GeaDIF5LFf9KH6MP
J6mXLGMbNh1nQX^9TIJEV9fLYZ^Z[kBc^l2o`<G4_L;1];VhZk2_YJZYZk:_XJNVTiVHRHj?Qhb?S9:G
UI^RVj6XQ8f@QXnBOhR;KgQkGfQ[DEYM@4U<<S/n9C0^5R0J4adA5A`=31<631483Q<A20d@0`040003
000700<>00XH0Q0S0a@Y0Q@[010U01@Y01HZ01@Z01H/0aX`0AP^01<Y010[014/0A8]0A4^0A4^0A4^
0Q8_0a<`014d01<c018c018c018a0Q4a0A0`0A4^01@`01@`01@`01@`01@`01@`01@`01@`0Q8_0Q<^
0Q<^0A8/0A8/0A<Z0A@Y01<X01@V0A8U014R010Q010P00lO0a0P0a0N0a<P0A4N010M01<O0QXV1b4]
0alZ01PS11dW0A`V01`U01lY02@`0B/g130m1S=01bm102lk034j1SDm4R`h000@82Dj=CaE5S=201PS
01PR0A/Q00dC11dW8SY68SU93C@l3Sa4449>B7Z6B79n=e5H:Bld>3<e7cd`:CL[=3<U>CDS<SLR:cHR
<CLT>CTY:c@O:34L9bhI:BhI;34L<38N<38N<C8N;c8R;c8R;c8R;S4Q;C0P:bhN:B`L:2/K;c<J;c<J
<3@K<3@K<3@K<3@K;c<J;c<J:RhE;C4H<CDL<cLN<cLN<3@K;30G:RhE;S8I;S8I;C4H;30G:RhE:2`C
9RXA92P?9c0F:c0E;S0C;RlE:RXL82DX5Qlc3Q/k61hY72<N8BTB9RX=:RLB:b@C:RD@:2P:8bH=8bH=
8RD<8R@>8B8>824=820>820>6Ad:7R0=8bDA9bPD:2XD:b/C;R`D<2hF:bXF:bXF:RTE:2LC9bHB9B@@
92<?92<?7b4;7Ah:7Ah:7Ad;7Qh<7Ad=6AP:5QD75AT66al<828?7Al<71`:81h<8Al=7Q`:6Q/76a`8
71d97Ql;7b0<7b0<7b0<7b0<6A`<5aX:5AP941D62a0120`031<651/><2dH>cPSB4D`D4dhE54lFEI1
HEi9J6E@H6=:HfI=IfYAJVeDJVeDJVeDJfiEK6mFM7=OM7=OM7=OLW5ML6mKL6mKLW5MM7=OMGAPMGAP
MWEQMgIRNGQTO7]WOWeYP7m[P7i/PGm]PGm]PX1^PX1^Ph5_Q89`Q89`PX1^PX1^Ph5_Q89`Q89`QH=a
QXAbQXAbQ89`Q89`Q89`QH=aQXAbQXAbQhEcQhEcRHMeRHMeRXQfRXQfRXQfRhUgRhUgRhUgRXaiRXai
RXYhRXYhSH]iT8ajTHekTHekSXajSXajSXajShekT8ilTHmmTHmmTHmmTXenTHamShYkSHQiRhIgRXEf
RXEfRXEfSHeeTi5iSh]bQ7mVSHI[^k>Ffm2dbknSdLJZdLJZdLJZd/N[d/N[d/N[dlR/dlR/d/N[d/N[
d/N[d/N[d/N[d/N[d/N[d/N[dLJZdLJZdLJZd/N[d/N[d/N[dlR/dlR/d/N[d/N[d/N[d/N[d/N[d/N[
d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[dLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZ
dLJZdLJZdLJZdLJZ003=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?>b<?>b<?>alC?b<G?alO@b<W@b<W@
b<W=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O<alK<alK<alK=
b<O=b<O>bLS>bLS>bLS=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=
b<O<alK<alK<alK=b<O=b<O>bLS>bLS>bLS<alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<
alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<alC<alC<alC<alC<alC<alC<alC<
alC<alC<alC<alC<alC<alC<alC<alC<alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>
alC>alC>alC>alC>alC<alC<alC<alC<alC<alC<alC<alC<alC;a/?;a/?;a/?;a/?;a/?;a/?;a/?;
a/?<alC<alC<alC<alC<alC<alC<alC<alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>
alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>b<7>b<7>b<7>b<7>b<7>b<7>b<7>
b<7>alC>alC>alC>alC>alC>alC>alC>alC=al3=al3=al3=al3=al3=al3=al3=al3<bl7:bKo9akg@
c/?5`[BJU8MLEdQRGDibKfN6Pg^@SHFFTh^QWYJMVY:@SHF=RX:6Pg^:Qgn?S8BASXJ=RX:5PWYkN71e
LVYQHEENGU9JF4eIDdIHDD9HD3mKDD1NDD5NE49NE49MDd5LDT1LDT1KDCmKDCmJD3iPE49QED=RETAS
EdESEdESEdERETAQED=WFDMWFDMVF4IVF4IUEdETETASED=SED=PE49PE49PE49PE49PE49QED=RETAR
ETAND3eMCcaICSYJCSaLCcmMD41LCd5JC41HDdA<BC/l=bhZ9R4M5aPC3A8910d500X000L000L000P0
00P000T000X000X000X91a<71A451A451A400Pd000T00@`52A@11A011A011A021Q4421<72aH:3QT<
41/000/01Q<00@h11a@000/62AL311861aD01A@011<00a000Pd01@`420d730l93Q4?51<S:2M1ATEN
Hf9^Lg9_M7=XKFaQIVE]LVU>DdXa=2/[;2<e<RXk=Bhi<BXc:b@l?2``<20];Adh=BHl=bPf<B8k=2E6
?c0f=28k>BLo?B]0?Bhm>R`l>B/m>Bho>c0g>R/h>b`i>blj?30k?38o@3M4ACa9BT59BD=?CdUEEDmF
EU1@D4Y:BTA6AT15ACl_<RT^<BPc=Bln@Se?E5=OHfAUJVeVJfiPIVESJFQMHf9CFEQ>E5=>E5=6C4/j
@3lH7QT>5P`D6`hG7Pl@5@H>4PL?4@/92PP<3Ph730/42@`020l02a<03AT03Ad03Ad03B804RL05RX0
5B/05bl16c<06C<05Bl13RP33b/442`33R`132X02b/23Bd33Bl03Rl03c003c01434143423S013Bl3
3Bl04b`04b`04b`04b`04b`04b`04b`04b`042X042X04BP04RL04RL04bD04bD04b@04R404R404200
3al03Qh13Qh23al23al54R0041d03a`152477BT98bl78bh37bX78BP482L07BH07RL08R`1:CD7<Cd:
=T<7;Sd4=400<3L3<cT?:CD000hP9SdZ<dh;:3L04Qd06B<56b403QDT>4=KLGePMhM5O7m0NX0`KGM;
QI59Lgm0E5T_:R]7=2lL=28X<R8f<B8g<R<^=2<X=28Z<R4a<28Y<QhW<1`T;ATV;1TZ;Q//<1d_<Ah_
<AhZ<1lZ<1lZ<1lZ<1lY;ahW;A`V;1/U:aXX:QLY:aPZ;1TZ;1TZ;1TZ;1TY:aPX:QLW:AHZ;1T^<1d`
<Ql`<Ql];a`X:QLU9a@W:AHW:AHV:1DV:1DT9Q<R914P8PlO8@hM:1@Q:1<U:0lW9Q4T8aDM7alD72T=
6bh>61lA71@H80TM80LP70XP6PdP70TN808K7@LK7@LK70PJ6`LJ6PPI6@TI6@TI6@T>50<@5PDD5`LE
6@HG6@DJ6`LN80XT8`hM7PhM7PhL7@dJ6`/H6@TG60PF5`LE5PHC5`@B5P<A50@A50DB5@HA4`L?4@D<
3@<;4P<A60TE6P/B5`PB5@HF5PPG5`TE50HF5`LE5PHC50@A4P8?400>3`0<3@0<3@0?4@0C5@8H6PLN
80dU9a@_<Ahj?R]5BCIACSUIET5RGdYXIE1YIU5YIU5[J5=/JEATIdiWJU5YK5=ZKEAZKEAZKEA[KUE]
L5MbL5icLEmdLV1bL5iaKee`KUabL5ieLf5gMF=gMF=hMVAjN6IlNVQoOF^1Off3PFn3PFn4PW24PW24
PW25Pg65Pg65Pg66Q7:2P6j3PFn3PFn4PW25Pg66Q7:6Q7:6Q7:6Q7:6Q7:6Q7:7QG>7QG>7QG>8QWB8
QWB;RGN;RGN;RGN<RWR<RWR=RgV=RgV=RgV<SW^;SGZ<S7Z<S7Z>S7ZASG^BSWbCSgf>S7Z>S7Z?SG^?
SG^@SWbASgfASgfASgf>Rgb=RW^<RGZ;R7V;R7V;R7V<RGZ<RGZ=SGF;RG61OFB5P6N2Nf2CRfk6^ioI
cK7@aJWAaZ[AaZ[AaZ[Baj_Baj_Baj_Baj_AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[@aJWAaZ[AaZ[A
aZ[Baj_Baj_Baj_Baj_AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[A
aZ[@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJT00<g6`lg6`lg6`lg6`lg6
`lg6`lg6`lg6`lk8`lk8`lk7a<o8aLo7am38bM38bM38bLg8alg8alg8alg8alg8alg8alg8alg8alg8
alg8alg8alg8alg8alg8alg8alg8alc7a/c7a/c7a/g8alg8alk9b<k9b<k9b<g8alg8alg8alg8alg8
alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alc7a/c7a/c7a/g8alg8alk9b<k9b<k9b<c7
a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7
a/c7a/c7a/c7a/c8`lc8`lc8`lc8`lc8`lc8`lc8`lc8`lc7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<k7
a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<c7a<c7a<c7a<c7a<c7
a<c7a<c7a<c7a<_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`lc7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<k7
a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7
a<k7a<k7a<k7a<k8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<g7
`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<_:`<O6_<O5^lk<`L2m[gegJVaWF7A_H89oNYNDSijKUYVFTIZG
TYBAS8n<QiFBSIBAS9^HTj6NVJ:OVY^HTiBAS8n<Qhj;QX66QG]mOFm`K6ESFeaJCeaGB5eGA5mHA65G
AF1FA61FA61FA61FA61FA5mE@emE@fAHAVEIAfEIAfIJB6EIAfEIAfAHAV=GAFMIAfMIAfIHAVIHAVEG
AFAFA6AFA6=E@eeGA5eGA5eGA5eGA5aF@eYD@EUC@5QB?eUB?eM??UM<?UE:?5E9?EA8?5I8?5E8>TM1
;TU2<DY5=TY4>D0k<RhZ9A/F4`h920D62PH72`L830L830H72`<420011@000`@030D13@002@002`01
3`002P002P885@433P023@0130002`002`002P002@002@0540<74P0020L9500020D54@002@P64P85
3@<730H93@/=3Q0A3aHE4ATJ4AdK4b8Q5c/j<5mNE81oMHn>Q8^:P7akLG1_IGj1LF1QDD10<3Lb8cdf
9dDj;4Pk;DXj;DA2<3dk:CPf93Te8c/d8cTb8CXb8Cde93Db7CPe83/h8chj9clk:Chj:3dh:Cdh:D=2
;D=2;D91;Cln:S/i9cPe9SPe9STf9cHc9CLd9SHc9C@a8cDb93hk;Da9>eMDATE2<dU8>UaJCgelLZ2P
V[Jg/kVk^kFg]j2VXJ:XXj2VXJ2VXJZ`Zk6g/Z:XXh^AS5AEBdmAAE5FAdiCA496>Sm3>3lo>C<b;RL[
9B8V81XP6a@I5`lE50XB4PD>4@8;3P0<6@8B8PHF9P@F9`<G:@HK<0DL<P8I;`4A8P<B9@DD9`@B:04?
9P0=9`8>:PDA;@0B:00C:@4C:P@D:`@D:`HC;@@A:`D@:`0C:00C:00C:00C:00C:00C:00C:00C:04B
9`4B9`4B9`4B9@4C904C908E908E900B7`4B7`0A7P0@7@8?7`8?7`D?80D?80<@7P0=6`0@7@DH9@dS
;`hV<PTS;`@P:`LN9P@N9@4N9@0N9`0Q:`8Y<PD_>`Pe@0@Y=`TjA00`=`@b>A8/>0035BT^AbD`C0PR
<P0?6`HH8`LG7P<@64IDH92Q[Y>W^7FOY66BVSYeOcmkQd5eO4=RHb<`:3He9b0d7BT_738[72lY72@[
720]7b@[72PW6B0[5adX51dV4QdV4R4W52DY5RHZ5bPZ5b4V5b4V5b4V5b4V5b4V5b0U5QlT5AhS51`N
4QdO4ahP51hP51hP51hP51dO4a`N4R0R5R0R5R4S5b4S5b0R5QlQ5AhP51dO4a`N4Q`N4Q`N4Q`N4Q/M
4ATK3aPJ3QLI3A0M3a@K31TK21`J21XI2a<G4P`E6@LC7@PC5``G3A0I11DH0QPE1aXD2APF11PJ01DG
0aDG0aDG11DG11DF1Q@D1Q@D1Q@D1PP?00XA0PhC10hD0a0D0A@F0aLI1A/L218E1Q4D1A4D1A4D1A4D
1A0C110C110C10dD1@`C10XA0P/B1@`B1`/A1PT>1@L<0`L@0`dF2@hG2P`C1P`@10lC1a4C1`lA1A<F
1a4D1@d@0@`?00d@0A8E1QLJ2aXM3RPY5C4c7C/m9d=5;di=>5UI@FATC6a/E6ISCVUVDFaYE6i[EVm/
EfeZEF]XDfYWDViaFfmbG71cGFiaFf]^F6Y]Efa_FFiaFfYXEVe[FG1^G7=aGgAbH7IdHWUgIGajJ7ek
JGekJGekJGilJWmmJh5oKH>1KhB2L8F3LHF3LHF3LHJ4LXJ4LXJ4LXJ4LXJ4LXB2L8B2L8F3LHF3LHJ4
LXN5LhR6M8R6M8N5LhN5LhN5LhR6M8R6M8R6M8R6M8R6M8b:N8b:N8f;NHf;NHj<NXj<NXj<NXj<NXf?
O8b>Nhf=Nhf=Nhn=Ni:>O9>?OIB@OXn=Nhn=Nhn=Nhn=Nhn=Ni2>O92>O92>O8f:O8b9Nhf:O8f:O8n<
OY2=Oi:?PI>@PXV9LI2>MXF1J9B?MYJ?M9B<Kl:gVmgA]M35ZM35ZM76Z]76Z]76Z];7Zm;7Zm;7Zm76
Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]35ZM35ZM76Z]76Z]76Z];7Zm;7Zm;7Zm76Z]76Z]76Z]76Z]76
Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]35ZM35ZM35ZM35ZM35ZM35ZM35ZM35ZM35
ZM35ZM35ZM35ZM35ZM35Z@00cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3c/S3c/S3c/O4clS5clO7d<S9
d<S9d<S9cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7c<O6c<O6
c<O6cLS7cLS7c/W8c/W8c/W8cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7
cLS7cLS7c<O6c<O6c<O6cLS7cLS7c/W8c/W8c/W8c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6
c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<S3c<S3c<S3c<S3c<S3c<S3
c<S3c<S3c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4
c/O4c/O4c/O4c/O4c/O4c/O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4blK3blK3blK3blK3blK3blK3
blK3blK3c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4
c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/S1c/S1c/S1c/S1c/S1c/S1
c/S1c/S1c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0b<Nm`l:h
aL>ic/c1_kb^L6YMOgY[Qh9cTXn:YjBOZJJQWY^FVIJAUiB?ViRCZZNR/ZnZ[jbWXj2KSHZ5Lg1[HEiI
FeQCG5UD@DI??T97>Cdn>c`h@T<iD510Gei:JFIAGUA2GeE3H5I4HUQ6I5Y8IUa:Iee;J5i<Ie]9Ie]9
Ie]9Ie]9Ie]9IEU7I5Q6HeM5I5I4I5I4HeE3HUA2HE=1HE=1H590H590EE4nEE4nEE4nDdllDDdjCDTf
BTHcB4@aD4ThCTLhBT8eB3hdAC/aACT_@cL[@SHZ@c`X@S/X@3XW@CXY?cT/>cL/=c8Y<BlU81lQ81lQ
7ahP7A`N61LI4A0B2PT;1PD70`0;1@4=000:000<1`PF0@@C000>0`PG0@8<0P<=1@H@1`PB1`PB1PLA
10D?0P<=0`D?0P@>000730dG00083@TD1`<>5a<N3a4B5ADE71dK9RHP<2hT=c@V?3LX?CTW>C@U>cHW
?CPY?cX[@C`]@C`]@C`]@C`]=3DQ>3LS?c/XASl/@cTW@38P@C4PB3HU;B`H=SDQ>SHS=S0M>38O@S/X
ACh[@SPVBDD]BTH^CDTaDdhiF58oFUA1F550ETlnE50gFEDlGe]2I618IV5<J6=>JVAAJfEBJ65@If1?
HU]:Ee0oBT<b@c`[@c`[ASl^ACl/>CDR=C8SAD@fIVEKPX9lSXn;Si2>SY68SY68S8n6Si:9VIbCUYV@
LWE/BDa3@Sla?3/]?Cd_=STZ;30T<SD/>CPd;R`[;2hR9bTM8B<G71hB6AX@5QL=4a@;4A8900H=0``E
1a8J1A4M1A8P1aHV21PY0aDV014G01<K0ADP01<P010O00lP010S0Q<V014L018M01@P0A@Q11DR0a<S
0Q4Q0A0P01<U01<U01<U01<U01<U01<U01<U01<U0Q<X0Q<V0Q<V0Q@U0QDT0aHU0aHS0aHS0Q@O0Q@O
0A8O0A4N0a0P0a0P1Q0Q1Q0Q00dK00`J0A4N31dZ4BLc42Pd1b4]0Q`X0QXP0A/R0AdT01lX02<[02L`
0B/g1Blk0B@a33]3034f1C<j638n10dQ=3]D:SEA2R<c014M1aLS1a8J1a0IEf=_Z[[7Z[c=XKS0PJB^
Bgb:A7j:BH>9BWUf63TZ7C8L8S8J9b`G:b@E9AlB72<F6RLI7bHI8b4F628A5Al>51`;51`;6Al>7B0@
7B0@7B0@5a`=5a`=61d>61d>61d>5a`=5Q/<5Q/<51D<5AH=5QL>5QL>5QL>5QL>5AH=51D<6Q/B61T@
5AH=4Q<:4Q<:4a@;5AH=5aP?5AH=5AH=5QL>5QL>5AH=51D<4a@;4Q<:2aP@41P=5AP96AH75aH84QD<
31@C1a<G1Q<E2AL<3aP351H25a<86A895aD35aT05AL35AL45AL45AH65AD75AD75AD95AD92Q443A@7
41L84aP951L75AT661X76Q`82`l3310431043A453Q863a<741@84AD92Q4220l21`h11`d220d420d4
1`/51@T300X01Q0421050`/00`T020`12@d21`/02Ph22Ph22`l34QH:7b<G<CDY@dLkCU96FEU1H618
IVI>J6M=IVE;IFA:IfA8IfA8KfaGKV]FKV]FKfaGLVmJM75LLg1KLVmJKG1JKW5KKW5KKG1JK6mIKG1J
L7=MLgIPLVmPMG9SN7EVNWMXNWMXNWMXO7UZOGY[Ph1aPWm`PWm`PGi_PGi_PWm`Ph1aPh1aQXAbQXAb
QXAbQXAbQXAbQhEcQhEcQhEcQH=aQH=aQXAbQhEcR8IdR8IdRHMeRHMeR8IdR8IdR8IdR8IdR8IdRHMe
RHMeRHMeSH]iSH]iSXajSXajSXajShekShekShekSHmlSHmlSHekSHekT8ilTXilU91nU91nShekShek
ShekShekShekShekShekShekRXUkRXUkRhYlSHanT8n1Ti:4UIB6UiJ8T91hZjVAWIV0ZJB;^K:G^[:E
dLJZcL6Ud<FYd<FYd<FYdLJZdLJZdLJZd/N[d/N[dLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZd<FYd<FY
d<FYdLJZdLJZdLJZd/N[d/N[dLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZ
dLJZdLJZd<FYd<FYd<FYd<FYd<FYd<FYd<FYd<FYd<FYd<FYd<FYd<FYd<FYd<FY003=a/?=a/?=a/?=
a/?=a/?=a/?=a/?=a/?>alC>alC?b<G?b<G?b<G@bLK@bLK@bLK?b<G?b<G?b<G?b<G?b<G?b<G?b<G?
b<G>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC;a/?;a/?;a/?<
alC<alC=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G<alC<alC<alC<alC<alC<alC<alC<
alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alK<alK<alK<
alK<alK<alK<alK<alK>bLK=b<G=b<G<alC<alC;a/?;a/?:aL;=a/?=a/?=a/?=a/?=a/?=a/?=a/?=
a/?9`kc;aKk>b<7?bL;?bL;?bL;@b/?@b/?<a[oBc<GBc<G;aKk9`kc=al3?bL;;aKk=al3=al3=al3=
al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=
al3>b<7>b<7>b<7>b<7>b<7>b<7>b<7>b<7=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=
al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=al3=
al3:aKc:aKc:aKc:aKc:aKc:aKc:aKc:aKcAbKc=aKS@b[o=akbWXYUkN71mNW:IUhn^ZjNa[ZZ_[:RU
XYjPWIVVXin_[:Re/Zjo_[Zd]:jNXYN1QGYQI694A50a;4LV7d@H5dT00BXB539cN8NGVj2^/;2YZJVk
^KVLWI^IUiJ5Q81WI5mBD4I?CD9GDdQJEdUMDCmMD41MD41LCd5KCT1IBcmHBD1GB3m;@cI:@CM9@3I7
?SE6?CA4>S=3>C92=c<f<b/f<b/e<RXd<BTb;bLa;RH`;BD`;BDV:28U9b4T9R0S9AlQ8adO8A/N81XM
7aTO8A/O8A/P8APO81LP7aDQ7aDP7Q<P7Q<S7a@W8aPU8QXR7aXP7QdK6Q`?41@110T00Pd00Pd00Pd0
00`000`200`400`400`00@`00Pd00Pd00Pd10`h20Ph20Ph30`l:1`8=2`<C40PJ60hU81L_:Ahe;b@h
<RDo=B@o=BA0=RE0=RDo=B@n=2<m<b8l<R51=bE1=bE1=bE0=R@o=B<m<b4k<Alj<1hl=R<l=R<l=R<l
=R<l=R<l=R<l=R<l=R<m=b@m=b@m=b@m=b@m=b@m=b@m=b@m=bA0>b96?bI>AbiICcMMDCUICCELCSMQ
DcaWFD=ZG4I[GTQ[H4YYHDYYHda[Idm/JU9aJ5A_IU9/HdmZHDeVGDUOET9FCCU@Ac=4?bY0>bHe<1/R
7P/E4`4J60H[:a/m?Bdo?c4n?S0l?2hh>2Xc<bD/;1hW9aTT91HO6a0S8AHM7a<I7A4K7A4I5``O6@hb
:1hV7QhQ6QLL6A4N7Q8T91HV:1`U9QdP8Q`J6QXE5aP>4AD73A@22aD43A/44B464R@:5B<33Q`02QP0
31X03Qh031`031`03al03Al03R014B834b@252D15BH15BH052D152<152<152<04b804b804b804b80
4b835BH252D04R<04B8042403b003b003b0242813b403R003Qh03a`03a`03a/041`53aT13AL03aP4
5al77RH88RT27bH06R405A/05Q`06Al07B<08BT09Rd0:C80;3@8=D82>D80<S/;>T8`B5@;4AhF62<Y
;cX>7bP45Ah02Q455ah96AmDHVS>f=nlaLV7ZkECPhm0PI0aNHXnO8a7Kg/O;C<H4aDC60TC60TD6@XE
6P/G70dF6``C60T@5@HD60dC5``C5``B5P/B5P/A5@XA5@XA5@XJ6P`E5@LD50HI6@/I6@/C4`DC4`DH
60X<3@T>3`/A4PhD5A4E5Q8E5Q8D5A4C510:2`T?40hC510C5@l?4PT>4PLC5`/H7@hD60dB5P/C50XD
5@/H5`dJ60hI5`dG5@/C5PHC5PHD5`LE60PF6@TE60PE60PD5`LK6`/L70`M7@dM7@dM7@dK6`/I6@TH
60PO7`lP810Q8A4Q8A4Q8A4O7`lM7@dK6`/H60PD50@E5@DI6@TH60HD508H6@DP8@dG60hC50X>3`D=
3P@>3`D@4@L?40H>3`D<4@8830052@062@0:30H;30P92PP61PH53@<730<73@872`09300<3`0C5@8G
6@Hb<aTj>b57B2iCE3YKG49PHDMTID]VIdeQHdERI4ITITUVJ4]WJ4iXJ51XJ51XJ51/JeM]K5Q^KEU_
KUY_KUY^KEU^KEU]K5Q`Ke]aL5abLEeaL5a`Ke]bLEeeM61hMf=jMfQjMfQjMfQjMfQkN6UmNV]oO6f0
OFj2PFf1P6b0Of]oOVYoOVZ0Of^1P6b2PFf3PFn4PW27QG>:R7J9QgF5Pg65Pg67QG>5QGN6QWR7R7R7
R7R7R7R7RGJ6R7F6R7F8RWJ6R7B2Q76ATGn1PFn@SWb;RGN8QWB=RgV<RWR;RGN;RGN=RgV?SG^?SG^?
SG^DTH:BSh2BSh2DTH:GU8FGU8FBSh2=RW^@SX>:R7f5PgR5PgR:R7f>S86>S86=Rh2ARH:?RXNFUYJW
ZZjg^l30aLS8c<gAdm?0_KG:ak:l^9G9`9kHbJo@_j[Caj_BbZGCbJ_CbJ_Bb:[AajWAajW@aZS@aZS?
aJOAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWBajWBajWBajWB
ajWBajWBajWBajWBajWAaZSAaZSAaZSAaZSAaZSAaZSAaZSAaZSAaZSAaZSAaZSAaZSAaZSAaZSAaZSA
aZSAaZ[AaZ[@aJW@aJW@aJW@aJT00<g6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lk7a<k7a<k7a<o8aLo8
aLo8aM39a]39a/o8aLo8aLo8aLo8aLo8aLo8aLo8aLo8aLk7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7
a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<_6`l_6`l_6`lc7a<c7a<c7a<g8aLg8aLg8aLg8aLg8aLg8aLg8
aLg8aLg8aLg8aLc7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7
a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/g8aLg8aLg8aLc7a<_6
`l_6`l_6`l[5`/g6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`m7;a<o9`/c6_lW3_<K0^LO1^/W3_<_5_/k8
`M7;a=3:`lc6_lo9`]G?b=G?b<o9`/g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7
`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<k8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lg7
`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7
`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<_6_L_6_L_6_L_6_L_6_L_6_L_6_L_6_Lg5
^<c6^M7;`<O3^:JQV8J3Nh^9PJJSW[:`[kJd/kFc/Zf[ZZZXYk6_[[Zh]knm_;>a/KNh];Vl/jbaZ8jA
Sf9SKCLeBahI>002:P0292``B9FKY[k2am;DeLC4a<K5am7Bd<S9ak:a[I>CSG]iLFYXGUQFC4]9?T<j
;D<j;D8i;44g;D0e;Chc:c``:S/_:C4/8c4[930Z8blY92dV8b`U8R/S8b/S8bDT82@S7b@S7b<R7R8Q
7B4P724P720O6ahO6ahO6adN6Q`M6AXK5aTJ5QPI5API5A`M6a`M6a/L61dL61hK5QdK4ahK4ahK4ahJ
3alM4b0M5AdJ5Q/I61PG6@h?4`@42P043@043@043@02300230012`012`402P0530063@473P@73`H9
4@P:4P/:4``;52LT7bTW7bdZ8S0^93@_9SH`9CH`9CD_8Sle93le93le93hd8chd8cdc8S`b8C`b8CX`
7SX`7S/a7c/a7c/a7c/a7cX`7ST_7C`f8c`f8c`f8c`f8c`f8c`f8c`f8c`f8c`f8c`f8c`f8c`f8c`f
8c`f8c`f8c`f8c`g7Shi84Ho9U16;U=9<EI:<Ua@>6EG@6QH@FQJ@fYLAFYNAVQNAVMPAfQSBV]VCG9[
DViWCV]TBfQQB6MPAfENAF9K@UmH?f1J@eaG@U=>>DE1;STg9C/i9dE5=E1@@3Xj;3Ti:cLg:CHf:3De
9cDe9cHf:3Hf:38`9BX/82HZ7R0W6QdQ5B/[7dU5>VELDWQaKWYdKgilLXR7NI:BQ9VKSifNUIjNV9>D
TZja[iRMW4Q=D0P@5`094@0<5P0030<<6@0;5`8>6PDB80@D8@0?7`0@80<C8`0>800>808@8P8B8`4C
908D9@0C900C908B8P8B8P8B8P8B8P8B8P8B8P8B8P8B8P@D9@<C908B8`0@8@0?800?800?800?804?
8@4?8@0>800>7P0?700?700?6`0?6`D?6@4=5`0?60<F7PPM9@LQ:08N9@0I80@L8P@L8P8O904Q9`0U
;@0Z<@4/=@4_=`0/=`0_>@0^=`Xh@2i7D@@:5`H84a8H8`@F7@PJ8@0C6PHI80/Q9f=iO[75bYV]/Un6
SdIhQ3QiR31hRCn0SdUfPBa0AA@H6AXL41HH314C1`h@10h@114C1aDG2aLI3A4E2Q4E2Q<G31@H3AHJ
3aPL4ATM4QTM4Q<E2@lA1@lA1A@F2Q@F2Q0B1Q0B1QDG2`l@30h?2`/<20L810<40001000100010042
00H70`/<20/=1`P;0PT=0PdA1A8F2QDI3Q<G31<G31HG3AXI3a`K4A`J41/I3`P;00/>010C0aHI2A`O
3b4T52@W5bDX63Ti:Chn;TM7=e9B@UeMCFIVEVa/G6m_GgalK8:2LXR8N8F5MG=cHeMGAcPh:2DU5Bh^
72PX5RLW5BPX5R<T41TJ1Q<D01@E0@`?00hA0Q0C110C10lB0`hA0PlB0a0C11<G2`hB1PT=0@D900@8
00@700<600<6000400H:01@F2R8U5S0a8Cdm:dQ9=Dm@?5UJ@5iOAF=TBVIWCFIWCFAUBf=TBV=TBVQZ
C6U[CV]]D6a]Dfe^E6i^EVi]F6e/EfUXE6UXE6YYEF]ZEV]ZEVa[Efa[Efa[Eg1_Fg9aGGAcGgEdH7Ed
H7MfHWYiIGelJ7ajJ7ajJ7ajJ7ajJ7ekJGmmJh1nK85oKGelJ7akIgakIgakIgelJ7mnJX60K8:1KH5o
KGmmJgmmJh5oKHB2L8J4LXJ4LXJ4LXJ6M8N7MHR8MXV9MhZ:N8Z;Mh^<N8^<N8R:M8V;MHJ7Lhb=NHV8
M8n=Nh^9Mh^9Mhj<NXf;NHb:N8f;NHn=Ni2>O96?OI6?OHn>P8f<OX^:O8Z9NhZ9NhZ9NhR7NHN6N8B4
N8N7NhZ:OXb<P8^;OhR8O8J6NXF5NH5nNJFTX<S<cM?Ig/SAeL;;cm?HfNCZjL?0^=OD_lk:Ym;9YmW:
/<nnZM34Z<_3W];8Z];8Z];8Z]77ZM77ZM36Z=36Z<o5Ym77ZM77ZM77ZM77ZM77ZM77ZM77ZM77ZM77
ZM77ZM77ZM77ZM77ZM77ZM77ZM77ZM;7ZM;7ZM;7ZM;7ZM;7ZM;7ZM;7ZM;7ZM76Z=76Z=76Z=76Z=76
Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=35ZM35ZM35ZM35ZM35ZM35Z@00c<G2c<G2
c<G2c<G2c<G2c<G2c<G2c<G2c/O4c/O4c/O4c/O4clS5clS5clS5d<W6clS5clS5clS5clS5clS5clS5
clS5clS5cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3b/G2blK3
blK3blK3c<O4c<O4c<O4c<O4cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5blK3blK3blK3blK3blK3blK3
blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK5blK5
blK5blK5blK5blK5blK5blK5c<O4c<O4c<O4c<O4blK3blK3blK3b/G2c<G2c<G2c<G2c<G2c<G2c<G2
c<G2c<G2cLO0c<JoblFnblFnblFncLO0c/S1clW2c/S1c/S1blFnbL>lblFnc/S1c<JoaKnhc<Joc<Jo
c<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Jo
c<Joc<JocLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0c<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Jo
c<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Joc<Jo
c<Joc<Joc<Nnc<Nnc<Nnc<Nnc<Nnc<Nnc<Nnc<Nna/2ec/Rmc/Zo_KR_WibDShf5ViRC/:fX/kFf^;Zk
]kVj/;:c[[2a];Jg^kfn_/31_K_1_Kbn^Kbj/kNbZ:f[W:2UTI:PRXVMO8:IIfj1J71mTiVPW:6TZJf^
Zjf^/[6e/kFe];Jf];Fc[Zn]Y:>OSX^6JFIQBdQ3;RXU;RXU;BTT;2LT:RDT:2<R9R0Q91hO7A/J7A/J
7A/K71XJ71TK6aPJ6aLL6aLL5aPL5aPL5aPL5aPL5aPL5aPL5aPL5aPL5QHF5QHF5QHF5ADE5ADE51@D
51@D51@D5AHJ5AHJ5aHH61DG61HF6QHE6QHE6QDB61D=6aP@6QLB61DA5Q@D5QDG4Q4E30/?10hE10hE
1@dD10`C10XA1@P@10L?10L?1@d=20d>2Pl@3A4B3a<D4aDF5QDG5aHH924L9bDM;R/S<c4W>3<Z>S@Y
>C<X>38U>S8Q>C4P>30O=blN=blN=blN=blN=blN=B/I=R`J>2hL>S0N>c4O>c4O>c4O>c4O>cDR>cDR
>cDR>cDR>cDR>cDR>cDR>cDR>cDR>cDR>cDR>cDR>cDR>cDR>cDR>cDR>S@M>38K>S@M@CTRAS/UBChX
DTD_G4liHe@jIEHlIePnIeY0IU]0J5e2JV56KFA9L6Y=K6I9If54IEm2If54JF=6JfE8K6I9IV19I5i7
GUU4Ee8mCd/hC4XhCT`jDDlmGEe=F5Q8CdloATHf?cl_>SXZ>3PX>3PX>3//:c0Q<STZ;cTY72<D9bXK
B4LiEe54MVeYO7M^RHIhUIF5XJ:B[:bP/kBZ^KVc^;^b/;:/[;2[XZVVMgmn=T102ADG00X>00<<00@<
00PB0`lK0Q0L00`J00`L0Q4Q0@dO0PhP0@lQ0A4R0Q8S018S018S014R0A4Q0A4Q0A4Q0A4Q0A4Q0A4Q
0A4Q0A4Q0a<T0Q8S0A4R010Q00lP00lP00lP00lP0@lQ0@lQ00hP00lO010M00lL00lK00lK0PhH0@dG
00lH0a@M1Q/S1QdU0Q`S01PO1AlU0b0U0b4V0R@Z0RL_0B/b0Rdf0S0h2Blk0S<m03@k5D19>DmJ1`dH
000;00TB00dD2adT1aXQ01PN1B8WIXJ;L9FIGH>7D7^4E8RD?Gj==7Z;?Gj=AGJ0=55E1QHE61P<6AT=
6a/?6a/?6QX>61P<5QH:51@84aL<4aL<4aL<4aL<4QH;4QH;4AD:4AD:7b4E6adA6Q`@71hB6Q`@5QP<
5AL;5aT=10H00P@00080008000800`D01PP220X40040004020X43Q0:4QD<61`A82@I9RXO82HK8RPM
:RhS=cP^@d@jCdi4EUE;FEM=L7=TLgIWNGa]P8=dQhYkSY62TYF6U9N8VIV;VIV;Vi^=W9b>WIf?WIf?
WIf?W9b>UiN9WIf?Xj>EYZJHXZ:DUYJ8R8QjOgmaC4hj?Cl[;S0L9bTE9BLC9RPD:R`H;c4M61/;71l?
7R4A6Qd=4A@430l02`h03A000PH00`L010T01P/02Q004QP7728?8RPE=cPX?d0`BddjEeM5HF1<IfIA
KFYEL6eHIFQ?IfYAJFaCJFaCJ6]BIVU@IVU@IfYAIVY=IfY@J6]AJFaCJVeDJVaFJFYFJFYFLG9NL75M
LG9NLG9NLW=OM7EQMGIRMWMSK6eIKg1LLgAPMGIRMWMSMgQTNGYVNgaXNWaVNG]UNG]UNG]UNG]UNgeW
O7iXOGmYPH9^P85]P85]P85]PH9^PX=_PhA`Q8EaRHUgQHEcPH5_P81^Ph=aQXIdQHEcPh=aRhYeRhYe
RhYeS8]fS8]fS8]fSHagSHagS8adTI5iShiiRXUdTi9nSXajRhUgT8enS8alS8alRh]kRh]kRh]kS8al
SHemSXinRhb2RX^1RX^1R8UoQhQnRHZ0SHj4T967PHAkR8^2Si:9TIB;SI27Rhj5S8n6SY68QHV4VZ6N
/KZm_/[@amGKc=SN`<c>/[blXIjFb/NbcLVVc/FSd/>YckjYeLV]c/JQd/RZdLNYdLNYdLNYd<JXd<JX
d<JXd<JXdLNYdLNYdLNYdLNYdLNYdLNYdLNYdLNYdLNYdLNYdLNYdLNYdLNYdLNYdLNYdLNYd/NYd/NY
d/NYd/NYd/NYd/NYd/NYd/NYd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FW
d<FWd<FWclBXclBXclBXclBXclBXclBX003<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;=a/?=a/?>alC>
alC>alC?b<G?b<G?b<G>alC>alC>alC>alC>alC>alC>alC>alC=a/?=a/?=a/?=a/?=a/?=a/?=a/?=
a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?:aL;:aL;:aL;;a/?;a/?<alC<alC<alC<alC<alC<alC<
alC<alC<alC<alC<alC;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;
a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/G;a/G;a/G;a/G;a/G;a/G;a/G;a/G;a/?;a/?;a/?;
a/?;a/?;a/?;a/?;a/?<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;6`;W8`[_<a[o@b/?CcLKBc<G>b<7;
aKk@b/?AblCBc<GAblCAblCAblCAblC?bL;<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<
a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o=al3=al3=al3=al3=al3=al3=al3=
al3<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<
a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<akk<akk<akk<akk<akk<akk<akk<
akk8`[O@c<7;a[f_[:BFU8bDTHbPX9Z/ZjNb]KVf^Kfd]k^]/;BZ[K6^/KFa];Ra];Rg/kjf][bf^;Vf
^kVe^kZc^;^]/kZZ[[VS[;FFX:NJXjN//[NZ[k:_/[J]/;BYZJnSYjRPY:FLX:6HVYZ?ShmgMgMFE5@l
>SXR8R8R8B<R8B<P7b<N728L6R0J5b0H5Ah@4aL@4aL@4aP@4aP@4QXA4Q`A4Q`A4Q`>41X>41X>41X?
4A/?4A/?4A/@4Q`@4Q`@4Q<@4Q<@4Q<@4Q<@4Q<A4a@A4a@A4a@?3QP?3QL?3QLA3aDD41DD41DF4A<F
4A<E4PdH5A4H5A4C4A0D4Q8H5ALH51TD41D>6Qh=6Ad=61`=5QX<5AT=4aP;4AH=4AH>50l?5A0@5Q4D
61<G61@I6QHL6aLM71PD4@`G5@dN6a<U8aT/9ahc;B8e;b@f<2<e;A`d;1/c:aXb:QTb:QTc:aXd;1/d
;1/h;Q`i;adk<Alm<b4n=28n=28n=28n=28j=24j=24j=24j=24j=24j=24j=24j=24j=24j=24j=24j
=24j=24j=24j=24j=24j=B0e<1/e;QXg<1`i<1`j;a/n<am7>BIHBBmKC39NCcEODSQREC]VFCm/GdEa
I4Y[ITMXHdATGd1TGd1VHD9YI4E[ITM[ITMUGTEPFT=MEd1IE3mHDciEDCiACce?CC]:BSY8B3Q6ASI3
@c=1@C50@310@311@C4k@34S:Q/[=BD[=RH>60PF6``c<bDb;b4f<2Do>Ba8ACIACceEED=LG4iVIE]_
K6N;Sh>HW92OYIZTZJ2V[JJCVYEFH5XH8Ah741@02@d010/01`l02Q@02QH02QP03Ad03Ad13Qh23al1
42014B414B404B004B01420142014201420142024B424B424B434R824B4142003al03Qh03Qh03Qh0
3al03R003R013b41420041d03a`03a/03QX13AL13AL03aP14Q/45al46B4362005Qh16b4072407R<0
8BL092`1:302:c@4;CHD=3l;=Sl4=CdK@TXoE5`;4A`00``02A803QD:72<46R0051/06b5COH@ZG68Z
HFI=O8ARV:=1OhlbMhPlNXY4Mh4oHVD171TG5P`I60hK6Q0K6Q0I60hG5P`F5@/F5@/@5P/A5``A5``B
60dC6@hD6PlD6PlE6a0<40D<40D=4@H@50TA5@XB5P/C5``E6@hD5Q0F618J71HP8Q`W:B<_<B/f>38j
?3IDEU1JG5IQHeeXJf9]L6MdMfikOWF1Q7^DVXnDVXnDVXnJWY>PXINTYI^WYYbVYI^IW8fKWXnMX96P
XiBRYIJSYYNTYiRTYiRWYiVVYYRVYYRUYINTY9JSXiFRXYBQXI>QXI>OWi6LW8jJVXbKVhfNWY2RXYBU
YINCUginPF]RIDm:CCLi>bL[;ATQ8a0J70TK80/I7PTC60<<4@0730062`083@0;40093@4@5@HJ80lT
:QL^=B0lA2e;E3YEGT=NGd]RI4iYJ5=ZJEAYIU5WHTeTH4QTGTMUIe5VJ59XJUAXJUAXJUAZK5I]KeU`
LUaZKEA[KUE/KeI]KeU]KUY/KEU/K5Y[JeU[JeUZJUQZJUQ[JeU/K5Y^KUaaLEmbLV1_KeebLV1fMVAi
NFMiNFMiNFMjNVQkNfUkOFMjO6IjO6IjO6IjO6IkOFMlOVQmOfV6QWB5QG>4Q7:4Q7:3Pg63Pg62PW22
PW24Q7:6QWB5QG>3Pg64Q7:7QgF9RGN7QgF?SWB>S7B=Rg><RW:;R7>;R7>;QgB;QgB:RW:@T7R>SGR4
Pfn?Sgf6QWJ4Q7J;Rgf6QWZ6QWZ7Qg^6QWZ6QWZ7Qg^9RGf;RgmkOgV0Q7j4R8:7RhF8S8J<T8ZDV9:J
WYRa]K2c]k:d^;>d^;>e^KBj_[W1aL37blK<emC?fm^jbLb:W:=UMWmKJg9KIfeEH6AoO7Bi]Z79aJ;8
_ig<_J??_ZWIcK7AbJC@aZS@aZS@aZS@aZS@aZS@aZS@aZS@aZS@aZS@aZS@aZS@aZS@aZS@aZS@aZS@
aZS@aZS@aZS@aZS@aZS@aZS@aZS@aZS@aZSAaZSAaZSAaZSAaZSAaZSAaZSAaZSAaZS@aJO@aJO@aJO@
aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO>`jO>`jO?a:S?a:S?a:S?a:P00<_4
`L_4`L_4`L_4`L_4`L_4`L_4`L_4`Lg6`lg6`lg6`lg6`lk7a<k7a<o8aLo8aLk7a<k7a<k7a<k7a<k7
a<k7a<k7a<k7a<g6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lW4
`L[5`/[5`/[5`/_6`l_6`l_6`lc7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<_6`l_6`l_6`l_6`l_6
`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6
aL_6aL_6aL_6aL_6aL_6aL_6aL_6aL[5`/[5`/[5`/[5`/_6`l_6`l_6`l_6`l_4`L_4`L_4`L_4`L_4
`L_4`L_4`L_4`Lc6_l_5_/_5_/g7`<k8`Lg7`<S2^lBn]lBn]lS2^lg7`<k8`Lc6_l[4_Lg7`=;<aL_5
_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5
_/_5_/_5_/_5_/g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5
_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5
_/_5_/_5_/_5_/c7_/c7_/c7_/c7_/c7_/c7_/c7_/c7_/g8_m?>aLG2^ZJSVi:?RYJETJ6PW::SWjb_
/k2c]k2c]j^^/ZV//:b_/jf`]:^^/ZVX/ZNV[jFX[:N[[:V^[jR_/ZN]/Z:Z/JVc/j:/[:^b]JV_]9jT
ZI6EVXR<TGIjOeQOHTaAE3Tn@BX]<AhQ9ALG7A<A5a4?5A0C610C60lA6@h?6@d>60/;5`P850L75@D8
40D840D74@H84PH84`H75@L85PL75`444P444P854`<650<650@75@D85PD85PX<50X<50X<50/=5@/=
5@/=5@/=5@`>5PL74`P850X94`/:50d:4a0<4Q4=4a4=4Pl=318@3a8@40l=3@l<3QLB51TD5QPB5`hJ
70hJ70lH6`hG6PlF6A0E60lD5`lD5a4E3a4E3a@F41@F41LG4AXG4QXG4QXG4Q/H4a/I4A`I4AdK4B8M
52LQ5R/U6RdW6S8[6S8[6S8[6S8[6S</6c@]73D^7CD^7Cdc8Cdc8Chd8Sle8cle8chd8Shd8Sdc8CXd
8CXd8CXd8CXd8CXd8CXd8CXd8CXd8CPb7cPb7cPb7cPb7cPb7cPb7cPb7cPb7cLc8CD^7C</6cL_7SP^
7C@Z6CDX63P[6d@h84Lk8d/o9e12:eE7<5a>=fAF?fYLAFAO@6AO@6=N?fEP@FMR@fMR@fEP@F=N?e19
<4a5;4U2:DM1:TM2;DQ3;TE1;T<o;4Q6=4Y8=Te;>Di<>Ti<>Ta:>4Q6=4I4<TE8>28X5b0X5alY60dE
120S4d10<40k;34Z6cH_7STe8SHe83@c7c@d93`j<4=1>CPk;4A9>TeAAE=GBfM^HHF;P8jFRhR@QB<[
:Q4I6@082`0530094P8;60<<6P@=6`0;6@4<6P0=6`8?7@0@7@0@7@0@7@0@7@0>7P0>7P0?7`0?7`4@
804@808A8@8A8@4A7P0@7@0?700>6`0>6`0>6`0?700@7@0=7`0>804?8@4@804A7P0@7@0>6P0=6@4=
5`0=5P0>5`4@6@8C70<D7@8E7@4D700E6`0F700J7`0L8`4P:@@U;PHY<`P[=@dU<@<W;`0T:`hd>CE8
D0L>5`073PLC6@HJ7`DH7`4G7@0E700M9Cm^MPE0BAUJHS=ZLE6<USajRSUgRDInSe:0RdecMA@a;Q@H
3A<G310D2@dA1P`@1A4E2QXN4b4U6PlG318J3aLO51hV6bD]8R`d:C8j;cDm<U1DBEAHCEYNDf1TFFQ/
HG5eJWIjKgQlLHF8OhR;PXb?QY6DRiFHSiVLTiZMU9^NUJ6TVj:UW:>VWJ>VWJ>VWJ>UWjBVX:JXXYfU
VY^SV9bRUi^QUYjRUj2QUijOUIbMTjFWVjFWVjFWVjBVVZ>UVJ:TV:2RUYnQUIZLT9ZLT9ZLT9ZLT9ZL
T9^MTI^MTIbNTZ>UVJBVVZBVVZ:TV9nQUIZLT9FGRi:DR:BZTijTSIBIQ8J;MW=gI5ULC3Xm;R<V5b0U
41DJ1@T>00D:00`A01LL1b0U42<X4ce2<d=8>DaB@E9HAEEMAUYSBF5ZCfI`DUaOAUmRBFASCVIUD6UV
DF]VDFeXDfmXEFi`GFi`GFa^FfY/FFMYEVQZEf]]FVi`GG1cGG5dGW9dH79dH79dHG9cHg5bHW5bHV]/
G6]/G6a]GFe^GVi_Gg1aHG5bHW9cHgAeIGMhJ7YkJg]lK7YkJgUjJWUjJWUjJWaoJG]nJ7]nJ7]nJ7ao
JGf0JWn2K7n2K7amKGenKWenKWenKWenKWenKWenKWenKWEgI7j0KH>5LWn1KWeoK863L8B6Lh>5LXJ7
KHJ7KHF5KHF4KhJ5LHN5LhR6M8V6MhF5KHR:M8N8M8B5MH>6Mh65NWn4NhJ:Q7b3O7n6Oh>:PhF<QHN>
Qh^BRi2GT9FLUJVa/:ng][S0_kg5a<38alC<blWAd<kFeM3HelcDdlWAd<_Cd]3HemGMg=SPgmWQh<oM
fk[<cI6TZFMlQ6AfPH2AVYfZ/ZF_]X1mML2mZ=;>Zlo6Y<joYLnnZMK:[/c4Wlo5Ylo5Ylo5Ym36Z=36
Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=76
Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35
Ym35Ym35Ym35Ylg2Y/g2Y/k3Ylk3Ylo4Z<o4Z000blC1blC1blC1blC1blC1blC1blC1blC1c<G2c<G2
cLK3cLK3cLK3c/O4c/O4c/O4cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3c<G2c<G2c<G2c<G2c<G2c<G2
c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2bLC1bLC1bLC1b/G2b/G2blK3blK3blK3blK3blK3
blK3blK3blK3blK3blK3blK3b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2
b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G4b/G4b/G4b/G4b/G4b/G4b/G4b/G4bLC1bLC1
b/G2b/G2b/G2blK3blK3blK3blC1blC1blC1blC1blC1blC1blC1blC1d<[3blFnal6jal6jc<JodL_4
d/c5dL_4blFnc<Joc/S1d<[3c<Joa/2ia/2ibL>lblFnblFnblFnblFnblFnblFnblFnblFnblFnblFn
blFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnc<Joc<Joc<Joc<Joc<Joc<Jo
c<Joc<JoblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFn
blFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnb/Flb/Flb/Flb/Flb/Flb/Fl
b/Flb/FlblVob/No^KJ^WY^FTI2<VYVEWj2NWIjLY:JWZJ^/[:j_ZZb][:j_/K>d/K>d[[2a]kZn/[Fi
[K2dZZnbZK2cZJndXjb`WjR/Vj>ROhN7LGMlD5EN>d199R/d:Bld7RDX5QlS4AXN3aDJ3A<J3@lI30dG
4A4M6QPT10L?10H@10H@10HA0`D@0@8@000?000>008<008<0@<=0@<>0@8@0@8@0@4A0@4A000?000@
000@0@4A0@4A0P8B0P8B0`<C10D?10D?10D?1@H@1@H@1@H@1@H@1@H@0P@?0`<?10D?1`H@20L@30X@
3PX@3`/@1`H82`X<30/=2PL92`H840/=5@hA5@hA210@2A4A2a0A2a0A310A3Q0A3a4B3a4B4A<=4A<=
4a<=5A8=5Q<>5a<>5a<>6A<>7Q/F71XB6aP@6aT?7QT@91hC:B<H;2HI;b/I<BdK<blM=C4O=c<Q>3@R
>3@R>3@R?C<Q?C<Q?C<Q?C<Q?C<Q>c4O>S0N>BlM>C<P>C<P>C<P>C<P>C<P>C<P>C<P>C<P=c4N=c4N
=c4N=c4N=c4N=c4N=c4N=c4N=2lP<2/L<b`M>34R>c8T>BhP=R/M=R/M<2TF<b`I>2hL>c4O@SHTBcd[
DdDcFD/iFE<fFU@gGELjHU`oIEm2I5i1H5XmG5HiG5<hFU4fETlfEDheEDlhEU4lEe8mEE4nCd/hDThk
Ee=0FEE2EU8oCd/hAT8_@3`Y@T8b;2dM;C0P=3XY<3<S>c/[BdHgASd_?cXU@C`W@ShV>cTQ<C0K;R`J
;bdR=34Y?3hb9bTM8R@H;S0T:bdQ7b4E;c4UCe55;3<^6B0M1P`;00H900P?0@LB00LD00LF00PF00TG
00/I00dK0@hL010M010M010M00dM00dM00dM0@hN0PlO0a0P0a0P0a0P0@hL0@hL00dK00`J00`J00dK
0@hL0@hL00dO00hP0@lQ0Q4Q0Q8O010M00hJ00dI00dF00dF00hG00lH0A0I0A0I0Q4J0Q4J014H018I
01DK01LO1A/V1b0Z2B<_2bDa0Q@O01LP01PM1bT_<4991PhE1@dD41hT2R<W01HK0QPN01TS2BTd?Vag
3DYD6f1Z8fEZ@86:Ah>CAgnBCGf?DWR4AfIY8c/i<3P^>T8hB516DEU?EEeCEUiDEemEFF5GKWI[LGU^
MWicOHEjQ8b1Ri>8T9R=Ti^@Qhb3S968SiB;TIJ=UibCWjBKXjROXZNNWZ:GX:BIXjNLYZZOYj^PYZZO
Y:RMXjNLWJ6FW:2EVinDVYfDVI^EV9ZDUiRDUiRDTifATi^@U9bAVZ2EWjFJYJVNZ:VOYjRNW9fCW9fC
WIjDWYnEWYnEWYnEWIjDWIjDYZZOY:RMXJFJWZ:GW:2EVYjCVIfBV9bAVIfBVinDWJ6FWj>HWj>HWZ:G
VinDVIfBRY5lT9J3UYb;VYn@VinCV9bARhj5OX1jH6=CDEA4@D@d?D0`AdXjE5M7G5m?GF1@HVQGIF]J
IfeJIfeJIFaGHFQCGfM@GVI?HVE?I6MAIVUCJ6UEJVQFK6YHLVeNMG1QJV]KJV]KJ6UIIVMGI6EEIFIF
JFYJK6eMJfeIK6iJKFmLKVmOKg1PKfmQKViPKViRLG9RLW=SM7EUMWMWMgQXMgQXMgQXMgQXMGIVMgQX
NGYZNGYZMgQXMWMWMWMWMgQXNWaYNWaYNWaYNgeZO7i[OX1]P89_PH=`OGi^OWm_P85aPX=cQ8EeQHIf
QHIfQHIfQ8IcS8ikRXaiOh5^NG]XNWaYNWaYM7ISNgmVNgmVNgiXOGm/P85aQ8AfR8QlRXUoPhMdQ8Qe
PHIgTYR=MgmhRiBARiJDSiVIQI6ARiNGTYjNV:BTW:RXXjn_[;Rh/kno/[g1]l;6_<O;`Lc@`lkBa<oC
aM3DaM3DcmSKc=GHbmCGcMKId=WLc]OJa/oB_lS;_m7BYKRkR9^SPiJSX[?0_lcJ_/SBZk:kQ85i_kbW
dLfZd<NUdL:XckjYeLV]bl>Nc/BVc/BVclFWclFWclFWd<JXd<JXd<JXclFWclFWclFWclFWclFWclFW
clFWclFWclFWclFWclFWclFWclFWclFWclFWclFWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FWclBVclBV
clBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVc<6Uc<6UcL:Vc/>Wc/>WclBX
003;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7<aL;<aL;<aL;=a/?=a/?=a/?>alC>alC=a/?=a/?=a/?=
a/?=a/?=a/?=a/?=a/?<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<
aL;9a<79a<79a<7:aL;:aL;:aL;;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?:aL;:aL;:aL;:
aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:
aL;:aLC:aLC:aLC:aLC:aLC:aLC:aLC:aLC8`l39a<79a<79a<7:aL;;a/?;a/?;a/?;a<7;a<7;a<7;
a<7;a<7;a<7;a<7;a<7<a[o9`kc7`K[:a;g>b<7?bL;;aKk6`;W;aKk5_kS5_kS?bL;Fd<WDc/OAblC@
b/?;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;
aKk;aKk;aKk;aKk;aKk<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o;aKk;aKk;aKk;aKk;aKk;aKk;aKk;
aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;
aKk;aKk;aKk;aKk;aKk9a;_9a;_9a;_9a;_9a;_9a;_9a;_9a;^n^k>e/ZZRWiZ@T8ZAT8bKW9ZOX9jH
ViVOWIbTXZ6WYJBXYZF[ZJR`[Zf_[JbZZ:NOY::OY:>MXZ>HWZ><TYUbNX5EGF@nB4lT:B`A5AXK7BP@
4b4D5bD31a8>51T63A002Ph020l53A@;4Q/;3aX3118000`000d621061a4721871a<71aD61Q@40a<4
0a<41Ph41Ph41@l411041104118411840a<20Q020Q030a430a430a441184118411800@l00@l00@l0
0@l00@l00@l00@l00@l00@/00P`210`31@d71`d:2@d;2Ph<2`l310P82@d<2`l91@X910H>1`XB2`hD
2`h62`X730/:30`>3Ph?3`lC4A4D4Q8G4Q<D4`lE510G510I514J5A8M5Q<N5a@P5a@K61<K6A4L6A4M
6a4R7A@X8QL/9Q/^:1/[9aD^:QPc;adg<b4j=R@k=bDj=R@i=B<k<Alk<All<R0l<R0l<R0k<Alj<1hi
;adh<Qlh<Qlh<Qlh<Qlh<Qlh<Qlh<Qlh<Qlf<1df<1df<1df<1df<1df<1df<1df<1d`;Al^:1/^:1/f
;R4j<RDh;b8h;20i;B4[:1X/:A/^:1/_9aXa:1/g:alm<BE4=RY7@2M9@RU>AbiECSEKE3]MESeKE3]I
DSU3>Qm3>Qm3>Qm0>B0n>24n>24o>RE0>bHX914`;1Tl>2E6@Rm<B3E=BCI:AS=7@c0m>BLk>BM3@c5>
D3e@D3i;AcE3>bY0<b<o>B91?2=0?B4k>1``;QHV918R7Q<N6a<A4PPW:1h/;R8Q8ADT91Pd=2P^;R0F
5PPM9A/E71D=4Q093Pl32@h00P/000d00Q401A801a@02QH13AT13a/041`14Ad14Ad02a/031`031`0
3Ad13Qh23al3420342003QX03QX03AT03AT03AT03QX03QX13a/031h03R013b424B424Ql041d03QX0
31P031D03AH03AH03AH031H13AL23QP33aT03QD03QD041L141T24Qh55B4762D86BH441`06B007bDB
<SLfBDh841L43a<?82<58RH05QX36Al25R4G=496L7dSGFT@DElWL7@eNX=;QiM0LXHaEVXZAE<J<3DL
;RdlBSm>G55VM6UjR7f3THJ6U8V8UX^9Uhb;UHV<UXZ>V8bAVhnDWY:GXIFIXiNJY9RMXYVQYYfRYijN
XiZNXiZSZ9nSZ9nOY9^KWiBLX9FMXIJOXiRPY9VQYIZQYIZRYY^SYi^RYYZSYibTYijWZJ>XZJFYZZJY
ZZRT[Z:QZinOYibMYIZNY9VOXiRKWiBIWI:OX9JPXINQXYRRXiVSY9ZSY9ZRXiVRXiVAUHZBUX^BUX^D
V8fGVi2KWiBOXiRQYIZSYibQYIZLX9FHW96FVXnFVXnHW96IWI:JX8nKX96HW92CUXfFV9:QXZ2WYjNW
YZRNXI:DUhR9S7f5R7V8Rgb=T86>TH:=T85jP6eiOfahOV]iOfiiOfihOFieNV]cN6UfOFQfOFQgNfQd
MfMbLVA`KV=`KV=aKfE`LfAaM6EbMFIaM6EaM6EcMVMhNfakOVmaMF9bMV=dMfMeN6UfNFYgNFegNFeg
N6ibMFIdMfQgNV]jOFijOFiiO6egNV]eN6UmP75nPG9oPW=nPG9mP75mP75oPW>2QGJ2Q7R2Q7R3QGV4
QWZ6R7b9Rgn;SH6<SX:>TH:?TX>@ThBBUHJBUHJAU8F@ThB?TX>?Th2=TGj2QW=eNFIeNFInPVmlP6ea
MF9gOfQgOVUfO6UgO6ejOW9nPGR1Pgf4QH5kPW=eOW5fOgFNZZAXMG>DXjFHZ:jEYjj=X:RCYZjK[[JO
/[ZR]KfX^l>aa<bic=Bmb]:lbM6kb=2lbM6nbm>nbm>mb]:lbM74d=C3cm?3cm?1cM6mbLfg`lN`_<2[
]k^0Si:>WZBM[kZQ/L6JZKVEWk2HWZ^LX:^5PWZg]9o5`Ik=a:;Ca:[A`:_EbJg>aZ7=`jG>a:K>a:K?
aJO?aJO@aZS@aZS@aZS?aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO?
aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?
a:K?a:K?a:K?a:K?a:K;`:C<`JG<`JG=`ZK>`jO?a:P00<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<c5
`/c5`/c5`/c5`/g6`lg6`lk7a<k7a<g6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lc5`/c5`/c5`/c5`/c5
`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/S3`<W4`LW4`LW4`L[5`/[5`/[5`/_6`l_6
`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5
`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5a<[5a<[5a<[5a<[5a<[5a<[5a<[5a<S3
`<S3`<W4`LW4`L[5`/[5`/_6`l_6`l[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[4_L_5_/g7`<o9`/_5
_[fg/:VSW9VCS96;Q8R2Nhb6OjFOV<2j/l_5_/_5_/W3_<[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4
_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_Lc6_lc6_lc6_lc6_lc6
_lc6_lc6_lc6_l[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4
_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_L[4_LS3^/S3^/S3^/S3^/S3
^/S3^/S3^/S3^Zj[XinMUHj;QXJ5PHf>RYZKVI^NW9NIVIZGTinLV::OVj:OVjFRWZRUXJFRWYnLV5YQ
FTU@CC<h>B0V:aDM918I8PdF7`/D7A/O90<53`l?7`L96a0B90023@`E6@LA4@/E704;4P063`884`L:
60H960/;7A4A8`T;4`T;4`X;5@/;5`/;5`X:60X:60T860L63`L63`L63`L640H440H440H34PD24@<0
3`<03`<03`<03`<03`<03`<03`<03`414@004000400040003`003`003`003`012@012@0320852PH7
2`P:2`/:30/:30<62`X:40h=4@/730/620l82a@;3Q@;3P`=2`d>314?3Q@B4APD4a`G5QdH5ahI61XF
5A/G5Q`H5alJ6B<K6bDM7BTO7bTO7b@Q72DS6bHS6bLU6bTT6b/U6R/U6RXT5bDQ3bTU4bl[6CDa7cTe
8cTe8cPd8SHb83/a7c/a7c`b83dc8Cdc8Cdc8C`b83/a7cPb7cPb7cPb7cPb7cPb7cPb7cPb7cPb7cD_
73D_73D_73D_73D_73D_73D_73D_734^82XW6BXT5blY73D]83@[7S<Z7CHZ7Rh]8bd/8R`Z82XU72XS
6RdT6c4V7SLZ8SP_6cXa7Clf8TLn:U17<eI=>EM>>UM>>UU><UYA=UaC>5UB>EI?=U9<=E9=>5=>>C/g
944m:TU5<U1<>E=??55=>Ta8=DQ4<DDm;4a5=4a8=Ti<>UEA?de5=4Tl;592<TM2:DU5:DU7:DI39c/i
8Bd[6B8N4a`F3bDV7B0Q62DT6Rd/8RTY7AlM4R@R5c@c9A8H3ADJ4APN6APM70dA5P043@003P055004
4@054P085@0<600>6P8@704A7@4A7@0:6`0:6`4;708<7@<=7P@>7`D?80D?808>6P4=6@4=6@0<600<
604=6@8>6P<?6`0<7P0=7`4?8@<B8P8B7`0@7@0>6P0<600<5@0=5P0=5P0=5P0;5@0;5@<=5`D?6@0:
4P0:4P0:4P094`0;5`0<608=6`<>70TC7@TP:0PZ<1lm@Si>E0H>5@0830HG6P0N7`0D608H7P0@6ahh
ATU`Oc9VMP0iBBAaM2=[LciiRBEBI`@S>00>7@001Q<O7`@E30/L4aHW7R4b:Bm0=d=DBeY[HVYkLXF?
PhJ@Q8VCQhbFRY2JSYBNTYJPU9RRUY6HTINNUiVPVIJMUYVPVJ6XXJ:YXYjUWZ6UVYnSV9jRUifQUYfQ
UYnSV:6UVZ>WW:2UUYnSUijRUijQV9nQVj2QWInPWYfNW9>MTI:LT9>MTINOU9fSV:2VVj:VVj6UVZBU
VjBUVjBUVj>TVZ6RV9nPUYbMTi^LTZ6UVYnSV9fQUY^OU9^OU9^OU9bPUIfQUYRLTI^OU9nSV:>WW:BX
WJ:VVinSV9fQUYJJSY^OTiZMU9:DSY6BT9ZIVinNXYnMXifNU9fNU9bMTibMTibMTi^LTYZKTIVJT9bS
SYRORYFKR9NMS9^OTinSV9nRVIfPUi>NRYNPS9ZRTIbQTYbNTYZKTIbJTYbJTYJIRYJIRYFHRI>FQi2C
Q8nBPi6DQI>FQhf@P8jAPI2CPi:EQY>ERIBFRYBERiBERhnBPi:EQYJIRYVLSIVLSINJRi>FQi2CQ8nB
Pi2CQ96DQI2CQ92CQ96DQIFHRIVLSIJGSIJGSINHSYVJT9^LTYjOUJ6RV:>TVZ2SU:2SU9nRTijQTY^N
SiNJRi>FQi6DQGf1KWIjIfQ/FF=WE7AhIH^?O8jBOh65LWZ5LGV4L7J0L7AmL7AlLWIlMgQmNgUnOFUc
If1[HF5]IibZZ5ASIY6SZYRZ]I:U/XVOZhjT/9BZ]YF[]iF[]iN]^Ijd`:FkakG4cK2ob:Zi`ZZi`Zfl
aJnnajjmaZbka:Fc^JBb^:6_]IVW[I2NY8bJX8nMXi>QYjZi_:6a^9^[]iZY^INS]IFM[YbO[ZFU/i6>
Q[^hXlG1W/o6Y=O8[]2oZ]?7Zl_3W/g3YLg3YLk4Y/k4Y/o5Ym36Z=36Z=36Z<o5Ylo5Ylo5Ylo5Ylo5
Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ylo4
Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/_0Y<_0Y<c1YLg2Y/k3
Ylo4Z000cLFncLFncLFncLFncLFncLFncLFncLFnblC1blC1blC1blC1c<G2c<G2cLK3cLK3cLK3cLK3
cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3c<G2c<G2c<G2c<G2c<G2c<G2
c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2bLK2b<G1alC0alC0alC0alC0b<G1b<G1c/O4clS5
c/O4cLK3blC1blC1cLK3clS5cL[2blS0bLJnbLJnb/Nob/Nob<Fma/>kb/G6bLC5bLC5bLC5b<?4b<?4
b<?4al;3b[o1c<73cL;4clC6clC6c/?5cL;4c<73`[nk`l2la<6ma<6ma/>oa/>oalC0b<G1aK^kbKno
c<;2cL?3cL?3c<;2cL?3c/C4c<Nn_kZadLc3_;N^al:ibLBkNGA[H5]BI5eDI5eD?cP_RhAkf=78`kbc
aKjeb<6hblC1b/?0b/?0bL:ob/?0blC1c<G2c<G2c/FlclJmclJmclJmclJmc/FlcLBkcLBkaL2gaL2g
a/6hal:ial:ib<>jbLBkbLBkblJmblJmb/Flb/FlbLBkbLBkb<>jb<>jblBkblBkb/>jb/>jbL:ib<6h
b<6hb<6hc/Bmc/Bmc/Bmc/BmclFnclFnclFnclFnbL2fbl:hcLBjclJld<Nmd<Nmd<NmclJlcLJmc<Fl
c<FlblBkblBkc<FlcLJmcLJmdLRoclJmc<>jakje_kJ]]ZfT[ZFLZJ2GYin>ZJ2B[:BG/jZP^[>Z_[Ra
`;Ze`KZga[Zh_[J_bL>h`knd^K>/d<_:al37Qgj;81lX7Q`X6aPX5Q@W4a8R3Q0J314D2a4@0`PG0`PG
0`PG1PPJ2@TK2PXL2`TM30XN20`G20`G20`G20`G20`G20`G20`G20`G30dG30dG3@hH3@hH3@hH3PlI
3PlI3PlI4Q4E4Q4E4Q4E4Q4E4Q4E4Q4E4a8F4a8F4@lE4@lE4`lE4`lE5@hE5PhE5`lF5`lF3PL>3`P?
3PL>3PL>3@H=2`@;2@8920480`H;1`L=2P/?410@5aDD6APD6aPC6QP@7QTH7QTH7QTH7APG7APG71LF
71LF71LF9QhG9QhG9AdF9AdF9AdF91`E91`E91`E:B<N9R0K8Q`G91/G9a`H:1dI:AdI:AdI9b0G9b0G
9b0G9b0G:24H:B8I:b@K;2DL9QlF9b0G:24H:R<J;BHM<2TP<b`S=2dT?C<Q?38P>c4O>S0N>BlM>BlM
>BlM>S0N<bhO<bhO=2lP=2lP=C0Q=C0Q=S4R=S4R=c<Q=C4O<bhO<2/L;bTL;RPM;bTN;bPO:RXL:RTK
:BPJ;2TK<2XM;bTL;bLJ;BDH:bXL;2/M;RdO;bhP;RdO:bXL:2LI9RDG:2@I:BHH:bPI<RhK>CDM@3`S
AT8UBTHYCdDcDDLeET/gFTlkGU4kH58kH58kH58kDdheEDheETlfF4hfFThfFDdeFD/dFD/dDd/dDTXc
DDTbD4PaCdL`CdL`CdL`CdL`Ad8]AT4/A3lZ@C`W?STT>cHQ>C@O>3<N=c<P=c<P=c<P<c4O<30P;BdM
:RXL:BTK9RTP82<J6adG6AXF61TE4a@B3Pl=2`/;000400<81PP@30hF3@hH30`H20PD1@DA00/C0@`D
0``F10dG1`dJ20dL2@`K2@`K2a4L20hI0``F0``F1@lI1A4K110J0PhH00hJ0PhJ0`lK1@lI1PlH1@hG
1PhE1PhE110F0PhD0PhD0`lE110F1A4G1A4G110F0`HD0@D@00@;00D900D900@;000:000:000;0Q<L
3ahW;S]3GFI_00P?20hC00<83A0O1`hM010M1Al[7T9<;UeU7UAK0Sa2<TY@:3i462/b2ATP0PdE00PA
1@XC1``E10h>1Q0@1a4A1a4A1Q0@1a4A2Q@D3ALG8BP[;3@d?dM7EEeLJgE_OhZ2SYVAUj:HU:2DV:BH
VJBLUj6KVJ6PWZFXWJ>XVInVW:6TW:6TWJ6RWJ:QWj:PXJ:NXJ>MXJBKW:6HW:6HW:6HW:6HW:6HW:6H
W:6HW:6HWJ:IVIjEUIZAUY^BVIjEWJ:IWJ:IW:6HWZ:GWZ:GWj>HWj>HX:BIXJFJXJFJXJFJWJ6FW:2E
VYjCV9bAV9bAVIfBVYjCVinDW:BIX:JKXJNLXZJKWj>HWj2FWj2FXJ2FVifGVI^EUYRBUINAUINAV9ZD
VifGWInIVIfBVYjCVYjCVinDVinDW:2EW:2EWJ6FYJNQWZ2JUiVCV9ZDWZ2JXZBNX::LW9jHUinHUinH
V:2IV:2IVJ6JVZ:KVZ:KVZ:KVj>LVZ:KVZ:KVZ:KVZ:KVj>LWJFNWJFNVJ2IVJ2IVZ6JVZ6JVj:KW:>L
W:>LW:>LTIVBUIfFVJ:HWZJLXJNLX:NJWZ:FW:2DWJ6EWZ:FWj>GX:BHXJFIXZJJXjNKXjNKYJRIXJBE
WJ2AVIb=UiZ;UIR9TYF6T9>4RXUkRHQjQhIhQHAfPh9dP7maOgi`OWe_PXEfOh9cNgi_O7m`Oh9cPXEf
PXEfP8=dN89aQiB6AUM<>U1;=di:EVeYGWA_D6AO@Tm=CeaJHFaYSYVGKGUkRYZQOHjKSj>dQ9VXRj2_
SZ6`QYVXQ9FRR9VVRYbWRIVURI^VRYbWS9jYSInZSj6/Sj6/Sj6/Sj6/R:>]RjJ`S:NaS:JbTJ^iU[2n
UZnoTJZjSJK0SjK0RInhP9>XOHbOPhnQRiFVSiRVOH:0^[FVd<:Vd/>Sc/FZa/:Yd<VXcl2Id<FWd<FW
d<FWd<FWd<FWd<FWd<FWd<FWclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBV
clBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBV
clBVclBVclBVclBVclBVclBVc/>Uc/>Uc/>Uc/>Uc/>Uc/>U003<a;g<a;g<a;g<a;g<a;g<a;g<a;g<
a;g;a<7;a<7;a<7;a<7<aL;<aL;=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=
a/?=a/?=a/?=a/?=a/?<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<
aL;>blO=b/K<bLG:al?9a/;8aL77a<37a<34_kc5`;g6`Kk6`Kk6`Kk6`Kk8`l39a<7@b/?>b<7<a[o<
a[o=al3=al3;aKk9`kc5`[k5`[k6`ko7a<38aL79a/;9a/;:al?:`Kk;`[o<`l3=a<7=a<7=a<7=a<7<
`l3<a/7<a/7;aL3;aL3;aL3:a;o:a;o:a;o;`[k>aL7@al?@al??a/;>aL7?a/;@al?Bbl;9`[WLeLc;
a;_Cc<?:`kYcK6=BBd9LDdYOETe0=bj9P7OId<OBbL3Gc/GGc/G8`;W8`;W7_kS7_kS7_kS8`;W9`K[9
`K[:`KS:`KS;`[W<`k[;`[W;`[W:`KS9`;O?b;o?b;o?b;o?b;o?b;o?b;o>akk>akk@bL3@bL3@bL3A
b/7Ab/7Ab/7Bbl;Bbl;:`k[;a;_=a[g>akk?b;o?b;o?b;o>akk?a[g?a[g?a[g>aKc>aKc>aKc>aKc>
aKcCb/3Cb/3Cb/3Cb/3Ab;k?a[c=a;[;`[S<aKc;a;_;a;_:`k[9`[W9`[W9`[W9`[W@akk@akk@akk?
a[g<`k[9`;O6_KC4^k;9`K38_k77_k;8_kG9`[W7`Kc5_[_1_;W5^k^n]K;7`K[3_[F`[JFg/k:WXJI/
Ig0?4AT?41X=3A/<2Qd:21/61aD521042@`011<011<01A@211H51AL51AL611L71AP52A@52A@52A@5
2A@52A@52A@52A@52A@=3QP>3aT>3aT>3aT?41X?41X?41X@4A/A41@B4ADB4ADB4ADC4QHD4aLD4aLD
4aLF5ATG5QXH5a/K5a`N61dO6AhQ6QlR6b0K5a`K5a`K5a`K5a`J5Q/I5AXG4aPF4QL@3a<B4A<G5ADK
6APQ7QXS81PS8ALS8ALT7QTT7QTT7QTS7APS7APR71LR71LR71LY8aPX8QLX8QLX8QLW8AHW8AHW8AHV
81DT8ATT7QLR71DS6a@W7AHW7AHX71HV6Q@V7aHV7aHV7aHV7aHW81LX8APZ8aXZ8aXX8APX8APY8QTZ
8aX/9A`^9ah`:B0a:R4g;A`g;A`g;A`g;A`g;A`f;1/f;1/f;1/_:Q/_:Q/`:a``:a``:a``:a`a;1da
;1de<24c;Qla;1d_:A`]9a`]9a`]9Qd^9ahZ:Q`Y:A/Y:1X/:A/^:ad`:Qd^:1/]9APV91XW9A/X9Q`X
9Q`W9A/U8aTS8ALQ7aDO7A<R7A@T8A<Z9AHa:aPg<Qdl=Qlo>R54?BY8?b]<@bmAAS1GBc=ICCEKCSAK
CSABCCACCSEFCcIICcMHCSIICCEGBc=GBC9GCcQECCICBcA@B35>ARm;@ba:@R]9@BY7@Re6@Ba4?bY2
?BQ0>bHo>RDm>2<l=b8h=24g<b0g<b0d<R0`<20^;Qh[:adY:A/T9ahO8QTK7ALJ71HI6QHF5aDB4a4@
4@l931062@h21@X00@T000T00@/20Ph411000@X00P/010d01Q4221D32AH22AP32QT311810Q000@l0
0a4221D52aP22QL021D63Ql63ad83ah841d:41/<41/;41T<3QP221<11a811a8221<32A@42QD32A@2
21<=31`;2aT72A<11@X00@H000X111862AP04A`87RT462<U=SmLK7<01@d01P`>61l04aP68bP/BDi9
IV/eCeD37B<02a4272846A/04aH030l01@T00`L00`P21P/520d01PD020L12@P12@P020L12@P32`X5
3@`12@P63``<5A8A6aDG8QXS;R@c?c=0C41MJEebOW:8Th^EWiVLY:>QZJVSZZfRZ:fLXJ:LXJ:MXZ6M
XZ2OXijQXYjQXifQXifLXIRLXIRLXIRLXIRLXIRLXIRLXIRLXIRMXYVJWiJFVi:FVi:IWYFLXIRMXYVL
XIRNXYNNXYNOXiROXiRPY9VPY9VQYIZQYIZMXIJKWiBIWI:HW96HW96HW96JWY>KWiBKXiROYIZQYibR
YY^OXiROX9JNWiFQX9JLWiJKWYFIW9>HVi:IW9>JWIBLWiJNXIRPY9VPY9VQYIZQYIZQYIZQYIZRYY^R
YY^OXYVIW9>EV8nIW9>RYIbY[:>Y[:>VZJ2OZ9jOZ9jOZ9jOZ9jNYifNYifMYYbMYYbMYYbMYYbKY9ZJ
XiVJXiVIXYRJXiVJXiVKX9NKX9NMXYVNXiZPYIbQYYfRYijSZ9nLY9fNYYnPZ9jQZInRZ9fPY9RMXIFJ
Wi2PY9ROXiNMXIFKWi>HW92EVHfDV8bCUh^;SWn8Rgb5R7V4QgR4QgR4QgR2QGJ0PgB6QGN6QGN5Q7J4
PgF4PgF3PWB2PG>2PG>4QgR1Q7EoPW>0PgB3QWN4QgR4QgR2QGIfP6n2Sh54EDXcAd8/@cm8Ge]?IF13
Ee8gA48jB4A?FUN3SX]TL721TIQjRiQoTjB4VJR:Wjj=X:n7VZV4UjB8VjR<WJZ:VjRBYkJCZ;NDZKRF
ZkZG[;^H[KbH[KbH[Kb:Y[6<YkF<YkF:Y;B;YKF?ZKZ=Y[Z7X;AoV[F5W[R6W[J2Ujf1TZN5TjF8UJF9
TjB8RhW3_:_A`jK?`:38_jC4_jKCbZWCa9g@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO?a:K?a:K?a:K?
a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?
a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K=`ZC=`ZC=`ZC=
`ZC=`ZC=`Z@00<c4_Lc4_Lc4_Lc4_Lc4_Lc4_Lc4_Lc4_L_4`L_4`L_4`L_4`Lc5`/c5`/g6`lg6`lc5
`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/_4`L_4`L_4`L_4`L_4
`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`LG1_<G1_<K2_LO3_/O3_/S4_lW5`<W5`<S5
`<S5`<W6`L[7`/[7`/[7`/W6`LS5`<K0^LFo^<Fo^<O1^/[4_Lc6_lc6_l[4_LW5`<W5`<S4_lS4_lS4
_lO3_/O3_/O3_];9aM78a<o6`/g4`<c3_l_2_/_2_/_2_/c2^l_1^/[0^LRn]lNm]/Fk]<Bj/l>i//6j
/L:k//>l/l:k/[nh[kjg[[nh[l2i/;je[;R_Y/Nn]KZaZ<:i/;N^YF]RFDe4>da1>E=8@3T^9VmTG;>X
X;J[XkbaZKJ[XkjeZkfdZ[bcZKbcZKbcZKbcZKfdZ[fdZ[jcZknd[<2e[L2e[L2e[L2e[Knd[;jcZjbS
VZbSVZ^RVJZQV:VPUjVPUjROUZROUZVPUjVPUjZQV:ZQV:^RVJbSVZfTVjfTVjBMU:JOUZZSVZjWW[2Y
X;2YX:nXWjjWW[B[W[>ZWK>ZWK:YW;:YW;6XVk6XVk2WVZVOUJRNU:JLTZBJT:2FS9bBR9V?QIN=PiB=
Q9B=Q9><Pi6:PI29P8n8Ohj7OXj7OXV0MhV0MhMnMHElLh=jLH1gKWmfKGedJg]dIGQaHWE]H71YH6]U
GVIPFemJEe]FEDa5B44k?4U4@DQ5@3@c;c8`;b@S9@000`4430433@834@824P8250414@013`013000
4P004P004P004P004P414`804`804`<540<540<540<540<540<540<540<540/<5P/<5P/<5P/<5P`=
5``=5`d>60d>614?5A8@5Q8@5Q<A5a@B61DC6AHD6QLE6aHH6AHH6ATH6Q`I6adJ720K7B0K7B8K7QhK
7AhK7AlL7R0M7alL7QlL7QhK7AdJ71XE5Q`G61lK6R<O6RLQ6RPS6RXT6BXT5bXQ62XQ62XQ62TP5bTP
5bTP5bPO5RPO5RTS5RPR5BPR5BPR5BLQ52LQ52LQ52LQ524O520N4b4M4R8N4bDO52LN52DL4R8I3bDN
5BDN5BDN5BDN5BHO5RLP5bTR6BTR6BDN5BDN5B@M52@M52DN5BHO5RLP5bPQ638Y6c<Z73D/7SH]7cH]
7cD/7S@[7C<Z73<]83<]83<]83<]83<]838/7c8/7c8/7c@^8C<]834[7RlY7RhW7RdV7BdU7RhV7b@T
62<S5b<S5bDS62TU6RTU6RTS62LQ5QlL5alL5ahK5QhK5QdJ5A`I51/H4a/H4aLC3QPD3a`F3alJ4BDO
4R/T5BhW5S0Y63D`6cTb7S`f7d<k94Y0:4e4:E56:e97;4m9<U5;=5===UM?>5U>>5M<=UI9<eE8<UI>
=eE==U=;=518<De5;T]3;4U1:TQ0:DI1;4E0:d@o:T<n:D8m:44l9d4l9d0k9STe8STe8STe8SHd8S8b
8S0`82d]7b`/7R4U6QlR6AdP5a/M5a/L61/L61TJ61HG5ADI6PlB5PL:3P021`001P001P0020002P01
2@012@002P002`002`013P013P013`004000400140444`875P8960485`075@004@004P014P014P01
40023`013P002`054P064`07500750085@07500750064`003@003`033P022@001P002`L:6A4C9@0K
9QDa?1`f@S]DGUaaN@0020001aXZ<AA6@SERGceRH20j>PdJ71<F6QH@5@X01P0<2P0=2`8=2`<;2PD;
2PD:2@H820P820@;20L>2`T@3@T@3@P?30P?30T@3@XA3Q4I4PdF30`E2a8L41`V6R4[7QdW6QLR4R<]
8DI?AFmgL8R?RY:IUYRNWIbQXYjSYYbRXIbRXIfRX9fRX9nSWZ6RWZ6SWJ6SWIbQV9bQV9bQV9bQV9bQ
V9bQV9bQV9bQV9bQV9ZOUYNLTiNLTiVNUI^PUibQV9bQV9jRUijRUijRUijRUinSV9nSV9nSV:2TVIbP
UI^OU9VMTYNKT9NKT9RLTIVMTYZNTiZRUijTVInUVZ2TVIjRUijOUIjOUJ6PUYbPU9bPU9bPU9bPU9bP
U9fQUIfQUIjRUYVMTYVMTYVMTYZNTiZNTi^OU9^OU9^OU:>VWIjQV9VLTi^NUJ6TVjFXWjBWWZ6TVibT
VYbTVYbTVYbTVYbTVYbTVYbTVYbTVYfUVifUVifUVijVW9nWWJ6YWj:ZX:>[XJ:WWZ:WWZ:WWZ:WWZ>X
Wj>XWj>XWj>XWifVW9fUVibTVY^QUYROTYJJSYBGR9:EQXfBPhbAPXZ?P8R=OXJ;O8B9NX>8NH:7N8>6
Mh23M7f0LGf0LGf0LGj1LWaoL7]nKh:1Lh:1Lh>2M8B3MHF4MXJ5MhJ5MhN6N8B7N8>6Mh>6MhF8NHN:
NhN:NhJ9NXB7N7MoKWj8NdADBBDi=1db;cA9ASY>BC11?BLe<Ad[9cQ4?WJ1OUQTI7N7SH6BWgN;W7Z?
WWjCXWnDXg^@WgV>WGbAX7nDXgjCXWZFYg^GZ7fIZWjJZh2L[H2L[H2L[H2L[H:S/hBU]H>T]82P/h6P
]HBS^8:Q^7bK/W>A[7ZG/X2I/gjEZgf@YGj=X7Z8VWN4U8:6P;jhYM;3Xlo0WlW1Y<BoY];8Z];3W<o4
Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/k3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3
YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3
YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLg2Y<g2Y<g2Y<g2Y<g2Y<g2Y000c<Bmc<Bmc<Bmc<Bmc<Bmc<Bm
c<Bmc<BmblC1blC1blC1blC1c<G2c<G2cLK3cLK3c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2
c<G2c<G2c<G2c<G2c<G2c<G2blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1
blC1blC1b<BobLG0b/K1blO2c<S3cLW4cLW4cLW4`l2k`l2ka<6la/>nb<G0b<G0alBoa/>ne/k7e<c5
dLW2clO0clO0cLFnb/:kb<2ial:ia/6h`kje_kZa^kJ]]k:Y]:nV/jjUXIR?WYF<VY68UXf4TXV0T8Mn
ShImShImS7mgRgifRWeeRGadQgYbQWUaQGQ`Q7M_P7M]PGQ^P7M]OWE[Ng9XNW5WO7=YOWE[MfeSM6YP
NW1VKVAJMfeSMfeSCD<iA3X`Ac/aD4@j>blUDdLmN6aRNFeSNfmULVILKFAFK6=EJf9DJV5CJV5CJV5C
Jf9DJf9DK69HK69HKF=IKVAJKVAJKVAJKVAJKF=IL6ILL6ILL6ILKfEKKfEKKVAJKVAJKVAJKVAJKVAJ
KVAJKfEKKfEKKfEKKfEKKfEKJV5GKFAJLVUOMVeSN6mUN6mUMVeSM6]QL6QGL6QGKfMFKVIEKFEDK6AC
Jf=BJf=BJV1FJEmEIeeCI5Y@HEM=GUA:G598Fe57ETe3EDa2EDa2DdY0DDPnCdHlCTDkCD@jCD@kBd8i
B3lfAC`c@cXa@CP_?cH]?cH]@3TZ?CDX=c4V<RdT;RPS:2<P8QdL7ATH8AXQ40`B4`lD5A@F2P`=2P`=
30lC0@@8004:004<004?008A0P8D0`8F108F108F000C000C000B000B000B0@4A0P4A0P4A0@<>0@<>
0@<>0@<>0@<>0@<>0@<>0@<>10D?10D?1@H@1@H@1PLA1PLA1PLA1PLA3@dC3@dC3PhD410F4A4G4a<I
51@J51@J5ALG5ALG5ALG5aLG6QPH6QPH71LH71LH61PH61PH6QXJ6a/K6a/K6a/K6a/K6QXJ6A@C71LD
8Q`G91hG9QlF:20C:B8C:R4C:R0F:R0F:R0F:AlE:AlE:AlE:1hD:1hD924B8b0A8b0A8b0A8Ql@8Ql@
8Ql@8Ah?7QhB7adB7adB8QhC920E9AlD91/A8AP>8adF8adF8Q`E8adF8adF9AlH9R0I9b4J8adF8Q`E
8A/D81XC81XC81XC8A/D8A/D<2PK<RXM=BdP=blR>30S=blR=BdP=2`O<RhS<BdR<BdR<2`Q<2`Q;b/P
;b/P;RXO:BDJ:2@I9b8I9R4H9AlH91hI91hI91hI6AXA61T@6QP@6aTA7Q/C8A/D7aTB7aL@6QHE6QHE
61@C5a<B5a<B5a<B5a<B5a<B4`l>5A0?5Q4>6Q@?71H?8AXA9A`C9QdC:2@A:RLB<2/F=S0I>cDN@CXQ
A3dRB3lTB4@/BTH^CdTbDT`eEThgEd`fEDXdETTcD4PaD4PaD4PaD4PaCdL`CTH_CDD^C4@]AD0[AD0[
A3lZ@chY@SdX@3/V@3/V?cXU>SHS>SHS>SHS=cDS=3@T<S8R;blQ;RhP7b<H8BDJ82<J7B0G7AlI824M
7b0L71dI61dL5a`K51PI41<G2PdA10L<004600061P4:104:0`8;0@<=00D@00LA00TE00XF00<D00DE
00HF00PH00TI00XJ00XI00TH01@V01HV01LW0APW0aPW11LT11PS0aLR0ALS0aTU1A/W1A/W11XV0aTU
11XV1A/W2QXZ3Ah[42<[42<X3B0U3ahW524_6BHf5cM253@o7Sa7=eAMA5iU0QTQ738h@eIMBWE/:Di6
1bHO0Q<?20l<4@d<7a<C;AdN4ATB4QXC51/D5QXD5QPB4aD?4A4;3`l941HA4QPC5A/F5Q`G51XE4aTD
51XE5A/F6bDH72HI7bXJ8RdM9S4Q;3LW<C`/=D4_CeQ>K7E[S9B=W:BMWjJQWjJSX:JUX:JUW:>NW:>N
WJ>NWJ>NWj>NXJ:NXJ>MXJ>MW:6HW:6HW:6HW:6HW:6HW:6HW:6HW:6HW:6HVYnFVIjEV9fDVIjEVYnF
Vj2GVj2GWJ6FWJ6FWZ:GWZ:GWZ:GWZ:GWZ:GWZ:GVinDVYjCV9bAUYZ?UYZ?Ui^@V9bAVIfBV:2EW::G
WZBIWj>HWJ6FWIjDWIjDX9nEVYn@Vj2AW:6BWZ>DWZ>DWJ:CW:6BW:6BWJ6FWZ:GWj>HX:BIXJFJXZJK
XjNLY:RMYJVNXJFJW:2EWJ6FXJFJXjNLX:BIWJ6FW:BIW:BIWJFJWZJKWZJKWjNLX:RMX:RMXZZOXZZO
X:RMWjNLWjNLWjNLWjNLWjNLXJFJX:BIWZ:GW:2EVIfBUi^@UIV>U9R=SIF;S9B:Ri66R8n2Qh]oQXUj
QHQiQ8MgN7]/NGa]Ngi_OX5bP8=dPhIgQHQiQXUjS8n0RHamQHQiQ8MhPhIgPhIgPHAeOh9cPH1bPX5c
Ph9dQ8=eQHAfQhIhR8MiR8MiPhIgQ8MhQXUjQhYkR8]lR8]lQXUjQHQiNH5`NXAgB5Q=6b`X3b@Q7c@a
93Pc7Rl[6bTU2QPB:CD_JWI`CEYHJg^1SZ2[P9FTLXRDLhRGLXVHLHRGKhRHLHZJLh^MLh^MLI6XLi>Z
M9B[MYJ]MiN^N9R_N9R_N9R_NijbOZ6eOJ2dNifdOIngPJ>kOj2jNIZdMYB_NIRaNIF]M8bRL8JHL8:C
KGf=IgJ6Kg9Y/Z^Gc[nNeLFQd<FYb<6XdLJXckjGclBVclBVclBVclBVclBVclBVclBVclBVc/>Uc/>U
c/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>U
c/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>UcL:TcL:T
cL:TcL:TcL:TcL:T003;`kc;`kc;`kc;`kc;`kc;`kc;`kc;`kc;a<7;a<7;a<7;a<7<aL;<aL;=a/?=
a/?;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7:`l3:`l3:`l3:
`l3:`l3:`l3:`l3:`l3:`l3:`l3:`l3:`l3:`l3:`l3:`l3:`l38`[_9`kc:a;g:a;g9`kc8`[_6`;W5
_kS=b/;;b<38aKg7a;c8aKg6`k_3`;S0_KFn]Zni/JZaZJ:YXIZQVI:ITHZARH:;PgadJf9bJF1^IEaY
H5MTFe9OETeLDdYJDDQNDd]LDDUICTIFBd=CB41BAcmBAcmBAcmA@C]A@C]A@C]@@3Y@@3Y??cU??cU?
?cU>A3Y>A3Y<@SQ:@3I8?SA9?cE<@SQ?AC]?@cMCAc]CAc]9?C5?@cMDB3a9?C5AACU>@3AHBSi=?c=?
@CEFB3aEAc]FB3aA@cMKDD1KDD1ICciHCSeHCSeHCSeHCSeICciICD5JCT9KCd=LD4AMDDEMDDELD4AL
D4AEBCeEBCeFBSiFBSiGBcmGBcmHC41HC41GBcmGBcmFBSiEBCeDB3aCAc]BASYBASY<@cI?ASUCBSeF
CD1GCT5EC3mCBSeAB3]DBSUDBSUCBCQBB3MAAcI@ASE@ASE?ACACAceCAceBASaBASaBASaBASaBASaB
ASa>ACQ>ACQ>ACQ>ACQ<@cI:@CA8?c96?C13>S52>C12>C11>2m1>2m1>2m2>C12>C0m=bXj=2Td;bHb
;2D]:B@X92<S7QlO6Q/F5Al921881Q8<31X82AL82AL=4A`B5R401AH01AH011H011H31AL61AT81A/9
1Q`00QL00QL011L211H411@51Q@61Q@61Q820Ph20Ph20Ph20Ph20Ph20Ph20Ph20Ph20`d20`d20`d3
10h310h310h41@l41@l51`l51`l621082Q892a<:31@;3AD<3QH?4a@@51DB51DD5QLG5QPJ5aTJ5aTK
61XI61XI61XK6Q`L6adM71hM71hM71hL6adI51<M61DS7APU7aPV7aHW7a8X8A8Z8A<Z81HZ81HZ81HY
7aDY7aDY7aDX7Q@X7Q@P7a4P7a4P7a4O7Q0O7Q0O7Q0N7@lN7@lN7Q8M7A4M7A4P7Q<S7a@R7Q<Q6a0N
60dO6aHO6aHO6aHO6aHP71LQ7APS7aXT81/S7aXR7QTQ7APP71LO6aHO6aHP71LP71LV8QLX91T[9a`]
:Ah^:Ql]:Ah[9a`Y9AXS81PS81PS81PR7aLR7aLQ7QHQ7QHP7ADJ60hJ60hI5PhI5A0H50lH4a0G4PlF
4A0A4`dB4P`B4P`F4`hI5A0J5Q4J50lH4PdF51@F51@E4a<D4Q8D4Q8D4Q8D4Q8E4a<D40lE4A0F4Q4I
514L5A8M5a8P5a<P5a<P7@hQ7`dV8Q0Z9Q<a:aPf;a/i<Qhk=Ahl>BA1?2M5@2];A31@Ac=BBCEDBCED
BCE=ABi>ARm?Ac1?Ac1?Ac1>ARm=ABi<A2e5@2]4?bY3?RU1?2Lo>RDm>2<k=R4j=B0f<Qlf<Qlf<Qld
<R0a<B4_;al];Al/;1hQ9ATV:QhV:QlP8aXO8QTS9AlS9AlO81`I7Q`K81hL8B0J7ahF6Q/>4AD72Ph2
1@T400@300D100T41Ph62a@84A/:5R0;6R<B;3PD;SXG<CdI=D0I=d8J>4<J>TDK>dH7<Ch:<Cl;<cl>
=40A=ClA=ShA=CdA=C/<<c/>=Cd?=Sh?=Sh==3`>=CdA>40C>T8=<3X:;S@8:bh:;2`?;RlE<SHJ=SdP
>4@gF64UA4e4HFQLN7mBK78kDEI:GV<`A4TK:20>6a<;5PhB6Q<D6a@?4@/=3`TE5@l<4@P=4PT@4`XB
5@`E5PdE5PdE5PdF50`B5Q0D618G6aDG6aDF6Q@F6Q@G6aDI7ALB70/M9aHR;1/L9QDH8Q4/=RIGHE5l
QWJOYifX/:J_]jf//jbV[JJRZ:>NY9nJX9^LY9fLY9fMY9fMY9fOXifQXifQXYjQXYjLXIRLXIRLXIRL
XIRLXIRLXIRLXIRLXIRKX9NKX9NKX9NJWiJIWYFIWYFJWiJKX9NMXIJMXIJMXIJMXIJMXIJMXIJLX9FL
X9FJWY>IWI:GVi2EVHjEVHjFVXnGVi2HW96FWY>JX9FLXYNMXIJKWiBLWI>LWI>OWYBGW8fHWHjKX96L
XI:MXY>LXI:JWi2IWXnJWY>KWiBLX9FNXYNPY9VRYY^SYibTZ9fPY9VNXYNMXIJPY9VVZYnY[J:Z[Z>X
[:6X[Z>W[J:W[J:V[:6UZj2UZj2TZYnTZYnTZYnQYibMXiRGWI:BV8f=ThR:T8F9ShB:SX>9SH:7Rh25
RGj2QW]oPgQmPGIlP7ElPWMkPGIjPGAkOg=lOg1mP720PG60PG5mOVinOfn1PW:5QWJ9RWZ=SWj@TH6B
Th>9S7f7RW^4QgR3QWN3QWN3QWN2QGJ0PgB3PWB4PgF4PgF5Q7J6QGN6QGN7QWR7QWR2QGJ4QgR6RGZ7
RW^7RW^6RGZ5R7V5R7V0QWEjPgICHEHC92086aPC9R<F9b<E920I9b485`lR;bMOJfE4DDmIJVfBYJf:
X:ahSYYdS9QdRiYdSIedSYmcSZ9bT:=dTJI`U:aaUJecUjmeVK5fV[9fV[9fV[9fV[9lWk=nX;MnX;Mk
WKElW[J0XK]mWKYgUkAiVZiiV:efTJE_QiU_Q9=dQI9eQI5cPHe[Kf>`Zi;@`9cGaJ3AaJW7`:OAaZS@
_IS>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=
`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=
`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC<`J?<`J?<`J?<`J?<`J?<`J<00<_3_<_3_<_3_<_3_<_3
_<_3_<_3_<_3_<_4`L_4`L_4`L_4`Lc5`/c5`/g6`lg6`l_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4
`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3
`<[3`<[3`<[3`<W2^L[3^/c5_<g6_Lg6_Lc5_<[3^/W2^Lg4^lBk/[R_YZfTVjFLTibCRY:9P8^2NG9X
HFeSG6MMEV9HDEeCC5Q>Ae98@De3?555@E14@4i2?Ta0?4Xn>TPl>4Hj=TDi=DDi=DDi=DDi=DDi=DDi
=DHj=TLk=dPl>4Hg=DHg=DHg=DHg=DLh=TLh=TLh=TLh=TDj<TDj<T@i<D8g;d8g;dDj<T]0>4m4?5=5
>Ee?@e]=@EI8?5U;?eI8?5A6>Ui@A5A2=eU7?5a:?eU7?5E3>5E3>5U7?5U7?5I9>eE8>U=6>595=e54
=U54=U54=U95=dm3=e14>596>U=7>eA8?5A8?5A8?5=7>eA6>UA6>UE7>eI8?5M9?EM9?EQ:?UQ:?UM9
?EM9?EE7>eA6>U94>512=Tm1=Di0=4]2=De4=dm6>E58>e58>dm6>De4=da3=UI:?UI:?UE9?EE9?EA8
?5=7>e=7>e96>Tm3>Dm3>Dm3>E14>U96?5A8?UI:@5M;@EYAA5]BAEaCAUeDAeaCAUYAA5Q?@UM>@Da3
>T]2>DU0=dLn=D@k<T4h;clf;Che;3H`9C4]8RhY82PT7bDR7R0L6aTG5aDB51/K9a<D8Q0?8a4A:@d>
:PD68P4480H:8`<99P488@076`045P444`@45PL56@X46`436`436`856PD76@P860T:60X:5P/<5PH6
4PH64PH64PH64PH64PH64PH64PH64PD640D640H74@H74@H74@L84PL84PL84P42304230833@<43P@5
3`D640H74@H74@862`@730L:3`/;4@h>51<A5aLC6APD6Q<C6A@D6QDE6aLG7ALG7ALG7ALG7ALG7ATD
5AhI6R<O7RDQ72DO62@O5RPR5bXT5bXQ62XQ62XQ62TP5bTP5bTP5bPO5RPO5R4O5B0N520N520N51lM
4alM4alM4ahL4Q/L4aXK4Q/I4A`J4QhK4b0J4ahH4AhF3a`H4a`H4a/G4Q`H4a`H4ahJ5AlK5R0L5a/G
4Q/G4QXF4ATE41TE41XF4A/G4Q/G4QXG3a`I4AdJ4QhK4alL51hK4adJ4Q`I4A/G4Q/G4Q/G4Q/G4QXF
4AXF4AXF4AXF4ATF3QTE41XF4AXE4QXE51TD4aLA4QLA4Q4B3Q0A3A8A3A@C3aTF4QXE4QTD4ALB3a<D
4Q@E4a@E4a@E4a@E4a@E4a<D4Q<D4QDD41DD41TF4QXG4a`G51hG51dF4alF4a`J41dK4AhL4B8N4bLQ
52XU5RlX6C4Z6c8^6c@`7CXd8Chh9D<l:DPn;4Y0;T]1;da4;Da4;De5;Te5;Ta4;DY2:dLo:4Hn9d<n
:D8m:44l9clj9C`g8SXe83Td7cPc7S8^6c8^6c8^6c0^72d]7B`/72TY6bPX6RDY7B``92``92@X7B0S
6R@W7R@V81lQ6a`R7A/Q71TO6QHK6A@I618G5Q4E5Q0D5@@31`@220411`012@022P053P064@094`0:
4@0=500A600D6`0H7P0M8`4S:@DW;@@b>P@b>PPd>`Te?0`f>`hg>Phg>Q0g>@`g>Phi?0lj?@dh>``g
>Phi?1@o@QY5B1i7BQe4AQi5@b]ABd9VH5inOGJCUhBNY8BOXh>NXZ:k_hZQXd=GF2Dg>2Lg=P8@3`L1
01XD3AhL50h?1PdB2A/T6Q@O5@08018E314D2a0C2Q0C2Q0C2Q4D2a8E31<F3AHG3QLH3aPI41PI41PI
41TJ4A`M51lP5aDP31TS4R<]73I0<59LC7AmL9>LSjN_Y:bdZZ^cZJF]XifTWI^RVijUWYjUWYZQVYbV
VYbVVYfUVifUVinSWJ6SWJ6RWZ6RWYbQV9bQV9bQV9bQV9bQV9bQV9bQV9bQV9ZOUY^PUibQV9^PUiVN
UIRMU9VNUIZOUYfQUYfQUYbPUIbPUIbPUI^OU9^OU9^OU9VMTYRLTIJJSiBHSIBHSIFISYJJSiNKT9BL
TIRNTiZPUIbPUIZNTi^LTY^LTYjMTiFISINKSiVMTIZNTYZNTYZNTYRLT9RLT9RLTIVMTYZNTi^OU9fQ
UYjRUinSV:2TVJ:VVZ2TV9nSUj2TV:>WVjBXW::VVZ6UVIjRUYfQUIZNTYNKSiBHS96ERHjBQXfAQHZ>
PXV=PHJ:OXB8O865NH24N7n3Mgn3Mg]mLGYlL7YlL7YlL7UkKgUkKgUkKgQjKWEkL7ElKgQlL7]nKgf0
L862LX>5LXF5LhR9NHV:NXV:NXV:NXZ;NhZ;Nh^<O8^<O7n2Lgf0LGaoL7f0LH23M8>6Mh>6Mh>6MhB3
MHF4MXF4MXF4MXJ5MhJ5MhN6N8N6N8:5MXB7N8J9NXJ9NXF8NHB7N8F8NHJ9NXF;NWb3MUmZH14P70HG
50dN6`lN6Q<Q7AXY8@lN5Qd[855NET1>BTQJFh^NYXZP[7bDX7R@W7F?WGRBXWJDYgBCZ7>CZWFE[6bB
ZVfCZfnE[G2F[W:H/7:H/7:H/7:H/82S]h:U^H2S]g^M]7^M]GbN]WVJ]7:C[GZIZ7ZGYWJ@WW6:U7N:
TWj@UhFCVHFAUGYmKK^dVMG4WM?2VlZoXLFkXmC6ZMO4Wlk3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLg2
Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2
Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<c1
Xlc1Xlc1Xlc1Xlc1Xlc1X`00b/:kb/:kb/:kb/:kb/:kb/:kb/:kb/:kblC1blC1blC1blC1c<G2c<G2
cLK3cLK3blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1bL:obL:o
bL:obL:obL:obL:obL:obL:obL:obL:obL:obL:obL:obL:obL:obL:oc/Nnc<FlbL:ia;fd_KJ]]JjU
[ZNNZJ:ISgmhQ7A]MFENJEUBHE5:F4Q1CclhB3PaBClhAcdfAS`eAS`eB3hgB3hgAcdfAC/d@S<a@S<a
@c@b@c@bA3DcA3DcACHdACHd?Rl]?c0^@34_@C8`@S<a@S<a@S<a@S<a@38d@38d@38d@38d@38d@38d
@38d@38d?Rl/?Rl/?Bh[?Bh[?c0]ACHcCChkDdA1DT8eGDe0ETHiEdLjG4`oE4@gDD4dE4@gFdPkET<f
H4e0HDi1FdPkGT/nGd`oHDi1GDe1G4a0FTXnFDTmF4PlEdLkF4PlF4PlE4LiEDPjEdXlF4/mFD`nFTdo
FTdoFD`nF4PkF4PkF4PkF4PkF4PkF4PkFDTlFDTlEdLjETHiETHiEDDhDd<fDT8eDD4dDD4dCd@fD4Dg
DDHhDTLiDTLiDTLiDDHhDDHhCCdfCCdfCCdfCCdfCCdfCCdfCCdfCCdfCSlfCSlfCSlfCSlfD44hDT<j
EDHmETLnEd`nFDi0Fe12GE94GU=5GE94G553FTm1Fe99FU58F4m6DdY1CTDlAche@ST`?SD/?c/`?3L^
=c@/=30[<2dY:RPX924S8AhP51PS4aDW20TS10<U1@@/000W000Q000U2Plf1@/^00LR00<F000?004?
0`8B1`<F000J008J0@@I1@HJ20PH2P`G30dG3@hH30XF30XF30XF30XF30XF30XF30XF30XF2@XD2@XD
2@XD2P/E2P/E2P/E2``F2``F10H@1@LA1@LA1PPB1PPB1`TC1`TC1`TC008<0@<=0`@>10D?20LA2`LB
3@TD3@TD2PTC2`XD30/E3@`F3@`F3@`F30/E30/E3`hB5A@F7A/K7Q`K7Q/G7AXB81hD928H91hI91hI
91hI8adH8adH8Q`G8Q`G8Q`G7AXE7AXE7AXE7AXE71TD71TD6aPC6aPC6ALF5aDD5A<B5a<B6A@C6QDD
6a<C6Q8B5Q<?5A8>5A8>5A8>5Q<?5a@@6AHB6QLC514=514=514=514=5A8>5Q<?5a@@61DA61D@61D@
61D@61D@5a@?5a@?5a@?5Q<>6QLC6QLC6QLC6QLC6QLC6aPD6aPD6aPD6aPC71TE7AXF7QXI7API71LH
6aHH6QDG41<A4A8@4A8@5Q@C61HE6aLF6aHE6A@C4a@@51DA5AHB5QLC5aPD5QLC51DA4a@@5AH=5QL>
61PB6aPC7ATD71PC7AHC71DB71TE6aPD6aPD71PC7aTB8A/D9AhE9QlF:2LC:bLD;2PE<2XG=2hK>C8O
?S@R@3HTA3`UACdVAclXB40YB40YAShWA3`U@SXS@3/V?cXU?cXU?CPS?3LR>cHQ>SDP>SDP=30M=30M
=30M<S0N;blO;RhN;2`N:b/M:RlP<cPY<SHZ9RXN8BDJ9BPO92LN7AlI6b8K6B0I5QdF51XE4aPF51TG
5Q/J61dL3Q4E30lC1`X?0PD:0008000700070007004700<900D;00H<00T>00dB0ADJ1a/P22X`2b/`
3Bdb42lb4C0a4c4b530`530`22LX2RTZ2RTZ1bHW1B@U2RTZ4c8c73/l3Rd/534^7c/e<4]2BF1HIgQd
PY2?TIjPX[JgZKjlUZRWCUaJ114?008010h851/F;RXU4@d81P<05aLA6adG2a8;3A@=82PQ7AlI71hH
6Q`F5aTC51PB4QH@4QH@4QH@6aX@6aX@6aX@6QT?6aX@7QdC8b8H:2LM;3@S=Cd/C5=4LGQ[UifB[;6X
[;2ZY:RRZJfWZJfWYZ^RXJJMXjROZZnV[;:WZ[2UW:JIW:JIWJFJWJFKWj>MXJ>MXJ:NXJ:NW:6HW:6H
W:6HW:6HW:6HW:6HW:6HW:6HVIjEW:6HWJ:IW:6HVIjEUibCV9fDVYnFWJ6FW:2EW:2EVinDVinDVYjC
VYjCVYjCVIfBUi^@UIV>U9R=TiN<U9R=UIV>UYZ?TYZ?UifBVInDVinDVIfBVY^AVibBWYfCUYV@UiZA
V9^BVIbCVIbCVIbCVIbCV9^BX:BIX:BIX:BIWj>HWj>HWj>HWZ:GWZ:GV9b@UYZ>U9R<TYJ:T9B8SI65
RXj2Qh]oQ8QlPhMkPHEiOX9fNgmcN7a`MWY^MGU]M7Q/M7Q/MGU]MWY^N7a`NWibO81dOH5eNWa`NWa`
NgeaNgeaNgeaO7ibO7ibO7ibN7a`NGeaNWm`OX5bPX=cPhEbQHEcQHEcQXIdQXIdQHEcQ8AbPh=aPX9`
PH5_PH5_OH1aO7m`Ngi_OH1aP8=dPhIgQ8MhQ8MhPh9dQ8=eQ8=eQHAfQhIhR8MiR8MiRHQjPhIgQHQi
QhYkQXUjQ8MhQ8MhQXUjRHamRhinOHAgIg9X41hJ1AHC2AXG31/G4b4M62LO4b<H528GAUA9B5IBAEMH
QiZQRZ2[OiRRN92LLhjLMi>TMYJYLi>ZL9:ZLIB^Mi^cN9bdNIfeNingO:2hOJ6iOJ6iOJ6iPZ>cPj>f
PJ6dOIbaOIbaOYfdNiVbM9:[O9NQNiNNNY:HN8bANX^>Ohf<O8V7Mh:0OX1]_[JHeLFKe<6KbkfPa[ZR
eLN[flFRc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6S
c<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6S
c<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sc<6Sbl2Rbl2Rbl2Rbl2Rbl2Rbl2R003:`[_:`[_:`[_:
`[_:`[_:`[_:`[_:`[_;a<7;a<7;a<7;a<7<aL;<aL;=a/?=a/?:`l3:`l3:`l3:`l3:`l3:`l3:`l3:
`l3:`l3:`l3:`l3:`l3:`l3:`l3:`l3:`l39`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o9
`[o9`[o9`[o9`[o9`[nf[jJ_Z9nRVi:?R7miLVURFe9@BD16?cIKB45C@3U<>C9:=c1>>cAA?SMA?SM?
?3E7>cE5>C=3=c53=c54>394>392=S10=2i3<SE4<cI5=3M6=CQ7=SU8=cY9>3]9>3]2<CA3<SE4<cI4
<cI2<CA0;c8n;C0l:bi2=3Y2=3Y1<cU1<cU0<SPo<CLo<CLo<CM1<C92<S=2<S=3<cA6=SM=?CiGAdQN
CTmNCD1TDdIGASUMC3mYF4]QD4=OCT5NCD1XEDQGA3MRCd9UDTEOC3mQCT5LBCaLBCaNBd=MBT9KB41J
AcmIASiHACeHACeHACeCASQDAcUFBC]GBSaHBceIC3iIC3iIC3iNCD1NCD1NCD1MC3mLBciKBSeKBSeJ
BCaHAcYHAcYHAcYHAcYHAcYGASUGASUGASU=@SA>@cE>@cE?A3I@ACMAASQBAcUBAcUGAd5GAd5GAd5H
B49HB49HB49HB49HB49FAciEASeDACaCA3]DACaFAciGB3mIBT5BAcUEBSaHCCmKD49MDTALDD=KD49J
Cd5JDDQKDTUKDTUKDTUHCdIDBd9@Aci=A3/m>2lj=B`f<b/c<2/a;B`/:RXX9BLR8B<H7RTF6R`71bD0
02@50S<:1SX91c/A448>4T8:3cH222D00aH000d000/10@l60a<001P001T00QL311P71aL92aH<3AL=
3aL?3AT?3AT?3AT?3AT?3AT?3AT?3AT?3AT:2aD:2aD:2aD:2aD;31H;31H<3AL<3AL<3QP=3aT=3aT=
3aT=3aT=3aT=3aT=3aT;31X;31X:2aT92AL:1aH81A@911<911<30a4411851A<51A<51A<51A<41184
11821@X:2Q0A4QHD51@C4A0B4@dG50lL6Q8N6APN6APN6APM61LM61LL5aHL5aHL5aHJ5QDI5A@I5A@I
5A@H51<H51<H51<H51<E5ADE4a<A3`lC3PlD3a0F414H414H414A3PXA3PXA3PXA3PXB3`/C40`E4PhF
4`lI5Q8I5Q8I5Q8J5a<K61@M6QHO71PP7ATM6QDL6A@K61<J5a8I5Q4I5Q4I5Q4J5a8H5A4H5A4H5A4I
5Q8I5Q8J5a<K61@K61@G510H5A4I5A@J5QDJ5AHI51HG4Q@F4A<?4A4?4A4A4A4C4a<H5QHK5QLJ5AHI
4a@B50hD5Q0F618H6Q@H6Q@G6A<E5a4C5@lB5P/F5`dG60lK6A4K6A4L61<L5Q4L5Q4K6ATJ61PJ5AHH
51<I514L5A8M5a8P5a<T8`lT8`lU8@hU8@hZ914^9a@b:aPg;A/j<Q/l=1e0>254?2E6?RM6?RM5?BI4
?2Dm>2<m>2<m>2<m>2<m>2<m>2<m>2<m>2<i=B8i=B8i=B8g=B<e=BDd=2@b<R@a<B<]<R<g?2df>RhX
;20Q9AXT9ahS9QdL7aHF7Q@G7aDH7aPI81TI7aXH7A/H7A/G71/C6QdC61/@5AP>4AH=3aL?3QLA41XD
41/D4aLE51PB4aL?41@;3Q8<4A@C61/G7R425Q/45a`66A`96Qd:71d=7A`=7A`>71X;7A`<7Qd<7Qd9
6aX76AP=7ahH:RTR=3<K;2TU=30_?SHf@CLg@3Hl@3Y4AD==Bd/fA49:FED]>cL:50hD6aHI81T21P0H
6a863PLG7QLO9QlI6aDD50hI5Q4L61<I5A0D5A4D5A4C5a8C5a8B61<B61<C6A@C6A@K6`lK6`lJ6PhI
6@dJ6PhN7Q8U9ATZ:QiBFDYdNfbJXIBY[jBSZ9nLX9ZRYZ6]/JbX[:J//:Z[/:NVZj:RYijQYibOYIZJ
X9FLYiNLYiNMYYVMYIZOY9^QXifQXYjQXZ2LXIRLXIRLXIRLXIRLXIRLXIRLXIRLXIRIWYFLXIRNXiZM
XYVIWYFGW9>HWIBJWiJMXIJLX9FLX9FKWiBJWY>JWY>IWI:IWI:HW96GVi2EVHjCUhbCUhbDV8fEVHjF
VXnBVXnFW96HWY>JWY>IWI:JVi6JVi6MW9:HVYBHVYBHVYBHVYBIViFIViFIViFJW9J=THJ=THJ;ShB9
SH:6RWn4R7f3Qgb2QW]mPW=mPW=mPW=mPW=mPW=lPG9kP75jOg1iOVmiOVmhOFihOFigO6egO6egO6eg
O6ekP75jOg1hOFifNfaeNV]dNFYdNFYdNFYoOg5oOg5oOg5nOW1mOFmmOFmlO6ilO6iiOG5jOW9mP75o
PW:1PW:2PW22PW21PVimOF]mOF]nOVaoOfeoOff0P6j1PFn1PFn0PgAnPG9lOg1mP75oPW>0PgB0PgAo
PW>1P7:2PG>3PWB5Q7J7QWR9R7Z:RG^;RWb5R7V7RW^8Rgb6RGZ3QWN4QgR8Rgb<Sh2=T81mQ7M[MV`?
7AT45A895aD;6QHD8QhC8QXB8QL<6Pm0CT=CHE]<GUn9W:>=Xjj4WJMjU:1fTImhUZMjVJidUZeaU:ib
Uk5`UJ]bUjecV:ieV[1fVk5gW;9gW;9gW;9mW:^0WjioWJimVjinW:n2WkAoW;5jUZimUieoV9aoU9Ih
S8egQHA`OWYVL6YKHUeaLenf[Y3E`i[HaYg@`ZG8_:CEa:WG`Ik=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=`ZC=
`ZC<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<
`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<
`J?;`:;;`:;;`:;;`:;;`:;;`:800<[2^l[2^l[2^l[2^l[2^l[2^l[2^l[2^l_3_<_3_<_3_<_3_<_3
_<_3_<_3_<_3_<W0_L_2_lg4`Lg4`Lg4`Lk5`]78aMC;b<Nn^lRo_<[1_/c3`<g4`Lk5`/k5`/k5`/k5
`]37a<g4`<Vn^/Zn^<k3^lg0^<Fh/;jeZlo6_=K=`lc3^L6h[[J]XinFS8ElLVaIEVICD5e:AeA1?Tll
>Dll>E8o?5A1?T`j>D`j>D/i>4/i>4Xh=dXh=dTg=TTg=THj=THi=dHi=dHh>DHh>THh>THg>dHg>d8a
=4<b=D@c=TDd=dLf>DPg>TTh>dXi?48k>44j=d0i=Shg=3hg=3df<cdf<cdf<dHj=48f<40d<40d<48e
<d<f=40b<cd_<3la<cla<T8d=D/n?5Y>B6IKDfIKDf5GCF5GCF5GCF5GCF5GCF5GCF5GCF5GCF5GCF=B
AFACAVEDAfIEB6IEB6ACAV=BAF9AA61AB5m@Aee>AEa=A5]<@e]<@e]<@e]<@eA:@5U?AEY@AUU?AE]A
Af5GCF9HCV1FC6=CAfADB6EEBFIFBVMGBfMGBfMGBfMGBfEJC65FB5aA@e]@@UaA@emDAV1EAf5FB5]D
@eeFAF5JBFAMC6ENCFAMC69KBV1IB6IQF69KDUeFCEmFCFAKDVQMEFULE6EHD5Y=AEQ;@eM:@UQ;@eY=
AE]>AUY=AEQ;@eY>A5Y>A5Y>A5U=@eU=@eU=@eU=@eU=@f5EBf5EBf1DBUmCBEa@AUU=@eM;@EI:@4=8
>DA6<d12;44o9clk:3Tg;C<a<Bh/<Q0E=PP==001=000?000B086E@P<G`T?HPH=I0P<D`T7=@D05PH0
2@T040T07@D09000:P019`458PT:7Pl?6aPC71dF7AlG7Q/H6QPE5aHC5AHC5APE5aTF61HC5A<@4PdF
6PP@5`<950875P<76P@57`<38@4080829P018`007`006`826PD66`/;7@d=7`P:4PP:4PT;4`T;4`T;
4`X<50X<50X<50D54@D54@H64PH64PH64PH64PH64PH64PL73@P93@X93@/:30h;3A0;314=318=31@<
3AH>3aP@4AP@4AL?41L?41TA4Q/C50h?2`h?2`l@30l@310A3A4B3Q8C3a8C3aD>2aH?31PA3QXC41XC
41XC41TB3aPA3QD>2aTB3a`F4AXD3aLA2QPB2b0J4bLQ6R@O5R4L4alI4QhH4AlI520I5QlH5AhG51hH
4AhH4AhH4adF4adF4adE5A`D51`D5APG4aLF4QHE4AHE4ALF4QPG4aLF4QHE4APE4APE4ATF4QXG4aXG
4aTF4QPE4APE4ATF4QTF4QTF4QTF4QTF4QTF4QTF4QTF4QPF5ALE51DC4Q@B4A@B4A@B4ADC4QHD4aPG
3ATH3QXI3a/J41/J41XI3aXI3aTH3Q/K5ALG4AHC3QHC3Q/G4QdI51lI51dG4R0J5B4K5R8L5b<M62DO
6RHP6bLQ72PR7B@U5BLV62/Z734^83Pd8S/i8D0n84507SLa6SLc6cTd7cPe83Te8SHd8S<c8C8b82l_
8Bh^82d]8B`/82d/8Rh/930^9S4_9bde:Rlg;B/c:B0W81TP6ALM61HK6A<H5Q8J6A<K6Q@L6aDM71DM
71DM71@L6a<K6Q0K610K60lJ5`hI5P`G50/F4`XE4PXE4PhF5PdE5@`D50`D50`D50hF5Q0H614I6A8L
70lJ60/F50/F4`hI5Q0L5Q0M5@hK4a8R6`hN5`TI4P@D3@DE3P`L5ALW820`:A`[8ah]9B4`:2Dd;2Th
<2`k<bdl=2hm=BPY;A`M8ADG61LI6ALJ61<G4Q4E3a@I410J3A0J3@lI314K3Q8L3a8L3a4K3Q0J3ALG
5a<F51HJ5AXQ6QTQ5a0J3PlI318O4AhV5ATQ41LN3aDL3aDL3bT_95]QEXbAR9ZSVIVRV9VRV9ZSVIfV
W:6ZX:F^Y:RaYjb`ZjZ^ZJR/YjFYY:>WXZ6UX:2TWinSWY^RVi^RVi^RVi^RVi^RVi^RVi^RVi^RVinV
WinVWijUWYfTWI^RViVPVINNUiJMUY^RViNNUi:ITY6HTIBKU9NNUiNNUiJMUXZEThnFTiBHTY^LTj2M
V9fLV9RGVI>DV9nOPIfOPYbLQ9VKQiJIRIBHSI6FSI6ESiJIT9FITiBIV8jGVhRAWWn:WWN5W7:0W6>1
WV22WeUnVUAlSfN9Sh2JS8VJNH:<HG]mLHN9OI>ERI>ERHV;Ogj0M7]mLGeoLgmnL7mnL7mnL7mnL7mn
L7mnL7mnL7mnL7YiJgakKGelKWakKGYiJgUhJWUhJW]jK7QgJGQgJGQgJGUhJWYiJgYiJg]jK7]jK8:2
L8:2L8:2L8:2L8:2L8:2L8:2L8:2L860LX1oLH1oLGmnL7imKgelKWelKWakKG]kJGalJWinK820KX61
Kh:2L8:2L8:2L7moKGmoKH20KX61Kh:2L8>3LHB4LXF5LhV9MhV9MhV9MhZ:N8Z:N8Z:N8Z:N8Z:N8V8
NXZ9NhZ9NhV8NXR7NHR7NHZ9Nhb;OHZ<NHZ?P7^3O0hI5`lL7P0:3PTE5`/D5`dI7@8?3@/F3S0l<4]F
C3A2?Yb]/8nPZHjQ/86HYgNDXW>FY6bCXVF>WFV?XG6EYff<Xfj=Y76@YG>DZ7JGZWNKZgVM[GZN[XNS
]8FO[h6KZGnGXgnFWX>FWH>FVh:EVWb<Rgb:RGV4PG=jMFe`IfQXG6ISEFMRDj^PP;Z_SlZoWm35YLg2
X/ZoWlg2X]76Y]31XM31XM31XM31XM31XM31XM31XM31XL_0X<_0X<_0X<_0X<_0X<_0X<_0X<_0X<o0
X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0
X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<joWljoWlo0X<o0X=31XM31X@00b/:kb/:k
b/:kb/:kb/:kb/:kb/:kb/:kbl>lbl>lbl>lbl>lbl>lbl>lbl>lbl>lbl:obl:ob/6nbL2mb;nla[fj
a;^h`[Vfd/W6dLS5clK3c<?0b/6nakjka[fjaKbia;^h_;>``[VedLK2cL6k_kB/c;ngi]WAd/Jl`KF[
ZIfCTXIlOg=YKV9HHEE;FTi4FDI1Ed@oDd0kCc`gCCXeC3TdCCXeCS/fCC/jCC/jCC/jCC/jC3XiC3Xi
C3XiC3XiAcPeAcPeAcPfB3PiB3PiBCPkBCPkBCPlBSXkBSXkBSXkBSXkBc/lBc/lBc/lBc/lBCdkBCdk
B3`jAc/iASXhASXhASXhASXhAC/d@cTb@SLc@cPdASXhB3`jASXjA3PhC3i0C3hoCd52FTe;J5aHLfMQ
LfQPKfALL6EML6EML6EML6EML6EML6EML6EML6EMMFMKMVQLMfUMMfUMMfUMMFMKM6IJLVAHKF1HK5mG
JeiFJUeEJUeEJUeEJUeEJeiFMV]SNFiVN6eUM6UQM6UQN6eUNFiVMV]SNFaTNVeUO6mWOG1XOW5YOW5Y
OW5YOW5YM6]QLFQNKVEKKFAJL6MMM6]QMfiTMfiTMFmRMFmRMW1SMg5TN79UNG=VNG=VNG=VM79XLg5W
Mg9YO7M^Q7edQGacOgI]N6mVGU96GE55G514GE55GU96Ge=7GU96GE55G516G516GE57GU98GU98Ge=9
H5A:H5A:HeM=HUI<HUI<H5A:GU98Fdm5FDe3F4a2AdPhADDcAT<^A44/@3d^>SLb<S0f:b/i4aPo314n
1PXo1@M71`]B319M4AUV51aY1A5S1a1C1@Pd000F000:0@0@0`0L000Q004]10L]30l[5ALY6a`V8QhT
91hS91dP71TK6QLI61DG6AHH6aPJ71TK6QLI61DG4ALN2a0I10PC008D000E000I000K000K000M000L
000H000F000D0P4E1@DG20LG30/E2`XD2PTC2@PB1`H@1PD?1@@>10<=2@TE2@TE2@TE2PXF2PXF2PXF
2PXF2PXF5AHJ5QDI5QDG61DG5aDE6ADD6QDD6A@C4PX:50`<5Ph>5@d=50`<50`<5Ph>5`l?51<?51<?
4a8>4a8>4a8>4a8>4a8>4a8>5a0=614>6A8?6Q<@6Q<@6Q<@6A8?6A8?91hI91hI8Q`G81XE7QPA7aTB
8A/D8Q`E81/B7QT@7AP?7QPA81XE8A/F81TF7aPE7Q/C7Q/C7ATD7ATD7APE71LF71LF71LF61LC5aHB
5QDA5aHB5aHB61LC5aHB5QDA6QLC6aPD71TE71TE71TE71TE6aPD6QLC6QLC6QLC6QLC6QLC6QLC6QLC
6QLC6QLC5A<B518A4a4@4a4@4a4@5A<B5aDD61HE6QT?6QT?6aX@71/A71/A71/A6aX@6aX@7AdG6QXD
6AHA6AHA7ATD7a/F81XE7aTD81XC81XC81XC8A/D8A/D8Q`E8Q`E8Q`E820B820D8R0F9R8G:RLI;b/H
<c8H=cDG=C0G=S0I=S0I=C0K<RlJ<BdJ;R`J;B/I:B`M:2/L9RPL92HJ8R<I8B8I8B8I8B4K72@J82PN
7bLM61lH5A/F61hI6AhL61dK4a/J51`K51`K5AdL5AdL51`K4a/J4QXI4QdK4A`J41/I3aXH3APF31LE
2aHD2QDC4QXJ4ATI3aLG3QHF31@D2a<C2a<C2a<C3aPK31DH2Q@D2Q@D3APF3QTF3APE2aHC3Q`H3A/G
2aTE2ALC2ALC3A/G4b4M6BLS4b<L5BDN62PQ6b/T7RhW8C4Z8S8[8S8[4QLH314B2a4@4APE5A`G51/F
5alH72@M6BDI6BDI6BDI6BDI62@H5b<G5B4E4alC;C@a7RDR4aXE5QhG6b@J6B<G4ad@3aT<4QT<3QD8
6R4D?D<hJ6eTQhb3UIVCVIfGVJ6JV:2IUinHUinHVJ6JW:BMX:RQXZZSZJfXYj^VYJVTXZJQX:BOX:BO
X:BOX:BOX:FLX:FLX:FLX:FLXJJMXJJMXJJMXJJMV9fDV9fDVIjEVIjEVIjEV9fDUibCUibCUibCU9V@
TYN>TiR?UibCVYnFVj2GVYnFVJBLVj>IVYnFW9fDUiRDTiFFSi6KSI2NQI:PQ96OP8jPOHbONHVPMHJP
LhBOL8:OFWFQEgBQE7:QD6nRBffSAVRS@VFT@6FSBDfVC56/B56[B5:VFf6ZMgB/PgRPOVj=O7ibPhEi
RH]oQhUmP89fNWa`NWa`OGmcOGa^OGa^OGa^OGa^OGa^OGa^OGa^OGa^NgY/OGa^OWe_OGa^NWU[NGQZ
NWU[O7]]NgY/NgY/O7]]O7]]OGa^OGa^OWe_OWe_PX9`PH5_PH5_PH5_PH5_P81^P81^P81^OGa^OGa^
O7]]O7]]O7]]NgY/NgY/NgY/O7aZOGe[OWi/P81^PH5_PH5_PH5_PH5_Ogm]Ogm]P81^PH5_PX9`Ph=a
Q8AbQHEcRHUgRHUgRHUgRHUgRXYhRXYhRXYhRXYhRHQjRXUkRXUkRHQjR8MiR8MiRXUkSHanRhejRi21
O8Am4ahL3Q/M00X>1a<E2Q<F2ADI0a0>3QTA;3P/AU57;S`hUZNZU:F^TZFdPiZYMI:QJhfMI8RHH8BF
HXJHJhbPLHjSM96VNINZOYb]OYn_Oj2_OIj]O9j[PYbZPIVUOiFPO96IN8^BM8N:LH>4Kgj0LgmiK7I`
HVYSH6AIJFUKP7e^WIJ5/:VF_K:BaKZJc/>SclBTb[nOakbLbKjNcL:Rd<6Qd<6Qd<6Qd<6Qd<6Qd<6Q
d<6Qd<6Qbl2Pbl2Pbl2Pbl2Pbl2Pbl2Pbl2Pbl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2P
cl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2P
cl2Pcl2Pc[nOc[nOcl2Pcl2Pcl2Pd<6Q003:`[_:`[_:`[_:`[_:`[_:`[_:`[_:`[_;`kc;`kc;`kc;
`kc;`kc;`kc;`kc;`kcAb<C?a/;=a<3?a/;BbLGBbLG?a/;;`[jn]K6o][;0]k?3^[K8_k_=a<3BbLGD
blO>aL;Ab<G@al?@aL7Db<;DbL74]jn]X9RDPgYjJF1VEDaRDDQJBD1:>C15=2]<>c9??3M@?CQA?SUB
?cYB?cYA?SU@?CQ??3M;?3U;?3U;?3U;?3U;?3U;?3U;?3U;?3U<>cQ=?3U>?CY??Ca@?SmA?d1B?d9B
?d9BAT1BAT1AACmAACm@A3i@A3i?@ce?@ceBAD=BAD=AA49AA49AA49@@d5@@d5@@d5=@ca<@S]=@Si?
A41CAdEFBTQFBTYEBDUMDE5LD51QEEE]HEmkL6b3N7B3NG:1Mg21Mg21Mg21Mg21Mg21Mg21Mg21Mg21
Mg23NW63NW63NW63NW62NG20MfinMFamM6]mLF]mLF]lL6YlL6YlL6YmLF]nLVaoLfelLV^0MVmoMFim
LfanM6f5NgB8OWN6O7F5O7R6OGV7OWZ9P7b:PGf:PGf:PGf:PGf:Q7f6P7V2O7F0NW>0NW>2O7F2O7F2
O7F3PGN2P7J2P7J2P7J4PWR6Q7Z9Qgf;RGmnOgF0PGN6QG^;RX2<RX27PWUiM6]aJV5VFdeUFTaTFD]T
FD]VFdeWG4iUFTaTFD]OED]OED]PETaQEdeSFDmTFU1UFe5UFe5RF4iRF4iQEdePETaNE4YLDTQICdEH
CTABCCiCC3]ABcQ@BCQ:ACa1?T0d=4@[;DD52Ch213h003l004D00D`11e8335H33UP866D85UP53ch0
124001D10Q`312H00RX20Bd722hA4RhL72`R8RPU8b<T81lR7A`J5aTI5QPH5ALI5QPK61XL6A/K61XI
5QPD5R0?4A`92QP51AL40QP50Q`50Ah501l20al20ad411`51Q/81a/921P:2QP=2QT@3aT?3QP>3AL=
31H;2Q@:2A<921881a4:2A8:2A8:2A8;2Q<;2Q<;2Q<<2a@<2a@<2`d<2`d@3PhB410F4Q4I514K5Q<K
5Q<O61DQ6QLR6aPR6aPP6AHP6AHQ6QLS71TL5Q4K5A0K5A0J50lI4`hH4PdG4@`G4@`P6QDO6A@O6A@O
6A@O6A@P6QDQ6aHQ6aHR71DO6A8L5PlM5a0Q6a@S7AHR71DP6Q<Q7A8P714O6Q4P6Q<Q6a@Q6aHO6A@M
5Q<N7A<N71@M6a<M6QDM6QHL6ADL61LL61LJ5a8J5a8J5a8J5a8J5a8J5a8J5a8J5a8I5A0J5Q4K5a8K
5a8K5a8K5a8J5Q4I5A0L61<L61<L61<L61<L61<L61<L61<L61<G510G510G510H5A4I5Q8K61@M6QHN
6aLO7A<P7Q@Q7aDR81HR81HR81HR81HQ7aDQ8QTO81LN71@N71@Q7QHR7aLS7AHR71DP7ADP7ADP7ADO
71@O71@N6a<N6a<M6Q8I60hG5@dF4`hG4`hL5`hR7a4Z9Q<^;1@c;1<b:a8a:A8]9a0[9Q4Z914X914X
914T9QXT9QXS9ATR8aTP8APN7aHL71HJ6Q@<50XA6@lC6Q<?5Pl>50lC61HE6QPD6APB6QTB6QTC6aXC
6aXB6QTA6AP?5aH?5aHG82<F7b8D7B0C71lA6Qd?61/>5aX=5QT?5aL?5aL?5aL>5QH<51@;4a<94A48
410:4QT94AP84AD94QH;51L;5AD94a<74Q074a<95AD:5QH:5QH95AD95AD;5aL=6AT86AD96QH;71P>
7a/?81`A8QhA8QhA8Qh>6AL>6ALA71TF8AhG8adE8A/H9AdL:B4A81PC8QXE91`G9QhI:20I:20H9alG
9Qh@8Q/;71<;6Q8D8QLL9adM9a/K8aPK8QDY;bA1ASeSJ5n3Qh6LX9^Y[JRWZZROXZ2MXijMXijMXijN
Y9nPYZ6SZJBV[:NX[ZVX[:JUZJ>RYZ2OXifNXYbNXYbPY9jQYInIWYFIWYFIWYFIWYFIWYFIWYFIWYFI
WYFMXYVMXYVMXYVMXYVMXYVLXIRJWiJJWiJKX9NHWIBEVY6CV8nBUhj@UHb=TXV;T8N<UXJ=U8F;Sh>3
QWehOGacN85aN8]aO99EK:ADJj=AJZ9?J:1;IYm7I9e5HY]4HIY6IZQ4I:E2HZ<mH:0lGihlGihmHIdm
HIeQJ9UTKImRKImOJi]ZL9UlOIV8P967NHAnPG9nPG9mP75jOFigNV]gNV]jOFimP75jNF]jNF]jNF]j
NF]jNF]jNF]jNF]jNF]lNfenOFmoOW1nOFmkNVajNF]kNVamO6ioOW1oOW1oOW1oOW20Og60Og60Og61
P7:0P6j0P6j0P6ioOfenOVanOVamOF]mOF]kNVakNVakNValNfelNfelNfelNfemO6imOF]nOVaoOff0
P6j1PFn1PFn0P6j0P6ioOfeoOfeoOff0P6j1PFn3Pg64Q7:5QG>8R7J8R7J8R7J9RGN9RGN:RWR:RWR:
RWR8QgV:RG^:RG^:RG^8QgV9R7Z;RWb=S7j=Sgb<TH9oQh0M:2H<6A/02@d54A<741<13A423`d<5`lR
;R91C48Y=c>;W9nGZ;6GYkR8W:egTJ5[RIYSQ9MPPIAVQIY^Rj1jU:AmUjN2W:b5X:j4X:]oVjIhUIid
TIY`QXaaQ8]`PhQ^Oh9^O7]ZMgEWLVmULF]PIeYVJeabLf>1OffESgb[Y933^:;BaZk=`Z;>`j?>`j?<
`J79_Yk8_Ig:_io<`J7@`J7@`J7@`J7@`J7@`J7@`J7@`J7@`J7;`:3;`:3;`:3;`:3;`:3;`:3;`:3;
`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?
`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3>_io>_io>_io?`:3?`:3?`:000<W1
^/W1^/W1^/W1^/W1^/W1^/W1^/W1^/_3_<_3_<_3_<_3_<_3_<_3_<_3_<_3_<W0_<>j][fd/;fd/<:i
]LBk]l:i]Kfd/<o6`/_2_/Bk]kbc[kF/Z;6XY:jUXJfTX:ZQWZVPWJ:IUIfBSYnCSIN<Q7U/I5E8@65<
A5I1>E<n=U]6?Ua7?eI1>EE0>5e8@590>EA2>eI4?EM5?UM5?UI4?EA2>e=1>T`m>T`m>T`m>Tdn>ddn
>dho?4ho?4ho?5Q5@5Q5@5Y7A5]8AEe9B5m:C61;CF1;CUaBB5]AAe]AAe]AAeY@AUY@AUY@AUY@AUm@
CUm@CV1ACf1ACf1ACf1ACf1ACf1ACe]CC5aDCEeDD5mFDV9IEVAKF6EKFfILG6MOGfMOGfeUIGadM8V2
Ohf6Phf6Phf6Phb6PHb6PHb6PHb6PHb6PHb6PHb6PHb6PH^8P8Z7OhZ7OhR5OHN4O8F2NXB1NH>0N8V0
O8V0O8QoNhV0O8Z1OH^2OXb3Ohf4P8^5P8j8Phj8Phb6PHj8PiF?RYVCSYRBSI:>SI>?SYB@SiFAT9JB
TINCTYJBTIJBTI:?Rhn<R8^8Q8Z7Ph^8Q8b9QHf:QXb9QHj>R8j>R8n?RI2@RY6ARi>CSIFESiJFT9JJ
SiFISYBHSI>DRXj=Ph60MW=aIfQVG6iTDVaRD6]QCf]QCfeSDFeSDFaRD6YPCVAJD6AJD6EKDFEKDFIL
DVMMDfMMDfMMDf9HCV5GCF5GCF1FC5iDBUaBB5Y@AUU?AEQ?@EM??UI>?EA=?T]7@SllAC0`B2DXA`P7
C`L5D@<2DP00E000E002D`04D`06D08AH0@BFPD=B006<`02:P<5;@85<P03=0L6;Pd<;QDE;AdM:B0R
8b8P7b4N6AhK5Q/H6Q/H6QXG6AXG6AXG6A/H6QXG6ATF60T95@P850L75@L560L56@P47@T47`T48@@5
6@P76`T96``;6``<6Ph<60l;5`h:5@T540T540X64@/74P/74P`84``84`d9514=4Q4=4Q4=4Q8>4a<?
51<?51@@5A@@5A<C4aDC4aLE51/G5QdH5AlK5R<M62<M5QPB3AXD3a/E41XD3aTC3QPB3ATC3Q/E42PN
5bPN5bLM5RLM5RHL5BHL5BDK52DK51dG41`F3a`F3a`F3adG41lI4R8L5B<M5R4M4R4M4R8M52DP5bPR
6bXT7B/U7R/U82PT6BLS62DQ5RDP5bDO62<M5R0J5AdG4Q/L4Q/L4Q/L4aXK4QXJ51XI5ATH51TH51XG
4Q/H4a`I51`I51/H4aXG4Q/H4a`I51/G4Q/G4Q`H4adI51dI51`H4a/G4Q/G4QhJ5AhJ5AhJ5AhJ5AhJ
5AhJ5AhJ5AhJ5AdJ5QdJ5QdJ5QhK5alL620M6B4N6R8O6b<Q5R<Q5RDS62HT6BLU6RLU6RHT6BHT6B<U
6B8T62<S5b<S5b@R5b@R5bHR5bDQ5R@R62<Q5b<Q5b<Q5b8P5R8P5R8P5R8P5QXK4QLG4AHC3aHC3aXE
4R<N5B`Y6c<_7CTb6CL_63D]5S4Z5RlY5RlY5RhZ62l[6B@X72DY7BL[82P[8RLZ8BHX8R@V82<T828Y
8RH]9RL^9b8X8alT8R8W9B<X9b4V9B0X9b0X9b0X9b0X9ahV9AdU91/S8QXR8A8H7a8H7a0F7@hD6``B
6@/A60T?5PP>5@@<30H>3PP@40TA4@XB4PTA4@P@40L?3`@;50@;50D<5@L?5PL@50H?4`@=40<<3`<=
3@D?3`LA4@LA4@H@40D?3`H@40LA4@0C404D4@8E4P@G50DH5@HI5PHI5PHI5PXJ4`lO61DU7QPX8ADU
7Q8R6a<T6aHW7QTX91/Z9Qh]:Al^:Ql^:Qh]:Ah]:Al^:QH^8Q`b9R0d:1//7aHR5Q/S62hd:D55>VEY
HhZ>R:Z^ZJb`Zj2SXIfOWinQXJ2RXYRMViRMViVNW9ZOWIfRX:2UXj>XYZFZZ:faZjZ^Z:JZY:>WXJ6U
Wj6UWj:VX:>WXJFYWZBXWJ>WW::VVj6UVZ2TVInSV9nSV9^OU9^OU9ZNTiRLTIFISY>GS92DRHnCR8nC
R8jBQh^?Q8R<PHF9OX65NWf1MWYnLgEnJGQnJgMmK6icJVAYJUeULUiYOf9^RUEXXEAXXEAYX5AZWUA[
WE=ZVU=[VE5[VFM`TFMaSfQ`SFUaR6]bQFeePVmeP6mfOg26KWF:M7>9MVn4KVn2JGV5Ih27HX:4FX23
M7aoL7MjJgEhJGIiJWUlKG]nKgaoL7akKGakKGakKGakKGakKGakKGakKGakKGelKWmnL7mnL7imKgak
KG]jK7akKGimKh1oLH1oLH1oLH1oLH60LX60LX60LX60LWinK7inK7inK7emJgalJW]kJG]kJG]kJGak
KGakKGelKWimKgmnL81oLH1oLH60LWinK7moKH20KX20KX20KX20KWmoKGmoKGmoKGmoKGinK7moKH20
KX:2L8B4LXF5LhN7MHN7MHR8MXR8MXV9MhZ:N8Z:N8Z:N8R7NHZ9Nh^:O8Z9NhV8NXV8NXb;OHj=OhnA
OXbAPX::PbTd<PXG6@093@<?4@D>4@072`0;2@D@21DQ5D=>A2dk=gj?TYBU[YBS/hZM[7fDY76>WF^9
VVf8W7><X7R?YG^DWWbEWgbFWGbCVgJ>U726RfMmPV9hOFEcLV=aKf9`K6=]If9ZHfA/HFU`HfeaIGEd
GhR5L::NQ[ZcV/NnXl^oXlVkWlFgV/k3Xlc1XLZoWlZoWl_0X<g2X/g2X/g2X]31XM31XM31XM31XM31
XM31XM31XM31XLZoWlZoWlZoWlZoWlZoWlZoWlZoWlZoWljoWljoWljoWljoWljoWljoWljoWljoWljo
WljoWljoWljoWljoWljoWljoWljoWljoWljoWljoWljoWljoWljoWljoWljoWljoWljoWljoWljoWljo
WljoWljoWljoWlfnW/fnW/joWljoWlo0X<o0X000bL6jbL6jbL6jbL6jbL6jbL6jbL6jbL6jb/:kb/:k
b/:kb/:kb/:kb/:kb/:kb/:kYinHW9B=T8R1RH5jRH5jRH5jQgmhPg]dOWI_OGE^O7A]OGE^OgM`Pg]d
R81iRX9kVY6>PgYgQgijWiB@SH5kFe18DdHnKf9JLEYBLEYBK5E=IDi6H4U1H4U1HT]3I4e5FdU2FdU2
FTQ1FDM0F4HoEdDnEdDnEdDnDDDoDDDoDTI0DdM1E4Q2EDU3ETY4ETY4H519H51:HU9<I5=@IUACJ5IE
JEMHJUQII5]AI5]AI5]AI5]AIEaBIEaBIUeCIUeCJEaJJUeKJeiLKF1NKV5OKF1NKF1NK5mMJf=LK6AM
KFAPKfIRKfISLFQULVQXLfUYKVUXKVUXMg9aR8>2Thj=U8n>U8j?UY2AUY6>UY6>UY6>UY6>UY6>UY6>
UY6>UY6>UIJDU9FCTiBBTY>AT96?Si2>SXn=SXn=THb9THb9THb9TXf:Thj;UI2=UY6>Ui:?WIREWiZG
WYVFVYFBVYFBWYVFWiZGWIREVYRHVYRHW9ZJW9ZJWI^KWI^KW9ZJW9ZJV9JEUYBCUI>BUiFDViVHWYbK
X9jMX9jMX9nKXJ2LXZ6MXj:NXJ2LWYfIViZFVIRDTIF:SI66QXYoP85gNWU_LG1VJFMMI69HL6IDKVAB
KF=AKF=AKVABKVABKF=AJf5?IEaBI5]AI5]AHeY@HUU?HUU?HEQ>HEQ>G5=9G5=9G5=9Fe98FU57F4m5
ETe3EDa2DDPkD4LiCdLfC4@g@Sdj=C4l92@l61Xl1P=C1P9D1P5F0P1E0@1D001@001=005<009@00E>
00I7008l0@8e1@<g0`0g000d5aDc6QLa6a/[7ahW820P8B0L8AhI81dH71TK71TK71TK6aPJ6AHH61DG
61DG61DG3`hH4Q4K5A<O61DT61DU5a<V5A0U50lT3`lK4A4M4a<O5aHP6ADP61DN61<L5a8K3P/D3``E
40dF4@hG4a0I514J5A8K5Q<L5Q4B5Q4B5a8C61<D6A@E6A@E6QDF6QDF6ALF6APD6QLC6AHA6AH>6Q@=
6A@;6Q<:7AL@7aTB81XC81XC7QPA7QPA7aTB8A/D81L=81L=81L=8AP>8AP>8QT?8QT?8QT?7AT>7AT>
71P=7AT>7a/@8QhC9B4F9b<H9B8C:BHH:bPJ9b<H7aXA6A<<618=6Q@?9b@F9B8D8alD8alD91lF8adF
81XC7QPA7AdA7AdA71/A71XB71XB6aPC6aPC6aPD7AXB7a`D8AhF81dE7AXB71TA7Q/C81dE8Q`E8adF
8adF91hG91hG8adF8adF8Q`E8Q`E8Q`E8Q`E8Q`E8Q`E8Q`E8Q`E8Q`E8QhI8QhI8alJ8alJ8alJ8QhI
8QhI8QhI924C9B8D9b@F:2DG:BHH:BHH:BHH:BHH82<D8B@E92@F92@F92<E8b8D9B8D9R<E8b8H92<I
92<I92<I9B@J9B@J9B@J9RDK8RHK824H71/G6aLF7QTF8alJ;2PM<2dO=c0M=RlL<bdJ<R/J<2/L<2dN
<BhP<RlQ8bLL9BTN9RTP9bXQ9bTS9RLS92DQ8b@P7bHO92XU92XU7R<Q6QlM6QlN6AdN5QXK4QXI4QXI
4QXI4ATH41PG3aLF3ADD31@C1PTA1@P@10L?0PD=0@@<008:0049000800@400H600P80PX:0`/;0`/;
0PX:0@T900D>00L@0PTB0`/B0P/?0@X>00T<00P;0P`<10h>10h>10h>0P`<0`d=1@l?218B11DA1AHB
1aPD2AXF2Q/G2Q/G2Q/G2Q/G5bXQ7c8Y9cXa:Sdd:Sdd:C`c:S`e:cdf;C`h;Sdi;Sdi:cXf9SDa8c8^
8S4]8c8^638R7C@U7c8S72XN8bdQ?dLlKW9WT967WJ6KYj^UZZjYYZZUZ:^Y[k6a[:j^XJ>SY:RSY:RS
Y:RSYJVTYZZUYj^VZ:bWZ:bWZ:fTYZ^RXZNNWZ>JVj2GVYnFVYnFVj2GV9bAUi^@UIV>TiN<TIF:Si>8
SI66S925PHEjPHEjP8AiOh=hO81eNWicMg]`MWY_LWI[LgM/MGU^MWY_MWY_MWY_MWY_MWY_LgYUN7mZ
O7m_Mg]`KG9`IfigIW22IgF<KG>:KGB8KGB7KgJ7KgN4KgR1KgV0KgV0LG=dLgEeN7UeOWecPGi_PWi[
PgmWPWiRK7EXLG]_M7ibLg]aM7Y_OGe_Ph1aQh5^Oh9bO7m_NGa/NGa/O7m_OH1`OH1`O7m_Ogi`Ogi`
Ogi`Ogi`Ogi`Ogi`Ogi`Ogi`OGa^Ogi`Ogi`OWe_O7]]NgY/O7]]OWe_Ogi`Ogi`Ogi`Ogi`Ogi`Ogi`
Ogi`Ogi`O7aZO7aZO7aZNg]YNg]YNWYXNWYXNWYXNgY/O7]]OGa^OWe_Ogi`P7maPH1bPH1bOWi/Ogm]
P81^P81^P81^P81^Ogm]Ogm]Ogm]Ogm]OWi/OGe[Ogm]PH5_Q8AbQXIdQXIdQXIdQhMeR8QfRHUgRXYh
RXYhRh]iR8MiRXUkRhYlRXUkRHQjRXUkSHanT8n1T99oS962QHf6=T4o21DG00T=0Ph@0``?00T=00/9
00/33AT=CeY@>dU5LhB7RibURYRTQINROI>OM8jJL8ZHLHRHLhNHM8JGLHN<L8B9K863Ig]lHWAeGVi]
FFUXF6ITHFUOH6QNHFMLHFIGJ6UILG5OP7m[RXMb/:Z=^K6Da;VMbl2Rc/2Sc[nOc[bMcK^LbKjNb;fM
b;fMbl2Pc/>SclBTc<6Qb[nOcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pb[nOb[nOb[nOb[nOb[nOb[nO
b[nOb[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nO
c[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOcKjNcKjNcKjNc[nOc[nOc[nO
0038`;W8`;W8`;W8`;W8`;W8`;W8`;W8`;W:`[_:`[_:`[_:`[_:`[_:`[_:`[_:`[_=a[g4_KBj/jZd
[JBc[:>e[ZFe[ZFe[ZFg/:Nc[:>/YIbUWYFNUhjHTHRDSHBCS8>IT8f=Q86FSHV/XIfNTXa`IEeGBT9K
CTINBD5UD4QYE4aWDTYWDTYYE4aXDd]SCTIWETeVEDaSDTUQD4MQD4MQD4MRDDQSDTUNDd]OE4aPEDeQ
ETiSF51TFE5UFU9VFe=UFU9VFe=WFeEYGEMZGUY/Gee^HEm^HEm/IU]/IU]/IU]]Iea]Iea^J5e^J5e^
J5e_IV=aJ6EcJVMfKFYgKV]gKV]fKFYeK6UcKFIeKfQgLFagLFafKfafKfahL71jLW9fLfmeLVj0O7^C
ShjMV9VLUiVKUYROVYbQWIbQWIbQWIbQWIbQWIbQWIbQWIbQWIbOWinNWYjLW9bJVYZIVIVIVIVIVIVI
VIVKVIRJV9NJV9NKVIRLVYVMViZOWIbPWYfMVIRQWIbRWYfPW9^QWIbUXJ2VXZ6SWijXYZFXYZFXYZFY
YjJXYZFWYJBVY:>UXj:YYZ:VXinSX9bQWYZQWYZQWYZOW9RMVYJKUi:KUi:KUi:HU8nCShZ<R8>5PGb1
OGQaLVQ]KVAZJEmUI5YRH5ISGUESGUEUGUE[H59YGU1WG4iWG4iXGDmXGDmVFdeUFTaMEdaLET]LET]J
E4UIDdQHDTMGDDIFD4EDCT=DCT=DCT=CCD9BC45@BSm>B3e=Aca9@cQ:@SE9@S=7?c8o>C@c;cDS8SHH
6CD40d450dD714T60TT50TL50dD61T882D<11D052D<:34892Sd<2CX?33X=2SP;1C@M6bhL72XL6b@J
71dK71XM71PM6aXO6aXF4aDG51HH5ALF4aDD4A<B3a4C418D4A<B3Q<F4QPJ5Q`K5QlI4ahF41/D3AXC
31T=3Q8>3a<A41@B4ADD41DE3a@D3Q<C3A8A3Q0A3Q0A3Q0B3a4C418D4A<D4A<E4Q@E40dE40dF4@hG
4PlH4a0I514J5A8K5Q<H5A0H5A0J5a8M6Q8Q71<S7QDV81DW8AHT81DV8QLX91TX91TW8aPW8aPY9AX[
9a`f;R4g;b8g;b8h<2<i<B@j<RDk<bHk<bHm>R`m>R`n>bdo?2i0?Bm2?c54@C=5@SA5@c59AcE8ACHm
>R`/9ahM5a0G4@`G4@`O70dL6@/J5`TJ5P/L60dN6A0M5a0M5a0T81DS7a@S7a@S7QDR71DR71DR71LR
71LO7A<R81HU8aTS8ALP7Q@N718Q7aDT8QPT7A@T7A@U7QDV7aHV7aHU7QDT7A@T7A@U7QDU7QDU7QDU
7QDU7QDU7QDU7QDU7QDR7QTR7QTS7aXS7aXR7QTQ7APP71LO6aHU7a8V81<X8QDY8aH[9AP[9AP[9AP[
9APN8A4Q91@U9QHV9aLU9ADU9ADW91DY9QLU9ATU9ATU9ATV9QXV9QXW9a/W9a/X:1`R9aPO8aPL71HH
5a<H5A4J5Q4M6a4O7Q0L6@/L6@/K5``I5``I60hJ6@lI6Q4I6Q4D6PlD6A0D6A0C5a4B5Q4A5A0?4Q0>
4@l52`H:40/<4@l730X42@P52@X52@X21PL01`H01`H020L020L01`H01PD010<010<62`h52Pd42@`3
20/21`X11PT01@P01@P020P12@T22PX22PX22PX22PX12@T12@T22Q4431<63a<53Q843A033@d33@d4
3`d;514<5A8<5A8<5A8<5A8=5Q<A6QLE7Q/A81PC8QXE91`G9QhI:20K:R8K:R8K:R8`@SDgBC`kC44i
BSlgB3leASdb@S/]?CHP;bLR<BTS<RXQ<2PN;BDN;BDS<RXX=bl[?R/dA3=0CCeCGE1_N6^@UX^Y[J:e
]Zf[/JJVZj:OY9^NXYbTZ:>X[:NPXj6DUiFPXiZOXYVMX9NKWYFIW9>GVY6FVI2EV8n;THJ:T8F7SH:5
Rh22R7f0QW]oQGYoQGYjO71iNfmhNVifN6adMVYbM6QaLfM`LVIcMFUdMVYeMf]fN6afN6aeMf]eMf]d
MVYbM6QcMFUeMf]eMf]dMVYdMVYfN6ahNVieNfYhOVemP71nOW1fNVm`MG=/MGU[MWifM6YeLfQfLfEe
LV=fLV1dL5efLEaeLEUPKFmSLG1XMG=]NG=bNg5aNFi_NFU_MVMfMG5iN7AkNWIlNgMoO7R2OWV7PGb8
PW]nPG5mP71mP71oPW:0Pg=oPW9mP71kOVj0Og60Og60Og60Og60Og60Og60Og60Og5lNfenOFmoOW1n
OFmkNVajNF]kNVamO6inOFmnOFmmO6imO6imO6ilNfelNfelNfejNVQjNVQjNVQjNVQkNfUkNfUkNfUk
NfUiN6YjNF]jNF]kNValNfemO6inOFmoOW1mOF]nOVaoOff0P6j1PFn1PFn0P6j0P6j0P6inOVamOF]l
O6YmOF^0P6j4Q7:6QWB5QG>5QG>6QWB7QgF8R7J9RGN:RWR;RgV8QgV9R7Z;RWb;RWb:RG^;RWb>SGnA
T8:@TWn;T867ShQ1C4X64aD02Ph13@l22`h031023`d130@;5`]NJEm6E51SM7MlSIIjR8iiS95eRi5]
QH]YP8QYOXIXN8ATLWiPMG=OLVmLKFYIJ6AGIEmIHeeKHeaLI5eLGDeSHe5]K5QiMV67PfZKU7V_YhZl
]9O;`:3;`:39_Yk8^i_9^Y[<_IgC`J;GaJK9_Yk9_Yk;`:3=`Z;>`j?<`J78_Ig5^Y[?`:3?`:3?`:3?
`:3?`:3?`:3?`:3?`:39_Yk9_Yk9_Yk9_Yk9_Yk9_Yk9_Yk9_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=
_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=
_Yk=_Yk=_Yk=_Yk=_Yk<_Ig=_Yk=_Yk=_Yk>_io>_il00<S0^LS0^LS0^LS0^LS0^LS0^LS0^LS0^LW1
^/W1^/W1^/W1^/W1^/W1^/W1^/W1^/[3^/S1^<Jo]/Fn]LJo]/W2^Lc5_<k7_[nh[l2i/<6j/L>l/lFn
]LO0]lS1^<W2^LFl^Lo6`m37`lc1_M34_/Zo]j>FSW=VGUm<A5E2>U=0>5m<A6UFCVQECFEBBVICBfUH
CfUHCfUHCfYID6]JDFeLDfmNEG1OEVQOEVQOEVYQF6aSFViUG6mVGG5XGg9YH6aVFfeVGFiWGVmWH75Y
HW9YIGA[J7A[J7I^IgI^IgE]IWE]IWE]IWA/IGA/IGA/IG5/JG=^JgIaKWUdLGYeLWYeLWUdLGQcL7Uc
K7afKgmiM7miM7igM7igM85iNHAlO7elN7akMhR6QIfKVjNTYZ:NXj6MXZNSZJNUYJNUYJNUYJNUYJNU
YJNUYJNUYJNUYJBSYj>RYZ6PY9nNXYnNXYnNXZ2OXj6PY9nQXIjPX9jPX9jPX9nQXJ2RXZ:TY::TY:NU
YJ^YZJf[ZjZXZ:VWYjZXZ:NUYJ:PX:VVXZVVXZRUXJRUXJJSWjBQWJ>PW::OViVET9FAS92<Qhb8PhR4
OhB0Nh1lMgeiM7eeKWadKGYbJgM_J7=[I6iVGfUQFVMOF6=QEfARF6IQF6EPEfIOEVQOEVQOEVUPEf9F
BV1DB5iBAUiBAUiBAUiBAUa@A5Y>@U==@U9<@E9<@E5;@51:?e1:?dm9?Tm9?Te7?4e7?4e7?4a6>d]5
>TY4>DQ2=dM1=T0o=D0n<d<n;d8m;Shi<3Ha<R/W<b8P=1TP>a/Q?Q`Q@Q/O@Q/M@1/M?adQ?R0T@1DH
=1TL>1PK=aHG<aPF<adJ<ahK<AdH;A`K91`M8AdM7A`M6A/L61hL6ahK7AhJ7aPE5aXG6AdJ71`I6aXG
6AXG6A`I6alL7QD@4ALB4aXE5QTD5QLB51HA4aPB5aXD6AHF5QLG5aTG5aXH61/F61`E61/D5a/D5aTG
5QTG5Q/I61dK6QhL6b0N7B8P7b8P7c4[9S8/9c<]:3@^:CH`:cLa;3Pb;CPb;Chl=40n=TA1>DY5?4m;
@5E?A5UCAUaDAfAQDfISEFQUEfUVF6UVF6YWFFaYFfm/GVUVEfUVEfUVEfUVEfUVEfYWF6YWF6YWF65N
Cf5NCf9OD69OD65NCf1MCUmLCEmLCF]ZEFe/F6aZF6ISEEaHCE5;A4Y4?dM0?C8_82h[72TV62HS5BHR
5bPS6RPS6RPS6RlW6RlW6RlV72hU6bhU72hT7BdS72dR7R<N5BLR6BXU72PS6R@O5R8M52HQ62XU72HO
5RLP5bLP5bPQ62PQ62LP5bLP5bHO5RLP5bLP5bLP5bLP5bLP5bLP5bLP5bLP5b8L5B<M5R@N5bDO62HP
6BDO62@N5b<M5RTT5BXU5R`W62hY6RlZ6c0[730[730[72@X5BP/6Bh`7Bla7Rl_7Bh^734_7C<a7bT[
7bT[7bT[7bT[7bPZ7RPZ7RPZ7RLY7AhW4ahS51`P5A`M51XJ51/I4A`J3a`K3A8@210A214A2`lA2`l@
30`?3@T>30T>3A0E30lD2`hB30hB30dA30d@3Pd@3PhA3`lE41HK6APM6aDJ6A<G61DI6QHI7A<F6Q<K
6Q<K6Q@L6a@L6a@L6a<K6Q8J6A8J6A<H5a<H5a<H5a<H5a8G5Q8G5Q8G5Q4F5@hF5PdE5@dE5@hF5PlG
5a0H614I6A8J6Q4J7A<L7a@N7Q<M7A0K6A0K618M6QDP7ADP5QLR61XU6a`W7AdX7QlZ828]8bD`9R<_
8b@`92Lc9b/g:bhj;S0l<34m<C8n<SE6>3U:?3M8>c51=Rdl=2/j<R8`:QPV81XV6Q`X71dY7A/W6aXV
6QhZ7RLc9blk;e]QCV]aGWn5M96FQijRUZ:VViNJTHR;PXR?PXZAQ8fDQhnERXR=Q7j3NWUmMg]oNGIj
KWIjKWEiKG=gJg5eJFmcIfeaIFa`I6idJFmeJVmeJVmeJVidJFabIfY`IFU_I7AfJWAfJWAfJWAfJWAf
JWAfJW=eJG=eJG=eJGAfJWIhK7MiKGQjKWQjKWQjKWQjKWQjKWUkKgQjKWEgJg9dJ75cIg=eJGIhK6md
Jg=dJWIfJ7UgIGMgIGIfJ75eJW1eK7YkJgUjJWYjJW]iIg]gIGaeI7afHgaeHVUcKFYdKVieLW1gM79g
MG9gMG9gMG5fM7QjIWIhI7MiHgQkHWUlHgUlHgQkHWQlHgb0KGj2Kgn3L7n3L7j2Kgb0KG]oK7]oK7im
KgimKgimKgimKgimKgimKgimKgimKg]jK7elKWimKgelKWYiJgUhJWYiJgakKGelKWelKWelKWakKG]j
K7]jK7]jK7YiJgUiIgUiIgUiIgYjJ7]kJGalJWalJWemJgYiJgYiJg]jK7akKGakKGelKWelKWimKgal
JWemJginK820KX61Kh61Kh61Kh61Kh20KWinK7alJW]kJGemJh20KXB4LXJ6M8B4LXB4LXF5LhN7MHR8
MXV9MhZ:N8^;NHR7NHV8NX^:O8^:O8Z9Nhb;OHn>P96@PY2BOhZ?P8R@RDYED`DB500;3`4=3`8;3P0:
3P@A3`@?1`XF2V=^I4ABCTaMH6MhPFYkN6eoOV^1OfAlO6=hNVEhNfAbN61ZLEa^Iea/IEUXH5UVGUaU
FeiVFfAXGFIZGfm[DgahH92;LZ>MP;>YRl2eULg1WmG9YLBjV<VmVlc0W/g1WljoWljoWljoWlo0X<Vn
W/_0X<c1XLg2X/c1XLZoWlRmWLRmWLjoWljoWljoWljoWljoWljoWljoWljoWlVnW/VnW/VnW/VnW/Vn
W/VnW/VnW/VnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fn
W/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/bmWLbmWLfnW/fnW/fn
W/joW`00b<2ib<2ib<2ib<2ib<2ib<2ib<2ib<2ibL6jbL6jbL6jbL6jbL6jbL6jbL6jbL6jb<6hb/>j
c<FlblBkbL:ib<6hb<6hbL:ib/>jb/>jblBkblBkb/>jbL:ib<6hal2gakjkakjka;^ga;VebKfgcL:j
bkjf`[F]Z9V@MfQODT<jDT<jETLnCd0gDT<jHE99GTi2HE55IEE9JEU=KEeAL61DLF5ELV9FK6=JKFAK
KVELL6MNLVUPM6]RMVeTMfiULFmTLW1ULW1VM79XMG9ZMW9]Mg=^N7=`OGA`O7=_Ng9^NW5]N6m[MfiZ
MVeYMFaXKfiZLW5]MGA`N7McNWUeNWUeNGQdN7McNgQ`OgadPgmjPgmjPWejPgikQh:1RXF4PH9nPH9n
SHj<Xj>S[:^]YjJZYZBZ[:Z`YjJXYjJXYjJXYjJXYjJXYjJXYjJXYjJX[JV_[:R^ZZJ/ZJF[ZJF[ZJF[
ZjN][:R^XZBUXJ>TXJ>TX::SXJ>TXZBUXjFVY:JWZZV[ZjZ/YjJXWIbNTi:DRhZ<PH22N7MiNWIaNGE`
NGE`N7A_MW9]LfmZLFeXL6aWKFMPJfENJF=LJF=LJVAMJVAMJ69KIV1IJ5mEIeiDIEaBHeY@HUU?HUU?
HeY@HeY@E4m6FE99GEI=GeI=GEA;FDi6F4]3ETU1Fdi6FDa4ETU1ETU1EdY2EdY2E4LoDTDmBT@iBT@i
BT@iBdDjBdDjBdDjBdDjBdDjB48gB48gB48gB48gAd4fACldA3hc@cdb=3L^=cL[>3PX?3PV?3HY=C0]
;BT_9b8a7B`X7b/[7bX^72D^6R4Z620W6R<W7bHY8RLV8RLZ7R8W61/S61XR8B0T9R@T9R<O8B4Q8B8P
8b@P92HP9RDQ9R@T9R8X9R4Z9B8T:BHX;BX/;BX/;BX/;BX/<Bh`=34c@3di@Slk@d0l@Shm@ShmAD50
C4Q7DDe<DE9>De9>DU1?E51?EDm@EDm@ETi?ETi?Cda7DDi9E55<F5E@G5UDH5eHHf1KIF9MI5aEI5aE
IUiGIemHJ61IJV9KJf=LJf=LIVALIfALIfEKJFEJJfEJJfEHKFEHKFIGIV=EJFIHJfQJKFYLKFYLKV]M
LFiPLg1RKfmOKfmOKViNKViNKFeMK6aLJf]KJf]KJFIGJFIGJFIGJ6EFIV=DHUm@Gea=GEY;FeY5GEa7
H5i<IV=DJVIKJF=LIEmJHEYGFEI7De11BTLh@d0b@3`a?c/`?ST`?CP_>2`P>2`P>2`R>2`R=bXR=bTS
=bTS=RPR91lF:B@K;2LN:RDL9R4H91lF9b8I;2LN<2TP<BXQ<R/R<R/R<R/R<R/R<BXQ<2TP9b0G9b0G
9b0G9b0G9b0G9b0G9b0G9b0G8Q`E8adF9R0I:28K:B<L:B<L:28K:28K<2/L<B`M<bhO=C0Q=S4R=c8S
=c8S=c8S;34L<CHQ>3XV>C/W>CXV>3TU?3/W?SdY<C@U<C@U<3<T;S4R;C0Q:bhO:RdN:RdN8b`G8b`H
9b`M:2`Q:b`S;B`R;2`N;BdM8b@P8RDS8bHT82DT7b@S724R6QlP5QdP6R8H6R8H6B0I6R0K728M7b@R
8BHT8bPW7B8P8bPV9R/Y8bPW8RHW8bLX8bHZ8B@X6b<R72@S7BDT7RHU7RHU7BDT7BDT72@S6b0N6b0N
6b0N6b0N6b0N6b0N6b0N6b0N620P620P6B4Q6b<S7RHV8RXZ9Rh^:C4a8B/[8bh/8bh/8B`Y7RTV7RXT
8RlW9S<[7bTM8bdQ:C<W;CL[;SP/<3X^<S``<cda;cTY<C/[=3h^>48b?4Hf?dTi@D/k@D/kB5E5BeQ8
BEI8AE55AU57Ae9:@4Y4=3dj=T0c=T0c<cd`:cDX92hQ92hQ;3HY<cd`=CHRCDdkI6EEK6aNJfeQK6eS
JFaSIFQOG6ACFF5@HFQIL7MZM7]^Jg5VIVaQJVmVKG=RKG=RKWASKgETL7IUL7IUL7IUKgETIfeRJFmT
Jg5VKG=XKWAYKG=XJg5VJFmTKViPKViPL71RLG5SLg=UM7AVMGEWMWIXLW9TLW9TLg=ULg=ULg=ULW9T
L71RL71RJf]MKFeOKViPKFeOK6aNKViPM7AVNGU[L7=aL7=ZM7=UNGEROGYUP7iVOX1ZOGm[JWA^KGA_
KWA_LGE`M7EcMWAcNGEdNGEdRG]TRG]TQgYTQgUWR7UYRWY^S7]bSGacO7QgNWEbNGI^P7]bQ81ePh5f
PH1fP85gNgm/OH5^Oh=`OH5^NWi[N7aYNGeZNgm/NgY/NgY/NgY/NgY/NgY/NgY/NgY/NgY/NWU[O7]]
OGa^O7]]NWU[NGQZNGQZNgY/OGa^OGa^OGa^O7]]NgY/NgY/NWU[NWU[N7QVN7QVNGUWNWYXNg]YOGe[
OWi/OWi/OGa^OGa^OWe_OWe_Ogi`Ogi`Ogi`P7maNg]YO7aZOWi/P81^PH5_PX9`PX9`PX9`P81^OWi/
O7aZNg]YO7aZOgm]Ph=aQXIdPh=aQ8AbQHEcQXIdR8QfRHUgRXYhRh]iR8MiRHQjRhYlRhYlRhYlS8]m
Shj0TY63Si5nRHioRI6:CeYH114C00`@0@d?0P/>00@80a0>1A0821@8H6]Q?4Y6>4U<EVM`Hg=/IGUd
IG]fH7McH7McJ7YiJWQgIg1cHG9YGg1WH6iSH6aPHVYOIf]OJVaPKFeOU91dYIj3^k>Fb/2Rcl>QcKnK
bk^Fb[^Db;bJb[jLcL6OcL2Pb[fMb;ZMb[ZMbk^Nb;fMb[nOc<6Qc<6Qb[nOb[nOcL:RclBTc[nOc[nO
c[nOc[nOc[nOc[nOc[nOc[nObKjNbKjNbKjNbKjNbKjNbKjNbKjNbKjNcKjNcKjNcKjNcKjNcKjNcKjN
cKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjN
cKjNcKjNcKjNcKjNcKjNcKjNc;fMc;fMc;fMcKjNcKjNcKjN003:`KS:`KS:`KS:`KS:`KS:`KS:`KS:
`KS;`[W;`[W;`[W;`[W;`[W;`[W;`[W;`[W9`[W9`[W9`[W9`[W9`[W9`[W9`[W9`[W8`KS8`KS8`KS8
`KS8`KS8`KS8`KS8`KS6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kKAb;o3^[6WW9B2MFeODTY>?SM??cQG
ACiNCdILCDALCDANCdISE4]XFE1[G5=/GEAZHEQ/HeY_IEicJF9eJVIfJVQgJfUgJfUcL6QeLVYhM6mi
MG1iM75jMG9lMgInNGR1O7V1O7V1O7V0NgR0NgR0NgR0NgR0NgQlM7AfKViaJFU`J6QfKVimMGF1NGV3
Ng^=OW^?Pgn>Pgn7P7f5PH26QhF6R8R2QhJ7QhN:RXZGUiNXZ:R_[jn[Zj^YZJV[Zj^^[Zj^[Zj][Jf]
[Jf][Jf][Jf][Jf][JfWYjNYZJV[Zj^/[:b][Jf/[:b[Zj^ZZZZUY:JYZ:ZZZJ^VYJNVYJNWYZRUY:JP
Wj6j]k>OW9QoO7Q/JFEYIV9/JFEZIf=UHUi[IV=[IV=YI65WHUmUH5eTGeaRGEYQG5UOFE9MEe1IDdaE
CdQABdA>B45;ACi:A3e>B45>B45=Ad1<ASm:A3e9@ca8@S]8@S]2?3E6@3U:A3e:A3e8@S]7@CY9@ca;
ACi6?ca6?ca6?ca6?ca8@Ci;A45>AdA@BDIDDDeEDTiDDDeCD4aBCd]CD4aFDdmJEe=MFUIMFUIMFUIO
G5QRGe]UHUiYIV9[J6AYIfI]JfY`KVe^K6]YIfIUHf9UHf9WIFAhLg1jMG9nNGJ1O7V3OW^3OW^2OGZ1
O7UoPgilP7]fNGM^L71ZJVY]J6YeJg5lL7IjMFaeKfQ]J6EWHF9SGUmUHUiVIeiYJV1_JfI/J6=XIF1W
If5YJF=XJVAUIf5PI5iQH6AQH6ARHFETHfMUI6QVIFUWIVYWIVY[HFiSHGAOHgESIfaXJUiXJUMKJ5Y?
IF1UH5MUH5MUH5MUH5MVHEQVHEQVHEQVHEQVHeEVHeEVHeEVHeEVHeEVHeEVHeEVHeETIeQUJ5UWIeUX
J5YXIeUXIeUXIEMXIEMUIU9UIE=VIUAWIeMXJ5QYJ5YZJ5eZJ5eZJ5e[JEi/JUm/JUm/JUmZJ5eXIU]W
IEYVIEMQH59RHE=ZJE]/JeeSHUAMG4iLFdeMGUAKG59LG51LG4iOGdmPH4iRHDeRHDePFdaRGDiUHDmX
I59YIE=XI55WHe1VHTmcK5=TFD]QDdeRFDaOFD9QGd5TGdYLDdU=C3QACcePGTaBCd1=BSa>Bce6@SM7
@cQaL68e=2Ha<29IF4Z2PG=3@S@[:Q`i>2Xf<R0^:QP^:QP[9QLV81<^:1/c;B8X8QL/;1`Z:QXK6`]=
CCdU9AD`<20^;Qh^;Qi2>R<l=1dl=1e1>B90>24l=1e1>B9<A2e5@2M3?RDo>b9=BC52?bXd<ahn?BTb
<Ad]<Qdg?2La=B8W:Q/Z;20Z:b4Z:b8b<R`c;adb;Q``;1X^:QP]:AL/:1H/:1H/:1HM7QXJ6aLE6A@F
6QDG7APG7QTF7APC6QD@5a8?5Q4@5a8C6A@J7QTP91lY:RH];RXU;2LW;RTZ<B`/<bh/<bhZ<B`W;RTU
;2LU;2TV;BXW;R/W;R/U;2TS:RLP9b@O9R<R:BHI81dP9b@P9b@K8QlH7a`F7AXW;R/S8c4S9RXS:1lM
:1@K;1LW?S10F5QAKGAGLH9LMGl_AT8R=bPX>bHT=B0/?BlM;R<]=bX[=BPZ=2L/=RT`>Rdc?C0b?2l_
>B`_>B``>Rdb?2lf@3<lASU2C3m5Cd97DDADFda9D4=EG4m:D4E<DTLoA3]7C4<h?3Hk@c8h?Rdd>RTb
=BD[;Qh];Qhn?RiADD5WJU]XJea[KUm/Kf1VJEYRIEIZKEieN6U]KUY]KUY]KUY]KUY]KUY/KEU[K5QZ
JeM^KEm_KV1`Kf5`Kf5aL69`Kf5`Kf5_KV1bLF=bLF=bLF=bLF=aL69`Kf5^KEm]K5ibLV1]KE]]KEeb
LV9dLfEbLF=`KV=bL6EdLVMdLVMcLFIcLFIcLFIbL6EbL6EbL6EiMfaaKfAfM6UkNFifM6UhMV]oOG9k
NFj1P79hMfUeM6IlNff2PG>1P79mO6imO6j3PGImNg1gMFYgMFYkNFimNg1hMV]cLFIkNfUgMfEnOVb2
PW1iNFMkNfV0P6ijNVQjNF]kNValNfeiN6YgMVQhMfUmO6j2PG>2PG>1P79oOW1mO6ilNfekNVajNF]j
NF]kNVajNF]iN6YiN6YiN6YiN6YjNF]kNVagMVQgMVQiN6YjNF]kNVakNVakNVakNVajNF]kNValNfem
O6imO6imO6ilNfekNVakNVajNF]hMfUhMfUhMfUjNF]kNVamO6ikNVakNVakNValNfelNfemO6imO6im
O6inOVanOVanOVanOVaoOff0P6j2PW22PW1oOfenOVamOF]mOF]nOVb1PFn5QG>7QgF9QgF:R7J:R7J:
R7J;RGN;RGN;RGN<RWR;RgV;RgV;RgV;RgV;RgV:RWR:RWR:RWR@Q7:DS7^DSX5fMfdA5a8340h75QP2
5AP84@h94Pl?6QL440YCHUYLKF@J:b1YNVmPN7IWOG]^Ph1fQ89gPWmhOG]fNGMfMgEgMFY`Kf5]J5U_
JEInMF6ISGFbYH_5]i_;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c<_Ig<_Ig<_Ig<_Ig<_Ig<_Ig<_Ig<
_Ig<_Ig<_Ig=_Yk=_Yk=_Yk>_io>_io>_io=_i_=_i_=_i_=_i_=_i_=_i_=_i_=_i_;_IW<_Y[<_Y[=
_i_=_i_>`9c>`9c?`Ig;_IW;_IW;_IW<_Y[<_Y[=_i_=_i_=_i_<_Y[<_Y[<_Y[<_Y[<_Y[<_Y[<_Y[<
_Y[>`9c=_i_=_i_<_Y[<_Y[;_IW;_IW:_9S;_IW;_IW;_IW<_Y[<_Y[=_i_=_i_=_i_<_Y[<_Y[=_i_=
_i_=_i_>`9`00<[1^<[1^<[1^<[1^<[1^<[1^<[1^<[1^<_2^L_2^L_2^L_2^L_2^L_2^L_2^L_2^LW2
^LW2^LW2^LW2^LW2^LW2^LW2^LW2^LS1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<Jo]/Jo]/Jo]/Jo]/Jo
]/Jo]/Jo]/Jo][V`Yl>j/Lg2^/Zo]kFXX9:2Nf]KE592>eA5?5M8?ei?AVEFCFYKDVUJDFAEC5m@AfeT
FfmVGG9YH7AZHgEZIWAYIG9VI75UHgE_J7MaJWYdKg]eL7YcL7]dLGifMX1hN7mjMgmjMh1kN81kN81k
N81kN81kN81kN8V1PHAlO7mgMg]cLg]cLgUaLGM_KgA/K7EYIGicKhImNXZ3P8j:RI6ATHj@T8Z<S8^;
Rhf=SIJFUZBTY:VYZJFUYJ>SXjFUYJ:RXZ:RXZ6QXJ2PX9nOWinOWijNWYjNWZ6QXJ6QXJ:RXZ>SXj>S
Xj>SXj:RXZ:RXYbKWJ6PXZ>RY:6PXZ:QXjFTYZFTYZ6PXYFCTXB2PFm]K6ARHFARHFITHf=QH5iLFeUD
DeUDDeYEE5YEE5]FEEaGEUeHEeeHEf5NFV5NFV9OFf=PG6ERGVQUHF]XI6aYIG5^JW9_JgIcKgYgLgik
Mh9oNhJ3OhN4P8^8Q8j;Qi6>RY6>RXj;Qhf:QXj;Qi2=RINCTYJBTIJBTINCTYVEU9bHUijJVJ2LVi>A
T9:@Shj<RhV7QXF3PXB2PHN5Q8Z8Qi>AT9>AT9:@Si:@SiBBTIJDTiRFUIVGUY>AT9BBTIBBTI>AT96?
SXn=S92>SI6?SXf8QHb7Q8^6PhV4PHJ1OX=nNh1kN7iiMWYaM7A/KF]THFEPEf=OE6EODVQPDfQPDf5L
CEiJCe]HD5UEE5QFEEQIEeUMF5YNF5UGEeEEEEADE5AFEUUKFe]PGeYPGeYPGeULH5ULH5YMHE]NHUeP
I5iQIEmRIUmRIVIQHUiPJ5UOJUmRIV]VGG9YFf]XH6=VJVYUG6YUG6UTFfUTFfUTFfUTFfUTFfUTFfQT
FFQTFFQTFFQTFFQTFFQTFFQTFFQTFF9TF69TF6EUFFIVFVMUFVMUFVQTFFQTFFATDVATDVEUDfIVEVMV
F6QWFFQVFfUWG6aZGfaZGfaZGfaZGf]YGVYXGFUWG6QVFfETEV5PDV5PDVETEV=RE5]JC5MFB5QGBEQI
CeMHCUQHC5UIBe]KBeaLBUiMBEiMBF=NCfAOD6EQCfIRD6MSDFIRD6EQCVEQCVUSC6EMD6EKE6MNE6QT
C6EUAfERCFANDf]/G6QYFEEEAe9BA4];?f1OEG]jL96?QhF6O5UJD4U:@69SFGenM5MHCT11=dU:@4Y6
>dQ4>Di:?di:?dE1=TU5>T]7?40m;clm<T90=CDc:5iLDD4o=3Pf:bd[82d[83Pb7cH`7CLa7SXd8CXd
8CPb7cTc83`f8c/i8D0m:40m:4E4<3<d82/[6DI7=dU:>T13<dI9>DE8>D54=Cdo<bh`928S6B8S6BLT
5RHS5B<P4R4N420M3alL3R0M3b0M3a`M6AXK5aLH51DI51DK5QHL5a<J5A4H4aLN6ALN6ATO6Q`R7B8V
8BX[9bl`;38c;c0g<S0g<S0g<Rlf<Bhe<2dd;b`c;R/b;Bdd<Bdd<Bdd<Bdd<B`c<2/b;bT`;BT`;BD/
:BL^:b`c<2@[:24X9BH]:R@[:2H]:R<W:2P[:BT_92<[828[:2diADQCLE]YTfem/W5oZD5?IRXf>RDc
:20^72hm:2Le8bPb9BH`8bD_8RLa92/e:2dg:R`f:BXd9b/e:2hh:c4k;S@n<CI0<cQ2=C]5>3e7>T1:
>T=<?dQAA4aDBCm7?459?ce5>cLn=cM1<34k:S<k:SU1<498=d]>?UMJBV=VEVMZFf=VEf1SE5iQDUaO
D5mRDfY]GWQkK6UZEVY[EfY[EfY[EfY[EfY[EfY[EfUZEVe/GVi]Gfm^H6m^H6m^H6m^H6i]Gfi]Gg5`
HW5`HW9aHg9aHg9aHg5`HW1_HFm^H6m_GF][FF][Fg5aHGEdIW=bI7=aIWEcJ7IdJGIdJGIdJGEcJ7Ec
J7AbIgAbIgAbIgMeJW1^Hg9`IGEcJ79`IGEcJ7YhKGMeJVi]GgEdIWmnL8F4MXR7NHZ9Nhb;OHn>P7mm
LWajKgMeJWEcJ7MeJWYhKGekL7ilLGYjJ7=cHGMgIGYjJ7AdHWUiIgmoKGUiIgYiJg]jK7elKWakKGYi
Jg]jK7mnL8:1Lh1oLGmnL7elKWakKGYiJgUhJWUhJWUhJW]jK7YiJgUhJWUhJWUhJWUhJWYiJg]jK7Mf
J7QgJGUhJWYiJg]jK7]jK7]jK7]jK7akKGakKGelKWimKgelKWelKWakKG]jK7UhJWQgJGMfJ7MfJ7Mf
J7QgJGYiJg]jK7]jK7]jK7]jK7akKGakKGelKWelKWelKWinK7inK7inK7inK7moKH20KX:2L8:2L820
KWmoKGinK7emJgmoKH:2L8F5LhN7MHR6M8R6M8R6M8V7MHV7MHV7MHZ8MXZ8MXZ:N8Z:N8Z:N8Z:N8^;
NH^;NH^;NH^;NI><Ni:=OXj>PWMlLadW8@XH5`PL7@PM7`lV8A@[9PdT7a@[8deUFfZ2N1lg:f^3Mg>6
PgB5PGB3OgAnN71hKW1dJG9aIg=aIWIaHX1lJY:<NJJNQkN[TkncUlBfVLJgUl^lW<^lW<^lW<^lW<^l
W<^lW<^lW<^lW<bmWLbmWLbmWLbmWLbmWLbmWLbmWLbmWLbmWLbmWLbmWLfnW/fnW/fnW/joWljoWlfo
VlfoVlfoVlfoVlfoVlfoVlfoVlfoVlbnV/bnV/foVlfoVlfoVlfoVlfoVlk0W<^mVL^mVL^mVLbnV/bn
V/bnV/foVlfoVlbnV/bnV/bnV/bnV/bnV/bnV/bnV/bnV/foVlfoVlfoVlbnV/^mVL^mVL^mVLZlV<^m
VL^mVL^mVLbnV/bnV/bnV/foVlfoVlbnV/bnV/bnV/foVlfoVlfoV`00b/6hb/6hb/6hb/6hb/6hb/6h
b/6hb/6hbl:ibl:ibl:ibl:ibl:ibl:ibl:ibl:ibL:ibL:ibL:ibL:ibL:ibL:ibL:ibL:ib<6hb<6h
b<6hb<6hb<6hb<6hb<6hb<6ha[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfc/Nnbl:iakjeakbdb;^c_k:Z
/Z:KYYJ?JemEI5Q>G516F4a2G516HeM=JemEL6AJIE]AIE]AIEYBJ5aFKV9LMf]WP7A`QWUgMW1YN79[
NWA_NgE`NgAaNgAaOWIfP7QhOWUfOgYgOgYgOgYgP7]hP7]hPGaiPGaiQH1oQ7mnQH1oQH1oQX60Q7mn
OgYiNgIeM6UUKFAQHEYGF5=BGe]JLW9bQXR9TI>DShn?T92@UIFEWIfMX:2PWYjNW9bLWYjNWYjNWYjN
WIfMW9bLVi^KVYZJVIVIVIVIWIfMW9bLVi^KVYZJVYZJVYZJVi^KVi^KV9NIW9^MWYfOW9^MW9^MX9nQ
X9nQW9^MZZRWYJ>RX9jMWYbKX9jMX9jMWYbKViVHViNFViNFWIVHWYZIX9bKXYjMXinNY:2OW9bLW9bL
WIfMWIfMWinOX:2PXZ:RXj>SV9RHVIVIVi^KWIfMX:2PXZ:RY:BTYJFUVi^KWIfMWinOWYjNVi^KVIVI
VIVIVIVISHj<SHj<SHj<SXn=T96?TY>AU9FCUIJDXZ2OX9jMW9ZIUI>BT8j=Shf<THn>U9:AWI^JW9ZI
ViVHVYRGVYRGVYRGVYRGViVHV9JEUYBCU9:ATi6@Ti6@Ti6@THn>T8j=SXZ5S8R3Qh=nPGehNgMbMG5/
LViYL6aWLf5XJe]LHEI>GUE7GeU6Ge]8G5Y8FEI7DE1<DE5ADU5JDU=QD5AVCUIWC5IWBEITBdm/BDeZ
AD]XAdeZBU9_CEQdDEahDUeiEEmaEV1bEV1bF69dFF=eFVAfFfEgFfEgIfebGVUgEVAgGVAaKfMXNfQS
MfISKfAWK6YPJfUOJfUOJVQNJVQNJFMMJ6ILJ6ILIfEJIfEJIfEJIfEJIfEJIfEJIfEJIfEJHF=GHVAH
IVIJIfMKJFMLJFMLJfMLJfMLI6ABI6ABIFEEIVIFIfIHIfEJJ6IKJ6ILK6YOJfUNJVQMJ6IKIfEJIfEJ
IfEJIfEJIVEGI6=EHV5CHV5CGEa>EUE7E5=5EeI8DeE9DeE9EEE7EEE7EUI6EUI6F5I4F5I4HEe;HEe;
HUi<HUe>I5m@IF1AIf9CJ6=DG5]7HUiCGUMDFEA;G5]6F5XmDe8mF5A9@DDiGV9GEe]@T9>:S8j8U9J@
Wj2LYJJRT9B>OX9lH6ANIf]UMGUcOh=mNGegQHV3Ph60IVASC4]7>c/e=CH]@48f@dDi=3LXA48jD4i6
@d4iEE=;CTa4?C/c>cTa@T0hCDXkCd`mCDXkBDHgAd@eAD8c?c`]>3DV@40^?Sh/>S`YC4dmAdXk?44b
ADTm=SX^B4ToBT]1DU=9F5Y>D596?3l`<3<T<C@U=SL]=3D[<C8X;c0V;RlU;c0V<C8X<S<Y;blY;BdW
:B/U9b/U:2`V9RdV9B`U8RXS92`U9B`U9RdV:BdW:blY;c4[<S8/<c<]:S4Z:C0Y9bhW9RdV9B`U9RdV
9bhW:2lX7bDP7bDP7R@O7R@O7R@O7R@O7R@O7bDP6R0K9B/V9B/V6b4L6AlJ8BLR8BLR5Q`G7BDK8bTN
9B/P8BDP7R0[9RM9>S]cCDjBE5^[FV6V>Si^8bLo82DX7RDH:S<O:S@M9RlR9BhQ92dP9RlR:34T:S<V
:C8U:34T9c0S;SLZ=Slb>d@g?TLj@DXmATm2BeA7?TTiC5I9AU13CUQ<>48f@T]1<S/a<3Pa<3d];3TY
<3/[?dXjDUa<GVEFHVUJIV]LIfYKHFAEGV5BH6=DHfIGIVUJKG1QMGQYJ6UEJ6UEJFYFJV]GJV]GJfaH
JfaHK6eIKFaNKVeOKVeOKfiPKfiPKVeOKVeOKFaNKfiPL6mQLG1RLW5SLW5SLW5SLG1RLG1RKFeKJFUG
JFUIL71PMGAVMGAVMG=XN7I[MWAYMWAYMWAYMWAYMG=XMG=XM79WM79WOgebO7Y_NWQ]NGM/NgU^Ogeb
PX1ePGmdQ8=eTi:4Wij@Y:>E[:^M]KBV]KBV[JbNZJNLYjFJX9jCTY25Q89gO7Y_O7Y_OgebR8QhOgm_
PH5aP81`MgMWNWYZPH5aO7a/MGAVN7MYNgY/O7]]O7]]O7]]OWe_Ogi`OGa^O7]]NgY/NWU[NGQZN7MY
MgIXMgIXNWU[NWU[NGQZN7MYN7MYNGQZNWU[NWU[MgIXN7MYNGQZNgY/O7]]O7]]O7]]NgY/OWe_OWe_
Ogi`Ogi`OWe_OGa^NgY/NgY/MgIXMgIXMWEWMWEWMWEWMgIXNGQZNGQZNgY/NgY/NgY/O7]]O7]]OGa^
OGa^OGa^OWi/OWi/OWi/OWi/Ogm]P81^PX9`PX9`P81^Ogm]OWi/OWi/P81^PX9`Q8AbQXIdQXAbQhEc
QhEcQhEcR8IdR8IdR8IdR8IdR8QfRHUgRHUgRXYhRh]iRh]iS8ajS8ajShn1QXUjQXb1N8=k;S`h3b4P
324R42LY01PA22TR0R4H7S`a@EaBJ89e5RhREVmQKGQ`KWI_KgM/LWIZMgQXOgiZR8E`T8adZ:29[ZJ?
^[2Ha[ZNcKnRd<6QckjMckbIbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbL
bkbLbkbLc;fMc;fMc;fMc;fMcKjNcKjNcKjNc[nOcKnKcKnKcKnKcKnKcKnKcKnKcKnKcKnKcKnKcKnK
cKnKcKnKc;jJc;jJc;jJc;jJb[bHbkfIbkfIbkfIc;jJc;jJc;jJc;jJbkfIbkfIbkfIbkfIbkfIbkfI
bkfIbkfIc;jJc;jJc;jJc;jJbkfIbkfIbkfIb[bHb[bHbkfIbkfIbkfIc;jJc;jJc;jJc;jJc;jJc;jJ
c;jJc;jJcKnKcKnK0039`;O9`;O9`;O9`;O9`;O9`;O9`;O9`;O:`KS:`KS:`KS:`KS:`KS:`KS:`KS:
`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS6_kK6_kK6_kK6
_kK6_kK6_kK6_kK6_kK6_kK0^K2n]Jc1^:o:_kO@`k_>`KW9_;C0]:Z/X9J>PWQbIUaODdUGBd5FBT1G
Bd5YGeEYGeEZH5I/HEU_HeebIV1eJFEfJVIhL6UkLfamM71nMG5nMG9nMG:1MgN3NGUoNWMoNWN0NgR1
O7V2OGZ2OGZ3OW^4Ogb2OGb4Ogj9Q8>=R8N@RhZAS8^@RhZ>RHR?R8FARXN?RXV<R8N=Rh^DTiFJVI^H
VY^BTY:BTY:EUIFHV9RKVi^KVi^LW9bMWIfOWinOWinOWinNWYjNWYjNWYjMWIfMWIfOWinMWIfKVi^J
VYZIVIVJVYZKVi^LW9bJVI^NWInMW9jIV9ZHUiVKVYbJVI^FUINIVIVLW9bPX:2SXj>TY:BTY:BSXj>R
XZ:SWYnSWYnSWYnSWYnSWYnSWYnSWYnSWYnMX:BLWj>JWJ6HVinFVIfEV9bEV9bEV9bQY:RQY:RPXjNO
XZJNXJFMX:BLWj>LWj>GVYjHVinHVinFVIfDUi^BUIV@TiN@TiNIWYfIWYfJWijKX9nLXJ2NXj:OY:>P
YJBLW9bLW9bLW9bJVYZGUiNFUYJHV9RJVYZKVi^KVi^JVYZIVIVHV9RGUiNGUiNGUiNJV9NGUIBDTY6D
TY6ETi:BT8n;RHR4PX5mNGAjMW5dL6]_JfIZIV5WHeiVHUeVHUeXGeaUGEIRG4mNFdeJFe9EF5a@EFA=
DV]4CG=3C7M3C7i0BhDkBXPhBX/dB8TbBHLd@Y@b@98_?Hl/?Hh/?i0`@i@aAYLcB9ThCXlhCXliCi0j
D94kDI8lDY<mDi@nE9E9G8loEi4lEY9=G8YVIgagK6igJfEbJ65^Jf=^Jf=]JV9/JF5[J61ZIemYIUiY
IUiWIE]WIE]WIE]WIE]WIE]WIE]WIE]WIE]TIE]UIUaYJ5i[JV1]Jf5]Jf5_JV5_JV5WIeMXJ5QXJ5QX
IeUYIeaZJ5eZJ5iZJ5iZJ5eXIU]VI5UTHUMSHEISHEITHUMTHUMZJE]YJ5YWIUQSHUAMG4iIF4YIF4YK
FTaBEDIDEdQGEdUFETQEEDEDE4AFDdAFDdAEDd5EDd5EDd5FDdAIETMMFTaRGe5THE=PIEISI61GE5I?
CTYNH4eUJE1TIU=]JV9iPGNCVY=aN76h_[VVZjVPYJ>PYJBKX9nMY:6Z/Jj;TXmhOgaKHUmGGU/^=C8O
9R<g=cdN7R@92``00@031`4V;257CT5>EDHh=C5THEeYIV9ZIf=eLViXIF5]JVIaKVY`L6AcLfMaLFEZ
JUiYJEeZJUiTI5QJFTiPHeALGe1DFDYPI5QDFTm5CD9<E4XmAC/h=c<i>3A;BdEJFe5@DTI4AcQ9C3aB
ET=9CDM8C4I6BTA5BD=6BTA8C4I<D4Y>DTaOGeUOGeUOGeUNH5YMHE]MHE]JHEYJHEYAF55AF55DF59C
Ee5DEU1DE4iADD]@D4Y>EDi>EDi>EDi>EDi?ETm@Ee1AF55BFE98CTU7CDQ6C4M5BdI6C4M7CDQ9CdY;
DDa1Ad99CdY2B4=3BDA2B4<oAD13BD@i?cXk@3Lm@cPn@SLl?CTh>T8j?5A3AFi:CH0nB8Q:Dha1AVdh
>Dhl?D4o?cU0@38o@30j@cHj@cHi@SDj@cHkA3LkA3LkA3Lj@cHf?c8mASU7D4=<EDQ=ETU?F4]CG4mG
H5=GI5AQKV1KJ5YCGe=IIEUPJf5GHUQ>FE58F4M5EDA6ETE?G4aII5AHHe=AFd]9Dd=?DT=?DT=GFT]V
JEY_LV=`LfA]L65]L65ZJeMZJeMZJeM[K5Q/KEU^Ke]_L5a`LEe_KV1`Kf5`Kf5aL69`Kf5_KV1^KEm^
KEm^KEm_KV1aL69bLF=cLVAcLVAcLVAcLVA^KUaZJUQZJUY`L61dLfEdLfEeLfQhMV]eLfQeLfQeLfQd
LVMdLVMcLFIcLFIcLFIaKfAgMFYcLFI_KF9eLfQjN6elNVn0OW>NWHnTXiFTXiFRXI>^[Ink^Zba/::J
VH^KVHjTXYNYYibTXYNFU8V=Rh2=Rh2BT8FDU8BATH6EUHF>SWijNVYdM6AjNVYhN6Q`Kf5bLF=fMFMi
N6YkNVakNVajNF]jNF]kNVakNVakNVakNVajNF]hMfUgMVQfMFMjNF]iN6YhMfUhMfUhMfUhMfUiN6Yj
NF]hMfUhMfUjNF]kNValNfelNfelNfelNfeoOW1oOW1oOW1oOW1nOFmlNfekNVajNF]gMVQgMVQgMVQg
MVQhMfUhMfUiN6YiN6YkNVakNVakNValNfelNfemO6imO6imO6inOVanOVanOVanOVaoOff0P6j2PW22
PW20P6j0P6ioOff0P6j1PFn2PW24Q7:5QG>7QG>7QG>7QG>7QG>8QWB8QWB8QWB9QgF7QgF8R7J8R7J9
RGN:RWR;RgV<S7Z<S7Z8Sh20RGb9ThN0SX=3Dd`F9b<?8QlH;B/A;b@M>2hG;b<R=RXb@cI=G4hE7a99
DTE_Kf=dM6ImOF^;R7>GTgZVX8>d[Hbn]I?AaZS>`jG;_Yk9^Y[9^9O:^YK>_9O?_IS;_9c;_9c;_9c;
_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c<_Ig<_Ig<_Ig=_Yk=_Yk=
_Yk<_Y[<_Y[<_Y[<_Y[<_Y[<_Y[<_Y[<_Y[>`9c=_i_=_i_<_Y[<_Y[;_IW;_IW;_IW:_9S:_9S:_9S;
_IW;_IW<_Y[<_Y[<_Y[;_IW;_IW;_IW;_IW;_IW;_IW;_IW;_IW;_IW;_IW;_IW;_IW;_IW;_IW;_IW;
_IW:_9S:_9S:_9S;_IW;_IW<_Y[<_Y[<_Y[;_IW;_IW<_Y[<_Y[<_Y[=_i/00<W0]lW0]lW0]lW0]lW0
]lW0]lW0]lW0]l[1^<[1^<[1^<[1^<[1^<[1^<[1^<[1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<S1
^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo][ji/;nj/LBm]<Ro]/W0
]lNl]<>h/<6d[=?9_lc2^;neZjjTVYR>Q7meJfQNE5U?AEU=@EiBAVEICfeQEg9UGGEWHGIXHWEWHGI^
IgUaJW]bKWedL7edLGieLX5gMh=iNGmjMgmjMh1kN89mNX=nNhF0OHJ1OXJ1OXZ6QH^7QXb8Qhf9R8f9
R8j:RHj:RHn;RXV5Q8n;RY>?SY2>SY6>T96@TXj=THR7Ri>CTiBDU9FEUIJFUYVIVIfMWJ2PX:2PX9bL
W9bLW9fMWIfMWIjNWYnOWinOWj2PX:6QXJ2PX9jNWYbLW9bLW9bLW9fMWIjNWYbKWInNX9jMWiVHVYRG
VI^JW9^JW9NFV9bLW:6QXJJVYZRXZ:NWYjJVYZRXZ:VYZJ^YZJ^YZJZXZ:ZXZ:VWYjRVYZNUYJNUYJ2T
ZJ2TZJ2TZJ6UZZ:VZj>W[:FY[ZJZ[iZNXiZNXi^OY9bPYIfQYYjRYijRYinSZ9nSZ9jRYijRYifQYYbP
YIZNXiRLXIJJWi:HUi:HUiBJVIFKVYJLViNMW9NMW9NMW9jNWZ:RXZJVYZNWYjJVYZFUYJBTY:BTY::R
XZ:RXZ:RXZ:RXZ6QXJ6QXJ2PX:2PX9nMW9fKVYbJVI^IV9VGUY2>SH>1P7UgMW=`J75^IVaYHFQUGFIS
FfERFVISFfMTG5eSDV5WE65YF5YRFd]DHSa7Lc=1RC90VBHjVB@gVQhbWA/^XAL]Y1@/YQ<^Ya4_YP`S
[PXQ[0LNZ@<MY`4MY`<OZ@HS[@TV/0PZXPT[X`X/Y0/]Y@`^YPd_Y`h`Z0h`Z0l/W`P/XPdbY2U7X59P
TFmcOWIhK75gH79_JW9_JW5^JG1]J6m/Ifi[IVi[IVeZIF]ZH6]ZH6]ZH6]ZH6]ZH6]ZH6]ZH6]ZH6MX
GVQYGf]ZH6e/HVi/HVi/HW1[HVmZHFa/G6e/GVe/GVe[H6e[H6i/HVi[Hfi[HfaZGfYXGFQVFfESF6AR
EfAREfESF6ESF6YYFf]ZG6UXFVASEF1ODEiMCeeLCUeLCUMJBUYMCEiOCeiOCeaKCEYIBeeJC5iKCE9B
@55A?e1@@51@@59A@eIDBEYHCUeKDE=MEdY>DcHh@c8e>DeCB6ecH7j0M8>1P5QPFF]cK4A;AY2GU8jE
TY^QX:R^[JR][YBLVhnGUTaDDaLO7P0100D=30081`L?3P001P0010@52@430`45028W7U5GC6Q_HQ8@
3e]IF7EcLWIdLh1nOGQfMGUgMW1^KG9cJGEfK7AeJg9cJGAeJgUjL7UjL7EfK6icI7QlL7=gJfE[H3a4
>Blg;EYRFg5iLS`j>Chm>EQHDVIWGUAEBda?@5QKBemRDUEIE5AHDeAHDeEIE5MKEU]OFUmSGV5UH6ES
FfMUGFQYH6Y[HVU/HfQ]I6Q]I6U^IFEZHFI[HVM/HfY]I6]/HfUZHFQVGVMUGEmTFf5VGF=XGfAYH6=X
Gf5VGEiSFUaQF69VH65UGf1TGUmSGF1TGV9VH6AXHVEYHg1dKVibK5mSGG1dKVeaJeQLEVEYHfM[IFU[
JfUZIVY[HV]]HFa`IFYaK6M`LfA_MeEYNV5aOV9[M5aOHf]YJ7A_K6MSGVEQG5eTEeeTEeiUF5eTEeaS
EUaSEUaSEUeTEeQODUaSEV1WFV1WFUaSEUQODUMNDEQODU]VEUYTEeeWFSm9?GZ4N7b5NhVBR7InMgN6
N7V8NWV8NWN4MW5kKVI`HeUREDmHBdY=?T]>?eIIBVMZFg9eIW1cI6U/GFEXFFY[EfY[EfY[EfY[Efa]
FFi_Fg1aGG9cGg9aHg=bI7=bI7=bI7=bI79aHg1_HG1_HFi]Gfm^H75`HW=bI7AcIGAcIGAcIGAcIG9b
H6e]Ff][Fg1`H7=bI79aHg9`IGIdJGIdJGIdJGEcJ7EcJ7AbIgAbIgAbIgAbIgAbIhF3N85oM7UgK8>1
MXR6NhR6Ni>AQZb[WK6`XZRWVIJEQi6@PYJEQhj=OgelKXj<PInMT[2^XkFcZ:^YWYnMTYVGS9RFRhf<
OY:APifLSYBCQGEdIVQWFFi]Gfm^H6m^H75`HWEdIWUhJW]jK7]jK7YiJgQgJGYiJg]jK7akKGakKG]j
K7YiJgQgJGMfJ7UhJWUhJWQgJGMfJ7MfJ7QgJGUhJWUhJWQgJGUhJWYiJgakKGelKWelKWakKGakKGmn
L7mnL7mnL7mnL7imKgakKGYiJgUhJWQgJGQgJGUhJWYiJgYiJgYiJgYiJgYiJg]jK7]jK7]jK7akKGak
KGelKWelKWelKWinK7inK7inK7inK7moKH20KX:2L8:2L861Kh61Kh61Kh61Kh:2L8>3LHB4LXB4LXR6
M8R6M8R6M8R6M8V7MHV7MHZ8MXZ8MXN7MHN7MHR8MXV9MhZ:N8^;NH^;NHb<NXVAP8B>OY6KRhJ@Pe9M
DaDR6PTH41DS7A/T5alV5b@Y6QdN3SLe8eQA@5QA?X^1KiNBOJ2IQJZUS;F^Tl2fV<FkVLRoV/g2W<Ri
V<VjVL^mVLnoVlnoVm2nVLjlUlbjUL^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^l
W<^lW<^lW<^lW<^lW<^lW<^lW<^lW<bmWLbmWLfnW/fnW/bnV/bnV/bnV/bnV/bnV/bnV/bnV/bnV/fo
VlfoVlfoVlbnV/^mVL^mVLZlV<ZlV<VkUlZlV<ZlV<ZlV<^mVL^mVL^mVLbnV/^mVL^mVL^mVL^mVL^m
VL^mVL^mVL^mVLZlV<ZlV<ZlV<ZlV<^mVL^mVL^mVL^mVLVkUlZlV<ZlV<ZlV<^mVL^mVL^mVLbnV/^m
VL^mVL^mVL^mVLbnV/bnVP00b;nfb;nfb;nfb;nfb;nfb;nfb;nfb;nfbL2gbL2gbL2gbL2gbL2gbL2g
bL2gbL2gal2gal2gal2gal2gal2gal2gal2gal2gb<6hb<6hb<6hb<6hb<6hb<6hb<6hb<6ha[nfa[nf
a[nfa[nfa[nfa[nfa[nfa[nfa/6ha/6ha;nf`[^b`KR_`[V`b;fec/>k_;:X`KN]bKnecL>ib/2f_K>Y
Zj6GWiF;LVMIJEeAGU96Ed]1FDe3IEQ@M6IPOW1ZLVQQMF]TN6eYNVm[Nfm]OW9`PGEeQ7QhOGQeOWUf
P7]hPGaiPgikQH1mQh9oQh9oQh>2R8B3RHF4RHF4RHF4RXJ5SHV8T8b;TI:@TY>AShn?RXV;SHb>UYFI
W9^OWI^QTi>CUYJFUYJFUYJFVIVIX:2PY:BTY:BTWYjNWYjNWinOX:2PX:2PXJ6QXZ:RXZ:RXJ6QX:2P
WinOWinOWYjNWinOWinOWinOVYVKWIbNWIbNVYVKVYVKWijPXJ2RWYfOU9JGV9ZKVifNVifNVI^LV9ZK
VifNWZ2QXj:TXj:TXj:TY:>UYJBVYZFWYZFWYZFWW9nSW9nSW9nSW9nSWJ2TWj:VX:>WXJBXWj:VWj:V
Wj:VX:>WXJBXXZFYXZFYXjJZW9nSVijRVYfQVYfQVijRVYfQUiZNUIRLUi^LV9bMVYjOVinPW:2QW:2Q
W:2QW:2QVI^LW9jOXJ>TXjFVXJ>TWZ2QW9jOW9jOW9jOW9jOWInPWZ2QWInPWInPW9jOVifNW9ZIW9ZI
ViVHUiFDT8j=Ph60MG=bK6YYLW1VKfeSJfUOJ6ILIF=IIF=IIVAJIfEKF6A>Gf]EHFeKE61P?4YW93=k
5BRG4BB]1b:X11jX0AVY01F[01B^01Jb01Zd0aje00ne00ne012f012e016f01>h01Rm01c101bh01bh
01fi01jj01nk026m026m02:n01jf01bi02Bk5cbdAEfUJ7F;LgeaKW]QNWMbNGIaNGIaN7E`N7E`MgA_
MgA_MW=^MG=[MG=[MG=[MG=[MG=[MG=[MG=[MG=[K6eTK6eTKfeUKfeUKfaTKV]SKfURKVQQLG1RLG1R
LFmTLFmTLFmULFiVLFiVLFiVLW1ULFmTKfeRKF]PJfUNJVQMJVQMJVQMJFQJJVUKJ6MIIFAFHf9DHf9D
GEa>EUE7EUY7Fem<HV=CI6EEI6=EHf9DIf=HJVIKIFIBI6ABHV9BH5mAH5iCHV1FIF9JIV9MCEQP;cM8
6b0e61h[;38aF61FMWYeKVidOhMmSiJ?NX5j[K>^YjbZYjbZXZNVVYnN[kJcZ:n/PXV6IVeZEEaICEAA
<cXg:c8_>3Xk828S30h>00<100@05AXA9b`S8RPM4A8>BDY6EUMCGf1LEUMCEeQDGEiJF5UEHV9FH61D
H61DHV9FGemCG5a@GUiBHf=GEUU:GF1AEea=E5Q<=S`a;3@YDe]AHf]Q>SXd>c/eEEE?G5eD@T<j>c`b
@D8h=CH/@TI0@dM1A4Q2ATY4B4a6Bdm9CU9<Ce==H5iDHV5GIfILIfQNIfQNIFUNI6YOIVaQJFmTJg5V
L7AYMGI/MgQ^NGQ^NGQ^NWQ^L7AYLGEZLWI[LGEZKW9WJFeRI6QMH6AIIFMQIFMQIFMQIFMQIFMQIVQR
J6YTJ6YTIfUSHfEOC4i8HfEOGEmI?d4kEeUCH69LHV=WHfARIFILJV]KKG=LJgENIgEMHG=LEfeKFfeL
GfULEEU=IfILNGE`K6UULFiZJFeQJfmSJfmSJViRJ6aPIVYNIf]OJ6aPJ6aPJ6aPJFeQJFeQJFeQIf]O
IFUMHfMKHVUJGFAGGfII<cT^Ri66SY>:YJZQSI6;Si^?Uj>GWjVMW:JJUinDTiV>S9:7RHf2OX5bMgY[
M7MXMWUZMGQYKW5RJ6]LIVUJJ6UEJ6UEIfQDIfQDJFYFJfaHKVmKL75MMGAVMGAVMGAVMGAVM7=ULg9T
LG1RLG1RKfiPL6mQLG1RLg9TM7=UM7=UM7=UM7=UMGESKfmMK6aLL71PLG1RL6mQLFmTM79WMWAYMWAY
MWAYMWAYMG=XMG=XM79WM79WPGmdWifBWI^@THn4W9Z?WI^@WI^@[jfR/K2R^[V[/k:TUYF7NWU[LW5S
MWEWNGQZRHMlV9J;ZjVN];:W[J^PWifBTHn4RHMlQXEgSXeoWIb>UIB6MWEWJ6MIKfiPLW5SM7=UMGAV
MgIXNgY/OWe_Ogi`O7]]NGQZNGQZNWU[NgY/O7]]O7]]NWU[N7MYMgIXNGQZN7MYN7MYMgIXMgIXN7MY
N7MYNGQZNGQZNGQZNgY/O7]]OGa^OGa^OGa^OGa^OGa^OGa^OGa^OGa^O7]]NgY/NWU[NGQZN7MYNGQZ
NWU[NgY/NgY/NgY/NWU[NWU[NgY/NgY/NgY/O7]]O7]]OGa^OGa^OGa^OWi/OWi/OWi/OWi/Ogm]P81^
PX9`PX9`PH5_PH5_PX9`PX9`Ph=aPh=aPh=aPh=aR8IdR8IdR8IdRHMeRHMeRHMeRXQfRXQfQhMeQhMe
R8QfR8QfRHUgRXYhRXYhRh]iR8ehQX]fTYJ3PXIcHVEE9bXK6ah?92HJ<RTE?C@PGE8lH5<mOg5JWhid
/Z67dKfT^K6C_kNIb;jPcLBScL:RbknMak^IakVEakVEb;ZFb[bHbkfIc;jJc;jJc;jJc;jJbkbLbkbL
bkbLbkbLbkbLbkbLbkbLbkbLb[^Kb[^Kb[^Kb[^Kb[^Kb[^Kb[^Kb[^Kb[^Kb[^KbkbLbkbLbkbLc;fM
c;fMc;fMbkfIbkfIbkfIbkfIbkfIbkfIbkfIbkfIc;jJc;jJc;jJbkfIbkfIbkfIbkfIbkfIbK^GbK^G
bK^Gb[bHb[bHbkfIbkfIbkfIb[bHb[bHb[bHb[bHb[bHb[bHb[bHb[bHbK^GbK^Gb[bHb[bHb[bHbkfI
bkfIbkfIbK^GbK^GbK^Gb[bHb[bHbkfIbkfIbkfIb[bHb[bHbkfIbkfIbkfIc;jJ0038_kK8_kK8_kK8
_kK8_kK8_kK8_kK8_kK9`;O9`;O9`;O9`;O9`;O9`;O9`;O9`;O7`;O7`;O7`;O7`;O7`;O7`;O7`;O7
`;O8`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kJe/jVm^k79a;_?
b/7@bL3=a;_8_kK7_;C=a;[;`[S:`KO9`;K8_kG6_K?1^:jm]:[1]:J_XYBDQWYiJemWF4mQDDYRDT]V
ETmZH5U]HeaaIV9dJFEfJVQiKF]mLG60M7AjMG9kMW=mN7EoNWN1O7V4Ogb5P7f6PGimNgZ1Ogj5Ph:7
QHB8QXF:R8N>S8^BT8miNg^4QXJ@TY:HUiVJVIfJVIfBT9J9QhfCTi>GUiNHV9RFUYJIVIVQXJ6UYJFS
Xj>SXj>SXj>SXj>RXZ:RXZ:QXJ6QXJ6QXJ6PX:2PX:2QXJ6RXZ:RXZ:RXZ:QXJ6QXJ6LVifOWZ2NWInJ
VI^KVYbQX::SXZBPWj6NX:6QXjBSYJJSYJJSYJJSYJJUYjRVZ:VOWZ2PWj6QX::SXZBUY:JVYJNWYZRX
YjVYZjbXZZ^VZ:VUYjRTYZNTYZNTYZNTYZNWZJZVZ:VVZ:VUYjRTYZNSYJJRY:FRY:FRY:FPXZ>OXJ:Q
XjBTYZNTYZNQXjBOXJ:MWj2NX:6PXZ>RY:FRY:FRY:FQXjBQXjBOXJ:QXjBRY:FRY:FQXjBPXZ>QXjBS
YJJSYJJSYJJTYZNTYZNTYZNRY:FPXZ>OXJ:TXZ6TXZ6QWijIUiJ=RhZ1OgigMGAbL6m_KF=]Jf5ZJ5iW
IE]UHeUTHUQTHUQTHUQPHEMUJ5UWJEeJGf11C6XV=GhA9YT67Z`06ZL05jL04jT03jX03Z/24Jd55Jh9
5jl04:`04jl05[805k<05k<06KD37kX89;l08Kl08Kl08/008l409L<19/@29lD29lD6;/809l809l8D
>ka4FJiZLYMgNgadNFYkNWIkNWIkNWIkNWIkNWIkNWIkNWIjNGEjNg9jNg9jNg9jNg9jNg9jNg9jNg9j
Ng9eMVeeMVefM6aeLf]dLFUbKfMaJfA`JV=dLfEdLVMcLFIcLFMcL6QcL6QcKfYcKfYeLfQeLfQdLVMc
LFIaKfA_KF9]Jf1/JUmZJE]/JeeYJ5YWIUQXIeUXIeUKFTa<Bce8CCQ@ED1KGDYPHE5SHUAUHeQ/Iei`
Jf9aLem`LUi`LF5`L69aL6IcLFUeLVegM71KJG/c?5LV:d`P9SdK8R]8D4m]L7EEEF=PIU][LFI^LfZ0
QGb5RH>GViJUZJBa];:OYJ1jP7]MHeiQIf:5RhJ2R8=kPGamPgj7Qh5TI5i8B48o?cU6AT1HF59HFE12
@cY;CDMIFeECEDmiNgELGUQKGEMLGUQRI5iOGU1IF4YNGDmVIEMNGDm>CCm@Cd5NGDm@DSm8BCU2@c=A
E4E?E4E:CT9BF4e1Ac`l?C<d=B]6Aci9BT4e=Blo?cU5A40V9B4g>2li>S4k?3<m?SDn?cHn?cHn?cHn
?cHm>c51?cE5A3Y6AC]3A3Xo@cPo@cQ1ACY2AS]3Aca5BCi:Bd5>CD=@CdEBD4ICDDMCEdaCEdaCEdaA
EDY?DdQ<D4E9CD97Bd13ASe3ASe4Aci5B3m5B3m5B3m5B3m4AciFFE1LGeI0@cY?DTU5B3lZ;BA>DDQC
ETe5BDA9BdE@CdEAD49@D3i@E45BFTUDH4iBGDeDFdiJG515@cU=Bd5NGU9@DTIKGe=JGU9LH5AMHEEK
Ge=GFdmEFDeFFTiHG51KGe=HG51HG51LH5ASIe]XK61WJemTJ5a[KUm_LFEWJEdo@3JBThVQXYVa/ZVP
X9ZAVHjKXiRSZIjQYibRYY^UYYbTYI^OX9JHVhb>TH:3QWMlOg1eN6U]L65ZKEi]L65ZJeMXJEEWJ5AW
J5AXJEEZJeM]KUY_L5aeM6IeM6IeM6IeM6IdLfEbLF=aL69`Kf5`Kf5aL69bLF=dLfEdLfEdLfEdLfEd
LfEfMVA_Kee/K5a_KemaL69`Kf5aKfAdLVMbL6EbL6EbL6EbL6EaKfAaKfA`KV=`KV=cLFJKVHjLVXn;
RGjCTHJAShB?SH:WYIZXYiVWYYRLVhf6QGM_KV1THeEYJ5YbLF=YIeadLVN6Q7VGUHZPWY>NW96EThR=
Rh2;RGj?SH:JV8fDTXMlNVmbL6EiMfaiMfahMfUgMVQhMfUjNF]nOFmoOW1lNfeiN6YfMFMgMVQiN6Yk
NVajNF]iN6YfMFMeM6IiN6YhMfUgMVQgMVQgMVQgMVQhMfUiN6YiN6YjNF]kNValNfemO6imO6imO6im
O6ijNF]jNF]kNVakNVakNVakNVajNF]iN6YfMFMgMVQiN6YjNF]kNVajNF]iN6YhMfUkNVakNVakNVal
NfelNfemO6imO6imO6inOVanOVanOVanOVaoOff0P6j2PW22PW21PFn2PW23Pg63Pg63Pg63Pg63Pg63
Pg66Q7:6Q7:7QG>7QG>8QWB8QWB8QWB8QWB8R7J8R7J8R7J8R7J9RGN9RGN9RGN9RGN<Rg6;RG6IUGf<
R72?R7AXHDeWGTY/HdnHRVjWVGbiZhk6^IW0/i?CajG9_IW<_Y[1^Y?5_9O8_i[9_ig9_9c7^Ic7^Ic7
^IcAaJ7=`Ig7^iO3]iG2]YC3^IO8_Yc;`Io;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c:^i_:^i_:^i_:
^i_:^i_:^i_:^i_:^i_:^i_:^i_:^i_;_9c;_9c;_9c<_Ig<_Ig;_IW;_IW;_IW;_IW;_IW;_IW;_IW;
_IW:_9S:_9S:_9S;_IW;_IW;_IW;_IW;_IW9^iO9^iO9^iO:_9S:_9S:_9S;_IW;_IW:_9S:_9S:_9S:
_9S:_9S:_9S:_9S:_9S8^YK9^iO9^iO9^iO:_9S;_IW;_IW;_IW9^iO9^iO9^iO:_9S:_9S:_9S;_IW;
_IW:_9S:_9S:_9S;_IW;_IW;_IT00<Ro]/Ro]/Ro]/Ro]/Ro]/Ro]/Ro]/Ro]/W0]lW0]lW0]lW0]lW0
]lW0]lW0]lW0]lO0]lO0]lO0]lO0]lO0]lO0]lO0]lO0]lS1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<Jo
]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/S6_<G3^LBo]/6l/l:k//Fl/lJm]<Nn]LBk/L:i[l2g[L:i[lFl
//Nn]<Ro]LNn]<JiZlVl[/Vl[/6cYjjOUY>4NgQXHFMGD6EIDfQLEVaPG71TH79UHgIYIgY/KGi`LGQc
L7UdLGYeLWehMGmjMh9mNXAoO8F0OH>1P8N5Q8b:RHf;RX^9R8Z8Qh^9R8f;RY2EU9:DU8b>ShF7R8N6
RY2>U9RDVYVEVi>CTiRHV9VIVIJFUYRHV:6QXJBTY:6QXJ>SXj:RXZ6QXInOWijNWYbLW9^KViZJVZ2P
X:6QXJ>SXjFUYJJVYZFUYJBTY:>SXj6PXZ>RY:6PXYbKWI^JW9jMWinNX9bKWIJIWIRKWi^NXYfPY9jQ
YInRYZ2SYj2SYj>RYZBSYjFTZ:FTZ:JUZJNVZZRWZjRWZjFSXZFSXZFSXZJTXjNUY:RVYJZXYj^YZ:JT
XjJTXjNUY:RVYJZXYj^YZ:bZZJbZZJRVYJJTXjJTXjRVYJbZZJf[ZZ^YZ:RVYJ>OY:BPYJJRYjRTZJRT
ZJRTZJNSZ:JRYi^NXY^NXY^NXYZMXIVLX9bOXj:UZJJY[J>VZZ>VZZBWZj>VZZ:UZInRYYfPY9^NXZ6O
WZ2NWIbJVI6?SX>1P7MeM79`Kg5_KVi/HVe[HF]YGfUWGFQVG6MUFfMUFfMUFfeOHfmSHFiWGVESHU5G
KSQ5PahdVQ0YZ@<LXP4IX@@FX`<CXPLBXPXBX@`CWPlEWP0@V@<CW0LGX0HHX@@GX0DHX@LMY@XPZ00P
/`0P/`0Q]04R]@8S]P@U^0DV^@DV^@/d/`0X/P0T/Q4d/dAE[6m_WH9kRX5lNg]jMW]jMW]jMW]jMW]j
MW]jMWakMgakMgalMWalMWalMWalMWalMWalMWalMWalMWmoNGinN7mlMgaiM7YfLGMcKWI`JgA^JGAb
IgAbIgAbIgAbJ7AaJG=`J7=_JW=_JWAbIgEcJ7EcJ7AbIg9`IG1^Hfe[H6]YGVm^H6m^H6a[GFYYFfe/
GVa[GE]JC4M6>3Tn:D97<U1B?eQIBEeLCV5OE6]VGG5/HfY/F6]]FFi_Gg5aHgEdJWUfLGejMWmkNTmN
N2<]Cb4XCahT@@TA7SLm@V1RK40nDC8d:4A6>VEVG6EVG6]/Hg]kMHN7PIRHT[Nk]GAhLTmCCEEIDhV=
QfmcKEmSGEUMEe]KCf=SEg=bJ75`IV1NEUeJEF9OFU]HDfIYH5iQF5mRFK2cZXR;PWAgKUePEemRFFQU
EVAQDW5^GhB1LWmlKF]XFFm/GHJ3M6i]FFEVDU]KBFMXF69UEEaOD6Q]GU]ODfe`HEeODfEVG6QYH6=S
GHB2PI:@T6aZJV1PE65QEF=SEfEUFFATF69REV1PE5iNDV1NE6ARF6UWGFQWGF9SFEmPEUeQEUiREe]O
E5]OE5eNE5eNE61OEF5OEF9PEV9PEUEICUAHCE=GC59FBe9FBe=GC5EICUIJCeEHCeIID5QKDUULDeUL
DeQKDUIID5EHCdiAB65TFd54>dE8?cPk<RLZ8E5DBdiAB4M>@E1DB5MGBe=AAd]8@4a9AEIFEUmRIVe/
KW1^KWQbLeQACU5<@eIGAci5<4UF?4]?@diBATmCAda@A4Q<@4I:?TM;?dU=@Da@A4M;?d=7>dI:?TmC
AeAHC55EBDeAADE4=UMEBTQ6>bl]8gEcJIJCRijKTiRDSiRNTijRUibPUIFFS8n@QY2?QH^9Oh5oMGAg
J6iaHVa_H6a_H6a_H6Y]GVe`HG=fIfe^FVa]FFY[EfUZEVY[Efa]FFm`G75bGWAcIGAcIGAcIGAcIG9a
Hg5`HVm^H6i]Gg5`HW9aHg=bI7AcIGAcIGAcIGAcIG=bI7EeHfi^G6][Ffi^GW5`HW1_HG9`IGIdJFe[
H6aZGfaZGfaZGf]YGV]YGV]YGVYXGFe[H9bJSijLTHZ8OI2>PhZ8OHN5NZ:PUK6`XYfLSXV8NX:1Lh1o
LG]jK7MfJ7IeIh^9OXj<PIFCR:6OU:VWW:RVVijLTIBBQi:@QHn=PYBBQhn=PWajKgMeJW]iKWMeJWQg
JGIeIgEdIWQgJG]jK7akKGYiJgMfJ7AcIGEdIWQgJGUhJWUhJWMfJ7EdIW=bI7QgJGQgJGMfJ7IeIgIe
IgMfJ7QgJGQgJGUhJWYiJg]jK7elKWelKWimKgelKWelKWQgJGUhJWYiJgYiJg]jK7YiJgYiJgUhJWEd
IWIeIgQgJGUhJWUhJWUhJWQgJGMfJ7]jK7]jK7]jK7akKGakKGelKWelKWelKWinK7inK7inK7inK7mo
KH20KX:2L8:2L8:2L8:2L8>3LHB4LXB4LX>3LH>3LH:2L8F3LHF3LHF3LHJ4LXJ4LXJ4LXN5LhN5LhV9
MhV9MhV9MhR8MXR8MXR8MXR8MXR8MYJBMYN@MJBMPZ:IO/BiW[FWT;j^Ul:bVl>gULZnW;ZaS<g4WjbU
O]7=Y;jjTKbhSlW2UlS0V<JmUlBkU/:gUlNiWL^lX]30ZL:fT/BhU/FkVLNmVlNnWLJmW<FkWLBjW<^l
W<^lW<^lW<^lW<^lW<^lW<^lW<^lW<ZkVlZkVlZkVlZkVlZkVlZkVlZkVlZkVlZkVlZkVlZkVlZkVl^l
W<^lW<bmWLbmWL^mVL^mVL^mVL^mVL^mVL^mVL^mVL^mVLVkUlVkUlZlV<ZlV<^mVLbnV/bnV/bnV/Rj
U/VkUlVkUlVkUlZlV<ZlV<ZlV<^mVLZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<RjU/RjU/VkUlVkUlZl
V<ZlV<^mVL^mVLRjU/VkUlVkUlVkUlZlV<ZlV<ZlV<^mVLZlV<ZlV<ZlV<ZlV<^mVL^mV@00akjdakjd
akjdakjdakjdakjdakjdakjdakjeakjeakjeb;nfb;nfb;nfbL2gbL2ga[nfa[nfa[nfa[nfa[nfa[nf
a[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfa;fda;fd
a;fdaKjeaKjeaKjea[nfa[nfa;fda;fda;fda;fda;fda;fda;fda;fdaKje`kbc`[^b`[^b`[^b_kR_
^kB[]k2WUHR0QWUaLfINJ5]CJEaDL6=KMVUQNFaTMV]WMfaXNFiZNg1/OgA`PgQdQgahRGijQhAlRHIn
RXJ1RHB1R8>0RXF4T8^:UHn@SXn=SHj<S8f;Rh^;SHb>T8nAU9>GUiJJT9>GTYFIUIRLUYVMUiZNVIbP
WJ2TX:>WYJ6LWYZETXj9QH5lN7A_LfmZOWYeS8R3TY6CUIBFVYVKX9nQXj:TYJBVYZFWYZFWWj6RWZ2Q
W9jOVYbMVI^LVI^LVI^LVI^LWj6RXZBUYJNXY:JWXJ>TXJ>TYJNXZJ^/XjFVXjFVXjFVY:JWY:JWY:JW
YJNXYJNXYJNXY:JWXZBUWZ2QWInPWj6RY:JWZ:Z[YJNXYJNXYJNXYZRYYZRYYZRYYjVZYjVZYJF[YJF[
YJF[YJF[YJF[Xj>YXZ:XXJ6WXJBYX:>XWj:WXJBYXjJ[YJR]Y:N/XjJ[X:2VX:2VX:2VX:2VX:2VXJ6W
XJ6WXJ6WYJNXYJNXYJNXYjVZZ:Z[YjVZXjFVX::SXjBRXZ>QVIZFRXV5P7ehNWMbMgA/LVmWKfaTKV]S
K6UQJVMOJFINJFINJFINJFINJ6INIfUMIFYKH6QMG6ASFUm^FEakFeZ4<d6C:S^B7c:C4RbH22NP026W
01^Y01JY1an]11b/01NX01:X01:[01Fb01Vg01bl11nf11nf0B2g0B6j02>m02Jo02O302W41BRn0Rc5
02c70C:n84^jDfjaMGjIOgemNWUeNgYfNgYfO7]gNgYfNgYfNWUeNGQdOGahO7]gO7]gNgYfNWUeNWUe
NGQdNGQdMgQ_MgQ_MWM^MGI]M7E/LgA[LgA[LW=ZMW=[MG9ZM75YLg1XLg1XLg1XLg1XM75YM79XM79X
M79XM79XM79XM79XM79XM79XLW1VKfeSK6YPKF]QL6iTL6iTKVaRJfUOF5M9EUE7E5=5E5=5F5M9GUe?
IVEGJVUKLW1VLW1VLg5WMG=YMWAZMgE[N7I/NGM]Jfb8FEim?DU[8SEH62Y77Rdm<3Tl?T8m<S0VAD<i
FeU?I69HHf5GIF=IL6iTO7Y`THn5MG=YHV1FK6YPNGM]MWAZJfUOIF=IJFUIJFUIJ6QHJ6QHIfMGIVIF
IVIFIVIFKFaNJ6IKKV]SZ:BOXinJIF9JIVAILg9TJVYJKFeMLW5SMWEWMgEZM79XL6iTKF]QLW1NK6YH
IVABI69@IfECJfUGKF]IKF]IK6aLLg=SM7=ULW5SO7Y_RhUoRXQnOWabLFmTKfeRKF]PKVaQL6iSKfeR
JVQMIVAIJVQMJfUNKF]PKfeRL6iSLFmTLFmTLFmTLFmTLFmTLFmTLW1ULW1ULg5VLg5VLg5VKViNJVYJ
IFEEIFEEJ6QHJf]KK6aLJf]KKVeOKVeOKfiPL6mQL6mQKfiPKVeOKVeOJ6MIJFQJJFQJJFQJJ6MIIFAF
HV5CHF1BJFYFHF9>I6ADJfYLI69HHEeHQ7ml/jj]/k30`l7=]K>iP820H65HIVMGK6iJIFQ?JVUEJFQD
JFQDJ6MCJFQDJVUEJfYFJfYFKFaHK6]GJfYFJVUEJFQDJ6MCIfIBIVEAF5];EeY:FEa=HVEFKFmSLgAZ
LgAZL75WM7MXLgIWLWEVL7=TKW5RKG1QK6mPJfiOJVUKJfYLK6]MKVeOKfiPLG1RLW5SLg9TL71NLG5O
LG5OKfmMK6aJK6aJKFeKKfmMJfiNK6mOK6mPK6mPK6iRJfaRJV]QJFYPJVaPJVaPJ6YNJ6YNJ6YNJVaP
JfeQKFmSL7=TL7=TLW9TL71RKfiPL6mQM75SMgAVKfiPKfiPKVeOKVeOKfiPL6mQLG1RLG1RMGM[RH]o
V9Z>VI^?UIN;UiV=VYb@VYb@YJBFZJRJ[ZfO[JbNYJBFUIB6QHAfNgY/W9n@YZVJ/;>T[k:SWj:CRXen
N7]/KW5RLWMXLgQYLgQYMWUZNGU[NWY/O7]]OGa^MGQYMgY[NGa]NGa]MgY[MWUZN7]/Ngi_NWe^N7]/
MWUZMGQYM7MXM7MXMGQYMWUZNWYXNg]YO7aZOGe[OGe[OGe[O7aZO7aZNWi[NWi[NWi[NGeZN7aYMg]X
Mg]XMg]XN7]/N7]/MgY[MWUZMGQYM7MXM7MXLgIWLgIVLgIVMGQXMWUYMgYZMgYZMgYZMWUYOH1`OH1`
O7m_O7m_O7m_NGa/MWUYLgIVOh1/PH9^PX9`PH5_Ogm_OWe_Ogi`P7maNGUWPh9dQH5fPWedOgU^Q7e^
ThejP7aTR8=ZR8=ZR8=ZR8=ZR8=ZRHA[RHA[RHA[ThE_U8I`V8YcWY5gZ9eo/JJ6]jb<^[2>_:j:`[>B
aKJEa[NGbKZJc;bOa[FJ_:^@`[RF`[RF`KNE`KJF`[NI`kRJaKVMa[ZN_[RK_[RK_kVL_kRM`;VP`KZQ
`KVR`KVR^K:I`;JNclJ[aK^Ma;VIdLFQaKZDak^Cb[bHb[bHb[bHb[bHb[bHb[bHb[bHb[bHb[bHb[bH
b[bHb[bHb[bHb[bHb[bHb[bHbkfIbkfIbkfIbkfIbkfIbkfIbkfIbkfIbk^Gbk^Gbk^Gc;bHc;bHc;bH
cKfIcKfIcKnEcKjGcKjGcKfHcKfHcKfIcKfIcKbKb;ZFb;ZFbK^GbK^Gb[bHbkfIbkfIbkfIbk^Gbk^G
bk^Gc;bHc;bHc;bHcKfIcKfIc;bHc;bHc;bHc;bHc;bHc;bHc;bHc;bHbk^Gbk^Gbk^Gbk^Gbk^Gbk^G
bk^Gbk^Gc;jJc;jJbkfIbkfIbkfIbkfI0037_[C7_[C7_[C7_[C7_[C7_[C7_[C7_[C7_[G7_[G7_[G7
_[G8_kK8_kK9`;O9`;O6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6
_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK3_;?4_KC4_KC4_KC5_[G5_[G5_[G6_kK4_KC4_KC4_KC4
_KC4_KC4_KC4_KC4_KC4_KC3_;?2^k;3_;?4_KC3_;?0^K2n]jk>`KW3]ZjbYIfQU8bAQ7aoLVY]H5QQ
E4a]HeaaIf1fK6EjL6UlLV]kLFYhKVMfK6E`JV=jM6f9PgjBS8NCS8V>QXJ8P825OGf<SHV>Shf@THnC
Ti>CTYBBTI>AT9B@Si>CUIJEUiRHVY^IVibJW9fLWYnPXZ>TYZNUXIamNGAACDQ2?SUACDQ/J6>6PWfF
TXfIV9ZLVifPWj6TXjFWYZRXYjVXYjVXYjVZ[:fWZJZQXjBLWYnJW9fKWIjNX:6PXZ>RY:FRY:FRY:FP
XZ>MWj2MWj2NX:6OXJ:QXjBQXjBQXjBQXjBRY:FRY:FSYJJSYJJQXjBPXZ>OXJ:LWYnKWIjLWYnPXZ>S
YJJSYJJSYJJTYZNUYjRVZ:VWZJZXZZ^XZZ^WYjfWYjfXZ:jXZ:jWYjfVYZbUYJ^TY:ZTYjbRYJZRYJZS
YZ^VZJjWZZnVZJjUZ:fTY:ZTY:ZUYJ^UYJ^VYZbVYZbWYjfWYjfUYjRUYjRVZ:VXZZ^Z[:fYZjbUYjRR
Y:FSY::RXj6HVIF9R8AnNgIiMW5gM6acL6Q`KFE^Jf=]JV9[J61ZIemYIUiYIUiYIUiYIF1ZJEmZKEiX
K61SJFAPIFiOHGUQH81LHXmDGXi<Ei13DiDkD9/eCJ4^BJ@WAJ@U>ZLQ=J@G;j4?9ih88Yh58:048:<3
8:H37Z@27jH28:L08JX08jd09Jl09k80:;<5:[04;KP0;KT0;[8G@ji5HjYVMiQbN8=mO7QmO7QmO7Qm
O7QlNgMjNGEhMg=gMW9hMg=hMg=hMg=gMW9gMW9fMG5fMG5eM71aLVUaLVUaLVUaLVU`LFQ`LFQ_L6M_
L6MfLf]fLf]eLVYdLFUdLFUdLFUdLFUdLFUdLVQdLVQdLVQdLVQdLVQdLVQdLVQdLVQbL6I_KF=]Jf5^
K69`KVA`KVA^K69/JV1ZJ5eYIeaWIEYVI5UXIU]/JUm`KV=cLFIaKfEaKfEbL6IcLFMdLVQeLfUfM6Yf
M6Y]KGeDFVd_>e<C8S`<6S0L:3@k@45ADdeQGeEXIUa_KF=_KF=ZJ5iTHUQSHEMUHeUfM6YUHeUNG59Z
J5ibL6I^K69WIE]WIE][Je][Je]ZJUYZJUYYJEUYJEUXJ5QXJ5QTHeEZJ5e/JF6>RXF:QX5UHUYYIea[
JUaYJEU[Je]_KV1bLF=cLFIaKfE^K69[JEmaKee/JUQXIUAWIE=ZJ5I/JUQ]JeU]JeUYJEU_Kem_KV1]
K5ieLfR2P7J1OgEfM6YaKfA`KV=^K65`KV=aKfAaKfA]Jf1YIea[JEi/JUm]Jf1_KF9`KV=aKfAaKfA`
KV=`KV=`KV=aKfAaKfAaKfAbL6EbL6EbL6E`L61]KEeYJEUXJ5Q[Je]^KUi^KUi]KEe^KEm_KV1`Kf5`
Kf5`Kf5`Kf5_KV1^KEmZJE]ZJE]ZJE]ZJE]XIeUWIUQVIEMUI5IXJEEQHTiRHU9YJ5YVI5YTHEUiMG2G
TXn=SI>OWZ:HV9QiN7ATIE][K5aaLUi/KUQ[JUIZJEEZJEEYJ5AYJ5AZJEE[JUI/JeM^KEU^KEU]K5Q/
JeM[JUI[JUIZJEEZJEETJEARIU=QIE9VJEU/Kf1_LV=/KV9XJUi[KUm[KUm/Kf1/Kf1]L65^LF9^LF9_
LV=[JUa[JUa/Jee]K5i^KEm_KV1`Kf5aL69^KUa_Kee_Kee]KE][JeUZJUQ/K5Y^KUa[KUi/Kem]L65]
L65]Kf=]KVA/KF=[K69_LFE^L6A]Kf=/KV9]Kf=^L6A`LVIaLfM`LfA`LfAaLF=_Kf5^KEm^KEmcL69f
LfEaL69aL69`Kf5`Kf5`Kf5aL69cLVAcLVA^L6AkOG65Qg^3QGUoPGEoPGEoPGEmOg>@Sh6JVH^XYiVb
/J>c/ZB[ZYbNWHnEU8Ja]:F`/jBZ[IjLWi29S7ejOFicMVMaM6E_M6E`MFI`MFIcMVMfMVQgMfUiN6Yi
N6YeN6UfNFYhNfahNfahNfagNV]hNfahNfabMFIbMFIcMVMcMVMeN6UgNV]hNfaiO6eeMF=fMVAhN6Ii
NFMjNVQjNVQjNVQjNVQhO6UhO6UiOFYjOV]kOfakOfalP6elP6eiO6aiO6aiO6ajOFejOFekOVikOVil
OfmeN6QeN6QfNFUfNFUeN6QdMfMcMVIbMFEcMVIdMfMgNVYkOVimP71mP71kOViiO6amOVYoOff2PW23
Pg>2PW:3PWB4PWN6Q7V>Sgn:RG^2P7F8PgZ5OgB7PW=jM65lN61mMU^0NEj6OfB<QFZCS76ITWNMUW^O
V7fk[IJl[iFn/IO0]9S3^9[5^Y[5^iW4^YS9`9k7_Yg7_Yg8_Z36_9k1]YZg[96`YHZTW7jOUgVFSW6>
QVV8OfB7OFF8OVJ9OfMoNf:1OFB5PFR:QVj?RWFCSWVESgbFT7f/YI:dZiO6^jFn/iS0]IOAa:C;_IW=
_i_:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S;_IW;_IW;_IW;
_IW;_IW;_IW;_IW;_IW:^YK;^iO;^iO;^iO<_9S<_9S<_9S=_IW=_iG=_YO=_YO=_IS=_IS=_IW=_IW=
_9_9^iO9^iO9^iO9^iO:_9S:_9S:_9S:_9S:^YK;^iO;^iO;^iO<_9S<_9S<_9S=_IW;^iO;^iO;^iO;
^iO;^iO;^iO;^iO;^iO:^YK:^YK:^YK:^YK:^YK:^YK:^YK:^YK:_9S:_9S:_9S:_9S:_9S:_9P00<Jm
/lJm/lJm/lJm/lJm/lJm/lJm/lJm/lJm]<Jm]<Nn]LNn]LRo]/Ro]/Ro]/Ro]/Fn]LFn]LFn]LFn]LFn
]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]LFn]L>l
/l>l/lBm]<Bm]<Bm]<Fn]LFn]LFn]LBm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<:k//:k//:k//Bm]<O0
]lO0]lJo]/Bm]<>h/<>h/<>h/<>h/;nd[;FZXZJKTiZ?QgE[I75WH6aRFfUOF6aRFg=YHWabJh5gL85l
LgmiLWafKgUcKW]dLH9kN8f5QIF=SH62OXB5PHR9Qhb=Rhn?Si6@TY6@TY6@TY6CU9BFUiJHVIRJViVK
W9^MWYnQXZ>UYZJSWhb9QFMTH4U6@T4n>UQEDHV6P[:_ZjVXZZ^Z[:f/[[2_/K6`/[:a/k6`/[2_/K>e
]Zf_/:BVYibNWiVKW9bNWj:TYJJXZJ>UYZ6SY9jPXIfOX9jPXIjPXIfOX9bNWifOX9jPXIjPXIjPXInQ
XYnQXYnQXZ2RXijPXInQXYnQXYjPXIbNWibNWinQXZ6SY9nQXYnQXZ6SY:>UYZFWZ:NYZZV[[:Z/[JVY
[jVY[jZZ/:ZZ/:ZZ/:VY[jRX[ZNW[JJY[ZFX[JBW[:JY[ZR[/:Z]/ZV//JR[/:JV[:JV[:NW[JRX[ZVY
[jZZ/:^[/J^[/JFWZ:FWZ:JXZJV[[:^][Z^][ZV[[:JXZJFVY::SXINHU8N6PWaiM7QeL7MdK7AaJG5^
IVm/I6i[HfaYHF]XH6YWGfYWGfYWGfiUHVmYHW1^Hg5aIFi_IVU[JfQYLfUXN7EeMG5cM6e_MfU/NVE/
OfA[QUmYQeeXR4mPVDYLVD=EUS]=U3=5TRi0TbXlUBPkUQhfVQlgVahhW1diWQ`kXQ`mY1/nYQ/nYQ`l
Wa]0Z18mZPdiY1a4WCiLWE]^TfMcQGakMgakMg]jMWYiMGQgLgIeLGAcKg=bKW=bKW=bKW=bKW9aKG9a
KG9aKG5`K75`K6i_IVi_IVi_IVm`Ifm`Ifm`Ifm`Ig1aJ7MdK7IcJgIcJgIcJgEbJWEbJWEbJWAaJG=a
Ig=aIg=aIg=aIg=aIg=aIg=aIg=aIg9`IW1^I6m]Hfm]Hg1^I75_IFm]Hfe[HGAbIg=aIW9`IG5_I75_
I75_I79`IG=aIW5_IG5_IG5_IG9`IW9`IW=aIg=aIg=aIgAfMVU^LEMPJDUEHDMAFe5GG6=THW5^IWUg
KGMeJgAbJ7=aIg9`IVm]HfQVG6=QEfQVG6ARF6MUFg9`IWAbJ6e[HF]YGfm]Hfe/GVa[GFa[GFa[GF]Z
G6]ZG6]ZG6]ZG5mND6e[H6aYHGA`Jg5]J6MTG6m]HVQWFF][Ffa/G6i]Gg1_HG1^Hfm]Hfi/HVe[HFm]
Ffe[FF]YEf]YEfe[FFi/FVi/FVe[FFQXF6a/G6a[GFYYFg1^HgUgKGMeJfi/HW5_I71^Hfm]HW5_I79`
IG9`IG1^Hfi/HFe[H6e[H6m]HW1^Hg1^Hg1^Hg1^Hfm]HVm]HVm]HW1^Hg1^Hg1^Hg5_I75_I75_I7=b
I71_HFe/GVe/GVi]Gg1_HG5`HW1_HFi]Gfm^H71_HG1_HG1_HG1_HFm^H6i]Gfa[GFa[GFYYFfYYFfUX
FVUXFVUXFVUXFVEVDV9RD69RDVIUEfQVFfUWGFi[HgA`JfEWHG1bK7EfKFY[HFEUEfYZFVe]Ff]/F6a[
Efa[Ef]ZEVYYEFYYEF]ZEVa[Efa[Efi]FFi]FFi]FFi]FFi]FFi]FFi]FFi]FFiaFf]^F6U/EVY/F6e_
G6e_G6Y[FfIWEfMXF6QYFFUZFV]/G6e^GVi_Gg1aHG1aHFa[GFe/GVe/GVe/GVi]Gfi]Gfm^H6m^H6e]
Ffi^G6i^G6a/FVYZF6UYEf][FFe]Ff]^GVa_Gfe`HFiaHVmaIFm`IVm`IVi_IG5cIg5cIg1bIW1bIW1b
IW5cIg9dJ7=eJFmbHg1cI75aHfi^H6e/GVe/GW5^H7AaHg=bI7=bI79aHg9aHg9aHg=bI7AcIGEdIVi`
I7EgJgQjKWIhK7=eJG=eJG5cIfe_HgUhJX:1Li2?PIfLSZBSUJBSUJ2OTIbKSJ2SU9^NSi6DQH>6MgMj
Jg=fIgIiJW]nKg5fIg9gJ79gJ7EhJGQhJWUiJgYiJgYiJgEhJGEhJGIiJWQkK7YmKWYmKWMjJgEhJG]n
KgaoL7aoL7aoL7]nKgYmKWUlKGUlKGYkJg]lK7enKWioKgn0L7n0L7n0L7n0L7UlK7UlK7YmKGYmKG]n
KWaoKgaoKgaoKgEiIWEiIWEiIWEiIWIjIgIjIgIjIgIjIgf0LGf0LGf0LGaoL7YmKWQkK7IiJWEhJGAg
J7EhJGMjJgQkK7QkK7IiJWAgJ79eIW=eHWMhJ7amKH20LX:2M8F5NHR7OH^:P8V<O8R8NXB3NI>AQi6<
Pj6NT7eiIZJSSZfUQk2XR[J^T;bdU/:jW<JnX<W1Xl[2Y;bdUkjfVL2hV/:jW<:kV/2jUkjhUKbfTk>`
TJ>OPY:>LH=oHfm[CeMB>Da6;de7<4]7;dm;<eMB?F9MB6mYEWefIHR1L8j7MZZYUJn^V[FcXKfkZL?0
/LO4]/W6^<[7^L6i[<Fl[];8]/BiYL2eV/k0XlNhV<ZkV/VkUlVkUlVkUlVkUlVkUlVkUlVkUlVkUlVk
UlVkUlVkUlVkUlVkUlVkUlVkUlVkUlZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZjU/ZjU/^kUl^kUl^k
UlblV<blV<blV<bnU<bmU/bmU/blUlblUlblV<blV<bkV/ZlV<ZlV<ZlV<VkUlVkUlVkUlVkUlVkUlZj
U/ZjU/^kUl^kUl^kUlblV<blV<blV<^kUl^kUl^kUl^kUl^kUl^kUl^kUl^kUlZjU/ZjU/ZjU/ZjU/Zj
U/ZjU/ZjU/ZjU/VkUlVkUlVkUlVkUlVkUlVkU`00a[fca[fca[fca[fca[fca[fca[fca[fca[fda[fd
a[fdakjeakjeakjeb;nfb;nfaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKje
aKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKje`kbc`kbc`kbca;fda;fda;fdaKjeaKjea;fda;fd
a;fda;fda;fda;fda;fda;fd`kbc`[^b`[^b`kbca[nfb<6hal2gaKjea;Va`kR``kR`a[^cb;feb;fe
aKZb`KJ^]ZfTZj:IVI27QWedN6mVL6MNKfIMKfIML6UPLfaSN71YOGE^PGQdQ7]hQWejQgikQ8AnQ8=o
Q8=oQH>2RHN6SH^;TXnAUI:DShn?TY:BU9BDUYJFUiNGVYZJWinOXZ:RXj2LZjRTZ:FQSHZ6JVMSIV=O
SHZ6^[Nc/:na/K2b/k:d];>e];>e/k:d/[6c/[6c[k6bZJ^/XJ>TVifNVI^LW9jOXJ>TYJNXXjFVWj6R
W9jOWZ2QXZBUYJNXY:JWXZBUVifNVifNVifNVifNW9jOW9jOWInPWInPX::SXZBUY:JWXjFVXJ>TX::S
XJ>TXjFVVYbMVifNWInPX::SXjFVYZRYZ:Z[ZJ^/ZJV_ZJV_ZZZ`Zj^aZZZ`ZZZ`ZJV_Z:R^YjZ_YJR]
YJR]YZV^ZJbaZZfbZZfbZ:^`Xj>YY:BZYJF[YZJ/Z:R^ZJV_ZZZ`Zj^aYZRYYZRYYjVZZJ^/[:j_[[2a
[:j_ZZb]YZNUXjBRUYNCQXF1NgQcN7E`N7E]MG9ZLVmWLFiVKfaTKFYRK6UQK6UQK6UQK6UQKF=SLFQT
M6mVMW9WM79WLW1XL6i]L6e_LW1NLFiOL6eOKVaQKfeSKfaWL6eYL6eYJG=mIW5oI6j0GfR3FV>4Een7
Deb8DUV:C5V=C5V=CE^@CEfBCUfECEjGBejGBejGAeZ=AejF@5^K=e:E>E>?Bej;GV^5Ig1nMGA`MGA`
MGA`MGA`M7=_LW5]LG1/L6m[L6m[L6m[L6m[L6m[L6m[L6m[L6m[L6m[L75XL75XLG9YLW=ZLgA[LgA[
M7E/M7E/MgA/MgA/N7E]N7E]MgA/MW=[MW=[MG9ZLg5WLg5WLg5WLg5WLg5WLg5WLg5WLg5WLg5WLW1V
LFmULFmULFmULFmUL6iTL6iTM79XM79XMG=YMG=YM79XLW1VLFmUL6iTLW1VLW1VLW1VLg5WLg5WLg5W
Lg5WLg5WJFaMKG5VL7M`LWQgLGMfLgAbM75YMVmVMG=YLFmUKVaRL6iTM79XMWAZLg5WL6iTKfeSKVaR
LW1VN7I/MWAZKfeSKF]QLFmUKFaNKFaNKFaNK6]MK6]MK6]MK6]MK6]MI6=EKVaQKFYRJfMRJVIQK6UQ
LW1UKFaNKfmOL71PL6mQL6mQL6iSL6iTL6iTL6iTKVaJKVaJKVaJKVaJKfeKKfeKKVaJKF]IJf]KKfmO
KVeOK6]MKfeRMG=YLg5WK6YPKfeRKfeRKfeRL6iSLFmTLW1ULFmTLFmTKVaQKfeRL6iSL6iSL6iSL6iS
KfeRKfeRKVaQKfeRKfeRKfeRL6iSL6iSL6iSL6iSLg9TLW5SL6mQKfiPL6mQLG1RLG1RLG1RKFaNKVeO
KVeOKfiPKfiPKVeOKVeOKFaNKFaNK6]MJVUKJ6MIJ6MIJFQJJfYLK6]MHf=AIVIDIfMGIVIFJ6MIJfUN
JFMMHf5GG69AHFADIFQHJFYJJFUIJFUGJVQFJVQFKVeIKFaHK6]GJfYFJfYFJfYFK6]GK6]GKFaHKFaH
KFaHKVeIKVeIKfiJKfiJKfiJK75FJVmDJFeDJVeGK6mIKFmKJfeIJ6YGJFYJJFYJJV]KJV]KJfaLK6eM
K6eMKFiNKfiPKfiPKfiPKfiPKfiPKfiPKfiPKfiPKFeKKViLKViLKFeKJf]IJVYHK6aJKfmMJVeMK6mO
KG1QKg9SL79VLG9XLG9XLG9XL79VL79VL79VL79VLG=WLG=WLWAXLWAXKg9SKg9SL71RKViPK6]MK6]M
L6eOLg1RLg9TLg9TLW5SLW5SLg9TLg9TMGAVMGAVLWAXLWAXLWAXLgEYM7IZMWQ/MGM[LWAXMWEWMgIX
NGQZNgY/Ogi`Ph9dQhIhRHQjNWe^Ngi_NWe^MgY[M7MXLgIWMWUZNGa]LgQYLgQYLgQYMWUZN7QZNGU[
NWU[NWU[MWUZMGQYMWUZN7]/Ngi_Ngi_N7]/M7MXM7MXMGQYMWUZMgY[MWUZMGQYLgIWLGAUMgQXMgQX
N7UYNGYZNGYZNGYZN7UYN7UYOH1`OH1`O7m_Ngi^NWe]NGa/NGa/N7][OX=^OX=^OH9]Nh1[NGiYN7eX
MgaWMW]VMGQYMGQYMGQYM7MXLgIWLGAUKg9SKW5RKG1QKG1QK6mPJVeNJFaMJVeNKG1QKg9SNGU[OWi`
QXIhSHf1TY67UiJ<W9ZBX9jFXJJG[;2T[k2V]K>[YjJL_kj`Ogm]^;NRa[jPa[jPaKfO`[ZL_[JH^K6C
]:b>/JV;^;FF]K:C[:V:X9ilT8i/PX1NNGMEM79@D54g@T<Y>SXR>3PP;RdH9B@@=3<OCTdiNg][QHEe
UIF5YjJH]K>X_K^``;jd`Kne][VZ^K^__l6eaLJlb<VobL[1bL[1b<S2e]39f=78h=S;bl6``[FObkbR
`k>Fb;JGbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^G
bK^GbK^GbK^GbK^GbK^GbK^Gb[ZFb[ZFb[ZFbk^Gbk^Gbk^Gc;bHc;bHc;jDc;fFc;fFc;bGc;bGc;bH
c;bHc;^Jb[bHb[bHb[bHbK^Gb;ZFb;ZFakVEakVEb[ZFb[ZFb[ZFbk^Gbk^Gbk^Gc;bHc;bHb[ZFb[ZF
b[ZFb[ZFb[ZFb[ZFb[ZFb[ZFb[ZFb[ZFb[ZFb[ZFb[ZFb[ZFb[ZFb[ZFakVEakVEakVEakVEb;ZFb;ZF
0035_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;?5_;?6_KC6_KC7_[G7_[G7_[G7_[G4_KC4_KC4_KC4
_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4
_KC2^k;2^k;3_;?3_;?3_;?4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC2^k;1^[72
^k;4_KC5_[G4_KC3_;?=a;_9`;O4^k;0]jjo]Zg0]jk0]jk1^:o9`;O:`KS8_kK0]jjaZ9nNUHb;PWUo
MVeeKfAdKV=cK6=cJfAeKFIgKVYhKf]iL6f4PGb5PWf6Pgj8QH6;QhJ=RHR@RhbAS8f=SHf?ShnBTY:D
U9BFUYJIVIVMWIfQXJ6PWYfRX9nVY:>TXZ6KVIRDTY6IUiJTXZ6ZZJ^ZZJ^ZZJ^ZZJ^ZZJ^YZ:ZYZ:ZX
YjVVZ:VSYJJPXZ>MWj2LWYnNX:6QXjBSYJJSYJJOXJ:LWYnNX:6SYJJUYjRTYZNRY:FIVibIVibJW9fJ
W9fJW9fKWIjKWIjKWIjPXZ>SYJJUYjRUYjRSYJJRY:FRY:FSYJJHVY^IVibKWIjNX:6QXjBTYZNVZ:VW
ZJZWYjfXZ:jYZJnYZJnYZJnYZJnXZ:jXZ:jVZJjTYjbTYjbUZ:fXZk2Y[;6XZk2WZZnSXjVSXjVTY:ZV
YZbWYjfXZ:jYZJnZZ[2WZJZWZJZWZJZYZjb][k2_/K:^/;6][k2WZ:JTYJ>GV9B7QX9lNGAiMW5iMVif
Lf]cL6QbKfMaKVI_K6A^Jf=]JV9]JV9]JV9]Hf=aJ6EfKVMfLFQfLVMcLFMbKfMcKfY_KFE^K6A^K6A^
Jf=]JV9_JF9`JV=aJfAZL5mYL65YKVEYK6YWJViWJ79VIWAUIGEZJG9[JW=]K7I]KGU^KWY^KWa]KWa/
K7aWJW9[KWaXKh=QJ85LHgaQIGMYJg=_KW1aL6aaL6abLFecLVidLfmcLVicLVibLFeaL6aaL6aaL6aa
L6aaL6aaL6aaL6aaL6abLfYbLfYcM6]dMFaeMVefMfigN6mhNG1hMFeiMViiMVijMfmiMVihMFegM6af
Lf]dLVQdLVQdLVQdLVQdLVQdLVQdLVQdLVQcLFMdLVQdLVQcLFMbL6IaKfEbL6IbL6IdLVQeLfUgMF]i
MfeiMfegMF]eLfUdLVQeLfUeLfUeLfUeLfUeLfUeLfUfM6YfM6Y]Ke]]LEi/LF9/L6E]KVEaKfMgLVUl
MFaeLfUdLVQbL6IaKfE`KVAaKfEbL6IcLFMeLfUaKfE_KF=aKfEbL6I_KF=]Jf5^K69/JUm/JUm/JUm/
JUm/JUm/JUm/JUm]Jf1]K5iYIea^Jf=_JfI_JfI_K6A]Jf1dLfE`L61`L61`Kf5_KV1_KF9_KF=_KF=_
KF=]JeU^K5Y`KUa`KUa`KUa_KE]^K5Y^K5Y^KUi`L61`Kf5_KV1`KV=bL6IaKfE/JV1]Jf1^K65^K65_
KF9_KF9`KV=aKfAbL6E^K65_KF9`KV=aKfAaKfAaKfA`KV=_KF9^K65_KF9_KF9_KF9`KV=`KV=`KV=`
KV=bL6EbL6EbL6EaKfA`KV=_KF9`KV=aKfA[JUa/Jee]K5i]K5i]K5i]K5i/Jee[JUa/Jee[JUaYJ5YX
IeUXIeUYJ5YZJE][JUaRHU1ZJUQ/K5YXJ5QWIeM[JUa[JUaVIEM[KeaXK5UZK5U]Kea`L5i_KE]]JU]_
JU]_KUY^KEU]K5Q[JUI[JUI[JUI[JUI/JeM[JUI[JUI[JUI/JeM]K5Q^KEU^KEU^KEU[KUAYK59YK5=Y
JeE[KEM/KEU/KEU[JeUZJUQ[JeU[JeU/K5Y]KE]]KE]^KUa^KUaaL69aL69aL69aL69`Kf5`Kf5`Kf5`
Kf5]KE]_Kee_Kee^KUa/K5Y/K5Y_KeeaLEmZKEe/Kem]L65_LV=aLfMbLfUbLfUbLfU`LVIaLfMaLfMb
M6QbM6QcMFUcMFUcMFU^LF9_LV=`L69^KV1/Jee/JeeaKV1cL69cLVAbLF=bLF=bLF=bLF=cLVAdLfEe
M6IaLfM^L6A]Kf=`LVIcMFUeMf]eMf]dMVYkNVaiN6YeM6IcLVAcLVAeM6IhMfUjNF]aM6EdMfQgNV]h
NfafNFYcMVMaM6E`LfAaMVMaMVMaMVMcMVMfMVQfMVQgMVQgMVQeN6UeN6UfNFYhNfaiO6eiO6egNV]f
NFYcMVMeN6UhNfakOVmmP75mP75mP75mP75gNV]gNV]hNfahNfahNfagNV]fNFYeN6UfNFYfNFYfNFYe
N6UeN6UdMfQdMfQdMfQbMV=bMV=aMF9_Lf1^LUm]LEi/L5e[KeaUIe]UIe]VJ5aWJEeWJEeVJ5aVJ5aU
Ie]SIEUSIEUQHeMQHeMSIEU/KV9gNFf0PWJEUh^KWI6UYYb][ZBc]:^i^K>n_[S2`[be_:o9clC=d<O>
d<[7b;oQhMF6QgNJW8RYY8FVXH:QW7fIU7F@Rfb7PV=oNU]kMUMDECEADS9:Bb]0@28e=AL^;Q0];@l]
;@lf>2@i>bM7BCEIFdQNGdmUIUJ5QGNZZYbSYi^Y[J:b]Z^i_;>l_[Ri^kFd]K6`/Jg3akc5b;o9c<?<
c/S=clW<cLW9b/S7b<K?b/OBc<GJe<W5_:jo/Ik:^j75]IS<^Y_8^YK8^YK8^YK8^YK8^YK8^YK8^YK8
^YK8^YK8^YK8^YK8^YK8^YK8^YK8^YK8^YK8^YK8^YK8^YK8^YK8^YK8^YK8^YK8^YK9^IG9^IG:^YK:
^YK:^YK;^iO;^iO;^iO;_I?;_9G;_9G;^iK;^iK;^iO;^iO;^YW:_9S:_9S9^iO9^iO8^YK7^IG7^IG7
^IG9^IG9^IG:^YK:^YK:^YK;^iO;^iO;^iO9^IG9^IG9^IG9^IG9^IG9^IG9^IG9^IG9^IG9^IG9^IG9
^IG9^IG9^IG9^IG9^IG6^9C6^9C6^9C7^IG7^IG8^YH00<Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl
/lFl/lFl/lJm]<Jm]<Nn]LNn]LNn]LBm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm
]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<:k//:k//:k//>l/l>l/l>l/lBm]<Bm]<Bm
]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Fn]L:k//2i/<2i/<6j/L:k//:k//2i/;ff[Kff[Kjg[[nh[l6j
/LBm]<Fn]LO0]kR_YKfdZ/Fl//[1]l_2^<Nn]<6h[[bcZK2WWJ:IShj5NgedJgAZHgAZHgM/J7Y_Jfe[
Hg9`J7YgLX9oNXV6PXb8Qhf9R8f8RHf;RXn=S9:@SiBBTIJDTiZHUijLVj:PWjFUYIfMWI^KVj:RXZRX
Z:NWYjBTY:>SXjJUYjJUYjFTYZFTYZFTYZFTYZFTYZFTYZ6SY:6SY:2RXj2RXj2RXj6SY:6SY::TYJ:T
YInQXYfOX9bNWifOX9fOX9bNWi^MWYVKW9VKW9ZLWIZLWI^MWY^MWY^MWY^MWYjPXJ2RXj:TYJ6SY:2R
XinQXYnQXZ2RXi^MWY^MWYfOX9nQXZ6SY:>UYZFWZ:FWZ:JV[:JV[:NW[JRX[ZVY[jRX[ZRX[ZNW[JFX
[J>VZj>VZjBW[:NZ[jR[/:R[/:JY[ZJV[:JV[:NW[JRX[ZVY[jZZ/:^[/J^[/JRZZjNYZZNYZZV[[:b^
[jj`/Jj`/Jf_/:NXYZFVY9ZKUhZ9QGmlMg]hLgYgKgMdK7EbJWAaJG9_Ig1]IFm/I6i[Hfi[Hfi[Hf]V
HfiYIW9^JG=_JW9_Ig9_Ig9_Ig=`J6i_Lg5`M75`LVm^L6i/K6e[Jg5/KG9^KFa^Ffa^Ffa/GVa[HFaZ
HVaYIFaWJ6aWJ79/Gg=]H7I`IGQbIgQaJ7Q`JGM_J7I^Ig5ZFgA^HgI`JgA_KW5[K71[JW5]J7A^Ig9a
KG=bKWEdL7IeLGMfLWMfLWMfLWMfLW=bKW=bKW=bKW=bKWAcKgAcKgAcKgEdL79cJW9cJW=dJgAeK7Ef
KGIgKWMhKgMhKgUfKWYgKg]hL7aiLG]hL7YgKgQeKGMdK7IdJWIdJWIdJWIdJWIdJWIdJWIdJWIdJWAb
J7EcJGIdJWEcJG=aIg9`IW=aIgAbJ75^IW=`J7IcJgQeKGUfKWQeKGMdK7EbJWIdJWIdJWMeJgMeJgQf
K7QfK7UgKGUgKGAgJ7AgJ7IfJWEeJGEcJGMeJgehKh9kLWIdJWMeJgQfK7IdJW9`IW9`IWIdJWYhKWQf
K7=aIfi/HVm]Hg9`IW=aIg9`IW5_IFaZH6aZH6aZH6e[HFe[HFe[HFi/HVi/HW5`HV=QEVi[Hg5]J79^
JG1]IFITFGEdIVe]GFe]GFe/GVe/GVaZGfaZH6aZH6]YGfaZF6i/FW1^G71^G6i/FVe[FFi/FVm]Ffi^
GVm_Gg1_HG1_HG1^Hg1^I6m]Hfi/HVe[H6i/HFm]HVi/HFe[H6i/HG1^Hg=aIVi/HFm]HW1^Hg5_I79`
IG9`IG5_I75_I6m]HVm]HW1^Hg1^Hg1^Hg5_I75_I75_I79`IW=aIgAbJ79`IW1^I6i/HVm]Hg1^I6a[
GFa[GFe/GVi]Gfi]Gfe/GVa[GFa[GFa[GFa[GFYYFfYYFfUXFVUXFVUXFVUXFVATDVYZF6a/FVUYFFMW
EfUYFFa/G6e]GFa]GF]/G6Y[Ff][Ffi[G6m/GG5]Ffm[FFi]FFi]FFa[Ef]ZEVYYEFYYEFYYEFYYEFYY
EFYYEFYYEF]ZEV]ZEVa[Efe/F6e/F6a^F6]]EfY/EVY[EfUYEfYZF6YZFV][FfQYEFUZEVY[Efa]FFi_
Ffm`G75bGW5bGW5`HW5`HW5`HW5`HW1_HG1_HG1_HG1_HFe]Ffm_GFm_GFi^G6e]Ffe]Fg1`GW9bH6Y]
GF]^GVe`HFmbHg5cIg5bJ79cJG9cJG9dJ79dJ7AfJWEgJgEgJgEgJgAfJWAfJViaHViaHW1`HVi^H6e/
GVi]Gg=`HWIcIG=bI7=bI79aHg9aHg9aHg=bI7AcIGEdIWAfJVmaIFi`I75cIg=eJG9dJ79dJ7AfJWEd
IWMfJ7UhJW]jK7]jK7UhJWMfJ7EdIWMjJgMjJgMjJgMjJgMjJgQkK7QkK7UlKGAiJWAiJWAiJWIiJWQh
JWQhJWUhJWUhJW9eIWAgJ7EhJGEhJG=fIg=fIgEhJGMjJgUlKGUlKGUlKGQkK7QkK7IiJWEhJGAgJ6ic
I6mdIG1eIW5fIg9gJ79gJ75fIg5fIfU/GFY]GVa_H6iaHW1cI79eIWAgJ7EhJFa_H6e`HFe`HFiaHVmb
Hg1cI75dIG5dIGEfK7IgKGQiKgYkLG]lLW]lLW]lLW]lLWioMGenM7YkLGMhKWMhKWn0MXf>Q9NHSZjb
YkBh[Kbo]/?5_lO9`l[;alk?bm3Acko8^lS@aL?:`lK:a<K8`/c@aFe`H55E@T5093ln8Sdl83Xi7CHe
6C<b5S4`530_4bhb5C8f6CTm83m2:4M:<E=F?F9TCVa^F7IiJH64M9>FQj2RUYjPU9^LTZVZX;jo][Ji
/;Nj/KZm];fo^L31_L?4`<K7aLO8a/;5_<C7_/O9`lW;aL[;al[;bLS9alO8a/_:a/o<amWEb/Bm[;ba
VlVkWlNfULnlVLRjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/Ni
ULNiULNiULNiULNiULNiULNiULNiULViULViULViULZjU/ZjU/ZjU/^kUl^kUl^mTl^lUL^lUL^kU/^k
U/^kUl^kUl^jVLRjU/RjU/RjU/RjU/RjU/NiULNiULNiULViULViULViULZjU/ZjU/ZjU/^kUl^kUlRh
U<RhU<RhU<RhU<RhU<RhU<RhU<RhU<ViULViULViULViULViULViULViULViULFgTlJhU<JhU<NiULRj
U/RjUP00a;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aaKbcaKbcaKbcaKbca[fda[fda[fdakjea;fda;fd
a;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fd
a;fda;fd`KZa`[^b`[^b`[^b`kbc`kbc`kbca;fda;fda;fda;fda;fda;fda;fda;fda;fda;fd`[^b
_kR__kR_`KZa`kbc`kbc`[^ba;fdaKjea[nfaKje`kbc`;V`_[N^_[N^bL2fa[fc`[V__kJ/_[F[`;N]
a;^aakjd`;R[`;R[_[F[^[6W/:NNWiF>S89kOW=_MgA/MgA/MgA/NGE`OGQePGaiQX60RHB3QhF4RHN6
S8Z9Shf<THn>U9:AVINFWI^JY:BTY:BTYZJVYZJVXJ6QWIfMXj>S[:b/YJBVYJBVYJBVYJBVYZFWYjJX
Z:NYZ:NYXZBUXJ>TX::SWj6RWZ2QWj6RWj6RWj6RW9jOWInPW9jOVYbMV9ZKUiVJV9ZKVYbMVYbMVifN
VifNVifNW9jOW9jOW9jOWInPW9jOWZ2QWj6RWZ2QW9jOW9jOWInPWj6RX::SX::SXJ>TXZBUXjFVYJNX
YJNXYZRYYJF[YZJ/YjN]ZJV_ZJV_ZJV_ZJV_Z:R^YJR]Y:N/XjJ[YJR]YjZ_ZJbaZ:^`YjZ_Z:R^Z:R^
Z:R^ZJV_ZJV_ZZZ`ZZZ`ZZZ`ZJ^/Z:Z[YjVZZ:Z[Zjf^[Jn`[Jn`[:j_Z:VWYZNUW9fISHb8PWmjOGYe
NgQ`MgA/MW=[MG9ZLg1XLFiVL6eUKfaTKfaTKfaTK6]WKVeYL6m[LVi]LFe/L6eYLVm[Lg1/Lg5aM79b
MG=cLg5`Kfe/KVa[L6i]Lg9^Lg1[LVmZL6eXKfaXKV]WKfYYL6]ZL6]ZKViRKfmSLW5WM7=YMW=[MG5/
LfmZLVeZL6eNLVaOMFiUMfmXMfiZM6iYLVmZLW9/MGA`MWEaMgIbN7McN7McN7McMgIbMgIbM7=_M7=_
MGA`MGA`MWEaMWEaMgIbMgIbLgA[LgA[M7E/MGI]MGI]MWM^MgQ_MgQ_NGI^NWM_O7UaOGYbOGYbNgQ`
NGI^MgA/N7I/N7I/N7I/N7I/N7I/N7I/N7I/N7I/M79XMWAZN7I/MWAZLg5WLW1VM79XMWAZL6eULVmW
M75YMgA/N7E]MgA/MW=[MG9ZMG=YMWAZMgE[N7I/NGM]NWQ^NWQ^NgU_JVaVKg5[MgQ_O7YbNgU_N7I/
MG9ZM75YMG=YMWAZN7I/NGM]NGM]O7Y`OgecPX1fNGM]N7I/MWAZM79XM79XMWAZMWAZM79XKVaRKVaR
KVaRKfeSKfeSL6iTL6iTL6iTLW5SIF=HLg1XKVYUKf]VMG9ZIVAILW5SK6aLKFeMKVeOKVeOKF]PK6YP
JVQNJVQNK6YHKVaJL6iLKfeKK6YHJfUGKF]IL6iLKViNKfmOL6mQLW5SLW1UL6iTL6iTLW1VKfeRLFmT
LW1UL6iSKVaQKVaQLFmTMG=XKF]PKVaQL6iSLFmTLW1ULg5VLg5VLW1UL6iSL6iSLFmTLFmTLFmTLW1U
LW1ULW1ULW1VM79XMWAZM79XLFmUKVaRKfeSLFmUKVeOKVeOKfiPL6mQL6mQKfiPKVeOKVeOKVeOKVeO
KVeOKFaNK6]MJfYLJFQJJ6MIIfMGIFEEIVIDJFUGJFUGJ6QFJV]GKVmKHV1HJ6MMJVQNJ6AIJFIHLVeN
LViLKVMFKVeIKFaHJfYFJVUEJFQDJFQDJFQDJFQDJVUEJfYFJfYFJfYFJfYFK6]GK6]GK6]GKVeIKVaJ
KVaJKFYKK6UKKFYLKf]PL6aQK6]GK6]GKFaHKVeIKfiJKfiJL6mKL6mKKVeOKVeOKVeOKVeOKVeOKVeO
KVeOKfiPK6aJKFeKKViLKFeKK6aJKFeKKfmMLG5OJVeMJfiNKG1QKg9SL79VL75WL75WL75WL79VLG=W
LWAXM7IZM7IZLgEYLWAXLWAXKG1QKW5RL71RKfmQKfiPL6mQMW=UNGIXMGAVM7=UM7=UM7=UM7=UMGAV
MWEWMgIXMGM[LG=WLWAXMWQ/MWQ/LWAXLgEYN7Y^LW5SM7=UN7MYNgY/O7]]NWU[N7MYMGAVMGQYLgIW
LWEVLWEVM7MXN7]/Ngi_OH1aLWMXLWMXLWMXM7MXMGEWMGEWMWEWMWEWKG1QLGAULgIWL7=TJfiOJVeN
L7=TMgY[L7=TKW5RK6mPJVeNJ6]LIfYKIVUJIVUJIf]OJFeQJfmSKW9VLGEYLgM[M7Q/MGU]NgeaO7ib
OX1dPH=gQ8IjQhUmRH]oRhf1TiB:TiB:U9F;UYN=V9V?VIZ@VibBVibBVIZ@VY^AW9fCWIjDWYnEWj2F
WYnEWYnEXZ>IXZ>IWj2FVIZ@UIJ<V9V?XJ:HZJZP][V`^[fd`<:l`lC0`lC0`L;0`L;0`L71b=;6`L[0
/k^d[;:]VYjHPXQmCE93;C<P?3lY?3lY?3lY?T4[@D@^ADPbBD`fBdhhG617HVI=JFaFKW1LLgERO7e]
R8UiTI63VYZ>Xj>G[jjT][B/][B/]K:]][>^^;Fa`/Fl`<>j_/6h_Kni_Kjj_[nk`<6o`/?1alRnb<W0
b/_2c<c6c/g9clk:clg<clg<d=;<e=G<g]g?bL>`_[FJb;^Ka;B?c;^DakVEakVEakVEakVEakVEakVE
akVEakVEakVEakVEakVEakVEakVEakVEakVEakVEa[RDa[RDa[RDa[RDa[RDa[RDa[RDa[RDb;RDbKVE
bKVEbKVEb[ZFb[ZFb[ZFbk^GbkfCbkbEbkbEbk^Fbk^Fbk^Gbk^GbkZIakVEakVEakVEakVEb;ZFb;ZF
b;ZFb;ZFb;RDbKVEbKVEbKVEb[ZFb[ZFb[ZFbk^GakNCakNCakNCakNCakNCakNCakNCakNCb;RDb;RD
b;RDb;RDb;RDb;RDb;RDb;RDa[RDa[RDakVEb;ZFb;ZFbK^G0034^k74^k74^k74^k74^k74^k74^k74
^k74^k;5_;?5_;?5_;?6_KC6_KC6_KC6_KC3_;?3_;?3_;?3_;?3_;?3_;?3_;?3_;?3_;?3_;?3_;?3
_;?3_;?3_;?3_;?3_;?3_;?3_;?3_;?3_;?3_;?3_;?3_;?3_;?1^[71^[72^k;2^k;2^k;3_;?3_;?3
_;?4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC3_;?1^[6o^:no^:o2^k;4_KC5_[G5_[G2^k;2^k;2^k;1
^[70^K31^[73_;?5_[G0^:_1^Jc2^Zg4_:o5_K35_K35_K35_K38_k;6_K35^k76_;;8_KG6^[C1]Jnl
/:ZXYYbKV929QWihM6m`K6MaK6UhLg9nNGR1OWZ4PGf7Q82:Qh><RHF@SHVDTHfHUI6IVIVIVIVMWIfR
XZ:PX:2KVi^LW9bQXJ6QX::QX::QX::RXJ>SXZBTXjFVYJNWYZRSYJJQXjBNX:6KWIjJW9fJW9fKWIjL
WYnFV9VIVibKWIjJW9fGVIZGVIZKWIjPXZ>KWIjLWYnLWYnLWYnMWj2MWj2MWj2NX:6MWj2NX:6NX:6M
Wj2KWIjKWIjMWj2PXZ>UYjRUYjRUYjRUYjRVZ:VVZ:VWZJZWZJZVYZbWYjfXZ:jYZJnZZ[2ZZ[2ZZ[2Y
ZJnVZJjUZ:fTYjbUZ:fXZk2Y[;6Y[;6WZZnWYjfWYjfWYjfWYjfXZ:jXZ:jXZ:jXZ:jZ[:fXZZ^WZJZX
ZZ^Z[:f/[Zn/[Zn/[ZnXZJNWZ:JNWi^?SXZ4PGaoO7MkN71gM6afLf]eLVYdLFUbKfMaKVI`KFE`KFE`
KFE]KfU^Kf]_L6i^KVi^Jfe^K6acKVmeLG1gLVUiM6]hMVafM6YbLFMaL6IcLVQgMVa`KWA_KG=_Jg1]
JFi_JVa_JVaaK6icK6mSK6UUKV]XL6m/LG9/LG9/Kg=ZKG5YK75dMW1cLVicL6aeL6meL6mbL6m_LG5^
M7=fMG5fMG5gMW9gMW9fMG5eM71dLfmcLVidLfmeM71eM71fMG5fMG5gMW9gMW9hMg=fMfifMfigN6mg
N6mgN6mhNG1hNG1hNG1iMVikN71mNW9nNg=nNg=lNG5iMVigM6aiMfeiMfeiMfeiMfeiMfeiMfeiMfei
MfedLVQgMF]iMfegMF]dLVQbL6IdLVQgMF]fLVegLfiiMG1jMW5kMg9jMW5iMG1iMG1dLVQeLfUfM6Yg
MF]iMfejN6ikNFmkNFmeMgQhN7QkNWIlNGAlNG5lNG5nNg=oOGEkNFmjN6iiMfejN6imNg5oOG>0OWAo
OG=fM6YjN6ikNFmgMF]bL6I`KVA`KVA`KVA_KF=`KVA`KVAaKfEaKfEbL6IbL6IcLFMcLVAZJ5ejMfmZ
IV5[If9kN71ZJ5e`Kf5^KUi_Kem`Kf5aL69`KV=^K69/JV1[JEm/JUQ^K5Y_KE]]JeUZJ5IZJ5I]JeU`
KUa`L61`L61cLVAeM6IeLfQcLFMdLVQgMF]aKfAcLFIdLVMbL6E_KF9_KF9bL6EfM6U/JUm]Jf1_KF9a
KfAcLFIcLFIdLVMdLVMaKfAaKfAaKfAbL6EbL6EcLFIcLFIcLFIcLFMfM6YhMVafM6YbL6I_KF=`KVAb
L6I`Kf5aL69aL69bLF=bLF=aL69aL69`Kf5_KV1`Kf5`Kf5`Kf5_KV1/JeeZJE]XIeUYJEUPH51OGdeX
J5I/K5YXJEEWJ5A[K5QPGEU]J6EaKFQ/Iei^J5ehLfAjLf9aJeQ]K5Q/JeM[JUIYJ5AXIe=XIe=XIe=X
Ie=/JeM/JeM/JeM/JeM/JeM/JeM/JeM/JeM/JEY/JEY]JUa]JUa^JUm`Jf9dKfIgLVUaL5aaL5a`Ke]^
KEU/JeM[JUIYJ5AYJ5A[JUa[JUa[JUa/Jee/Jee]K5i]K5i]K5iZJUQ[JeU/K5Y/K5Y[JeU[JeU^KUa`
L5i[KUi[KUi]L65^LF9_LFE_L6I_L6I_L6I/KV9]Kf=_LFE`LVIaLfM`LVI_LFE^L6A/Kf1]L65`L69_
Kf5`Kf5bLF=gM6IkN6YgMVQfMFMfMFMeM6IfMFMgMVQhMfUiN6Y^L6A/KV9_LFEeMf]eMf]aLfMcMFUk
OG5lNfejNF]hMfUfMFMfMFMfMFMhMfUiN6YcMVMaM6E`LfA_LV=_LV=_LV=]L65/Kf1WK5eWK5eWK5eX
JeaZJUaZJUa[JUa[JUaXJea^LF9aM6E/Kf1TIeQTIeQ]L65gNV]gNV]gNV]iO6elOg21Q7F6RGZ;SWn>
TH:8S82:SX:>TXJCUh^HW92KWi>NXYJOXiNQXiNRY9RTYYZUYi^WZIfYZinZ[:2[[J6YZJ>YZJ>ZZZBZ
ZZBZZZB[ZjF[ZjF[ZjFZZj6[[::/[J>][ZB][ZB][ZB][ZB/[J>VYifYZZ2ZZj6XZInTYI^VYif^[jFf
]jff^;:i^kFl_[Rl_KVh^KNc];:`/;2_[jnIYIVEX9JEWIJDViIlPgaSJEibNFYhOV]YKUUYKUUXKEQZ
KeY^LeidNFAjOfYnPfj0QVn8SGRAUX6FVXNJWHjPXYJYZina/ZRc/ZRe]:Zc/JVc/:^j]k;2_k_0_KVh
];>l_K>n_kK1`[W3`kg5a<34`ko3`L32`;o7b;k7b;k8bL3:bl;;blG<blO=c<S=c<S7blG<d<GIfL_5
`Zfm]IS8_9S6]i3>_Y?7^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG7
^IG6^9C6^9C6^9C6^9C6^9C6^9C6^9C6^9C8^9C8^9C9^IG9^IG9^IG:^YK:^YK:^YK:_9;:^iC:^iC:
^YG:^YG:^YK:^YK:^IS6^9C6^9C6^9C7^IG8^YK8^YK9^iO9^iO8^9C8^9C9^IG9^IG9^IG:^YK:^YK:
^YK7]i?7]i?7]i?7]i?7]i?7]i?7]i?7]i?8^9C8^9C8^9C8^9C8^9C8^9C8^9C8^9C6^9C6^9C7^IG8
^YK9^iO:_9P00<Bk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LJm/lJm/lJm/lJm/lJm/lJm/lJm/lJm/lJm
/lJm/lJm/lJm/lJm/lJm/lJm/lJm/lJm/lJm/lJm/lJm/lJm/lJm/lJm/lJm/l:k//:k//:k//:k//:k
//:k//:k//:k//Bk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LJm/lJm/lFl//Fl//Bk/LBk/L>j/<>j/<Bk
/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/L>j/L>j/L>j/L>j/L>j
/L>j/L>j/L>j/LBk/LBk/LBk/L>j/<>j/<>j/<>j/<>j/<:i[l>j/<>j/;jeZk>ZX::ISi68OXMnM8Mn
M8AkLH9iKh5hKXElLXb3NIB;PIV@QY^OVY^OVY^OVY^OVYZNVIRLUiNKUYNKUZ6PXZ6PXZ2OXJ2OXInN
X9jMWijMWifLWYjQWibOWIZLW9RJViVKW9^LX9jOXj2PYYfMWI^KViZJVYfMWJ:RXZFUYJFUYJ>SXijN
Y:2PYZ:RZ::RZ:6QYj6QYj>SZJFUZjBTZZ>SZJ:RZ:BTZZNW[JNW[J>SZInOYJNYZZJXZJFWZ:FWZ:FW
Z:JXZJNYZZRZZjFUZjFUZjJV[:NW[JNW[JRX[ZVY[jVY[jFX[JFX[JJY[ZJY[ZJY[ZNZ[jNZ[jNZ[jNZ
[jNZ[jJY[ZFX[JFX[JJY[ZNZ[jNZ[jJZ[jBX[J:UZZ2SZ::RZ:RV[:bZ/:n]/ijSXZJXZ:2RXXf>S7en
NWakMgQhLW=`Jf]ZIVi]JG5`K75`K6i]JFe/J6m^JW5`K75`K75`K71_Jg1_Jg5`K75`K7=bKW=bKWEd
L7EdL7EdL7EdL7AcKg=bKW5`K71_Jg=bKW=bKW9aKG1_Jfm^JVi]JFe/J6a[Ifm^JW1_Jg5`K79aKG9a
KG9aKG9aKG5`K79aKG=bKWAcKgEdL7MfLWQgLgUhM7YiMGUhM7YiMG]jMW]jMW]jMWUhM7MfLWEdL7Uh
M7UhM7UhM7QgLgQgLgQgLgQgLgQgLgIgKWEfKGEfKGEfKGIgKWQiL7UjLGYkLW]hL7]hL7aiLGaiLGai
LG]hL7UfKWUfKWQiL7QiL7QiL7QiL7QiL7QiL7QiL7QiL7QfK7UgKGUgKGUgKGQfK7MeJgIdJWEcJGAe
JgEfK7IgKGMhKWQiKgQiKgQiKgQiKgYkLGUjL7QiKgIgKGEfK7EfK7EfK7EfK7enM7enM7enM7enM7en
M7enM7enM7enM7MhKWQiKgYkLGamLgamLg]lLWYkLGUjL7AeJg=dJW5bJ71aIfm`IVm`IVm`IVm`IW5_
IG=aIgAbJ7IdJWIdJWEcJGAbJ7=aIfm`IVm`IVm`IVi_IFe^I6a]Hfa]Hf]/HW=aIW9`IG5_I71^Hfi/
HFi/HFe[H6e[H6Q[G6a_H79bI79bI6m^H6a[GFi[GFm/GW1^Hg1^Hg1^Hg5_I7=aIWEcJ7MeJWUgK7Qd
JGIbIg=_I75]HW1/HG1/HG5]HW9^Hf]XFVaYFfeZG6m/GW5^H75^H71]Gfi[GG1[HW5/Hg=^IGA_IWE`
IgE`IgE`IgA_IW9_HGAaHgEbI7AaHg5^H71]Gg5^H79_HFiYFVmZFg5/GG9]GW=^Gg=^Gg=^Gg=^Gg9`
GW9`GW5_GG1^G6i/FVaZF6UWEFQVE6AZDf9XDF1VCf5WD6AZDfQ^EfU_F6U_F6aXEV]WEFUUDfQTDVQT
DVYVE6aXEViZF6eWE6iXEFmYEVeWE6YTDFYTDFiXEG9/FFa[Efa[Efe/F6i]FFi]FFi]FFe/F6e/F71`
GW1`GVm_GFm_GFm_GG1`GW5aGg9bH7=dH71aGFa]FFYZF6UYFFQXF6QWFFMVF6Y`Ef]aF6Y`EfQ^EFE[
DVAZDFE[DVM]E6YZFVYZFV][Ff][Ff][Ffa/G6a/G6a/G6e]Gfa/GVa/GVa/GVi^H75aHgAdIWEeIg9b
I7=cIGAdIWEeIgEeIgEeIgAdIWAdIWQhJWAdIW=cIGMgJGQhJWAdIW5aHg9bI75gIW5gIW5gIW5gIW5g
IW5gIW1fIG1fIG1_IG1_IFm^I6e/HVa[HFYYGfUXGVUXGVUYFfUYFfQXFVQXFVMWFFMWFFIVF6IVF6EZ
FfEZFfI[G6M/GFQ]GVU^GfY_H6Y_H6a`IFeaIVmcJ75eJWAhKGMkL7UmLWYnLhF;P7n5NX67O7j4NG=i
KW^1MXfCR9:HSI^NUI^NUI^NUIbOUYfPUijQV:2SVZ2SVZBWWZFXWjFXWjFXWjJYX:JYX:JYX:JYX:Z]
Y:Z]Y:^^YJb_YZf`YjjaZ:nbZJnbZJ^^YJ^^YJZ]Y:Z]Y:^^YJb_YZf`YjjaZ;2cZ[2cZZnbZJjaZ:ja
Z:f`Yjf`Yjb_YZb_YZb_YZb_YZ^^YJZ]Y:Z]Y:V/XjV/XjjaZ:b_YZZ]Y:f`Yk:e[;>f[K2cZZb_YZfa
YZR/XJ6UVYRLTI2DRH^?Q8R<PHJ:OhV9MhZ:N8^;NHf=Ni6AOiFEPiVIQi^KRINJTIbOUZ:UW:JYX:V/
Xj^^YJjaZ;6dZkFh[kJi/;Nj/KJi/;>f[K6dZk6dZk:e[;fn^[fn^[jo^l31_L;3_l?4`<C5`LG6`/[=
a<[=a<W;aLW;aL[;al[;al_<b/c=blW=b<oAbmKDbLc5];baVlFgVm2nWlReU<RhU<RhU<RhU<RhU<Rh
U<RhU<RhU<RhU<RhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhU<RhU<RhU<RhU<RhU<RhU<RhU<RhU<Rh
TlRhTlRhTlRhTlRhTlRhTlRhTlRhTlViU<ViU<ViU<ViU<ViU<ViU<ViU<ViU<RhTlRhTlRhTlRhTlRh
TlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlVi
ULViULViULViULViULViULViULViULRhU<RhU<RhU<RhU<RhU<RhU000a;^aa;^aa;^aa;^aa;^aa;^a
a;^aa;^aaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbb
aKbbaKbbaKbbaKbbaKbbaKbb`[^b`[^b`[^b`[^b`[^b`[^b`[^b`[^ba;^aa;^aa;^aa;^aa;^aa;^a
a;^aa;^aa[fcaKbbaKbbaKbba;^a`kZ``kZ``kZ`a;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^a
a;^aa;^aa;^aa;^aa;^aa;^a`kZa`kZa`kZa`kZa`kZa`kZa`kZa`kZaa;^a`kZ``kZ``kZ``kZ``kZ`
`kZ``kZ`_KBZ_kJ/`kZ`aKbba;^a`;N]^k:X^:nU[:>IZ9nEX9N=V8n5T8MmRX5gQWecQ7]aQhJ2R8N3
RHR4S8^7T8n;UYFAViZFWYfITHj@UI:DW9VKXIjPXj2RXIjPWY^MViRJWYnMX:6OXjBRYJFUY:>UXJ2R
W9^OVIRLVi^KV9RHUIFEUiNGVi^KX:2PXJ6QXJ6QWinUXJ6WXj>YY:BZXj>YXj>YYJF[Z:R^XZ:XXJ6W
XJ6WXj>YYJF[YJF[XJ6WWYjTXJ>TXJ>TXJ>TXJ>TXZBUY:JWYZRYYjVZYjN]YjN]YjN]YZJ/YZJ/YjN]
Z:R^Z:R^XJBYXJBYXZFZXjJ[Y:N/YJR]YZV^YjZ_YJR]YJR]Y:N/XjJ[XjJ[Y:N/YJR]YJR]Z:baYJV^
XjJ[XZFZY:BZZJN][J^a[jfcYJZYZ:ZZX::RSi2>OWmkN7McMgMaN7E`KFaXL6m[LW5]LW5]KfiZKVeY
KfiZLG1/LG1/L6m[L6m[KfiZL6m[LG1/LW5]Lg9^NGQdNWUeNWUeNWUeNGQdN7McMgIbMWEaLg9^LW5]
LW5]LW5]LG1/LG1/LG1/LG1/KfiZL6m[LG1/LW5]LW5]LW5]LW5]LG1/LG1/LG1/LW5]Lg9^M7=_MWEa
MgIbN7McNWUeNgYfO7]gOGahO7]gNgYfNGQdMgIbN7McN7McMgIbMgIbMgIbMgIbMgIbMgIbMWM^MGI]
MGI]MGI]MWM^N7U`NGYaNW]bOW]cOW]cOgadOgadOW]cOGYbNgQ`NWM_MgQ_MgQ_MgQ_MgQ_MgQ_MgQ_
MgQ_MgQ_MgE[N7I/N7I/N7I/N7I/MgE[MG=YMG=YLgAZM7E[MGI/MgQ^N7U_N7U_N7U_MgQ^NgabNW]a
NGY`N7U_MgQ^N7U_N7U_NGY`NgabNgabNgabNgabNgabNgabNgabNgabMWM]MgQ^NGY`NW]aNgabNW]a
NGY`N7U_MGI/M7E[LgAZLW=YLG9XLG9XLG9XLG9XM79XMG=YMgE[N7I/N7I/MgE[MWAZMG=YLG9XLG9X
L75WKg1VKVmUKVmUKFiTKFiTKfeRL6iSLg5VMG=XMgEZMgEZMWAYMWAYK6mPKW5RLG5SKfmQKFaNJfYL
KV]ML6eOLW1ULg5VM79WMG=XMG=XMG=XM79WM79WM79WLg5VLW1ULW1ULW1ULW1ULg5VM79WKfiPKFaN
KFaNKfiPLg9TM7=ULW5SKfiPLg5VM79WMG=XMWAYMWAYMWAYMWAYMWAYLW5SLg9TLg9TLG1RKVeOK6]M
K6]MKVeOKfaML6eNLFiOLVmPLg1QLg1QLg1QLg1QKfmOKfmOKfmOKfmOKfmOKFeMK6aLJf]KI6IBHF=?
Gf5=Gf5=HVA@I6IBIFMCIFMCK6]GK6]GKFaHKVeIKfiJKfiJL6mKLG1LKVeIKfiJKVeIJFQDI6=?HF1<
HV5=I6=?JVUEJfYFJfYFK6]GK6]GK6]GJfYFJfYFIFECIFECIFECIVIDJ6QFJVYHKFeKKViLLW=OL75M
KFiJK6aJK6aLKFeMKVeOKVeOJFiIJg1KKG9MKG9MKG9MKW=NL7EPLgQSMGEUMGEUM7ATLg=SLG5QL71P
KfmOKfmOMWQ/MGM[M7IZLgEYLgEYLgEYMGM[MGM[LgEYLgEYLWAXLG=WL79VL79VKg5UKg5UIfUMI6IJ
IFMKJ6YNIfUMHfEIHVAHIFMKEee<F5i=FEm>FV1?Ff5@G69AGF=BGF=BI6EKIFILIVMMIfQNJFYPJV]Q
K6eSK6eSMWQ/MgU]NG]_NgeaOGmcOh5eP89fPH=gR8b0R8b0RHf1RXj2Rhn3S924SI65SI65SI66SY:7
T9B9TYJ;U9R=UYZ?V9bAVIfBWZBIV9jCVZ2EUYbARY25T9J;X:JKXjVNYjZQYjZQZ:^RZ:^RZJbSZjjU
[:nV[:nVZZfTZjjUZjjUZjjU[:nV[:nV[:nV[K2WZjjU[:nV[:nV[K2W[[6X[k:Y/;>Z/;>Z/;>Z/;>Z
[k:Y[k:Y[k:Y/;>Z/KB[/[F//KB[/KB[/;>Z/;>Z[k:Y[k:Y[[6X[[6X[[6X[K2W[K2W[K2W[:nVZjjU
ZjjUZjjUYjZQZZfT[k:Y/[F//[F//KB[[k:Y[[6X[k>XZjnTYZZOWj>HVYjCUi^@UYZ?UIV>WYf?WYf?
Wij@XJ2BY:>EZ:NIZjZL[JbNZJbS[:nV/;>Z/[F//kJ]/kJ]]KR_][V`_L2g_L2g_;nf^Kbc]kZa]kZa
^[fd_;nf`<6m`L:n`/>o`lC0a<G1aLK2a/O3alS4b/g4bLc3bL_5b/c6blc8c<g9cLk<cLk<`lK4cLk:
fMO?dL^n`KNUakVRd;nTakFHb;RDb;RDb;RDb;RDb;RDb;RDb;RDb;RDb;RCb;RCb;RCb;RCb;RCb;RC
b;RCb;RCb;RDb;RDb;RDb;RDb;RDb;RDb;RDb;RDb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCbKVDbKVD
bKVDbKVDbKVDbKVDbKVDbKVDb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RC
b;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCbKVEbKVEbKVEbKVEbKVEbKVEbKVEbKVEb;RDb;RD
b;RDb;RDb;RDb;RD0034^k74^k74^k74^k74^k74^k74^k74^k75_;;5_;;5_;;5_;;5_;;5_;;5_;;5
_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;2^k;2^k;2^k;2
^k;2^k;2^k;2^k;2^k;4^k74^k74^k74^k74^k74^k74^k74^k75_;;5_;;4^k74^k74^k73^[33^[33
^[34^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k73^[73^[73^[73
^[73^[73^[73^[73^[73^[33^[33^[33^[33^[33^[33^[33^[32^Jo3^[34^k75_;;6_K?7_[C8_kG8
_kG2^Jo1^:jm]:Zh[jF`YifWWYBOUXbKTXRDSXVARhJ=Qh:9Pgj7PGb7PGb9Pgj;QH2BSXfETI2HU9>K
UiJLV9NJUYFHU9>FTY6PWi^NWIVKVYJIUiJHUYJHUYJIUYRJUiVKVi^HV9REUIFFUYJIVIVMWIfOWinP
X:2GV9bIVYjKW:2LWJ6LWJ6LWJ6NWj>PXJFRXjNQXZJRXjNSY:RUYZZUYZZRXjNOX:BOXJ:OXJ:OXJ:P
XZ>RY:FTYZNVZ:VXZZ^WZ:bVYj^TYJVSY:RRXjNSY:RTYJVUYZZUZ:fVZJjWZZnXZk2Z[K:[[[>/[kB]
/;FZ[K:Z[K:Y[;6XZk2XZk2Y[;6Z[K:Z[K:TZ:fSYjbQY:VPXjRRXZRVY:ZYYjf[ZJn[/:nYZj^QXj>F
UiF3Q81fMG5eMFmnNgIdLfmeM71fMG5eM71bLFeaL6aaL6acLVibLFebLFeaL6aaL6aaL6abLFecLVid
Lfm`Kf]aL6aaL6aaL6aaL6a`Kf]_KVY^KFU`Kf]`Kf]aL6aaL6abLFebLFecLVicLVi`Kf]`Kf]aL6ab
LFecLVicLVibLFebLFebLFebLFeaL6aaL6abLFeeM71gMW9iN7AjNGEkNWImO7QnOGUmO7QlNgMjNGEi
N7AfMG5fMG5fMG5fMG5fMG5fMG5fMG5fMG5fMfieMVeeMVeeMVefMfihNG1iNW5jNg9oO7AoO7AoO7Ao
O7AnNg=lNG5kN71jMfmfMfifMfifMfifMfifMfifMfifMfifMfifM6YgMF]gMF]gMF]gMF]fM6YeLfUd
LVQbLfUcM6YeMVafMfegN6igN6igN6igN6ihNFmhNFmgN6igN6igN6ihNFmiNW1jNg5iNW1iNW1iNW1i
NW1iNW1iNW1iNW1iNW1fMfegN6ihNFmiNW1jNg5jNg5iNW1iNW1hNFmgN6ieMVadMF]cM6YcM6YcM6Yc
M6YgMF]hMVaiMfeiMfeiMfeiMfehMVagMF]cM6YcM6YbLfUbLfUaLVQ`LFM_L6I_L6IbL6EcLFIeLfQg
MFYfM6UdLVMaKfA_KF9^LF9^LF9`L69^KV1/Jee[JUa_K5iaKV1]Jf1_KF9bL6EdLVMdLVMcLFIaKfA_
KF9^KV1_Kf5_Kf5`L69aLF=bLVAcLfEcLfE_L61ZJe]VIeMXJEU^KemaLV9_L61[K5a^KV1_Kf5`L69a
LF=aLF=aLF=`L69_Kf5aLV9bLf=cM6A`LF5]KUi[K5a[K5a/KEeTI59UIE=WIeEXJ5IYJEMYJEMYJEMX
J5IXJ5YXJ5YXJ5YXJ5YXJ5YWIeUVIUQUIEMYJUIVIe=SI51RHdmSI51UIU9UIU9TIE5QHdeRI4iSIDmT
IU1TIU1SIDmSIDmRI4iWJ5AXJEEXJEEVIe=SI51QHTiRHdmSI51ZJEEZJEEZJEEZJEEZJEEZJEEZJEEZ
JEE[JeU[JeU[JeU/K5Y^KUa`L5iaLEmcLf5^Ke]]KUY/KEU/K5Y/K5a^KUiaL69bLF=^LF5_LV9_LV9]
L61ZKEeXJe]XJe]YK5aZJUaZJUaYJE]XJ5YWIeUWIeUVIUQVIUQUIe]TIUYSIEURI5QRI5QSIEUTIUYT
IUYWJEeVJ5aTIUYSIEUSIEUTIUYUIe]VJ5a^L6A^L6AaLfMdMVY`LVI[KF5/KV9bM6QfNfagO6eiOVmk
P75mPW>0QGJ1QWN2QgR8RGn9RX2;S8:>ShFATXRDUH^FUhfGV8jFV8bGVHfHVXjKWI6NX9BPXYJRY9RS
YIVRYYZRYYZSYi^SYi^TZ9bUZIfVZYjVZYjVZYnVZYnWZj2X[:6Z[Z>[[jB//:F//:F]/jRW[J:Z/:FV
[:6HWY>KXIJX[Z>Z/:F/[jJ/[jJ/[jJ]/:N^/JR_/ZV_/ZV`/jZ_/ZV_/ZV_/ZV`/jZ`/jZ`/jZa]:^a
]:^]/:N]/:N^/JR_/ZV_/ZV`/jZa]:^a]:^d]jjc]Zfb]Jba]:^a]:^a]:^b]Jbb]Jba]:^a]:^a]:^`
/jZ`/jZ`/jZ_/ZV_/ZV_/ZV^/JR^/JR^/JR]/:N]/:N]/:N]/:NPXiZXZj:a]:^d]jjb]Jb_/ZV`/jZb
]Jba]JZ_/jR//:FY[J:X[:6WZj2WZj2X[:6`[jF`[jFa/:Jb/JNd/jVg]Zbi^:jk^[2e^:nh^k:k_[Fl
_kJk_[Fk_[Fm`;Nn`KS1a;_1a;^o`[Vl_kJk_[Fm`;O1a;_5b;o5a/;5a/;6al?6al?7b<C7b<C7b<C8
bLG9c<?9c<?:c<K;cLO<cLW=c/[>clg>clgIfmcEeMG<bLFb[JBLThFZW8[3/Yg:^:78^9C8^9C8^9C8
^9C8^9C8^9C8^9C8^9C8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9C8^9C8^9C8^9C8^9C8^9C8^9C8
^9C8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?9^IC9^IC9^IC9^IC9^IC9^IC9^IC9^IC8^9?8^9?8^9?8
^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8
^9?9^IG9^IG9^IG9^IG9^IG9^IG9^IG9^IG8^9C8^9C8^9C8^9C8^9C8^9@00<Bk/LBk/LBk/LBk/LBk
/LBk/LBk/LBk/LFl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl
//Fl//Fl//Fl//Fl//Fl//Fl//Fl//:k//:k//:k//:k//:k//:k//:k//:k//Bk/LBk/LBk/LBk/LBk
/LBk/LBk/LBk/LBk/LBk/LBk/LBk/L>j/<>j/<>j/<>j/<Bk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk
/LBk/LBk/LBk/LBk/LBk/LBk/LBk/L:i/<:i/<:i/<:i/<:i/<:i/<:i/<:i/<:i[l:i[l:i[l:i[l>j
/<>j/<>j/<>j/<Nn]<Jm/lBk/L:i[l2g[Knf[;jeZkjeZl2g[L:i[lFl//Ro]LRo]LNn]<Fl//>j/;b`
Z[N[YJjRW:>GTIV=Qi24OXYnN8QlMW]gLW]gLWahLh1lMhN3OY6=R9ZFTJ2LUiBBRYBAS9BAS9BASIFA
T9NCTYVDUIZEUYRFUINEU9JDTiJDTiNEU9NEU9RFUIRFUIZKWifNXYnPY:2QYInPY:2QYJ:SYjFVZZ2Q
YJ6RYZ:SYjBUZJFVZZBUZJ:SYj6RYZ6SY:2RXj2RXj6SY::TYJBVYjFWZ:JXZJJWZjFVZZ>TZ::SYj:S
YjBUZJJWZjNX[:6TZJ6TZJ:UZZ>VZjBW[:FX[JJY[ZJY[ZBW[:BW[:>VZj:UZZ:UZZ>VZjBW[:BW[:BX
[J>W[:>VZj:UZZBTZZNUZjRV[:ZX[Zba/:NYZJ>UYIjOWH^<R7QgLgAdKWmlMgAcKgAcKg=bKW5`K6m^
JVi]JFi]JFi]JFm^JVm^JVi]JFi]JFi]JFm^JW1_Jg5`K7AcKgEdL7IeLGIeLGIeLGIeLGEdL7EdL6m^
JW1_Jg1_Jg1_Jg5`K75`K75`K75`K71_Jg5`K79aKG=bKW=bKW=bKW9aKG9aKGAcKg=bKW9aKG9aKG=b
KWEdL7MfLWUhM7QgLgUhM7]jMWakMgakMgYiMGUhM7QgLgAcKgAcKgAcKgAcKgEdL7EdL7EdL7EdL7Ig
KWEfKGEfKGEfKGIgKWQiL7UjLGYkLWejLWejLWejLWaiLG]hL7UfKWQeKGMdK7EfKGEfKGEfKGEfKGEf
KGEfKGEfKGEfKGEcJGIdJWMeJgMeJgMeJgIdJWEcJGEcJG9cJG=dJWAeJgIgKGMhKWMhKWMhKWIgKGAe
JgAeJg=dJWAeJgEfK7IgKGMhKWQiKgUjL7UjL7UjL7UjL7UjL7UjL7UjL7UjL7UjL7UjL7YkLGYkLG]l
LW]lLW]lLW]lLWYkLGUjL7QiKgMhKWIgKGIgKGIgKGIgKGUgKGUgKGUgKGUgKGUgKGQfK7QfK7MeJgEf
K7AeJgAeJg=dJW9cJG5bJ75bJ75bJ7AbIgAbIgEcJ7AbIg=aIW5_I6m]HVi/HFY]GV]^Gfi^H6i^H6m^
H6i]Gg1]Gg1]Gf]YGVe[H71^Hg9`IGAbIgAbIgAbIg=aIVe`HFiaHVmbHg1cI71cI75dIG5dIG5dIG1c
HfY]GFAWEfIYFFe`H75dI6mbHV]^GV]^GV]^GVa_Gfe`H6e`H6a_Gfa_Gf]^GVe_G6i`GFmaGVe_G6]]
FVU[F6Y/FF]]FVQZE6U[EF]]Efa^F6e_FFe_FFe_FFe_FFe]Gfe]Gfe]Gfe]Gfa/GVYZG6UYFfQXFVeY
EVYVDfIRCfAPCFAPCFEQCVAPCF=OC6=VCF=VCFAWCVIYD6Q[DVY]E6a_EVe`EfY]Ef]^F6]^F6]^F6Y]
EfY]EfY]EfY]Efe/F6e/F6a[Ef]ZEV]ZEV]ZEV]ZEVa[Efi^G6i^G6e]Ffa/FV][FF][FFa/FVa/FV1Q
CF5RCV9SCf=SDFEUEFQXF6a[GG1_HFi`I6maIFmaIFe_HfU[GfEWFfEWFfEWFfIVF6MWFFQXFVUYFf][
GFa/GVe]Gfi^H6mcJ71dJG5eJW9fJgAhKGIjKgMkL7QlLGYnLgUmLWQlLGQlLGYnLgj2Mh:6NhF9OXR<
PHZ>PhnCR96ERX^?Q8F9OXR<PI2DRIBHS9FISINKSiVMTIbPU9jRUZ2TV:6UVJ2SVZ6TVj6TVj:UW:BW
WZFXWjFXWjJYX:^_Y:^_Y:^_Y:^_Y:^_Y:^_Y:b`YJb`YJR/XJR/XJV]XZV]XZZ^XjZ^Xj^_Y:^_Y:Z]
Y:Z]Y:^^YJ^^YJb_YZb_YZb_YZb_YZbaZ:N/Xj^`YjN/XiVNUI^PUjJ[XZJ[XZ^^YJ^^YJb_YZf`Yjja
Z:jaZ:jaZ:jaZ:nbZJnbZJnbZJnbZK2cZ[2cZ[2cZ[6dZjnbZJnbZK2cZ[2cZ[6dZk6dZk6dZk:e[;:e
[;6dZk2cZZnbZJjaZ:jaZ:jaZ:nbZK2cZZnbZJnbZJnbZJnbZJnbZJnbZJnbZJjaZ:jaZ:jaZ:jaZ:f`
Yjf`Yjf`Yjf`Yj>VWJR[XZjaZ;6dZk6dZk6dZk:e[;Bg[[>g[;:fZk6eZ[2dZK2dZK6eZ[:fZk>g[;Jc
[[Jc[[Nd[kRe/;Vf/K^h/kbi];fj]KFh[kNj/K^n]Kbo][g0]kk1^<33^/;5_;k1^;o2^Ko2^Kk1^;k1
^;o2^L?6_LK9`<S9aLS9aLO8a<O8a<O8a<O8a<O8a<O8a<S;`/W<`l[<a/c>b<g>b/k?blk?cLk?cL?5
a/_:c=GCd/k:aKnf[LBiZm?6]]G7]LNgTlNgTlNgTlNgTlNgTlNgTlNgTlNgTlNgT/NgT/NgT/NgT/Ng
T/NgT/NgT/NgT/NgTlNgTlNgTlNgTlNgTlNgTlNgTlNgTlNgT/NgT/NgT/NgT/NgT/NgT/NgT/NgT/Vi
U<ViU<ViU<ViU<ViU<ViU<ViU<ViU<NgT/NgT/NgT/NgT/NgT/NgT/NgT/NgT/NgT/NgT/NgT/NgT/Ng
T/NgT/NgT/NgT/NgT/NgT/NgT/NgT/NgT/NgT/NgT/NgT/ViULViULViULViULViULViULViULViULNg
TlNgTlNgTlNgTlNgTlNgT`00`kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ`a;^aa;^aa;^aa;^aa;^aa;^a
a;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^a`KZa`KZa
`KZa`KZa`KZa`KZa`KZa`KZa`kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ`
`kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``[V``[V`
`[V``[V``[V``[V``[V``[V``;N]`KR^`KR^`[V_`[V_`kZ``kZ``kZ``;N]`KR^`kZ`a;^aaKbbaKbb
aKbba;^a`KR^`KR^`kZ`a;^aaKbba[fca[fca[fcb[jdbKfca[Z``[J/_;2V]ZZP/:BJ[:2FT8^2RhIm
QH1gOgYaO7M^OGQ_P7]bPgieOgecQH=iSX^3UI::VIF@Ui:?TXf:SXV8SX^7Shb8TXn;TXn;THj:Shb8
SHZ6RhR4S8j?SY2ATI>DTYBETYBETiFFUINHV9ZKVYbMW9jOWZ2QX::SX::SWj6RWZ2QWZ2QWInPW9jO
VifNVifNVYbMVifNVifNW9jOXZBUXJ>TXJ>TXJ>TXZBUY:JWYZRYYjVZYjZ_YjZ_Z:^`Z:^`Z:^`Z:^`
Z:^`Z:^`ZJbaZ:^`YjZ_YjZ_YjZ_YjZ_Z:^`ZJbaYZZ_YZZ_YZV^YZV^Z:R^ZZR^ZZR^ZZR^YZ^ZXjFU
XjFUYJJTUIJBP7mkMWI`O7UdLG1/KfiZKFaXJfYVJVUUJFQTJFQTJ6MSJfYVJVUUJVUUJVUUJVUUJfYV
K6]WKFaXLG1/LW5]Lg9^M7=_MGA`MGA`MGA`M7=_Lg9^Lg9^Lg9^LW5]LW5]LG1/LG1/LG1/L6m[LG1/
LW5]Lg9^M7=_Lg9^Lg9^Lg9^LW5]LG1/LG1/L6m[LG1/Lg9^M7=_MWEaM7=_MGA`MgIbN7McN7McMgIb
MWEaMGA`Lg9^Lg9^Lg9^M7=_M7=_MGA`MGA`MGA`MWM^MGI]MGI]MGI]MWM^N7U`NGYaNW]bO7UaO7Ua
O7UaO7UaNgQ`NWM_N7E]MgA/M7E/M7E/M7E/M7E/M7E/M7E/M7E/M7E/MG=YMWAZMgE[MgE[MgE[MgE[
MWAZMWAZLgAZM7E[MGI/MWM]MgQ^MgQ^MgQ^MgQ^M7E[LgAZLgAZM7E[MGI/MgQ^N7U_NGY`NgabNgab
NgabNgabNgabNgabNgabNgabO7ecO7ecO7ecO7ecO7ecOGidOWmeOWmeO7ecNgabNW]aN7U_N7U_MgQ^
N7U_N7U_NGM]N7I/N7I/MgE[MWAZMWAZMWAZMWAZMGI/M7E[M7E[LgAZLW=YLG9XLG9XLG9XLW1ULW1U
LFmTLFmTLW1UM79WMWAYMgEZIfYKJ6]LKFeOL71RLW5SLW5SLFiPKfaNKfeRL6iSL6iSLFmTLW1ULg5V
M79WM79WLW=SLW=SLW=SLW=SLW=SLW=SLW=SLW=SLgERKW1MJVaIJfeJLG=PMGMTLgERL79OK6iKKFmL
KW1MKg5NKg5NKg5NKg5NKW1MIVQBJ6YDJVaFJVaFJF]EJF]EJfeGKFmIJ6I>JFM?JVQ@K6YBK6YBKF]C
K6YBK6YBIVIFIfMGJ6QHJFUIJFUIJFUIJFUIJFUIMVmKLfaHKVMCK6EAK6EAK6EAJfA@JV=?JfY@JFQ>
IfI<IFA:IVE;J6M=JfY@KFaBJfiEJVeDJ6]BIVU@IFQ?HfI=HVE<HFA;I6=?Hf9>HV5=H5m;H5m;H5m;
HF1<HF1<FEU7F5Q6EeM5EUI4EUI4EeM5EeM5F5Q6DU<oEUM3FU]7Gem=Hf=CJFUILW5SMgIXLW=YMWM]
NW]aOGidOWmeOh1fPH9hPhAjPhEiQ8IjQHMkQhUmRH]oRhf1S8j2SHn3Si>8T9B9TYJ;U9R=UIV>Ui^@
V9bAV9bAUYZ?UIV>UIV>UIV>V9bAW:2EX:BIXjNLVinDWJ6FXJFJXjNLWJ6FUYZ?VIfBXJFJW9nFWJ2G
WZ6HWj:IX:>JXZFLXjJMXjJMYZRRYZRRYZRRYZRRYZRRYZRRYZRRYZRR[K6V[K6V[;2UZjnTZZjSZJfR
Z:bQYj^P[K6V[K6V[K6V[K6V[K6V[[:W[[:W[[:W[JnY[JnY[JnY[JnY[JnY[JnY[JnY[JnYZjnYYZZT
ZjnYZJfWVinIWJ6KZ:bVZ:bV[[6X[k:Y/;>Z/KB[/[F//KB[/;>Z/;>Z[[6X[k:Y[k:Y[k:Y/;>Z/;>Z
/;>Z/;>Z/;>Z/;>Z/;>Z/KB[/KB[/KB[/KB[/[F//;>Z[k:Y[[6X[:nV[:nV[:nV[:nV[K2W[K2W[K2W
[K2W[K2W[K2W[K2W[K2W[K2W[:nV[:nV[:nV[:nV[K2W[K2W[K2W[K2W[K2WZZfTYjZQZJbS[[6X/kJ]
]KR_]KR_/kN//kN//[J[/[J[/kN/];R]];R]]KV^]KB`]KB`][Fa]kJb^;Nc^;Nc^;Nc^;Nc]KR_]kZa
^Kbc^[fd^[fd^kje_/6h`<>j^Kbc_L2g`LBk`lJm`lJm`lJm`lJma<Nnb<W5alS4alS4alS4alS4a/O3
a/O3a/O3b<_2bLc3blg7c<k8cLk:cLk:cLk<c<g;blo@c<k>d]?AbLK1]K2W]jjTa;^]akb^akNCakNC
akNCakNCakNCakNCakNCakNCakNBakNBakNBakNBakNBakNBakNBakNBakNCakNCakNCakNCakNCakNC
akNCakNCakNBakNBakNBakNBakNBakNBakNBakNBb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCakNBakNB
akNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNB
akNBakNBb;RDb;RDb;RDb;RDb;RDb;RDb;RDb;RDakNCakNCakNCakNCakNCakNC0033^[33^[33^[33
^[33^[33^[33^[33^[34^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74
^k74^k74^k74^k74^k74^k74^k74^k74^k71^[71^[71^[71^[71^[71^[71^[71^[73^[33^[33^[33
^[33^[33^[33^[33^[32^Jo2^Jo2^Jo2^Jo3^[33^[33^[34^k73^[33^[33^[33^[33^[33^[33^[33
^[33^[33^[33^[33^[33^[33^[33^[33^[31^:o1^:o1^:o1^:o1^:o1^:o1^:o1^:no]Zc0]jg0]jg1
^:k2^Jo3^[33^[33^[2m]:Zo]Zc2^Jo5_;;7_[C7_[C7_[C7_[C3^[32^Jo1^:k0]jfo]Zbo]Zc0]jg0
]jg1]JW3]j_7^jo:_[;;_k?:_[;7^jo5^Jg2^Zfn]ZVg[j:/Y9NOUhZBRWf8P7>2NVf3OgB1OG9mN6mk
MVelMVn0NWF5OgZ8PWf7Q82:Qh>>RhN?S8R>RhN<RHF;R8B;R8AnP821Ph>3QHF5QhN5QhN6R8R9Rh^;
SHfBU9BEUiNHVYZJW9bIVi^HVYZHVYZIVi^EUiRDUYNBU9FATiB@TY>@TY>@TY>@TY>DUYJDUYJEUiNF
V9RGVIVGVIVHVYZHVYZOXZNOXZNOXZNPXjRPXjRPXjRQY:VQY:VSYZ^RYJZQY:VQY:VQY:VQY:VRYJZS
YZ^OXjROXjRQY:VQY:VSXjVTXZRSXJNRX:JNXj:OXJ6QXj>TYJ>KW9R<RhMnOWQjMg9eM71bLFe^KFU/
JfM/JfM]K6Q/JfM[JVI]K6Q]K6Q/JfM/JfM/JfM]K6Q^KFU_KVY]K6Q^KFU_KVYaL6abLFecLVicLVic
LVifMG5fMG5eM71eM71dLfmdLfmcLVicLViaL6abLFecLVidLfmdLfmdLfmcLVicLVi^KFU^KFU_KVY`
Kf]`Kf]`Kf]`Kf]`Kf]`Kf]bLFecLVieM71eM71eM71cLVibLFebLFecLVicLVidLfmeM71fMG5fMG5f
MG5fMfieMVeeMVeeMVefMfihNG1iNW5jNg9mNW9mNW9nNg=nNg=nNg=mNW9lNG5lNG5dMFadMFadMFad
MFadMFadMFadMFadMFafM6YfM6YhMVahMVaiMfeiMfehMVahMVadMF]eMVafMfegN6ihNFmhNFmhNFmh
NFmhNFmgN6igN6ihNFmiNW1jNg5lOG=mOWAmOWAmOWAmOWAmOWAmOWAmOWAmOWAmOWAnOgEnOgEmOWAm
OWAmOWAnOgEoP7J0PGMmOWAlOG=kO79iNW1iNW1hNFmiNW1iNW1iMfehMVafM6YeLfUdLVQdLVQdLVQe
LfUcM6YcM6YbLfUbLfUaLVQ`LFM_L6I_L6IdLVMcLFIbL6E`KV=_KF9^K65^K65^K65YK5eYK5e]KEm_
Kf5bLF=bLF=`KEm]JUa/JUm]Jf1^K65_KF9_KF9^K65]Jf1]Jf1bKf1`KEi^Jea]JU]]JU]^Jea`KEia
KUm]K5Q[JUIZJEE[JUI]K5Q_KUY_KUY^KEUZJEA[JUE]K5M^KEQ_KUU_KUU_KUU_KUUbKUIeLEUgLe]h
M5ahM5aiMEekMemnNV9eL5MfLEQgLUUiM5]jMEajMEajMEaiM5]iM5mjMF1mN6>0NfJ3OVV5P6^7PVf7
PVfLTgRIT7FES76CRVnDRg2DRg2DRg2CRVn:QVZ5PFElN5abKU9YIDURGT9NFSiLF3aEDc]ACcM>C3A<
BS9=Bc=>C3A>C3A=Bc=;BSI:BCE8Ac=6AC55A315A317AS97AS96ASA6ASA7AcE9BCM;BcU>CSa@D3iA
DCmADSiFEd=NGd]UIE=/K5aeMFF0Og68QgV5Qg^9Rgn?THFCUHVEUh^GVHfIVhnKWI6KWiBLX9FLX9FM
XIJMXIJNXYNNXYNOXiRJWiJKX9NLXIRLXIRLXIRLXIRKX9NJWiJMXYVLXIRKX9NKX9NKX9NMXYVOY9^P
YIbQYYfQYYfSZ9nUZZ6QYYfKX9NLXIRQYYfWZJ>WZJ>WZJ>XZZBXZZBYZjFYZjFYZjFY[JNZ[ZRZ[ZR[
[jV//:Z]/J^^/Zb^/ZbZ[jJZ[jJZ[jJZ[jJZ[jJZ[jJZ[jJZ[jJ`/jZ`/jZ`/jZ`/jZ`/jZ`/jZ`/jZ`
/jZ`/Zb`/Zb_/J^_/J^_/J^_/J^_/J^_/J^[[jVVZZB[[jVX[:JKWiVMXI^Y[JNY[JN^/JR_/ZVa]:^b
]Jbb]Jba]:^_/ZV^/JR`/jZ`/jZa]:^a]:^a]:^b]Jbb]Jbb]Jb`/jZ`/jZ`/jZ`/jZ`/jZa]:^a]:^a
]:^_/ZV_/ZV^/JR]/:N]/:N]/:N^/JR^/JR[[ZF[[ZF/[jJ/[jJ/[jJ]/:N]/:N]/:N[[ZF/[jJ/[jJ/
[jJ]/:N]/:N]/:N]/:Nc]Zf/[jJVZJ2VZJ2/[jJb]Jbd]jjc]Zfb]Z^c]jbc]jbc]jbc]jbc]jbc]jbc
]jbe]k6e]k6g^K>h^[Bi^kFi^kFh^[Bh^[Bk_[Fl_kJl_kJj_KBh^k:h^k:j_KBl_kJi_;>n`KS4akk7
b/77b/76bL35b;o5b;o7b<C7b<C7b<C6al?6al?6al?6al?6al?7b/79c<?;cLO<c/S<cLW;c<S:blW9
b/S@eM>o`/2^[j^HVI23PWR?Rh2[YIRg/Z?6]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y76]Y76]Y76
]Y76]Y76]Y76]Y76]Y76]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y76]Y76]Y76]Y76]Y76]Y76]Y76
]Y78^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?6]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76
]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y78^9C8^9C8^9C8^9C8^9C8^9C8^9C8
^9C6]Y;6]Y;6]Y;6]Y;6]Y;6]Y800<:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l>j/<>j/<>j/<>j/<>j
/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<2i
/<2i/<2i/<2i/<2i/<2i/<2i/<2i/<:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l6h[/6h[/6h[/:i[l>j
/<>j/<>j/<Bk/L:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l6h
[l6h[l6h[l6h[l6h[l6h[l6h[l6h[knf[;nf[<2g[L6h[/:i[l:i[l>j/<Bk/L6h[/6h[/6h[/6h[/6h
[/6h[/6h[/6h[/2g[L2g[L6h[/:i[l:i[l>j/<>j/<>j/;jeYknfZ<6hZ/>j[<Bk[LBk[L:iZl6hZ[nf
Z<6hZ/>j[<Bk[LBk[L:iZknfZ;fdYZBNTI^ER8f7O89lLGaeK7ifKhAlMHR0NGmkMX9nNHF1O8J2OHJ2
OHR4Ohf9Q96=R8^=SHj@T92BTY:DU9:DU9BFUYNIVIVKVhnATI>EUINIVIRJVYJHV9FGUiJHV9RJVY>E
UY:DUI6CU92BTi2BTi2BTi6CU96CU8j@T8nATI6CTi:DU96CThnATHf?Sh^=SHF8SHF8SHN:ShV<THZ=
TXb?U8jAUXjAUY6DVI2CV8nBUhnBUhnBUhnBUi2CV96DVIVMXYZNXifPYIfPYInOYInMXifKXI^IWiVN
WIfOWifOWifNW9bMVINFTXN7PGYgLW9aKFi]JFUXI6QWHfUXI6]ZIVYYIFUXI6QWHfQWHfMVHVMVHVMV
HVQWHfUXI6YYIG1_Jg5`K7=bKWEdL7MfLWMfLWQgLgQgLg5`K75`K79aKG9aKG9aKG=bKW=bKW=bKW5`
K79aKG=bKWAcKgAcKgAcKgAcKg=bKVi]JG1_Jg9aKGAcKgAcKg=bKW5`K71_Jfi]JG1_Jg9aKG=bKWAc
Kg=bKW9aKG5`K7=bKW=bKWAcKgEdL7IeLGMfLWMfLWQgLgIgKWEfKGEfKGEfKGIgKWQiL7UjLGYkLW]h
L7aiLGejLWikLgikLgikLgikLgejLWEfKGEfKGEfKGEfKGEfKGEfKGEfKGEfKGMeJgMeJgUgKGYhKWYh
KWYhKWYhKWYhKWEfK7IgKGQiKgUjL7YkLGYkLGYkLGUjL7YkLGYkLGUjL7UjL7YkLG]lLWenM7enM7en
M7enM7enM7enM7enM7enM7enM7enM7ioMGenM7amLgamLgamLgioMGn0MX21MgenM7amLg]lLWYkLGUj
L7UjL7UjL7UjL7YhKWQfK7IdJWEcJGAbJ7AbJ7AbJ7EcJG5bJ75bJ71aIfm`IVi_IFi_IFe^I6e^I71^
Hg9`IGEcJ7MeJWQfJgEcJ79`IG1^HgAgJ6mbHfe]Gf][GFe/GVi]Gfi[GFaYFfQVFfaZGg=aIWUgK7]i
KWUgK7IdJG=aIWUbHGI_GW=/Fg9[FW9[FWI_GWYcHWefIG]eHWegI81jIh5kJ7miIWmiIX1jIh9lJH9n
IX=oIhF1JHN3JhV5KHZ6KXZ6KXZ6KYN=MIV?Mi^ANI^ANI^ANIbBNYjDO:2FOZRMPZVNPjZOQ:bQQZfR
QjfRQjfRQjbQQZjURZnVRk6XSK>ZSkF/TKN^TkN^TkN^TkndU[baTkV^T;R]SkV^T;Z_TKZ_TKZ_TKZ_
TkN/T;2URJNLP9bAMI66JXQmHH=hG6AOAUiI@5E@=e1;<Ti9<4e8;d]6;DY5;450;3ln:S`k9cXi9CTh
93Th93/j9S`k9d51;d92<4=3<DE5<dQ8=Ta<>Ti>?51@?Ti?>eAE@E]LB61PCVATE6][FgEdIWimKgn2
LhB7N8Z=OXnBPi:EQY>FQiJIRYNJRiZNTiZNTi^OU9bPUIfQUYjRUinSV9nSV::WWZ>XWjFZXJFZXJFZ
XJBYX:>XWj:WWZN/XjN/XjN/XjN/XjR]Y:R]Y:R]Y:R]Y:V^YJJ[XZJ[XZR]Y:J[XZ2UW9nTVj6VWJJW
XjJWXjNXY:NXY:RYYJVZYZVZYZZ[YjFYY:JZYJJZYJR/YjV]Z:Z^ZJ^_ZZb`ZjfbZJjcZZjcZZjcZZnd
Zk2e[;2e[;2e[:nbZJnbZJnbZJnbZJnbZJnbZJnbZJnbZK2a[Jn`[:n`[:n`[:n`[:n`[:n`[:n`[:fa
[:R/Yj^_ZZN[YYVMV9bPVjR/YjR/Yjb_YZf`YjnbZK2cZ[2cZZjaZ:b_YZ^^YK2cZ[2cZ[6dZk6dZk6d
Zk:e[;:e[;:e[;2cZ[2cZ[2cZ[2cZ[2cZ[2cZZnbZJnbZJjaZ:f`Yjf`Yjb_YZf`Yjf`YjjaZ:nbZJ^^
YJb_YZb_YZf`Yjf`YjjaZ:jaZ:jaZ:b_YZf`Yjf`Yjf`YjjaZ:nbZJnbZJnbZK:e[:nbZJb_YZZ]Y:^^
YJjaZ;2cZ[6dZk:fZk:fZk>g[;>g[;Bh[K>g[;>g[;>g[;Bg[[Fh[kNj/KVl/kVl/kVl/kRk/[Rk/[bo
][g0]kg0]k^n]KVl/kVl/kbo][k1^;bo]/33^/C7_/K9`<K9`<K9`<K9`<S;`/O8a<O8a<O8a<O8a<O8
a<O8a<O8a<O8a<O:`LW<`l[<a/_=al_<b<W:a/O8a/G6a:6XXIZQVZ:WWZR/XJJXW;>cYLG5]L_8^LJf
T/JfT/JfT/JfT/JfT/JfT/JfT/JfT/JfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfT/JfT/JfT/JfT/Jf
T/JfT/JfT/JfT/JfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLNgT/NgT/NgT/NgT/NgT/NgT/NgT/NgT/Jf
TLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJf
TLJfTLJfTLJfTLNgTlNgTlNgTlNgTlNgTlNgTlNgTlNgTlJfT/JfT/JfT/JfT/JfT/JfTP00`[V_`[V_
`[V_`[V_`[V_`[V_`[V_`[V_`kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ`
`kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``;V``;V``;V``;V``;V``;V``;V``;V``[V_`[V_
`[V_`[V_`[V_`[V_`[V_`[V_`;N]`KR^`KR^`[V_`[V_`kZ``kZ`a;^a`[V_`[V_`[V_`[V_`[V_`[V_
`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`KR_`KR_`KR_`KR_`KR_`KR_`KR_`KR__[F[_kJ/
_kJ/`;N]`KR^`[V_`kZ`a;^a`kZ``[V_`;N]_kJ/`;N]`[V_a;^aa[fc_KBZ_kJ/`KR^`kZ``kZ``[V_
`KR^`;N]`kb]`kb]`[^/`[^/`KZ[`[^/`[^/`[^/a;b[`[ZY_kNV_KFT_KFT_kNV`KVX`k^Z_kRY`KV/
`[Z]_[F[/ZVOXYV@THN0QgefLFeXLfmZM71[MG5/Mg=^OGUdQh=nSh^6QXR8RH^;S8j>SHn?SY2@Si6A
TYBDUINGT9:BUINGVI^KVYbLV9ZJUiVIV9ZJVYbLUiVJUiVJUYRIUYRIUiVJV9ZKVI^LVYbMV9ZJVI^K
VifMVifMVI^KUINGT9:BSHn?T9>HTIBIU9NLUiZOVYfRWJ2UWj:WXJBYXjJ[XZFZXZFZXJBYXJBYXZFZ
XZFZXjJ[WZ:WWj>XXZFZXjJ[Y:BZY::XXInUX9jTUY^JW9jNVI^KUiRFVY^GWYfIShn9NgQcIFAPH5mK
FeYFFUUEG5]GGUeIGEaHG5]GFEQDF5MCF5MCF5MCF5MCFEQDFUUEFeYFF5MCFUUEG5]GGUeIH5mKHF1L
HF1LHF1LJVUUJVUUJfYVKFaXKVeYL6m[LG1/LG1/LG1/LW5]Lg9^M7=_MGA`M7=_M7=_M7=_LW5]M7=_
MgIbNWUeNWUeN7McMGA`Lg9^KVeYL6m[LW5]Lg9^M7=_M7=_LW5]LG1/Lg9^Lg9^M7=_MGA`MWEaMgIb
N7McN7McMWM^MGI]MGI]MGI]MWM^N7U`NGYaNW]bN7E]N7E]NWM_NgQ`O7UaO7UaO7UaO7UaMWM^MWM^
MWM^MWM^MWM^MWM^MWM^MWM^MgE[N7I/NGM]NgU_NgU_NgU_NgU_NgU_MWM]MgQ^NGY`NW]aNgabNgab
NgabNW]aNGY`NGY`N7U_N7U_N7U_NGY`NgabNgabOGidOGidOGidOGidOGidOGidOGidOGidOGidO7ec
NgabNW]aNgabO7ecOWmeOh1fOGidO7ecNgabNW]aNGY`NGY`NGY`NGY`NgU_NGM]MgE[MG=YM79XM79X
MG=YMG=YKg1VKg1VKg1VKVmUKFiTK6eSK6eSJfaRHf5FJfUNN7I[QH=hSH^0T8j3Shf2SH^0OH1aMGQY
KFeOJ6QJJ6MIJFQJK6UKK6UKJVQMLg5VP7icS8YoTY25THn4SH^0R8IkRGm^Qge/PgUXPWQWQ7YYRGm^
ShEdThUhWYB2Y9Z8ZZ2>ZZ2>YYb:Y9Z8YYb:ZZ2>[ZJ?/:RA/ZZC]:bE]jnH^;2I^K6J^K6J^ZbE_:jG
_[2I_[2I_:jG_:jG_[2I`;:K_[2D_[2D`;:F`K>G`[BH`[BH`[BH`[BH_kBF_kBF_kBF_[>E_K:D_;6C
^ZnA^Jj@`KNE_[BB^k6?^k6?_K>A_kFC_kFC_kFC]jV<^jf@`;:E`kFH`[BG_[2C^J^>]JN:Yif5Vi5i
RX1XNW1HKVA<IE]3GE<kF4hfC4/gBTTeAdHbA4<_@d8^A4<_AD@`ATDa?3`Z?3`Z?3`Z?Cd[?cl]@D4_
@d<aA4@b@T<_AdPdC4diC4`jC4`lCdloEUE7GUe?GV5AIFQHKg9RN7][P8=cQXUiRhinSi:2TiN<U9R=
UYZ?VIfBW:2EWj>HXJFJXZJKVZ6JW:>LWZFNXJRQXjZSXjZSXjZSXjZSWjJOX:NPXZVRYJbUYZfVYjjW
Z:nXZ:nX[;>/YZfVY:^TYjjWYjjWXZVRWZFNWZFNZJZVZZ^WZjbX[:fY[JjZ[k2//;6]/;6]Z[2[Z[2[
Z[2[Z[2[Z[2[Z[2[Z[2[Zk6/Zk:[Zk:[Z[6ZZ[6ZZ[6ZZ[6ZZK2YZK2Y/K>]/K>]/K>]/K>]/;://;:/
/;://;://K:^/K:^/K:^/K:^/[>_/[>_/[>_/[>_/kNb[K6/[k>^ZZjYVinJWJ6LZZjYZjnZ[[6X/;>Z
/[F//kJ]/kJ]/KB[[k:Y[K2W[[6X[[6X[k:Y[k:Y[k:Y/;>Z/;>Z/;>Z/;>Z/;>Z/;>Z[k:Y[k:Y[k:Y
[k:Y[k:YZjjUZjjUZZfTZZfTZjjU[:nV[K2W[[6X[:nV[K2W[K2W[[6X[[6X[k:Y/;>Z/;>Z[[6X[[6X
[[6X[k:Y/;>Z/;>Z/KB[/KB[[[6X/KB[/[F/[k:YZjjUZJbS[:nV/;>Z/[J[/[J[/kN/];R]]KV^]KV^
]KV^]KV^/;BX/[JZ];R/][Z^]k^_]k^_][Z^]KV]]kZa^Kbc^[fd^[fd^[fd_;nf`<>j`lJm_/6h`<>j
`LBk`/Fl`/Fl`lJma/W0b<_2alS4alS4alS4b<W5b<W5bL[6bL[6bL[6al[1b<_2b/c6blg7b/_7b<W5
aLK4`lC2^/:g[;BYZk:U[K6U[:nP_;f]d=:oe]K4a[JBa[JBa[JBa[JBa[JBa[JBa[JBa[JBa[JAa[JA
a[JAa[JAa[JAa[JAa[JAa[JAa[JBa[JBa[JBa[JBa[JBa[JBa[JBa[JBa[JAa[JAa[JAa[JAa[JAa[JA
a[JAa[JAakNBakNBakNBakNBakNBakNBakNBakNBa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JA
a[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAakNCakNCakNCakNCakNCakNC
akNCakNCa[JBa[JBa[JBa[JBa[JBa[JB0035^Jg5^Jg5^Jg5^Jg5^Jg5^Jg5^Jg5^Jg7^k76^[35^Jo4
^:k5^Jo6^[38_;;9_K?3^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33
^[32^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo3^[33^[33^[33^[33^[33^[33^[33^[31^:k2^Jo3^[33
^[33^[33^[32^Jo1^:k1^:k1^:k2^Jo2^Jo2^Jo3^[33^[33^[32^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2
^Jo1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1
^:k1^:k1^:k1^:k1^:k4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4
^:c3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_5^Jg4^:c4^:c3]j_3]j_2]Z[2]Z[1]JW2^:NdZYVPUXF?
QGB5NfZ1MfJ2N6N3NFQkO7=oOGF7Pgj?RXN=RHR5QHF3R8V9Ti>FUINHUiVGVIZHVY^IVYjJVinHVIfD
UIVIVYRMWYbGV9J=SXb?T8jJViVJViV@THn@U9FDV9VJW9fMW9jMVYbLUiVKU9NLTiJJWI^AU9:FUYJR
XZ:QX::CUIJ=TY>GW9fDV9fHW:6JWZ>EVIj@U9VCUibQYJZ]/KJLXZ6FW9^KXJ2OXjBJWYnPXZ>VYj^Q
XZJPXj6VZJNY[:ZSZ:JMXZ2IX9fHWibHWib7SH9lPGQ_Mfe/M6Y]M6e]LF][K6QYJ6A^KFUcLVidLfm_
K6Q[IV=]J6EbJfQbJfQXIf=WIV9UI61UI61VIF5XIf=/JfM^KFU]K6Q`Kf]bLFecLVibLFeaL6abLFec
LVidKfadKfafLFifLFifLFidKfabKFYaK6U^KFV5Q825Q82KVYJJVIF6QH6<RhMjNGEaLVU/KFA/KFAb
LfYdMFa_L6M^KfIbLfYdLfmdLfmeM71fMG5fMG5gMW9gMW9hMg=fMG5fMG5iMW5jMg9kN71lNW1oNW5o
NW5lNW1lNW1kNFmkNFmkNFmlNW1mNg5nO79fM6YgMF]iMfejN6ikNFmjN6ihMVagMF]nO79mNg5lNW1k
NFmkNFmlNW1lNW1mNg5jNg5fMfeiNW1oP7IkO79bLfUfMff2PgUoOG=kNFmmNg63PGN4PWQnO79kNFmm
Ng60PGN1P7IoOWAoOG=nO7:0Ng:2Ng:2Ng:0O763OgB4P7F4P7F2OW>1OG:1OG:2OW>6Q7Z3PGN0OW=n
OW9nPG9mP75hOFidNFYXL6EZL6EZL6E/L6E/L6E^KfE^KfE`KfEPJ5iVJf9ZKfI]L6M/KfI/KFAXJF1V
I5adLF9`KEicL661OVnASWnCT865PW=eLV=hLeYhLeYiM5]iM5]jMEakMUekMUelMej?PFZEQg2OTGZX
VX>^X8V_XHZ]WhR[WHJbYhVcZ8ZdZH^fZhfg[8ji[Y2j[i6k/9:m/IFm/IFm/IFn/YJn/YJn/YJo/iNo
/iNn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFo]9Jo]9Jo]9Jo]9Jo]9Jo]9Jo]9Jo]9Jo]9Jo]9Jo]9Jo
]9Jo]9Jo]9Jo]9Jo]9Jn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn
/iG2/YG1/IC0/9?0/9?0/9?0/9?1/IC2/YFm[Xjm[Xjm[Xjn[hnl[HfdYHFXVGVOT72=OF20LUE[H49H
D3=@C31@CC57B2hn?bE9@Rm7@Re0@bXm@bXj@2Lf?2<k?BM2@Bdj>BDl>bLo?RY3@Ri7AS9:BCE<BcM=
C3Q>D3aADcmFF4AKGDYRHe=YJUYaLF=fMVQlO6b4Q7B?SX2FUXZFV8bGV8jGVi2IW9>GWI:KXIJOYIZQ
YYfRYZ2RYZ2SYj:TZ:>Z[:J[[JN][jV/[ZR[[JN[[JN/[ZR^/:ZY[J6Y[J:Y[J:Y[:>XZZBVZ::UYZ:T
YJ6VZZFY[JR[[jZ//:^Z[ZVY[JRZ[ZV[[jZ][ZZ^[j^^[j^_/:b`/Jf`/Jfa/Zja/Zj]/:N]/:N]/:N^
/JR^/JR^/JR_/ZV_/ZVb]Jbc]Zfb]Jb`/jZb]Jbf^K2c]Zf/[jJh_;6Z[Z>WZj2c]Zfj_;Je]k6_/:b_
/:ba]:^b]Jbc]Zf_/ZVVZJ2OXYVUZ9n`/jZ_/ZV_/ZV`/jZ`/jZa]:^a]:^a]:^a]:^f^K2f^K2d]jjb
]Jb_/ZV]/:N[[ZFZ[JBVZJ2VZJ2VZJ2WZZ6WZZ6WZZ6XZj:XZj:TZ9fTZ9fUZIjWZZ6XZZBZ[:J[[:R[
[:R/[jJ]/:N^/JR_/ZVa]:^b]Jbc]Zfd]jj`/jZa]:^a]:^a]:^b]Jbb]Jbb]Jbc]Zfe]Zfd]Jbd]Jbc
]:^a/ZV_/:N][ZF/[JBf]jji^[6l_KBk_;>h^K2f]jjg^:ni^[6a]:^c]Zfe^:nh^k:i_;>i_;>h^k:g
^[6b]Jbd]jjf^K2j_KBm`;No`[W0`k[1a;^o`;c0`Kg1`[k2`ko3a<34aL75a/;5a/;5a/;6al?7b<C8
bLG8bLG8bLG7b<C7b<C:blO9b/K:blO<cLW=c/[;c<S6al?3a<2e^Jfa]JV^/ZJ`/ZJc/jNh^:c7aK[E
dlS5^Ig0]IO0]933^I76^Y;3]ho3/ho5]9?5]I35]I35]I35]I35]I35]I35]I35]I35]I35]I35]I35
]I35]I35]I35]I35]I37]i;7]i;6]Y76]Y76]Y76]Y76]Y75]I38]i38]i38]i38]i38]i38]i38]i38
]i38]i37]Xo7]Xo6]Hk6]Hk7]Xo7]Xo8]i35]I35]I35]I35]I35]I35]I35]I35]I37]i;7]i;6]Y76
]Y76]Y76]Y76]Y75]I36]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y77]YG8]iK8]iK8]iK9^9O9^9L00<Fi
[LFi[LFi[LFi[LFi[LFi[LFi[LFi[LNk/LJj/<Fi[lBh[/Fi[lJj/<Rl//Vm/l>j/<>j/<>j/<>j/<>j
/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l>j
/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<6h[/:i[l:i[l>j/<>j/<:i[l:i[l6h[/6h[/6h[/6h[/:i[l:i
[l>j/<>j/<>j/<:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L6h
[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/Bh[<Bh[<Bh[<Bh[<Bh
[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZlBh
[<Bh[<Bh[<>gZl:fZ/:fZ/:fZ/6eZK^aX;fcX/2fYL2fYKZ`WjjTTijDPi>9N7UhJW9^Hg9]I7ihLhJ2
PH63PgV0Pg=oPH68Rh>:SHF<ShR>ThfAUY:FViJHX9NIXI^MWYZLWHj@TH22PhB6QiFGV9jPXIbNWi6H
Vi>HVi>HViBGViJGVi^JWZ:NXjJRYi^PWiZOWY^MWIfOX9nQXYfQXYbQXYbQY9fRYJ2UZ:2UZ9bQY9FJ
WIBIW9^PXj:WZZR][YVNWi2EUY6EUY:FUi^OX:2TYIZNWk2a[k2a[jf^[:NZZ:BWYJ6TXYbOWIRKVI>D
RhV:PGYmM75dJfa_IVY/IVa/IVi^J69OFVQUH6aYI6]WHViXHg=]J7Q_JgM^JW=`Jg9_JW5^JG1]J75^
JG=`JgEbKGIcKVe/J71_Jg9aKG=bKW5`K75`K75`K7=bKW=^JgA_K7E`KGIaKWIaKWE`KGA_K7=^JgAc
KhV8Q8j=RJNVXZb[YibKUibKUhV8Q7ioMW=dJfi_IW9cJWMhKgEfKG9cJW9cJWAcKgAcKgAcKgEdL7Ed
L7IeLGIeLGIeLGIeLGIeLGUfLGUfLG]hL7ajL7mjLGmjLG]iKg]iKgYhKWYhKW]iKgajL7ekLGekLGMe
JgQfK7UgKGYhKWYhKWUgKGQfK7MeJgajL7ajL7]iKg]iKg]iKgajL7ajL7ekLG]lLWIgKGIgKG]lLWen
M7YkLGQiKgUjL8J4NX:0MWilLWilLX5oMH>1Mh5oMGmmLgYnLgYnLgenM81oMH:1MhB2N8J4NXV4Nh1n
M85oMH:0MX1nM7ilLWekLGekLGmmLh1kLWmjLGekLGimLh20M7eoLgUkKg=gJgAhK7EgJg=eJG=cIg9`
IG1^Hg1/HFm[H6ibIVMYGFU[GgEeJGEcJ6YXGFYVFg9^HfeWE6mYEWI`GH=mJY2:MiNAOYF?O96;N9ZA
MYbCN9nFNjBKP:VPQJjUR[:YS[B[T;>VS;FXS[R[TKb_UKf`U[jaUkf`U[b_UKZ_TKZ_TK^`T[baTkfb
U;ndU[ndU/2eUkfaUKfaUKfaUKjbU[jbU[jbU[ncUkncUkjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKnd
U[ndU[ndU[ndU[ndU[ndU[ndU[ndU[ndU[ndU[ndU[ndU[ndU[ndU[ndU[ndU[jcUKjcUKjcUKjcUKjc
UKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUL:bUL6aU<2`Tl2`Tl2`Tl2`Tl6aU<:bUL:c
Tl6bT/2aTL6bT/>dU<6bT[b]SKNXR;JWQk:TQjZOPIF=L71YCTe:;TE4:Ti?=DE2;DA3;T14:ca2:C]1
:3i1:40m:3lj9DY9=4Q7<TE4;d=2;D50:d50:d50:d91;4E7<DI8<TQ9=DY;=da<>U1@@5ADA5MGAf=Q
CfMTEFYZFVi^H7AdJ7YlL8B5NhV=PXnCQiBHS9VMTYfQUYnRVJ:TWZFWXJNYXjNYXjV[YJZ/YZV[YJNY
XjFWXJJXXZRZY:Z^XjZ]Y:^^YJ^]Yj^]YjZ[YjVZYZVZZ:^_ZZb`Zjjb[Jjb[Jb`Zj^_ZZb`Zjjb[Jf^
ZZj_Zjj_Zjj_Zjn`[:n`[;2a[K2a[K6dZk6dZk6dZk6dZk6dZk6dZk6dZk6dZk:e[;>f[K6dZk2cZ[:e
[;>f[J^^YJ2SVYBHSHV=PXF9OY6DRj>UWjnaZk:c[k>d/;:e[;:e[;>f[K2cZZJYX9nRVJFXWk2cZZnb
ZJnbZK2cZ[2cZ[6dZk6dZk6dZk6dZk2cZZnbZJjaZ:b_YZ^^YJV/XjR[XZNZXJBWWZBWWZBWWZFXWjFX
WjJYX:JYX:JYX:b`YJfaYZjbYjnbZK2b[;:d[[>d/;>d/;Bg[[Bg[[Fh[kFh[kFh[kFh[kFh[kFh[k2c
Z[6dZk6dZk6dZk:e[;:e[;:e[;>f[KBe[;Be[;Be[;>dZk:cZ[2aZ:j_YZf^YK>dZkJg[[Vj/KRi/;Jg
[[Ff[KJg[[Ri/;:e[;>f[KBg[[Ji/;Nj/KNj/KNj/KNj/KBg[[Fh[kRk/[^n]Kg0]ko2^L33^/33^[o0
_<31_L72_/;3_l?4`<C5`LG6`/G6`/G6`/K7`lO8a<S9aLS9aLS9aLO8a<O8a<[;alW:a/[;alc=bLg>
b/_<b<K7`l?4`;Jj[[:fZZncYk6cYkBdZ;Vi[LS6^mKDbLJjW/2eUl2dT<>iTLJjT/:fS/>cSlFdTlFe
T<FeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<JfTLJfTLJfTLJfTLJf
TLJfTLJfTLJfTLRgT<RgT<RgT<RgT<RgT<RgT<RgT<RgT<RgT<NfSlJeS/JeS/JeS/JeS/NfSlRgT<Fe
T<FeT<FeT<FeT<FeT<FeT<FeT<FeT<JfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJf
TLJfTLJfTLJfTLNgTlNgTlNgTlRhU<RhU<ViU@00aKV]aKV]aKV]aKV]aKV]aKV]aKV]aKV]a[Z`aKV_
aKV_aKV_aKV_a[Z`ak^ab;bb`kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ`
`kZ``kZ``[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``KR^`KR^
`[V_`kZ``kZ``[V_`KR^`KR^`KR^`KR^`KR^`KR^`[V_`[V_`kZ``kZ``[V_`[V_`[V_`[V_`[V_`[V_
`[V_`[V__kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^
`KR^`KR^`KR^`KR^`KR^`KR^a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/
a;R/a;R/`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`[JZ`[JZ`[JZ`KFY`kVXa;ZY
a[b[b;j]b;j]`kVX_;:Q]ZbKThejNgASGUI9BT8k@C`i>cdn>dA7?TY>>Da?@55DB5ILCe]QDEYSD5IQ
D5AOCe9PFV1WF5iUCE=J@TQ?ATaCF5iUI6YaIF]bI6mcJ75eJW=gK79gKG=hLGEjMGUnNGb1PhR;Ri2C
SIBGRY6DSYFHVYnRWZ>VVIjQWjBSXZNVY:VXYJZYYJZYYJZYZ:f/ZZn^ZJfbY:R]XJJYXZNZYZ^/Zk2a
[;6bZ[2_XJ:PWIjLWI^JXZ2OZJNV[:ZYZZRWYjFTZjRPYZ>KViR@RhV1OG]cLW=ZKVmVJVeTLW1XMG9Z
M75YLF]TLf]TM6aULfURK69KJFINJVMOJVMOK6UQKFYRKV]SKfaTL6eUKFaXKfiZLW5]LW5]LG1/L6m[
L6m[LW5]LFiZLVm[Lg1/M75]MG9^MG9^MG9^M75]OWeiSXf9U9>?ZJRT/:n[YZFQYjJRV9NCSXn6P85h
LgA[LgA[MgQ_N7U`M7E/LG9YLg9^Lg9^Lg9^Lg9^M7=_M7=_M7=_M7=_MGA`MWEaN7E`NGIaNgQ`O7Y`
OWU`OgYaNWQ^NWQ^NGM]NGM]NWQ^NgU_O7Y`O7Y`N7I/N7I/NGM]NWQ^NWQ^NGM]N7I/N7I/NWQ^NWQ^
NGM]NGM]NWQ^NgU_OG]aOG]aNgabN7U_M7E[MGI/OWmeQ8EkOWmeM7E[SXb2SXb2QhEkOG]aOWabQhEk
R8IlP7idO89gO89gOH5fOH5fOWmeP7meP7meOgidO7]aOGabOWecOGabO7]aOWecPH1fQ8=iQWmfQGie
PgiePX1fP7idNgY`M7=YKFiTLg1RLg1RM6iQM6iQMFePMFePMFaOMFaONGMUN7ITMG5OL6aJMg1OQGi]
THUhUHelXIMoYI^3Zj69[jF=/JN?]:ZB^JnG_K>K^ZfC^jjD_:nE_[6G`;>I`[FK`kJLa;NMaKRNa;NM
`[FK`KBJ`KBJ`KBJ`[FK`kJL_kBF_kBF`;FG`;FG`KJH`KJH`[NI`[NI_K6E_K6E_K6E_[:F_[:F_[:F
_k>G_k>G_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E
_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_K:D_K:D_K:D_K:D_K:D_K:D
_K:D_K:D`[:E`K6D`;2C`;2C`;2C`;2C`K6D`[:E`K:B_k2@_Jj>_Jj>`;6A`[>C`kBD`kBD`[FE`[FE
a[^M_[BFU8iaHUi2DTlcGU/oI6M>IfYDHVQAF5i7EEQ2F5E0E4/gBSlY?CTQ?3PP>cLO>cLO?SXR@ShV
B4@/BdL_AD@ZAD<[AT@/Ad@_BDDbC4PeCTXhCd/iE50mEU8oEeE3F5Q6GUi>IFEGKfmQM7MXOH1`PHAe
R8]lSi65U9F;VIZ@WYnFXZ>JXZFLXjJMYJROY:NNXZFLXJBKXjJMY:NNYJROYZVPYjVSZ:VUZJZVZJZX
ZJZXZ:RX[K6[[[:/[k>][K6[ZjnYZZjX[;2Z[[:/[Zn[[Zn[[Zn[[Zn[[Zn[[k2/[k2/[k2//[F//[F/
/[F//[F//[F//KB[/KB[/KB[/KB[/[F//KB[/KB[];N^/KB[XZFLTYF<T9B9RHf2PHEjPhImUINAZjfW
][Nc]KJb/[F//[F//kJ]/;>ZYZVPX:>JYJRO/;>Z[k:Y[k:Y/;>Z/;>Z/KB[/KB[/KB[/KB[[:nV[:nV
ZjjUZZfTZJbSZJbSZ:^RZ:^R[K2W[K2W[K2W[K2W[[6X[[6X[k:Y[k:Y/kN//kN/];R]]KR_][Rb^;Zd
^;Ve^KZf^[fd^Kbc^;^b]kZa][V`]KR_];N^/kJ]/;>Z/KB[/KB[/KB[/[F//[F//[F//kJ]];F/];F/
];F/];F//kB[/K:Y[k2W[ZnV/;6X/kB[]KJ]][N^]KJ]];F/]KJ]][N^/kJ]/kJ]/kJ]/kJ]/kJ]];N^
][V`][V`]kZa^;^b^[fd_L2g_/6h`<>j`<>j`<>j_l2l`<6m`L:n`/>o`lC0a<G1aLK2aLK2aLK2a/O3
alS4b<W5b<W5b<W5alS4alS4b/_7bL[6b/_7c<g9cLk:blc8a/O3`lC0^;b`/kN[[k>W/K>W];BX^KV]
b<JkemG:a[ZN`;FG_k>?`[R@aKVA`[J>`k>?aKBCa;B?a;B?a;B?a;B?a;B?a;B?a;B?a;B?a;B?a;B?
a;B?a;B?a;B?a;B?a;B?a;B?aKF@aKF@a[JAa[JAa[JAa[JAa[JAa[JAb;N@b;N@b;N@b;N@b;N@b;N@
b;N@b;N@akJ?akJ?a[F>aKB=aKB=a[F>akJ?akJ?a;B?a;B?a;B?a;B?a;B?a;B?a;B?a;B?aKF@aKF@
a[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JBa[JBakNCakNCb;RDb;RD
0034^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c5^Jo5^Jo5^Jo5^Jo5^Jo6^[36^[37^k72^Jo2^Jo2^Jo2
^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo1^:k1^:k1^:k1^:k1^:k1^:k1^:k1
^:k2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo0]jg1^:k2^Jo2^Jo2^Jo2^Jo1^:k0]jg0]jg0]jg1^:k1
^:k1^:k2^Jo2^Jo2^Jo1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:jo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo
]Zc0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg3]j_3]j_3]j_3
]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3
]j_2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[6_:_1]jJk/J2i[ijl/Z71]jK5^j[8_Zg4_:FbZIF@QWES
FDlh<RdP820N9BPV<SHI<S@Q=c`]@DHgAdhc?d/U;3/H7B`A5BLH7bhL8c8K8S4H7bhK8S4U;3/Y<3lW
;Sd[=Shc?THoBU96DEU8DEY4CEHoB54lADhg?dHnB4m6DUQ8E5Q7DeM>EeYLHfIZKG5^Lg5^Lg5_M79b
MgEeNWQhOG]iOWaiOWaiO866RHj>TYNCV9^GWZ6CVYf@V9RBW9bc]KF][jnYZj^/[:bZZZZWYJFRX:2P
WYjFU9>MVIRPViRMV9FFTXf=SHN2Q7ihOGAZJEm[JEmYIeeYI5]_J5mfKfIgKVEbJF1]J5m^JF1`Jf9b
KFAdKfIeL6MfLFQfLFQ]K6Q_KVYaL6aaL6a`Kf]^KFU_KVY`Kf]_K6Q`KFUaKVYcL6adLFeeLVifLfmf
Lfn6QH6@Sh^GUY:PWi^RXIfPWi^SXYjRXIfKW9>>ShIoP7MgN6meMVeeMVecM6]bLfYbLFebLFebLFeb
LFebLFecLVicLVicLVieM71eM71hMG1iMW5jMfmkNFmnNG1nNG1jN6iiMfeiMfehMVaiMfejN6ikNFml
NW1iMfeiMfeiMfeiMfeiMfehMVahMVahMVahMVahMVagMF]hMVaiMfejN6ilNW1mNg5jNg5lOG=gN6ic
M6YmOWB:Rh69RX1mOWB@SXBJV8jFU8Z4PWQnO7:7QG^:R7j1OgElQGQlQGQmQ7MnPWImPGEmOg=kOG5l
O71oOWAoOWAmO79kNW1iN6ijNFmmO7:1P7J3NW23NW22Ng:3O7>2O7EoO7AnNg=lN7=kLf9mMFB2N6N6
O6^<OfnBPg>FQgNGR7R?RG:UWhRHT7U`J55hKEN]X8[4]j6cYY32]9S5]i_6^9c4]YZo/IFn/9C1/iO5
]i_6]I[5]9W4/iS2/IK0[iBn[I:lZi2kZXnn/YJm/IFk[i>j[Y:k[i>m/IFo/iO1]IVn/iFn/iFn/iFn
/iFn/iFn/iFn/iFn/iFm/IFm/IFm/IFn/YJn/YJn/YJo/iNo/iNn/iFn/iFn/iFn/iFn/iFn/iFn/iFn
/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn
/iFn/iFn/iFn/iFn/iFm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YC2/YG1/IC0/9?0/9?0/9?0/9?1/IC2
/YG1/Y:o/92m[Xjl[Hfl[Hfm[Xjo/92o/92k[hffZHVg[8bm/iF`Z8Z>R6]]IT]JESYIGT=XKUEdNV=d
NFAmOVZBRgNMT7ZJRW=dKE9_J4eUGT=JDcQ?B2e7@2E1>Qln=aa4@BE3@2A3@2A4@2M7@b]9ABe9A2m9
A2m6@RY9ABe;B3=>BcI?CSY?Cce@D3iADD5RI55WJEI^L5efMfMmOFn4Q7J;Rgn@T8BEUh^GVHfKWI6M
Wi>NX9BOXIFSYIVUYi^QXYVRXiZSXifTXinUY:2VY:>VY:>UXj>//:Z//:Z//:ZZ[ZRX[:JX[:JZ[ZR/
/:Z^[j^_/:b_/:b_/:b_/:b_/:b_/:b_/:b`/jZ`/jZ`/jZ`/jZ_/ZV_/ZV_/ZV_/ZV_/ZV`/jZ`/jZb
]Jbf^K2b]JbPXiZ=T8NFVXnGVi2@U8V7RX6@TXbVZ::d]K6e][:b]Jbc]Zfd]jj`/jZWZZ6PXiZVZJ2`
/jZ_/ZV_/ZV`/jZ`/jZa]:^a]:^a]:^a]:^_/ZV_/ZV_/ZV^/JR^/JR^/JR^/JR^/JRd]jjd]jje^:ne
^:ne^:nf^K2f^K2f^K2c]jbc]jbd^:fe^:nf^;:g^K>g^;Bh^KFg^[6f^K2e^:nd]jjc]Zfb]Jba]:^a
]:^`/jZa]:^a]:^a]:^b]Jbb]Jbb]Jbc]Zfd]Jbd]Jbd]Jbd]Jbd]Jbb/jZa/ZV`/JR_/:Na/ZVc]:^d
]Jbe]Zfe]Zfe]Zff]jjc]Zfb]Jba]:^a]:^a]:^c]Zfe^:nf^K2j_KBk_[Fm`;Nn`KRo`[W0`k[0`k[0
`kZo`;c0`Kg1`[k2`ko3a<34aL75a/;5a/;5a/;6al?7b<C8bLG8bLG8bLG7b<C7b<C:blO9b/K:blO<
cLW=c/[;c<S6al?3a<2i_K6d^:b`]:Ra/jNc/jNi^Jg8a[_GeL[7^io0]INo/ho2^935^I72]Xk3/ho6
]IC4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o5]I35]I35
]I35]I36]Y76]Y76]Y77]Xo7]Xo7]Xo7]Xo7]Xo7]Xo7]Xo7]Xo7]Xo6]Hk6]Hk5]8g5]8g6]Hk6]Hk7
]Xo4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o5]I35]I35]I35]I36]Y76]Y76]Y75]I35]I35]I35
]I35]I35]I35]I35]I35]I36]Y76]Y76]Y77]i;7]i800<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<>g
[LBh[/Bh[/Fi[lFi[lJj/<Jj/<Jj/<:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i
[l:i[l:i[l:i[l6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l2g
[L2g[L6h[/:i[l:i[l6h[/2g[L2g[L2g[L2g[L2g[L6h[/6h[/6h[/:i[l:i[l6h[/6h[/6h[/6h[/6h
[/6h[/6h[/6h[[nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[<2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g
[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>g
Zl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl6eZL6eZL6eZL6eZL:fZ/:fZ/:fZ/:fZ[jd
XkjdXkneY<:hYlFkZ/BjZL6gY[jdXlFmY/_0[<NjZZfQUH=kM5UFDSLl>bL_;aX_<1X]<20c>2Ph?bL`
?ALN;@L>7`866@0560@:7@L=80P>8@T?8P`B9@`B9@T?8Q0I9Q`U<R/g@cQ4D3i:ESe9ECU5DCA2CSHo
C30lAS52BcA7CRPk@2Da=D=:CFa_LhJ;PX>8Ogn4Ngf2NGn4Nh25O7n4Ngj3NVY]LFa_LeaQI5EKH65Z
KV5YL5USJV1ZLDIAEDeFFUaUJG1fNgj2QhB7S8n?UIVIWiJQYJ2WZZFX[:JSYJ6OWiZKVHZ@RgZ4OXJ7
OX:3NW]iLG=aJGEbJW]eKWYdKGI^Ifi[Hfm/I71]IG1]IG1]IFm/I6i[Hfi[Hfa[Ifm^JW5`K71_Jfi]
JFe/J6e/J6i]JFa[Ifa[Ife/J6i]JG1_Jg9aKG=bKWAcKh60O8b;QijMVJ6PW9jMVIjMVInNVZJUXJ6R
VI^LThj?QWn0MgEfKG9cJWEfKGMhKg9aKG9aKG9aKG9aKG9aKG9aKG9aKG5`K7AcKgEdL7MdKgQeL7Yg
Kg]iKgehKgiiL7YhKWUgKGUgKGQfK7UgKGYhKW]iKgajL7YhKWYhKWUgKGUgKGQfK7QfK7QfK7QfK7Id
JWIdJWIdJWIdJWMeJgUgKG]iKgajL7UjL7ioMGamLgEfK7UjL8R9Oi2AQhf>Q8b:P9jLTZ6OUHj<PX1n
M8B2N8N5Nh5oMGQoL7V0LGb1LWf2Lgn2Lh61Lh20LWmoLGilLGilLG]iKWQfJgEcJ7AbIgMeJWYhKGie
Ih1gJHAkKXV0MY29P9ZCRZ6KU:NQVZ>HQ:FJQZZLRJjPSKBUT[ZYU[f/VL6]Vk>[S/W1Y;^`U8n4J924
J;naULo1YKb[T;j_Skj_Skn`T<2aTL6bT/6bT/2aTKn`T<BaU/BaU/FbUlFbUlJcV<NdVLNdVLReV[Z^
T[^_Tkb`U;faUKjbU[ncUl2dV<2dV;baTkbaTkbaTkbaTk^`T[^`T[^`T[Z_TKfaUKfaUKfaUKjbU[jb
U[jbU[ncUkncUkjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjc
UKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKbaTkbaTkbaTkbaTkba
TkbaTkbaTkbaTl:bUL6aU<2`Tl2`Tl2`Tl2`Tl6aU<:bUL>dU<>dU<>dU<>dU<6bT/2aTL2aTL2aTKfa
SkZ`S[N]RkV^S[jdU[:XRXR0HeeE>4iB=F9VCGAiI7enKXZ7N:>LRK^]UlJeVkN]Sk:XRZRNP9^ALh^1
Hg]aDfiTAVMM?eYC<UI><559:de5:4Y19TDl8Cle7C/a6DA094E19DM2:DU5;4U7;dY7<TM6<DI5<4Q;
<Te?>E=E?eYKAf1PCVMWEFm_Gg=cHg]kKGmoLHF5MhZ:O8n?PIBDQYZJS9jNT:2OUJ6PUZ>QVJFSVjJS
WZNTX:NTX:NTX:N/XjR]Y:V^YJR]Y:N/XjN/XjV^YJ^`Yjf^ZZj_Zjj_Zjj_Zjj_Zjn`[:n`[:n`[:nb
ZJnbZJnbZJnbZJnbZJnbZJnbZJnbZJb_YZjaZ;2cZ[>f[KNj/KBg[ZFXWiBGSX^?Q9FISYNKT8jAR8nA
Rj6SWK6b[[Jg/k>f[K>f[KBg[[6dZjNZXJ6TVjJYX;6dZjnbZJnbZK2cZ[2cZ[6dZk6dZk6dZk6dZk6d
Zk:e[;:e[;:e[;>f[K>f[KBg[[Bg[[2cZ[6dZk6dZk6dZk:e[;:e[;:e[;:e[;6eZ[:fZk:fZk>f[K>e
[kBf/;Ff/[Ff/[:e[;:e[;:e[;:e[;:e[;:e[;6dZk6dZk2cZ[6dZk6dZk6dZk:e[;:e[;:e[;>f[K>d
ZkBe[;Ff[KFf[KFf[KBe[;>dZk>dZk2aZ;6bZK:cZ[Be[;Ff[KJg[[Jg[[Ff[K:e[;6dZk2cZ[2cZ[6d
Zk:e[;Fh[kJi/;^n]Kbo][g0]ko2^L33^/33^/33^/33^[o0_<31_L72_/;3_l?4`<C5`LG6`/G6`/G6
`/K7`lO8a<S9aLS9aLS9aLO8a<O8a<[;alW:a/[;alc=bLg>b/_<b<K7`l?4`;Zn/[Bh[:ncYk2bY[:b
Y[NgZlO5^]OEb/NkWl6fV;ncSl6gSlBhT<:fS/BdT<NfULBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBd
SlBdSlBdSlBdSlBdSlBdSlBdSlBdSl>cS/>cS/BdSlBdSlFeT<FeT<JfTLJfTLNfSlNfSlNfSlNfSlNf
SlNfSlNfSlNfSlJeS/JeS/FdSLFdSLFdSLFdSLJeS/JeS/BdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSl>c
S/>cS/BdSlBdSlFeT<FeT<JfTLJfTLFeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<BdSlFeT<FeT<FeT<Jf
TLJfT@00`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`[J/`kN]a;R^aKV_a[Z`aKV_aKV_a;R^`KR^`KR^
`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`;N]`;N]`;N]`;N]`;N]`;N]
`;N]`;N]`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^_kJ/`;N]`KR^`KR^`KR^`KR^`;N]_kJ/_kJ/_kJ/
`;N]`;N]`KR^`KR^`KR^`KR^`;N]`;N]`;N]`;N]`;N]`;N]`;N]`;N]_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/
_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/`[JZ`[JZ
`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`kN[`kN[`kN[`kN[`kN[`kN[
`kN[`kN[`;BX`;BX`KFY`KFY`KFY`[JZ`[JZ`[JZ`KNV`KNV`[RWa;ZYaK^Za;ZY`;JU_;:Q]ZnL_K>Q
a;NWaKRZ]jfSV968IfEM@4<j7RHU3aLF0``?1@dD1P`G00<B000?000A000B000C004D000B000B000C
00<F00DH00LH1`lP51`]7RPi:C=4<Ci>>DIF?4]K@4YK;ci>:T1<:dE<73@j52@Z>dA8M7MkSI66RXj3
R8b1Qh^0RHf2RXj3Rhn4Rhn4T9B?Mgaj?dE482LZ<3M0=3i8;CQ6>TAEAeeXBemZEfUdH71lGF]gDeaY
D5QUEEeZ<51KA5eWEVE^GVE^JVeeN7f0OHN7NXR7PHN2PHF0N7agL75]KfiZLG1/Lg1/KfaXL6m[KfiZ
KVeYK6]WJVUUJFQTJ6MSIfIRK6]WKVeYL6m[L6m[KFaXK6]WK6]WKFaXJFYVJFYVJFYVJV]WJfaXKFiZ
Kg1/L75]N7McPX5mWijJXj:NXJ2LXj:NVYVEXj:NWIjEWIjEU9F<PhAkMWM^M7E/MgQ_NW]bLg9^Lg9^
Lg9^LW5]LW5]LW5]LG1/LG1/M7=_M7=_MgA_N7E`NGI^NWQ^OGQ_OGQ_NWQ^NWQ^NGM]NGM]NWQ^NgU_
O7Y`O7Y`O7Y`NgU_NGM]N7I/MgE[MgE[MgE[N7I/MWAZMWAZMG=YMG=YMWAZMgE[N7I/NGM]MWM]O7ec
OGidN7U_MgQ^P85gS8f3TiB:QH=iUI>9W9Z@T8j4Ph5gPGmePX1fPGmeO7m`O7m`OWi`OWi`OGa^O7U[
N7EWMgAVMg1ONW=ROGIUPGYYQ7e/RH9aT8UhU8elWiAnWiJ2XYR6Y9b;[:>E]ZjQ`K^`bL:i`;BL`;BL
`;BL`K>La;BMa;BMa[BMa[BM`KJJ`[NK_[>G^:b@^Zb@_k6Ea;>H`k:GaKJFa;FE`kBDaKJFbKZJbKZJ
aKJF`;6A`K6D`K6D`[:E`k>Fa;BGaKFHa[JIa[JI_K:D_[>E`;FG`KJH`KJH`;FG_[>E_K:D_K:D_K:D
_K:D_;6C_;6C_;6C_;6C_;6C_K6E_K6E_K6E_[:F_[:F_[:F_k>G_k>G_[>E_[>E_[>E_[>E_[>E_[>E
_[>E_[>E_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_[>E_[>E
_[>E_[>E_[>E_[>E_[>E_[>E_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C`[:E`K6D`;2C`;2C`;2C`;2C
`K6D`[:E_Jj>`;6A`kBDa;FE`kBD`K:B`K:B`K:B]Jb7`;NB`[RF^[2>_;6A_;6CXYMiOg=GHV94JFY@
LgAPNGQZP7e_THYgZYj6^ZjB^Jf;^jn=_K6?_[:@_;2>^Jf;]:R6/JF3VI1^THQVQWeKO7=BLVQ:IU`n
FTlcDDHZCDDWAd8S@S`O?c/N@CdQA40WA4<YAD<[?ChT@44WA4D[B4P`C4/fD4ljEUE1FeY6G5e=H65A
IfQHKFiNLgATNGYZP85aQHIfU9F5UIJ6V9R:W9b@WinCXZ6GXj:HY::JWJ>HXJNLY:ZOYZbQYZbQYZbQ
Z:jSZJnTZJZVZZ^WZZ^WZjbX[:fY[JjZ[Zn[[Zn[[k:Y[k:Y/;>Z/;>Z/KB[/KB[/KB[/[F/ZjjU[k:Y
/KB[/[F/];N^]KR_[K2WXZFLVIfBXjNLZ:bQXjJMWj6KYJNQ/;6]]kRd/kJ]];N^];N^/KB[Z:^RXJBK
YjZQ/KB[[k:Y[k:Y/;>Z/;>Z/KB[/KB[/KB[/KB[/KB[/KB[/KB[/[F//[F//kJ]/kJ]];N^[[6X[[6X
[k:Y[k:Y/;>Z/;>Z/;>Z/;>Z/[J[/[J[/[J[/kJ]/kF_];J`];Fa];Fa/KB[/KB[/KB[/[F//kJ]/kJ]
];N^];N^/;>Z/KB[/KB[/KB[/[F//[F//[F//kJ]/kB[];F/]KJ]][N^][N^][N^]KJ]]KJ]/K:Y/K:Y
/K:Y/kB[]KJ]][N^];F//[>Z/;>Z/;>Z/;>Z/KB[/[F/];N^][V`]kZa^[fd^kje_L2g_/6h_l:i`<>j
`<>j`<>j_l2l`<6m`L:n`/>o`lC0a<G1aLK2aLK2aLK2a/O3alS4b<W5b<W5b<W5alS4alS4b/_7bL[6
b/_7c<g9cLk:blc8a/O3`lC0^[jb];R/[[:V[[2T/;2T][JZa/Bie]C9b;bP`KJH_k>?`;J>`kN?`KF=
a;B@akJE`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`[:=`[:=
`k>>a;B?aKF@aKF@a[JAa[JAa[F>a[F>a[F>a[F>a[F>a[F>a[F>a[F>a[F>aKB=aKB=a;><a;><aKB=
aKB=a[F>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`[:=`[:=`k>>a;B?aKF@aKF@a[JAa[JAa;B?a;B?
a;B?a;B?a;B?a;B?a;B?a;B?a;F>a;F>a;F>a;F>aKJ?aKJ?0033]j_3]j_3]j_3]j_3]j_3]j_3]j_3
]j_2]Zc3]jg4^:k5^Jo6^[35^Jo4^:k4^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1
^:k1^:k1^:k1^:k1^:k0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg1^:k1^:k1^:k1^:k1^:k1^:k1^:k1
^:jo]Zc0]jg0]jg1^:k1^:k0]jg0]jfo]Zbo]Zbo]Zbo]Zc0]jg0]jg1^:k1^:k1^:k0]jg0]jg0]jg0
]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jfo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo
]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zc2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2
]Z[2]Z[2]Z[2]Z[2]Z[3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j^o/jO0]:S0]:S0]:S1]JW2]Z[2]Z[2
]Z[8_Zg3^JRm/j:j/9nl/Z70]ZG3^JS4^ZVn^jbm^:Vm]:K2]JO6^J_0]JNTWHj9Q7EEDD`h<c0M6APC
4QH@3aP621<00Q410aD41AT41AT41AT311P10QH10QH51QX:2al0018001@00aP32Qh;4RHE7S8O:ShW
<THkBE`iBea0FVQ:J7=7HfY:GF9[M7RFUYb;T86=TX>@UHJCV8VEVX^FVhbFVhbGW8fBVHb5SH=;DTdJ
8B@E7RP<5RL:5B/X<D`eEfLdEFDmFfa:I7E3Ffd`A5HS=4LS<TE5NHUJQYMUQ9=KJg]<EF97DE]7E5a4
Ee`mADA3BdY8D4m;DE1AEUEJGeiRI6ASIFEZK6aYJf]XJVYXJVYYJf][KFe^L71_LG5/JfM^KFU`Kf]_
KVY]K6Q[JVI[JVI/JfMXJFEWJ6AWJ6AWJ6AXJFEZJfM/KFU^Kf]fMG5dLfn=S8R=S8RAT8bKVYJ;RXJD
Thn?T8N@THR9RX5lOGAeMVefMfigN6meMVedLfmdLfmdLfmcLVicLVibLFebLFeaL6adLfmdLfmgM6mg
M6miMVijN6ilMfimN6mkNFmkNFmjN6ijN6ikNFmlNW1mNg5mNg5mNg5kNFmiMfehMVagMF]gMF]gMF]h
MVafM6YfM6YeLfUdLVQeLfUeLfUfM6YgMF]dMF]eMVagN6ijNg5hNFmgN6ioP7J:Rh60OWB5PgV9Qgf9
Qgf4PWR0OWB0OWB1OgF1PG62PW:6PgB8PgB7PW>7P764OFj4Nff;P6b@QG6GS7RNTgnTVHF[X8bbYi>g
[9S1]iVo]iZo]Y^l]9fl/inn]ZG5_Zo;`kJn]IZm]9Vn/iRn/INm/9Jn[iFm[YBo[YBj/YFbZXfh[I76
^Yk7^ino/IFn/9C8]ic3]IS2]9O0/YFo/IBo/IBn/9>k[I2iZhjo/IBo/IBn/9>m[i:l[Y6k[I2j[8nj
[8nl/I>m/YBm/YBn/iFn/iFm/YBm/YBl/I>n/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFm/IFm/IFm/IFn
/YJn/YJn/YJo/iNo/iNn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFm/YBm/YBm/YBm/YBm/YBm/YBm/YBm
/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFl/I>l/I>l/I>l
/I>l/I>l/I>l/I>l/I?2/YG1/IC0/9?0/9?0/9?0/9?1/IC2/YFjZh^m[Xk0/I70/I6n[hnm[Xjn[ho0
/I6aZ8>j/Hbn]I2j/8jk[Xjm/92fZ8^ZW7m/IdQSGTESGde`K65oNg2ARWVZXh[2^Ybm[h^n/8c0/Xk1
/ho0/Xjo/Hfm[h^k[HW5^YBo]8jfZXJ`Y82[WgfSUWJHRf^?PFA^IDAUGSeLECACCRm?BBa9ABQ4@BE0
?B50@292@RA3@RI3@RI3@RQ5@b]9Abm<BCA6ASA:BSQ@D3iEED=IFDMNGTaSHe5WIeEcMEmfMf=kO6R1
PFn7QgF=SGf@Sh6BTH>?UHZDVXnJX9FOYIZQYibQYibRZ9fSZIjSY:2SY:2UYZ:VYj>XZJFYZZJZZjN[
[:R/[jJ/[jJ]/:N^/JR`/jZa]:^b]Jbb]Jb[[ZF`/jZa]:^_/ZV_/ZVb]Jbb]Jb^/JRd^:fc]jbd^:ff
^K2c]Jn^/:Z`/Jff]k>d]jjd]jje^:nb]JbXZj:QY9^WZZ6b]Jb_/ZV_/ZV`/jZ`/jZa]:^a]:^a]:^a
]:^_/ZV`/jZ`/jZ`/jZa]:^a]:^b]Jbb]Jb`/jZa]:^a]:^a]:^b]Jbb]Jbb]Jbc]Zfb]Z^b]Z^b]Z^b
]Jbc]Jnc]Jnc];2c];2a]:^a]:^a]:^b]Jbb]Jbc]Zfc]Zfc]Zf`/jZa]:^a]:^a]:^b]Jbb]Jbb]Jbc
]Zfc]:^d]Jbe]Zff]jjg^:ng^:ng^:nf]jja/ZV`/JR_/:N`/JRc]:^d]Jba/ZV^[jJ]/:N_/ZVa]:^c
]Zfe^:ng^[6g^[6h^k:i_;>j_KBl_kJn`KRo`[W0`k[0`k[0`kZo`;c0`Kg1`[k2`ko3a<34aL75a/;5
a/;5a/;6al?7b<C8bLG8bLG8bLG7b<C7b<C:blO9b/K:blO<cLW=c/[;c<S6al?3a<2j_[:c]j^]/JF/
[Z:^[Z:d]:S4`[ODd/O9_J71]YRn/Xk0]Xk3]ho1]Hg4]938]iK3/hk3/hk3/hk3/hk3/hk3/hk3/hk3
/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk1/Hc2/Xg2/Xg3/hk4]8o5]I36]Y76]Y76]Hk6]Hk6]Hk6
]Hk6]Hk6]Hk6]Hk6]Hk6]Hk5]8g4/hc4/hc4/hc4/hc5]8g6]Hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk3
/hk1/Hc2/Xg2/Xg3/hk4]8o5]I36]Y76]Y74]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o3]8g3]8g3]8g4
]Hk4]Hk5]Xl00<>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl6eZl:f[<Bh[/Fi[lJj/<Fi[lBh[/>g[L6h
[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/2g[L2g[L2g[L2g[L2g
[L2g[L2g[L2g[L6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[[nf[;nf[<2g[L6h[/6h[/2g[Knf[;nf[;nf
[;nf[;nf[<2g[L2g[L2g[L6h[/6h[/2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L6h[/6h[/6h[/6h[/6h
[/6h[/6h[/6h[[nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[<:f
Z/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/>gZl>gZl>gZl>gZl>g
Zl>gZl>gZl>gZkncYkncYl2dZ<2dZ<6eZL6eZL:fZ/:fZ/2fYKneY;neY<6gY/BjZLBjZL>iZ<6gY[2`
Y;RdZKjeZ<2cYLFfY/^mZlJkYkbcWib<QGIXHU14@Slg>34]<adL9P/<6PD85`003P004@@45PL76@D5
5`414`414`D55`T77@L87@@770466`897@@=8@TD:0lJ;PXG;A/_@CQBHTm_NUikPV]nQH29SIBDVXfC
PY:HQiRNSIVOSYFKRY6GQXfCPXbBPH::NIRRTW^3O4A=D2D]>PH?8`TA;SM0HE9lSd]cQT]`Q5=dR4IU
NRQ3F0`T>P4H;P55F2QPLdA/Od5IJc=1Dc0mBcM7Dce@F4IBE4iJG5AMH51IG4aCET]BED]@DdQ=D497
BT=8BdA9C4Q=D4iCEUAIG5]PHemTIfa[Ifi]JFm^JVm^JVa[IfYYIFYYIF]ZIVQYIFMXI6IWHfIWHfMX
I6QYIF]/J6a]JGakMfYYIGIeLFe/J7IeLHV8Q7UhM8>2OX:3NX62NG]lLg9cJW5bJGIgKWAeK6e^IGEd
L7EdL7AcKgAcKg=bKW=bKW9aKG9aKG=bKWAcKgIcKWMdKgUfKWYhKWagKWehKgajL7ajL7]iKg]iKg]i
KgajL7ekLGilLWekLGajL7UgKGMeJgIdJWIdJWMeJgQfK7MeJgIdJWEcJGAbJ7AbJ7AbJ7EcJGEcJG=d
JVi_IG9cJGYkLGUjL75bJ7=dJWioMGekLGQfK7QfK81nM8B2N8:0MX1nM8:0MX9mKXJ1LY29NYRAPZ2G
RJNLSZZOTJ^PT[V[U;^]U[j`VKnaV[naV[naV/2bVl:dWKjeTknfUKjfV;fdVKR`VKN`W;bdXl2hYkVa
U;ZbUK^cU[jcUl2dV<:fV/FgVlFgVkbcV;fdVKbcV;baU[b_UKf`U[j_UKf^U;jbU[jbU[jbU[faUKfa
UKjbU/:fV/FiWKbaTKfbT[fbT[fbT[fbT[jcTkjcTkjcTk^`T;Z_SkZ_SkZ_Sk^`T;fbT[ndU<6fU[fb
U;fbU;fbU;fbU;jcUKjcUKjcUKndU[faUKfaUKfaUKjbU[jbU[jbU[ncUkncUkjcUKjcUKjcUKjcUKjc
UKjcUKjcUKjcUKfbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;jc
UKjcUKjcUKjcUKjcUKjcUKjcUKjcUK^`T[^`T[^`T[^`T[^`T[^`T[^`T[^`T/:bUL6aU<2`Tl2`Tl2`
Tl2`Tl6aU<:bUL6bT/:cTl>dU<2aTKb]SK^/S;j_Sl6bT/2gTKV`RkJ]R;Z`S[ncTKb_Skf]T;n_TXj3
Hg=ZCfEMC71ZGgijKhN3LIVFNZn]Rkf]R;f]R;f]R;f]R;f]R;j^RKn_R/2`RkfaRKZ]QkV/Q[f_Rl:d
T<>dTkn`T;Z[RkJ]Rk6XQZJOOY^DLhb7J7UeF6MSAU]G>TQ69dU7:DQ6:4I39d=094<o9TI2:TQ4;3ho
:d52;TE6<TM8=4U:=Ta=>E1A?E=D@51C>UAG?U]NAF=UCfa]FG=dH7QhIW]kJH>9OXV?Q96GS9NMTYZP
UI^QUY^QUYbRUijOVinPW:2QWJ:SWjBUXJJWXjRYYJVZYZNZXJR[XZV/Xj^^YJb_YZjaZ:nbZK2cZZb_
Y[6dZk:e[:b_YZZ]Y:nbZK>f[KFh[kFi[Z^_Y:V]X[>f[KNi/k6c[Jj_Zk>d/;Bg[[Bg[[Fh[k:e[:R[
XZ6TVjNZXK:e[:nbZJnbZK2cZ[2cZ[6dZk6dZk6dZk6dZk2cZ[2cZ[2cZ[2cZ[6dZk6dZk6dZk6dZjnb
ZJnbZK2cZ[2cZ[2cZ[6dZk6dZk6dZk6eZ[6eZ[6eZ[6dZk6c[K6c[K6b[[:c[k2cZ[2cZ[2cZ[2cZ[2c
Z[2cZ[2cZ[2cZ[2cZ[6dZk6dZk6dZk:e[;:e[;:e[;>f[K>dZkBe[;Ff[KJg[[Nh[kRi/;Ri/;Nh[k6b
ZJj_YZf^YJj_Y[6bZK6bZJj_YZ^/Xjb_YZjaZ;6dZkBg[[Nj/KRk/[Rk/[Rk/[Rk/[Vl/k^n]Kg0]kk1
^;o2^L33^/33^[o0_<31_L72_/;3_l?4`<C5`LG6`/G6`/G6`/K7`lO8a<S9aLS9aLS9aLO8a<O8a<[;
alW:a/[;alc=bLg>b/_<b<K7`l?4`;Zn/[>gZjb`Y:^]XJf]XK:bY/?1]]?Aa/VmXL6fV;jbS/2fS/:f
S/6eSLBdT<RgU/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/6a
S<6aS<:bSL>cS/BdSlFeT<JfTLJfTLJeS/JeS/JeS/JeS/JeS/JeS/JeS/JeS/JeS/FdSLBcS<BcS<Bc
S<BcS<FdSLJeS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/6aS<6aS<:bSL>cS/BdSlFeT<JfTLJfTLBd
SlBdSlBdSlBdSlBdSlBdSlBdSlBdSl>eRl>eRl>eRl>eRlBfS<BfS000`kN[`kN[`kN[`kN[`kN[`kN[
`kN[`kN[a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R^a;R^
a;R^a;R^a;R^a;R^a;R^a;R^_kJ/_kJ/_kJ/`;N]`;N]`KR^`KR^`KR^`kN[`kN[`kN[`kN[`kN[`kN[
`kN[`kN[a;R^a;R^a;R^a;R^a;R^a;R^a;R^a;R^`;R[`;R[`;R[`;R[`;R[`;R[`;R[`;R[`kN[`kN[
`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ
`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`kN[`kN[a;R/a;R/a;R/`[RW`[RW
`[RW`[RW`[RW`[RW`[RW`[RW`[RW`[RW`[RW`[RW`[RW`[RW`[RW`[RW`kVX`[RW`KNV`KNV`KNV`KNV
`[RW`kVX`;JU`;JU`;JU`;JU`KNV`KNV`[RW`[RW_kFT_kFT`;JU`;JU`;JU`;JU_kFT_kFTcl:b[jFD
PGQ[GEA:CTHoCDI3Ad91@3Xk=2hc:bL]6AHO1PD?000<0`HD0PLF004C000H000F0@<K008J000C0P@L
2`dU1@LO1@TQ1A0V7S56AUi`Aem[FVebRI6@OX9lSYV5UYj=VIfAVIZAW9^GWj:PVZ2OSIRFVIZHUYNE
RX^9TiRGCUMK9SDn8SI7>E5WEGBCBF^9F7^L@VB2?f5i;D]NEVij2AhV73Q9=UMV>V=/5TA;4Ce4>V1/
CVam<daP4c<n6CE08CM35RLd1a@R4Ql]:SY7<D5>73e0=55E<4U=>deDA4mG4QPS20hIC51KF5iSKW9c
M7=_M75YNgM/NgM/Lg5WK6UQIVYTJFeXJW1[KG=^K7=`JG9_IG1]I6m]M79XMG=YMWAZMG=YM79XLg5W
M79XMG=YMWEWMgEZMgI/MW=^KfmYK6aVKg1WMGI]K6mVKG1WKW5XKg9YKg9YKW5XK6mVJfiUL7=ZL7=Z
LgA[M7E/MgE]NGI^NWM_NWM_Q81eNgU^N7I[NWQ]NGU]MgM[O7a`Q8IjNGM_NWQ`NgY`OG]aOWY_O7U[
O7IYNWEVM75cMW5bMG5`MG5/M79XMW9WMgAUNGAUN71SN71SNG5TNg=VO7AWOGEXOWIYOgMZRGaVSh9/
V8]eXIAnZ9^5Zij8Zij8ZYf7Pg]TPgQRTHI`/:>=`KBN`[BN_k6KaKBO_k>G_k>G_k>G_k>G_k>G_k>G
_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G_k>G
_k>G_k>G_k>G_k>G_k>G_k>G_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E
_[>E_[>E_K:D_K:D_K:D_[>E_[>E_[>E_kBF_kBF_K:D_;6C_;6C_;6C_;6C_K:D_[>E_kBF_[>E_[>E
_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_K:D_;6C_;6C^k2B^k2B_K:D_K:D_K:D_K:D_K:D_K:D
_K:D_K:D`K6D`K6D`K6D`K6D`K6D`K6D`K6D`K6D`[:E`[:E`[:E`K6D`;2C`;2C_jnB_jnB_k2@_k2@
_k2@_k2@`;6A`;6A`;6A`K:B`;6A`;6A`;6A`;6A`;6A`;6A`;6A`;6A_k6=_k6=_k6=_k6=`;:>`;:>
`;:>`K>?_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_:^:R7mNH612HFQ=LGIQNWYZShEkZIN@_K:D^k2B
_:jA_:jA_jnB`;2C`:jA_Zb?_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;^jf9^jf9^jf9^Zb8^J^7^J^7
^:Z6^:Z6Z9YfWi5]Sh5MOFm;K5hjH58^FD/WEDLS@d<a?cl]@D4_ATHd@40^=SHT?Cd[CDdkD4leCTdc
CTdcE5<iG5]1HF16H5m5GEa2J6eHK75LLWMRNgm/Q8MgS8moTYF6UIR9X9f>XYn@XJ2BWinCWinCWj2F
YZNMZJbSYZJFZ:NIZZVK[:ZO[J^Q[J^Q[JZR[JZRZ:bPZZjR[K6U[K6V[K2W[[6X/;://[B^[[>T/;FV
/[JZ/[J[/;BY[k:Y/;>Z/K>][KJY/KZ]ZkBWYk2SZ;6TX:VLWjRK[KJYZ[6ZZ[6ZZ[6ZZ[6ZZ[6ZZk:[
[;>/[KB]/;BX/;BX/;BX/;BX[k>W[k>W[k>W[k>W[:jX[JnY[[2Z/;://;:/[k6[[[2Z[JnY[[F^/;B^
/KF_/kF_/kF_]KF_]KF_]kB_/[F//[F//[F//KB[/KB[/KB[/KB[/KB[/[B^/[B^/[B^/[B^/[B^/K>]
/K>]/K>]];N^];N^];N^/kJ]/[F//[F//KB[/KB[[k>X/KFZ/KFZ[;2UYJVNY:RMZ:bQ[K6V[K2W[k:Y
/KB[];N^][V`]kZa^;^b^;^b^<2f^Kje^;fd^[fd^kje`L:ia<Flb<Jn`/>o`/>o`lC0a<G1a<G1a<G1
`lC0`lC0`lC0aLK2alS4bL[6b/_7bL[6alS4aLK2al[1al[1b<_2b<_2al[1a/W0aLRoa<Nn];NW[[6R
ZJbSZZbVZJZVZjnY^/2ec=?6a[fL`kVG_kFC_k>?`;J>`kN=aKN=aKR<aKB=a;><a;><a;><`k:;`k:;
`k:;`k:;aKB=aKB=aKB=aKB=aKB=aKB=aKB=aKB=aKB=aKB=aKB=aKB=aKB=aKB=aKB=aKB=aKB=aKB=
aKB=aKB=aKB=aKB=aKB=aKB=a;><a;><a;><aKB=aKB=aKB=a[F>a[F>`[6:`[6:`k:;a;><aKB=a[F>
akJ?akJ?aKB=aKB=aKB=a[F>a[F>a[F>akJ?akJ?`[><a;F>a[N@b;VBb;VBa[N@a;F>`[><a;B?a;B?
a;B?a;B?a;B?`k>>0033]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_4^:c4^:c4^:c4^:c4^:c4^:c4^:c4
^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:k4^:k4^:k4^:k4^:k4^:k4^:k4^:jo]Zbo]Zbo]Zc0
]jg0]jg0]jg1^:k1^:k3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]jg3]jg3]jg3]jg3]jg3]jg3]jg3
]jg0^:_0^:_0^:_0^:_0^:_0^:_0^:_0^:_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3
]j_3]j_3]j_3]j_3]j_2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2
]Z[2]Z[2]Z[2]Z[3]j_3]j_3]j_4^:c4^:c2^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O2
^:O2^:O2^:O2^:O2^:O3^JS2^:O1]jK1]jK1]jK1]jK2^:O3^JS0]ZG0]ZG0]ZG0]ZG1]jK1]jK2^:O2
^:No]JBo]JC0]ZG0]ZG0]ZG0]ZFo]JBo]JBg[Y[3^JNn]ZFPUhYeK69FCTM:A3m9@Sm?CDe:B4Pn?Cla
=3P[;SHR9c0=4ah000/10a/001P41Qh51al00QX82R8?4BT622000a/232@C8cX`B5`eC5]:G6>1Rh^A
U99oRGb3S7n7Rh28RH2;RhF?ThjEW9NGXI^UYZ:MWYZGV9BIW9YTJfhd@d`^@U=1FFe9IX5CLHaYRJIK
OYQFN913I7AQOHP/B4l=9cPR@E0lH6X_FF0iHV]?MH5UPiIEL8DjF6<O>DDT>THkBeP[>dPA8BhJ:cP`
@e0I>3/`CE4G;cD03A@^>d<V;cP>51miOHR0QX]WJfb7R8IlNGAfM6b6Pgi^Kff7RHV8R8:0P7YfN79f
N79lOWQnP7YgNgEaMFmhMViiMfmiMfmhMVigMFefM6afM6afM6agMVaeLf]eLVegM6mfMG5dM6iaLF]_
KfUcMFmdMW1fN79fN79gNG=fN79dMW1dMW1_LF]_LF]`LVabLVadLFadLFafLVefLVejMfmhMFejMfmo
O7AlNW9dLVYaKfMcLFUkO7=kO7=lNW9kNW1kNFikMfaiMVQjM6MfLFifLFihLV]iLVUiLfIjLfAiLV5j
Lf1oMFB1MfJ6O6^<PW6CRGRISgjNU8>PUXFaY8jdYi6i[9Jn/I_1]9k0/ifo/Ybm/9Zg[iR`YHnbYi72
]Io7^ZC0/YbiZiFlZiJo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo
/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNn/iFn/iFn/iFn
/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFm/YBm/YBm/YBm/YBn/iFn/iFo]9Jo
]9Jl/I>l/I>l/I>k/9:l/I>m/YBn/iFo]9Jn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFm/YBm
/YBl/I>l/I>k/9:k/9:m/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YC1/IC1/IC1/IC1/IC1/IC1/IC1/IC1
/IC1/IC1/IC1/IC1/IC0/9?0/9?0/9?0/9>n[hno/92o/92o/930/I70/I70/I70/I6o/92o/92o/92o
/92o/92o/92o/92o/92n/8bo/Hfo/Hfo/Hg0/Xk0/Xk0/Xk0/Xjm[h^m[h^m[h^m[h^m[h^m[h^m[h^m
[h_2/I2SV7QlNUaSJ4eUJ59iMfFDR7bXUHfh[Hni[Y2l[Y6m[i:o[i:n[Y70[Y70[Y6m[h^m[h^m[h^m
[h^m[h^m[h^m[h^m[h^l[XZl[XZk[HVk[HVj[8Rj[8RiZhNiZhNm[h^m[h^k[HVgZHF^X7bTUW:JS6RD
QV9ZIe9;B3<e<Qdk>2=9AS5;B3=6@bi2?bY8A2]4@2M2?RE6@RU>BS5DD3MEDCQDD3M9C3I=D3YCED5L
GTYVJ5E_L61gN6QkO6b4Q7:=SGfJVXZPX9:OXIFKWI6EVHjCUhbRXYBSXiFTY9RUYIVWYYbXYYjYYinZ
Z:2TZ9bVZYjX[:6Y[:>XZj:YZjF[[JN^[j^//:B_/jNa]JZa]JZ_/ZV^/:Z^/:Z_/J^//JR`]Jb[/:NW
[:>Y[ZFPYIbNXiZ//JR^/jZ]/ZV//JR[/:N[/:N[/:N[/:N//JR_/ZV`/jZ`/jZa]:^b]Jbc]Zfc]Zfd
]jj[[ZF]/:N_/ZVa]:^b]Jbb]Jbb]Jba]:^^]Zb_]:^]/ZV]/:N]/:N`/JRa/ZVd/ZZe^:ne^:ne^:ne
^:nd]jjd]jjd]jjd]jj`/jZ`/jZ`/jZ`/jZ_/ZV_/ZV_/ZV_/ZVd]jjd]jjc]Zfc]Zfb]Jbb]Jba]:^a
]:^_/jRa]JZa]JZ]/JJWZj2UZIjY[J:^/ZN`/jZa]:^c]Zfe^:ng^[6h^k:h^k:h^k:c^k6g_;>j_kJn
`KRm`;Nm_[Fj^k:j^;2e][:g^;Bi^[Jm_[Zo`;c1`[k3a<33a<31`[k3a<35a/;7b<C7b<C6al?4aL73
a<3:cLC:cLC;c/G;c/G:cLC9c<?8bl;7b/6i_Zne^Jfe]Zbf]jjf]:bf]Z[1`[;@dKg5^iW1]iFm]8nm
/Xc0/hg2]Xk4]Xc3]H_4/hc4/hc4/hc4/hc3/X_3/X_3/X_2/H[5]8g5]8g5]8g5]8g5]8g5]8g5]8g5
]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g3/X_4/hc4/hc4
/hc5]8g5]8g5]8g6]Hk3/X_3/X_4/hc4/hc5]8g5]8g6]Hk6]Hk5]8g5]8g5]8g5]8g6]Hk6]Hk7]Xo7
]Xo2/hc3]8g4]Hk5]Xo5]Xo4]Hk3]8g2/hc4]8o4]8o4]8o4]8o4]8o3/hh00<:fZ/:fZ/:fZ/:fZ/:f
Z/:fZ/:fZ/:fZ/Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh
[/Bh[/Bh[/Bh[/Bh[/Bh[/Bh[/Bh[[jeZknf[;nf[;nf[<2g[L2g[L2g[L2g[L:fZ/:fZ/:fZ/:fZ/:f
Z/:fZ/:fZ/:fZ/:f[<:f[<:f[<:f[<:f[<:f[<:f[<:f[;ngZ[ngZ[ngZ[ngZ[ngZ[ngZ[ngZ[ngZ/:f
Z/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/6eZL6eZL6eZL6eZL6e
ZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL:fZ/:fZ/:fZ/>gZl>gZl>gZl>gZl6g
Y/6gY/6gY/6gY/6gY/6gY/6gY/6gY/6gY/6gY/6gY/6gY/6gY/6gY/6gY/6gY/:hYl:hYl6gY/2fYL2f
YL6gY/:hYl:hYl2fYL2fYL2fYL2fYL6gY/6gY/:hYl:hYkneY;neY<2fYL2fYL2fYL2fYKneY;neY;R`
VLBlYLW2[/:jZJ^TUHb4MfIPEDe6?D52>DY=A55ECdmDDTM=C3Q2@RLc=A/V:P004`003`004@004`00
4@856PD87@004@005`488@0>9A4S>QHW>Qh[>E5IH71eN7V3OGj4OhJ8PXV:PHN8OhB8OHN?Q8nISIbN
V92BS9ZLUY>GTWAlO3Q5CBHfARPnD3=:H3aDK3UGL3iMMT]^PTY/O5=fP3UKHBi4EQhgAb=3CRM:E5Ql
QVB7UFb;X5EaRDQTKbLoBc54DEMXME5QKR/nBb0f@RQ2CTISJ4iXKTaTJQle>ca>ECm<E0<<5CPoB9ZO
XWYnOgf0OWamNgYkNGUmOV]dN7b5SWaoOGYmNgYkMgYkMgemMginN7mlMgilM7enO7amNg]lNWQiMgIg
MG=dLW5bL71aKgmmO7QgLg9aKG5`K7IeLGUhM7EdL71_Jg9cKg9cKg=dL7AeLGAeLGAeLG=dL7=dL7Ei
M7EiM7MhM7QgLgQgLgYgLgUfLWYeLWaiM7UfLGQeL7]hLgeiM7eiM81lMhF1O820NWmoNGioMWilM7il
LWilLGmkL7mlKX9iKhElLX^2MI28MiN=NibAOIjCOInEOK6ST;:TTKFWU;V[V;f_W<2bWl>eX/FgY<:f
W/>gWlFiXLJjX/JjX/BhX<:fW/6eWLW2ZL2fW[fcVlBhX<FiXKnaV[Z/UKj^UkjbU[jbU[jbU[jbU[jb
U[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jb
U[jbU[jbU[jbU[jbU[jbU[jbU[jbU[fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fb
U;fbU;fbU;fbU;baTkbaTkfbU;fbU;jcUKjcUKjcUKjcUKbaTkbaTk^`T[^`T[^`T[baTkfbU;jcUKfb
U;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;baTkbaTkbaTk^`T[^`T[baTkbaTkbaTkbaTkba
TkbaTkbaTkbaTl2`Tl2`Tl2`Tl2`Tl2`Tl2`Tl2`Tl2`Tl2`Tl2`Tl2`Tl2`Tl2`Tl6aU<6aU<6aU;j_
Skj_Skj_Skn`T;n`T<2aTL2aTL2aTKn`T;n`T;n`T;n`T;n`T;n`T;n`T;n`T;j`S;j`S;j`S;naSKna
SL2bS/2bS/2bS[f_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkn^SK^`T9fJNg9dEf5TBgIbGhb2LIB3M[2U
QKFZR[b_SkjaTKj_Skb]SKn]S/6_T;f_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkb^R[b^R[b^R[b^R[^]
RK^]RK^]RK^]RKBVP[V[Qkj`S<:dT<6cSkb^R[FWPk6SOijGO7E^De9;<5E><f]TBGE^DfiWC6EN@f1L
@5QD>4e9;DI29T<o8d0l83`h73Pd64U:<4U9<DY:<T]:=Di=>E9A?EID@UQFA5]LB65RCVU[F75eHW]n
KX>8NHbAPY2GR9>FQiBFRYJHS9VJT9bMU9nPUj:RW:>SWIjRUj2TVJ>WW:FXWjFWXJJXXZVZYZ^/Z:^_
Y:jbYk2cZ[2cZZj`ZZj_Zjj_Zjn`[:^_ZK2d[Z^_ZJR/YZZ^Z:6UWijRW:^_ZJjcZZfbZJ^`YjZ_YZV^
YJV^YJV^YJV^YJZ/YZZ/YZ^]Yj^]Yjb^Z:f_ZJf_ZJf_ZJZ]Y:^^YJf`YjjaZ:nbZJnbZJnbZJjaZ;>k
/KBi/;6f[K:e[;:e[;Jg[[Vj/Kfk/k6dZk6dZk6dZk6dZk6dZk6dZk6dZk6dZk:e[;:e[;6dZk6dZk2c
ZZnbZJnbZJnbZKBg[[>f[K>f[K>f[K:e[;:e[;:e[;:e[;2dZK:fZk:fZjjbYjV]XZR/XJ^_Y:ncZ;:e
[;>f[KFh[kJi/;Nj/KRk/[Nj/KNj/Jng[K>h[kNl/kg0]l74^lG6_LG6_LS6_/;4_/?5_lC6`<G7`LG7
`LC6`<C6`<?5_l;4_/?5_lG7`LO9`lO9`lK8`/G7`LC6`<;5_<;5_<?6_L?6_L;5_<74^l33^/33^[Jm
/;Fk/;Vj/;^i[k^eZ;ZcWl2iW/W1Xl:hU[nfTKfaSKbaRknbS<:cS<:cS<>cRLBcS<BcS<BcS<>bRl>b
Rl:aR/:aR/:aR/BcS<BcS<BcS<BcS<BcS<BcS<BcS<BcS<BcS<BcS<BcS<BcS<BcS<BcS<BcS<BcS<Bc
S<BcS<BcS<BcS<BcS<BcS<BcS<BcS<>bRl>bRlBcS<BcS<BcS<FdSLFdSLFdSLBcS<BcS<BcS<BcS<Bc
S<BcS<FdSLFdSLBcS<BcS<FdSLFdSLJeS/JeS/JeS/JeS/:cS<:cS<:cS<:cS<:cS<:cS<:cS<:cS<>c
S/>cS/>cS/>cS/>cS/>cSP00`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`kN[`kN[`kN[`kN[`kN[`kN[
`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN]`kN]`kN]`kN]`kN]`kN]`kN]`kN]_[F[_[F[
_[F[_kJ/_kJ/`;N]`;N]`;N]`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`KF[`KF[`KF[`KF[`KF[`KF[
`KF[`KF[_kNZ_kNZ_kNZ_kNZ_kNZ_kNZ_kNZ_kNZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ
`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY
`KFY`KFY`KFY`KFY`KFY`[JZ`[JZ`kN[`kN[`kN[`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV
`KNV`KNV`KNV`KNV`KNV`KNV`[RW`KNV`;JU`;JU`;JU`;JU`KNV`[RW`;JU`;JU`;JU`;JU`KNV`KNV
`[RW`[RW_kFT_kFT`;JU`;JU`;JU`;JU_kFT_kFT`[^R^[>J]:jG_;FQb<6^`;RWW9B3MfiPAdXjA4Lg
@DHg@TPmAe16BEA<A51:?D]73a8Q1PTH1PTH1PTH1@PG3a8Q4QDT1@PG004F1@/R008J0@lV0a4W00@D
3aLT:2dfB55DEEYKJfmZPH9iQHMkO85bNH1aO8IfPhQoNWedTYF<QXZ4OH>2=d5831`Y1ALX52@e7C53
4RY07SeD@FAhFgn?HhVEKY:L>TYJ:Ca99d1:83e6EgN2Fgb;FWV>?E]d:D=?8CU5;d9?A5ERBeaYAeeY
=DmK7CU4?EAL=U1GIh68Jh>9FW1fI7Aj=d=90@T@M7UlW:6RI6UXLgEePHJ9G6A[IW9nB5MWEF1XIG1h
MX27Nh>:Mgf2MWYoOX:7RHbAPHB8P8>7P8>7PHB8Q8N;QHR<QHR<Q8N;Oh24NgenMWMeL75]MGE_O7]g
P7imPGelN7UeN7UeN7UeNGYfNGYfNGYfN7UeN7UeMWYeMWYeMWYeN7UeNWUeNWUeO7UeO7UeOWeiOW]g
OGYfP7eiQ7mlQX5nQh9oRX>0QXMnQHImQXAlQhEkRHMlSHUnT8eoThf0Wi>1XiR4ZYn;/jJ@^ZbE_[6G
`[>I`kFI`[>I`[>I`[>I`K:H`;6G`;6G_k2F_k2F_;2H_K6I_K6I_[:J_[:J_k>K_[:J_[:J_KJM^:jF
]ZbD_[:J`KFM_k6J_k6Ja;BM_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F
_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_K:D_K:D
_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_;6C_;6C_;6C_K:D_K:D_K:D
_[>E_[>E_;6C^k2B^k2B^k2B^k2B_;6C_K:D_[>E_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_;6C_;6C
_;6C_;6C_;6C_;6C^k2B^k2B_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C`;2C`;2C`;2C`;2C`;2C`;2C
`;2C`;2C_ZjA_ZjA_jnB_jnB`;2C`K6D`K6D`K6D_Zn?_Zn?_Zn?_Zn?_k2@_k2@`;6A`;6A_k2@_k2@
_k2@_k2@_k2@_k2@_k2@_k2@_[2<_[2<_[2<_[2<_k6=_k6=`;:>`;:>_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;
_Jn;_Jn;^:N6`[JD]Jj=T8a_NWMKOGMPQ7UUP71OZYmo/ZN7_:n?_k:B_Jj>^jb<_jf>`[2A_:j:_:j:
_:j:_:j:_:j:_:j:_:j:_:j:_Jn;_Jn;_Jn;_:j:_:j:_:j:_:j:_:j:^jf9^Zb8^Zb8^Zb8^jf9_:j:
_[2<_[2<^Jj>Y9UiTHIVShATUha/WI9bXIIfYIYjVI5cT8QZPg]MMFe?JF53GEDgDd/]CDDW@d0T@d0T
@d0TAD4XB4@/C4P`DD`gDdhiEEPoDUDlD58lCU4kDEI1Fem<I6YGK79QMWUZNGa]Oh5eQHMkRhb2Si27
TY>:TiB;U9J:UiV=VibBWYnEX:6HXj>MYjNQZZVUZ:VOZjbR[ZnV[ZnV[ZjX[JbX[ZfY/:n[[:fY/[>_
[Zn[[:fY[JjZY:FQWj2L[:fY/;BY[k>X[[:W[K6V[K6V[K6V[[:W[[:W/:n[[jjZ[jjZ[jjZ[ZfY[ZfY
[ZfY[ZfY[[:W[[:W[[:W[[:W[[:W[[:W[[:W[[:WZK6VZk6VZ[2U[K6V[[:W/[>Y];F[]kJ/[k:Y[k:Y
/;>Z/;>Z/;>Z/;>Z/KB[/KB[]KV^]KV^];R]];R]/kN//[J[/[J[/KFZ/kJ]/kJ]/kJ]/kJ]/kJ]/[F/
/[F//[F//KFZ/[J[/[J[/;BY[K6V[;2U[[:W/KFZ/kJ]];N^]KR_][V`][V`][V`]KR_]KR_`LVo_/>j
^;fd];N^/[F/]KJ]^KZa_[bd/K>]/K>]/[B^/[B^/[B^/K>]/;:/[k6[ZZbVZZbV[:jX[JnY[JnY[JnY
[:jX[:jX^;^b^Kbc^[fd^[fd^[fd^Kbc^;^b^;^b/[Z_]K^`^[^a_[^]_KJS_;6F_;2>`K:;`[JB`;F?
_K:<_[6;`[:=`k>>a;:=`k:;a;><a;><`k:;`k:;`[6:`[6:`[6:`[6:a;><a;><a;><a;><a;><a;><
a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><`k:;`k:;
`k:;a;><a;><a;><aKB=aKB=a;><a;><a;><a;><a;><`k:;`k:;`k:;a;><a;><a;><aKB=aKB=aKB=
a[F>a[F>`kB=`[><`[><`K:;`K:;`[><`[><`kB=`[:=`[:=`[:=`k>>`k>>`k>>0032]Z[2]Z[2]Z[2
]Z[2]Z[2]Z[2]Z[2]Z[3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3
]j_3]jg3]jg3]jg3]jg3]jg3]jg3]jg3]jfm]:Zn]J^n]J^n]J^o]Zbo]Zbo]Zc0]jg2]Z[2]Z[2]Z[2
]Z[2]Z[2]Z[2]Z[2]Z[0]:[0]:[0]:[0]:[0]:[0]:[0]:[0]:Zo]jZo]jZo]jZo]jZo]jZo]jZo]jZo
]j[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[0]:S0]:S0]:S0
]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S1]JW1]JW1]JW2]Z[2]Z[2]Z[3
]j_0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG1]jK1]jK0]ZFo
]JBo]JC0]ZG1]jK1]jK0]ZG0]ZG0]ZG0]ZG1]jK1]jK2^:O2^:No]JBo]JC0]ZG0]ZG0]ZG0]ZFo]JBo
]JBj]Ibl]Ynn]Ynn]Yo1^:C5_:S1]jFj/9jATge/KEU4AS<g>RY2BCY=EDY9DTQ0BClC5Qh82a<41`l2
1@d00`/<3aLB5Ad62A4011<531d00AD84bTC7S@43R012QP01A884AXO9RU2B4=XJUiiO6ajOFefNfaf
OG1jP7E`M6R9SH5kOWEoQH12Bdh:5R044b<95R@K:c`E;D4J=ThgFG19K810I7IAMHDH92i0D5MDIf`g
CE95HFQ5HW16IgXlGWDH=T4F<SdG;c/H:cPR=D8kDEdiDEdH=3lH;3LR>4<mEeiMNWm@JW1NLWMWMWTE
82@[<CJJWj9eNGY/L75mQ8MEGVM?G6Xc@e@cB5LoE6=<H75@I7EAHWEBHgIMJh5WMH]>EEi>EEiAF65G
GVMOIVmVKGIXKgQXKgQaMGZ0Q8F9ShZ:ShJ:SX>BThZKV9>MVIR7RH>6R8:5Qh65Qh64QX24QX24QX24
QX24RhB4RhB7RhF7RhF:S8J<S8J<S8J=SHN:S8J@T8ZDU8jJUi:LV9>KUI2BS8N<Pgn@SX>BSX>DTH>H
TXFLUhRSW8fXXI2[Xi:j[YJk/9Fo/YS1]9[3]IW3/YO1/IC0/9>jZHjjZHjkZXnlZi2m[96n[I:n[I:o
[Y?0]I[0]I[0]I[1]Y_2]ic3^9g4^Ik4^Ijn]ibm]9Vl/iS1]Y_1]Y^o/YRm/9Jo/9Jn/YJn/YJn/YJn
/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn
/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJl/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I>l
/I>l/I>l/I>l/I>l/I>k/9:k/9:l/I>l/I>m/YBm/YBm/YBm/YBk/9:k/9:j[i6j[i6j[i6k/9:m/YBm
/YBl/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I>k/9:k/9:k/9:k/9:k/9:k/9:l/I>l/I>k/9:k/9:k/9:k
/9:k/9:k/9:k/9:k/9:o[i:o[i:o[i:o[i:o[i:o[i:o[i:o[i:n[Y6n[Y6n[Y6o[i;0/9?0/9?1/IC1
/IBm[Xjm[Xjn[hnn[hnn[hno/92o/92o/92n[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnm[h^m[h^n/8bn
/8bn/8bo/Hfo/Hfo/Hfm[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^jZXJn[hjj[hn]YHNOUgZES76AQFf@
PV^YWgfaYhFl/8jn/Y2m[XfjZhZn[Hc2/I2l[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl
[XZl[XZm[h^m[h^m[h_2]92o/Hfl[XZiZhNhZXJk[HVn/8c0/Xjk[XRi[8JhZhFfZH>bYGnaY7ji[8K2
]Hnk/92h[HfcZ8R^Xh>WW7bOU7BGS6bBQfM`JDQ/I4ITG3iKDcICBRm<@bQ7?BE5>b=5A2Q6ABU8Abe9
BS1:CCA<CSQ;CSQ;CSQADd1FF4ENGdmWJ5Q^KV1cLfEeMFUeMFUlOFeoP724Q7J9RG^<S82AT8JFUH^I
V8jIVHfLW92PX9BRXINRX9RRX9RTXIbVXijRY9jXZZBVZ::TYZ2VZ::KWINFV9:QXifSYibSYibSYibT
Z9fUZIjVZYnX[:6Y[J:`[JR`[JR`[JRa[ZVb[jZb[jZc/:^c/:^[[jB[[jB//:F]/JJ_/jRa]JZb]Z^c
]jb_]jba]jbb^:fe^Jje^Jjg^:jf]jfg]Zbb]Jbc]Zfc]Zfc]Zfd]jje^:ne^:ne^:nd^:fd^:fc]jbc
]jbb]Z^b]Z^b]Z^a]JZb]Jbb]Jbb]Jbc]Zfc]Zfc]Zfc]Zfc]Zfa]JZb]Z^b]Z^a]JZ`]:V`]:Va]JZb
]Z^b]Jbb]Jbc]Zfd]jjd]jjc]Zfb]Jbb]JaOIeeOI5]NHeYPHeYUJ5m`LFQiNW60OWJNXIRPXiZTYijX
Zj:/[jJ`/jZb]Jbc]Zfl_kJm`;Nn`KRo`[Vo`[Vo`[Vo`[Vo`[Vi_;>j_KBk_[Fl_kJl_kJk_[Fk_[Fj
_KBf_kFm`kS3a;[7`KC6_JW6^9_3/hk1/8G2^931]8k0/hg2/Xg3/hk6]8o6/hk5/Hk3/X_3/X_3/X_2
/H[2/H[2/H[1/8W1/8W3/X_3/X_3/X_3/X_3/X_3/X_3/X_3/X_3/X_3/X_3/X_3/X_3/X_3/X_3/X_3
/X_3/X_3/X_3/X_3/X_3/X_3/X_3/X_3/X_2/H[2/H[3/X_3/X_3/X_4/hc4/hc4/hc4/hc4/hc4/hc3
/X_3/X_3/X_3/X_3/X_3/X_3/X_4/hc4/hc5]8g5]8g5]8g5]8g4]Hk4]Hk3]8g2/hc2/hc3]8g4]Hk4
]Hk1/Hc1/Hc2/Xg2/Xg3/hk3/hh00<6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL:fZ/:fZ/:fZ/:fZ/:f
Z/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:f[<:f[<:f[<:f[<:f[<:f[<:f[<:f[;fd
Z[fdZ[fdZ[jeZkjeZknf[;nf[;nf[<6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZl6eZl6eZl6eZl6e
Zl6eZl6eZl6eZkjfZKjfZKjfZKjfZKjfZKjfZKjfZKjfZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6e
ZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2d
Z<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<6eZL6eZL:fZ/:fZ/:fZ/2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2f
YL2fYL2fYL2fYL2fYL2fYL2fYL2fYL6gY/2fYL2fYKneY;neY<2fYL2fYL6gY/2fYL2fYL2fYL2fYL6g
Y/6gY/:hYl:hYkneY;neY<2fYL2fYL2fYL2fYKneY;neY;N`W;jgXl:iYK^bW[V^V[jcWlNiY/^mZ[jh
XJFQRH1mJ5mMBdM7=c`o<414>4Y>@dE<BCa3@3Y1?SPo?3Hm>T99ATYACT17A0D=50<:4`0030`D9B<Z
?BD_@1lZ>00;5aTT;3Dn@EMNEfebHgUkJ7amKGUkKgAgKWR2LVedIGf2LfmcIgQlMU5IFA0K8aPV<P<@
7P0A8P8I;`<N>3MELSmMNQ4_BP0E;RHb<VQdM6]hMSi>CBi5AciKHSmRL49XNS1GH1/nB0hZ=@LM:@LJ
9aT/>BDkAale@A8R;cY=FQXe?ba<DSmNHCiGFEe_L3m;C@L?5V5WK9FJVgQlOGEiNV]aMT5<E4iJISiE
GCM=F2m7Dba5EBm7Fc9:HS59IBm7IADO<18L;A4K;1<M;QLQ<QTS=1LQ<Q@N;aHL8cQ0@5]TFVE_GfI/
FFU/GFe/HVeZIGj2MWf1MG]oLgUmLGQlL7MkKgMkKgMkKgf7NWj7NWj7NX27NX27NX:6NXB6NXB6NWZ0
MGYnLgQiKgYiKhF3NIF@QinHSj6HSj:JRJ>KRZFNRj^QSk6VT[FZU;^^V;f`V[^`U;baUKjbU[jbU/2b
U/2_U;j]T[f/TL6cUl6cUl6cUl:dV<:dV<>eVL>eVLBfV/6fV/6fV/6fV/:gVl:gVl:gVl:gVl:gVkfg
V[ngV/2hVl:gVl6fV[ncUkfaUKf_TkfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfa
UKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKba
TkbaTkbaTkbaTkbaTkbaTkbaTkbaTkbaTkbaTkbaTkbaTkbaTkbaTkbaTkbaTk^`T[^`T[^`T[baTkba
TkfbU;fbU;fbU;^`T[Z_TKZ_TKZ_TKZ_TK^`T[baTkfbU;baTkbaTkbaTkbaTkbaTkbaTkbaTkbaTkZ_
TKZ_TKZ_TK^`T[^`T[^`T[baTkbaTk^`T[^`T[^`T[^`T[^`T[^`T[^`T[^`T[n_T[n_T[n_T[n_T[n_
T[n_T[n_T[n_T[j^TKj^TKj^TKn_T[n_T[n_T[n_T[n_T[f^S[f^S[f^S[f^S[j_Skj_Skn`T;n`T;j_
Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skf_Rkf_Rkf_Rkf_Rkj`S;j`S;naSKnaSKf_Rkf_Rkf_Rkf_Rkf_
Rkf_Rkf_Rkf_RlFeTKf]RKZ[R[f`T;V^S[2UQjjRQ[FYSJjTP[>YQk^_SKfaSkf^SK^/Rkj]S<2_S[^]
RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RKb^R[b^R[b^R[b^R[NYQKRZQ[V[QkZ/R;V[
QkRZQ[JXQ;FWPk^[Q[^[Q[^[Q[f]R;f]R;b/QkZZQKVYQ;RYR;Z[R[f^SKn`Skn`Skf^SKVZRKNXQkF[
RJnUPjBJN9F:JXIkGGM/CVaPA6IJ?UQ@<U9=;Ta6:DM39TI29TE1:4A09d4o9d90:4E3:dU7;di;=U=?
?5IB?eQD@UUE@eaOBEmRC6AVDVU[Efe_G75cH7IgIgYkJgeoK822KhF6MXR9NHV9Nh^;Ohj>PY2@Q8j?
QIJGSIBERi>DRYFFS8Z;PH>4NXj?QHN9OHN9OHN9OHR:OXZ<P8b>PXj@Q92BQY6@QY:AQiBCRIJERiVH
SY^JT9fLTYjMTi:FRY>GRiFISIRLT9bPU:6UVJFYWJN[WjbeZ:jeZ:jeZ;2dZ;2dZ;6cYk2bY[:bYZf`
YjjaZ:jaZ:nbZK2cZ[6dZk6dZk6dZjncYjncYjncYjncYjncYjncYjncYjncYk:e[;:e[;:e[;:e[;>f
[K>f[K>f[KBg[[:fZk:fZk>g[;>g[;>g[;Bh[KBh[KBh[K2cZ[6dZk:e[;>f[K>f[K:e[;:e[;6dZhB<
PX^@QiFJTJ:UW:jaZ;Vj/L31^<G3^k:fZkBh[KNk/;Zn/kg1][o3^<34^L75^[Bh[KBh[KFi[[Fi[[Fi
[[Jj[kJj[kJj[kZm];Zm];bo][bo][g0]kg0]kbo][bo][S2][o5^/G6_<K3]LJo[<RmX/FgTkn`RL:f
S<2dS<6bRl:bSLJdSlNcT<JbSlB_Sl>bRl>bRl:aR/:aR/6`RL6`RL6`RL6`RL>bRl>bRl>bRl>bRl>b
Rl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl:a
R/:aR/:aR/>bRl>bRl>bRlBcS<BcS<:aR/:aR/>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRlBcS<Bc
S<FdSLFdSLFdSL>dSL>dSL>dSLBeS/BeS/>dSL>dSL>dSL2`Rl2`Rl6aS<:bSL:bSL>cSP00`KFY`KFY
`KFY`KFY`KFY`KFY`KFY`KFY`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ
`[JZ`[JZ`[J/`[J/`[J/`[J/`[J/`[J/`[J/`[J/_KBZ_KBZ_KBZ_[F[_[F[_[F[_kJ/_kJ/`KFY`KFY
`KFY`KFY`KFY`KFY`KFY`KFY`KF[`KF[`KF[`KF[`KF[`KF[`KF[`KF[_[JY_[JY_[JY_[JY_[JY_[JY
_[JY_[JY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`;BX`;BX
`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`KFY`KFY`KFY
`[JZ`[JZ`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`KNV`;JU
_kFT_kFT_kFT_kFT`;JU`KNV`;JU`;JU`;JU`;JU`KNV`KNV`[RW`[RW_kFT_kFT`;JU`;JU`;JU`;JU
_kFT_kFT_KFT^k>R^JnN]ZbK_:nO`kFS`[:Q^j^J_K2J`;>M^ZnKWiN6MFiODT`oC4PmEE=9Ae13ADi1
BeA7C5E8BE95E5e@GFIIEEiA;CDd5alO00@;1@/H5Qd/<ca:?4QD2APQ;3Y0EV9RNX=iOXAcNG]XNWY/
NGYaM79aLG]ZK7ASMG]ZKg9SKgA[FV1O2A<J72H`1QHV00/M2R0i01@b=e9d@Ub07SAG00T/=ShgOHEn
J7=[AEA<9c`i@EmP;U=K=65/?Fad:E9K7Ce852`h1QLT1aLT4b<`5RHc0PlO7blo32La63Y0:Te@=51A
GW=aKWYj8Rde8RXaOhB7TYBDN7UgMgUiG65THfU^I79VGfmTEFIRAUUL=T]C9ci>7CA:6C5931X]1Q@W
0@lR00hQ0@lR00hQ00PK00<F0PdA;CPfEV=EIG9JIG1FJ6iGJV]KJ6ILIfeJIF]HHVQEGfEBGF=@G69?
G69?G69?E61<Dem;Dei:DEa8DU]7DUQ5DEM4DEM4ADloAD`mA4TjCDdoIFAFRH=fXYZ=Zj:E]:NA]JVA
]jVB^JbB_JjD`:nD`;2C`;2C]Jf@]Jf@^JjB^ZnC_K6E`;6G`K:H`K:H_K2F_K2F_:nE^jjD^ZfC^JbB
^:^A^:^A^ZnC^k2D_K:F_[>G_kBH_[>G_[>G_K:F][2C^[:E^k>F_K:F_;6E_[:F_k>G`K>G_K6E_K6E
_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E
_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C
_;6C_;6C_;6C_;6C_;6C_;6C^k2B^k2B^k2B^k2B_;6C_;6C_;6C_K:D^ZnA^ZnA^Jj@^Jj@^ZnA^k2B
_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C^Jj@^Jj@^ZnA^ZnA^k2B^k2B_;6C_;6C^ZnA^ZnA
^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA_ZjA_ZjA_ZjA_ZjA_ZjA_ZjA_ZjA_ZjA_jnB_jnB_jnB_jnB_ZjA_ZjA
_ZjA_ZjA_:f=_:f=_Jj>_Jj>_Zn?_Zn?_Zn?_Zn?_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_:j:_:j:
_Jn;_Jn;_[2<_[2<_[2<_[2<_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;a[JB_Zj:_:b8`K2?`K:A_K2@
_;6A`[NG]Jb7]jj9^Zj:^jn;_Jn;_:j:_Zj:_Jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^J^7^J^7
^Zb8^Zb8^jf9^jf9_:j:_:j:^Zb8_:j:`;:>`[B@`K>?_k6=^jf9^J^7^Zf7^:^5]jZ4^:^5_:n9_K2:
^Jb6]:N1/Z9n]:B0]jN3^JV5^JV5^:R4]jN3]jN3^Jb6^Zf7_:j:_Jn;_:f<^Z^;^:V9]ZJ9Y9MgV8][
Q7UILfQ:IEXnFE4dDTT^CD@YEE0aDTd^CDLZBD8WB44VBT<ZCDH]D4PaBDh_C50cD5@gDeHlEUU0FEa3
GEm9H69<HVE<IVU@K6iHL75MLgAPMWITNGUWO7a/N7]/P8=dOh9cOh9cP8=dM7MXKG1QMgY[LG=WLG=W
LG=WLWAXLgEYMGM[MWQ/MgU]N7MYN7MYNGQZNWU[O7]]OGa^OWe_OWe_M7Q/MGU]MWY^NGeaOH5ePHEi
QHUmR8b0PX]nPhYmPXUlQHUmRHf1T9:6UIN;Vi^?YJROYZVPYjZQYjZQZ:^RZJbSZZfTZZfTZjnS[;2T
[;2T[K6U[[:V[k>W[k>W/;BX/KB[/KB[/[F//[F//kJ]/kJ]];N^];N^/kN//kN//kN/];R]][Z_][Z_
][Z_]KV^/;>Z/KB[/[F//kJ]];N^];N^/kJ]/kJ][kN]/kR_]KZa^;^b^;^b]kR_/kB[/k6Y^[jc^knd
^knd^knd^[jc^;ba]k^`][Z__/:g_/:g_/:g_/:g_/:g_l>h_l>h`<Bi^;^b^Kbc^[fd^kje_;nf_;nf
^kje^kje][jc_L>h`/>i`;jc`kb]aKfV`kVK^[2>_k>9`;:8_k29`[2;aK:=a[:?aZn?a:f=`[6:`[6:
`[6:`[6:`K29`K29`:n8`:n8`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:
`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:`K29`[6:`[6:`[6:`k:;`k:;`k:;a;><`K29`K29
`[6:`[6:`k:;`k:;a;><a;><`k:;`k:;`k:;`k:;a;><a;><a;><aKB=`;6:`K:;`kB=a;F>a;F>`kB=
`K:;`;6:_jn:_jn:`;2;`K6<`[:=`k>>0031]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW2]Z[2]Z[2]Z[2
]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Zc2]Zc2]Zc2]Zc2]Zc2]Zc2]Zc2
]Zbl/jVm]:Zm]:Zm]:Zn]J^n]J^n]J^o]Zc1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW2]Zc2]Zc2]Zc2
]Zc2]Zc2]Zc2]Zc2]Zbn]ZVn]ZVn]ZVn]ZVn]ZVn]ZVn]ZVn]ZW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1
]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JVo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo
/jNo/jNo/jNo/jNo/jNo/jO0]:S0]:S0]:S1]JW1]JW1]JW2]ZZo]JBo]JBo]JBo]JBo]JBo]JBo]JBo
]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JC0]ZG0]ZFo]JBn]:>n]:>o]JC0]ZG0]ZG0]ZG0]ZG0]ZG0
]ZG1]jK1]jK2^:O2^:No]JBo]JC0]ZG0]ZG0]ZG0]ZFo]JBo]JBi/JBo]ZW2]jW0/jG1/JC5]JG8]JK5
/Z?8]j;3/Yo2/Z75^:Rh[In@QWaSFU55?SDg@RhjAC56DCe<Ed=9E41CGTYKIU9DGd]OJV8h@Ch=51L0
1@h42QL^=dA3DU/96b803a8lBDM_NFedNVM^L5adM6IkN7AgM7IZM6=]MFAeNfYgNV]bMFaOI6<01PX?
6B<bA5D`AEY@Ih488D<>9D/464435Ch01Rd32`1[M6MdOG1[Mf/cB40kFULD?D0ZF5lXGVD/Ff<_DedM
=d<762D64b49528021H6428000l892lD>3h09BLR@D1QMWAcPGm?FfD22aA5BTfWZ:J4PgmaL6b5QXAN
H61PIDIaMU]fOfYPJUhb@3h<7b@04b025RL13bD02b402Al03B<652X95bd75B/44RP74QH[>CEAGdeJ
JDeJITQPIdaSIE9QH59OIe1MIDiIHDYFGTMCFdABFT=AFD9AFD9;FD5:F418ESi6Dc]5CcQ2C3E2BS=0
B34g@Ri5CSYHGT]aLf2>SWb/Z9Jg/9nd[9^o/IFo/IG2/IK2/YG3/I;2[Xo0[HbnZhZi/iJh/YFi/IBi
[Y>h[I:iZiBiZiBl[9Ff[I:g[Y>h[iBi/9Fj/IJl/iRm]9Vm]9Vi[Y:k/9Bo]9S2]i_4^Ig5^Yk5^Yk5
^Yjl]YVo]iZn]YVl/IFj[i>l/9Bo/iO1/iNm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm
/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm
/IFk/9:k/9:k/9:k/9:k/9:k/9:k/9:k/9:k/9:k/9:k/9:k/9:k/9:k/9:k/9:k/9:j[i6k/9:k/9:k
/9:l/I>l/I>l/I>l/I>j[i6j[i6i[Y2i[Y2j[i6j[i6l/I>l/I>k/9:k/9:k/9:k/9:k/9:k/9:k/9:k
/9:i[Y2i[Y2i[Y2j[i6k/9:k/9:l/I>l/I>j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6n[Y6n[Y6n[Y6n
[Y6n[Y6n[Y6n[Y6n[Y70/9?0/9>o[i:o[i:n[Y6m[I2m[I2m[I2l[Hfl[Hfm[Xjm[Xjm[Xjn[hnn[hnn
[hnm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjl[XZl[XZm[h^m[h^m[h^n/8bn/8bn/8bm[h^m[h^m[h^m
[h^m[h^m[h^m[h^m[h^o[h_0/8c2[hc1[X^o[Xfm[Xfj[Xbf[8Zk/Xfi/8^i[HVj[XZm[h^m[h^n[XZl
[8Rk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVhZXJhZXJiZhNiZhNj[8Rk[HVk[HVk[HVk[HVj[8Rj[8Ri
ZhNhZXJgZHFgZHFgZHFeYh>hZXJj[8RgZHFfZ8BhZXJm[h^o/HfjZ8>kZHBlZXFmZhJmZhJn[8O1[h[3
/HbfYh2hZ8>kZhJn[XZn[XZlZhZiYhRfY8FhYhJiZ8NiZXZjZh^dYXVYVgnHS72<P6AcJTQZHCmME3=A
B2M;@B=<@BE@ABUEBRi4BRM7C2a:Cbm<DC9<DC9>DSEAECQDEceCEcYGFT1MH4IRIDaVJE1YJeE^L5Ya
LUi/KU]eMfAeMfAeMfAfN6EZK5URI55/KU]dM6IdM6IcLfEcLfEcLfEdM6IeMFMfMVQkNfUjNVQiNFMg
MfEeMF=cLf5bLV1aLEmYKUmYKUmXKEiXKEiYKUm/LF9^LfA`MFI]MfM]M6E/LfAbMfQjOg29S7fFVHZP
X9:UZ9nVZJ2VZJ2WZZ6Y[:>Z[JBZ[JB[[ZF//J://J:]/Z>^/jB`]JJa]ZNb]jRb]jRa]:^a]:^b]Jbb
]Jbc]Zfd]jjd]jjd]jjc]jbc]jbc]jbe^Jjg^k2h_;6g^k2f^Zna]:^b]Jbc]Zfd]jje^:ne^:ne^:ne
^:n`^:jb]jja]Zfc]Zfe^:nj^k:m_[G1_kNf^Zng^k2h_;6j_[>k_kBk_kBk_kBj_[>h_;6h_;6g^k2g
^k2h_;6h_;6i_K:j_[>j_KBk_[Fl_kJn`KRn`KRn`KRn`KRn`KRi`;>na;W2`kVo_[C1_[36`:g2_JBk
]IRo/XJn/8Jm[hG1/8W4/8g4[ho5[Xk3Zhg2/H[2/H[2/H[1/8W1/8W1/8W0[hS0[hS2/H[2/H[2/H[2
/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2
/H[1/8W1/8W2/H[2/H[2/H[3/X_3/X_3/X_0[hS0[hS1/8W2/H[3/X_4/hc5]8g5]8g2/H[3/X_3/X_3
/X_4/hc4/hc4/hc4/hbm[XNo/8W1/X_3]8g3]8g1/X^o/8Vm[XNo[hZo[h[0/8_1/Hc2/Xg3/hh00<Bf
Z/BfZ/BfZ/>eZL:dZ<:dZ<6cYl6cYl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl:fZ/:fZ/:fZ/:fZ/:f
Z/:fZ/:fZ/:fZ/6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZKnc
YkncYkncYkncYl2dZ<2dZ<2dZ<6eZL2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<6eZL6eZL6eZL6eZL6e
ZL6eZL6eZL6eZL2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2d
Z<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2f
YL2fYL2fYL2fYKneXkneXkneXkneXl2fY<2fY<2fY<6gYL:fY<:fY<:fY<:fY<:fY<:fY<:fY<:fY<:f
Y<:fY<:fY<:fY<:fY<:fY<:fY<:fY<:fY<:fY<:fY<:fY<:fY<:fY<:fY<:fY<:fY<:fY<6eXl6eXl2d
X/2dX[ncXKncXL2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX/6eXkjbX;b`W[ncXKjbX:jRT9Z>O5MF
@TU9=cm2<Sm6>Cm:@3]:@SU:AS]?BTAFBC]:AQdV<0005`006A/G=2h[@Bl[?P/<438d=5mTFg=jJfee
I69[EfA/FfadHfEgJVIcHg1iIG1dHGAiJUmVHBLc>A@T<GBGVf>3R7JDVINd^G^EVbU1A`0?5@0B6@01
0E1DCWMgIf]/F65YF3A:AA0c?B1>H25BG2mMJ3ANJRiAGRY5DbDjBADU=@0>7P0<<007900:71<R9CM3
?EIPDfA/FfM]FX:=Pb`d<`hD6f]^O92DWgEkP7j8PWF2M5USHf5^ITYJBEEWD4EEA0hI5`L<6`@58@P=
9PP>9@@97P066@L;7A<F91HJ9A<G8T98;dYC>E=NA5ETBE1QATYPA4]RATeVBU1MAdeIAD]GADYGAdUH
BTMEBCm?A3Y9@D18?T98?D=7>dE6=TU7=EIA?6IPBGE^EJ2ENJRMPK>XS;^`U;ndV;jcUkfbU[fbU[b`
U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;^_Tk^_Tk^_Tk^_Tkb`U;b`U;b`U;faUKb`U;b`U;b`U;b`U;b`
U;b`U;b`U;b`U;faUKfaUKfaUKjbU[jbU[ncUkncUkncUkfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfa
UKfaUKfaUKfaUKfaUKfaUKfaUKfaUL2dV;ncUkncUkjbU[jbU[faUKfaUKb`U;faUKb`U;b`U;b`U;^_
Tk^_Tk^_Tk^_TkZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKj_
Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj^TKj^TKj^TKj^TKj^TKj^TKj^TKj^TKj_Skj_Skj_Skj_Skj_
Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skf^S[f^S[f^S[f^S[f^S[f^S[f^S[f^S[b]
SKf^S[j_Skj_Skj_Skj_Skf^S[b]SKj_Skj_Skf^S[b]SKb]SKf^S[j_Skj_Skf^S[f^S[f^S[f^S[f^
S[f^S[f^S[f^S[f_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf]
R;j^RKn_R[n_R[n_R[n_R[j^RKf]R;j^R[j^R[j^R[j^R[j^R[j^R[j^R[j^R[b^R[b^R[b^R[b^R[b^
R[b^R[b^R[b^R[^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RKf]R;f]R;f]R;f]R;f]R;f]R;f]R;f]R;ZZ
QK^[Q[f]R;j^RKj^RKf]R;^[Q[ZZQKb/Qkb/Qkb/Qkb/Qkb/Qkb/Qkb/Qkb/Qkb/R;b/R;b/R;b/R;b/
R;b/R;b/R;b/R;ZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKb/R;^[QkZZQ[ZZQ[ZZQ[ZZQ[^[Qkb/R;^[
Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[6QO;6QO:jNNJNGLYR8HhIfDGAT?fYJ=Di9:4]69DQ38TU48da7
9U1;:U=>;EA?;UY?=5]D>F9NAFYXD6][DfeXDg9[F7a`GW5bGW=dH7IgHgMhI7IgHg=dH6i_Ff]/F7Mg
IGIfI7EeHg=cHG9bH71`GVm_GFi^G6i^G6a/FVQXEVIVE6IVE6UYEfe]Fg1`GV]^F6AWDG5dGWMiIGYl
JGEgI6e^GWIgIg9bI7alKXF5MiVIRjBTUZ2PTZZZW:ZZW:NZVjV/WJNYWJf_XkNf[:j/Y:bYXKbi/KNf
[:j]Xkjm/jj]Xknn]:RWWJb[XL2o]L6k[Z>RU;BfZ/34^:FYWZf^YLO4_;jf[kFh[kNj/KNh[kNh[jj/
Y;6^Y[nl];BaZKBeZk>dZ[:cZK6bZ;:cZKBeZkJg[KNh[Zn`Y[>dZ[Ri[kZk/KZk/KVj/;Vj/;Vj/;Vj
/;Vj/;Zk/KZk/K^l/[^l/[^l/[^l/[Zk/K^l/[^l/[^l/[bm/kbm/kbm/kfn];fn];fn];fn];jo]Kjo
]Kjo]Ko0][o0]/Fo^<2m^;bk]k^l^;no^L6o]<2k[;nhYKZ`S[naSL>bRl>bQl>`QL2`Q/6aS;ncSl6`
RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL:aR/>bRlBc
S<BcS<>bRl>bRl:`Ql:`Ql>aR<>aR<BbRLFcR/FcR/FcR/6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`
RL:aR/:aR/:aR/>bRl>bRl>bRlBcS<BbSLBbSLBbSLBbSL>aS<>aS<>aS<>aS<:aR/:aR/:aR/:aR/:a
R/:aR/:aR/:aR/FcS/FcS/FcS/FcS/FcS/FcSP00a;JZa;JZ`kFY`kFY`[BX`[BX`K>W`K>W`kN[`kN[
`kN[`kN[`kN[`kN[`kN[`kN[`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`KFY`KFY`KFY`KFY`KFY`KFY
`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY_[:V_k>W_k>W_k>W`;BX`;BX`;BX`;BX_k>W_k>W
_k>W_k>W_k>W_k>W_k>W_k>W`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY_k>W_k>W_k>W_k>W_k>W_k>W
_k>W_k>W_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_k>W_k>W_k>W_k>W_k>W_k>W_k>W_k>W_kFT_kFT
_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_[BR_kFS_kFS_kFS`;JT`;JT
`;JT`;JT`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS
`KFS`KFS`KFS`KFS`KFS`KFS`[JT`KFS`KFS`KFS`;BR_k>Q_k>Q_k>Q`;BR`;BR`;BR`;BR`;BR`;BR
`;BR`;BR_k>Q`;BR_[:P_;2N`KFSa;RV_;2N[j>AViF2Mg=QD510@D@e?dLl?DQ0=T8l<Cli?Di3=dE3
8R/d2@dP000F0P0F0P8B000800418bLRD5I;JG5PJW=NIFiIJG9NL7QWHg=RI6iML7MRLG=OKW=TEEiK
9SHm8SE4?UmXKHjGTK2iV;>mX;W3Vk6lGW9m4R@_1a<EATe8JFaMKFiJIVmK@5=:7C]084QD4daE75=L
7e9L6dUD6dEA7D=?4cE20R@a2QPd00DK00TE8S8aD5iCI6mOIFiJHfaGHVmQM7mg>3m2=S]4RXjIV9jS
N85nN8=kHfe]IG5[EVIEFFYEBEU86RDS1P/J1`PR1Q0Q1@hL1a0M5AhW9c<e=T4o?4E2>dDoDEa8D5]7
CUU5BUI2AE@o@U<n@U<n@E@oEEm>CUQ7A4hm?4Hf>48b=d0c>44d>T4d?d4eC4m0Hf=CN7ITS8MbWIN0
[jR=^k:G/JJ:]JZ>^ZnC_;6E_;6E^k2D^k2D^k2D^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^ZjB^jnC
^jnC^jnC_;2D_;2D_;2D_;2D^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC_K6E_K6E_K6E_K6E_[:F_[:F
_[:F_k>G_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_k>G_k>G
_[:F_[:F_K6E_K6E_;2D_;2D_;2D_;2D_;2D_;2D^jnC^jnC^jnC^ZjB^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA
^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_ZjA_ZjA
_ZjA_ZjA_ZjA_ZjA_ZjA_ZjA_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?
_Zn?_Zn?_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_:f=_Jj>_Zn?_Zn?_Zn?_Zn?_Jj>_:f=_Zn?_Zn?
_Jj>_:f=_:f=_Jj>_Zn?_Zn?_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;
_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jf8_Zj9_Zj9_jn:_jn:_Zj9_Zj9_Jf8_Zj:_Zj:
_Zj:_Zj:_Zj:_Zj:_Zj:_Zj:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:^jf9^jf9^jf9^jf9^jf9^jf9
^jf9^jf9_Jf8_Jf8_Jf8_Jf8_Jf8_Jf8_Jf8_Jf8^ZZ5^j^6_:b7_Jf8_Jf8_:b7^j^6^ZZ5_:b7_:b7
_:b7_:b7_:b7_:b7_:b7_:b7_:b8_:b8_:b8_:b8_:b8_:b8_:b8_:b8^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5
^ZZ5^ZZ5_:b8^j^7^ZZ6^ZZ6^ZZ6^ZZ6^j^7_:b8^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^ZZ5_:b7
_Zj9_jn:_Jf8^:R3/j=n/:1kYYelWYEdTXUXPgYIM6]:IE`kEdh]CdHUHETlH5XmHF14J6U?JFaCJVUD
L6YGMVmLJFYFJFYFJFYFJFYFJ6UEJ6UEJ6UEIfQDKFeKKFeKKFeKKFeKKFeKK6aJK6aJK6aJK6aJKFeK
KfmMLG5OMGESO7aZQXIdS8ajSI=lRY1iS95lMgaWPXIcT9>3VYf=V9^<XJ>GWZ2DWInCWInC[JnSZjfQ
]KN[[:jR/;>T^;^/[JnSX::FZjZP^;J^]K>[[JZU/;6W[ZnU/[>YWIjD^;V_]kR^]KJ/[ZnU`;f__;^]
]kV][[FXZ[2U/K:Y]K:Z[jVT/kJ][K2W[[6X^KZa^;J^^;J^`Kjf]kB/][N]]KJ//kBZ/;6W[k2V[ZnU
[k2V[k2VYjRN[:fS/K:X]KJ/][N]]kR^^;V_^[^a^KZ`^KZ`^[^a^[^a^[^a^kbb^kbb^kbb^[^a^[^a
^kbb^kbb^kbb_;fc_;fc_;fc_;fc_Kjd_Kjd_Kjd_[ne_[ne_[ne_l2f`l6g`;jf_Kfg_;fi`<2j`/2f
`[f^`[^X_;6A_K6?`;6:`[27`[66`[27`;2;_k6=`K29`K29`K29`K29`K29`K29`K29`K29`K29`K29
`K29`K29`K29`K29`K29`K29`:n8`K29`[6:`k:;`k:;`k:;`k:;`[6:`[27`[27`[27`k68`k68a;:9
a;:9aK>:`K29`K29`K29`K29`K29`K29`K29`K29`K29`K29`[6:`[6:`[6:`k:;`k:;`k:;`k6<`k6<
`k6<`k6<`k6<a;:=a;:=a;:=`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:`k6<`k6<`k6<`k6<`k6<`k6<
0033]JW3]JW3]JW2]:S2]:S2]:S1/jO1/jO2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[1]JW1]JW1]JW1
]JW1]JW1]JW1]JW1]JW0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0
]:Rn/ZJn/ZJn/ZJo/jNo/jO0]:S0]:S0]:Ro/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jO0]:S0]:S0]:S0
]:S0]:S0]:S0]:S0]:Ro/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo]JBo]JBo]JBo]JBo]JBo]JBo]JBo
]JBo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo
]JBo]JBo]JBo]JBo]JBn]::n]::n]::o]J>o]J?0]ZC0]ZC0]ZC1]J?1]J?1]J?1]J?1]J?1]J?1]J?1
]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?0]:;0
]:;0]::o/j6o/j6o/j70]:;0]:;0]:;0]:;0]:;0]:;0]:;0]::n/Z2o/j6n/Z2l/9jo/j74^:K3]jFo
/j70]ZB[Y96?R7M_K5iBDTHl@3Dd>C0e?3DF9ah>71X43QD011400A021A<93aH>5APS9b4i?cADFdaS
K5MSKEIQJeAUKUU[M5mSKUYRJU=`M5]_LUaWK5e8EE<T=cl/A5HRADmNOXVA[kZQ_LR^b=BmdmnV^LIl
Sia@HFAJJ6AYL6=bMf9ZLEa=G4h_B4@T@d@?Be4CCeDCCE<@AdhCBU4KDEPKCeHAAD`H:3P65b0@8R4o
D4EQLEmSL5YMJU9RK5ELK5E[N6YWLF/l@TM7C5F?UIbNYJQjPX5[M7MQK6UNK61BHU53DDDR;B/01145
1al=6B<341P;5a/U<c50D4E;FdY9FTE8FT<nCCloCT13D498EDM?FDa?FDa;E4M7D4<g?Rlh?c0k@351
A3A;Bc]IEdEXI59`K5Z<RWRHU86WXXfaZiBf[iJi[Y>j[Y:k/9:m/YJm/YJl/IFj[i>g[92g[92i[Y:l
/IFk[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>j[Y:j[Y:j[Y:k[i>k[i>l/9Bl/9Bl/9Bk[i>k[i>k[i>k
[i>k[i>k[i>k[i>k[i>l/9Bl/9Bl/9Bm/IFm/IFm/IFn/YJn/YJl/9Bl/9Bl/9Bl/9Bl/9Bl/9Bl/9Bl
/9Bl/9Bl/9Bl/9Bl/9Bl/9Bl/9Bl/9Bl/9Bn/YJn/YJm/IFm/IFm/IFl/9Bl/9Bl/9Bl/9Bl/9Bl/9Bk
[i>k[i>j[Y:j[Y:j[Y:j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6j
[i6n[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn
[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm
[Xjl[Hfl[Hfm[Xjn[hnn[hnm[Xjl[Hfl[Hfn[hnm[Xjl[Hfl[Hfl[Hfl[Hfm[Xjn[hnm[Xjm[Xjm[Xjm
[Xjm[Xjm[Xjm[Xjm[Xjm[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m
[h^m[HRm[HRn[XVo[hZo[hZn[XVm[HRm[HRn[XZn[XZn[XZn[XZn[XZn[XZn[XZn[XZl[XZl[XZl[XZl
[XZl[XZl[XZl[XZl[XZk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVm[HRm[HRm[HRm[HRm[HRm[HRm[HRm
[HRjZXFkZhJl[8Nl[8Nl[8Nl[8NkZhJjZXFkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhNkZhNkZhNk
ZhNkZhNkZhNkZhNkZhNjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFkZhNkZhNjZXJiZHFiZHFjZXJkZhNk
ZhNjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFeYH2eYH2fYX6gYh:iZHBkZhJl[8Nm[HRbYXBaYH>`Y8:^
XX2ZWWbRUWBISF^BQVAYI4ERGd1KGCmLHDIOHdYOHTaTHdmZIUAVIe=TIE5RHdmPHDeQHTiTIE5XJEE[
K5Q/KEe]KUi^Kem_L61`LF5aLV9bLf=cM6AbLV9hN6QoOfn3Pg>7QgN@T82MWHfWYiNPYI2QYY6[[ibJ
WX^_/Z:Y[9fb]JJQXiN[[J6UYi^^/:BMWi>^/:BVZ9ba/jNXZYjWZIfa/jNa/jNXZInYZZ6b/jZc/jf]
[JNVYiff]jfn_kF`/JNm_[Bd]J^`/JNXZInWYIZg]j^Z[Z:T[:75cL?JgMCDdLcDd<^`]Jb[/:Nk_[G@
dLSGf<oKfM7>c<Bg]:bg^:jf]jfd]J^a/ZR_/:J^[jF][ZB][ZBWZ9j[[::`/JNc]:Zd]J^e]Zbg^:jh
^Jni^[2i^[2i^[2j^k6j^k6j^k6k_;:k_;:j^k6j^k6j^k6k_;:k_;:l_K>l_K>l_K>l_K>l_K>m_[Bm
_[Bm_[Bn_kFn_kFn_kG2`;G0_kFk_KNl_KVn`;[2`KO5_k;5_Zfn]YRl/I6l[hVo[hG2/8O3/hVo[hZk
[HW1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8Vo[XO0[hS1/8W2
/H[3/X_2/H[2/H[2/H[2/8O2/8O2/8O2/8O3/HS3/HS3/HS3/HS1/8W1/8W1/8W1/8W1/8W1/8W1/8W1
/8W1/8W1/8W1/8W2/H[2/H[3/X_3/X_3/X_1[h[2/8_2/8_3/Hc3/Hc4/Xg4/Xg5/hk2/H[2/H[2/H[2
/H[2/H[2/H[2/H[2/H[1[h[1[h[1[h[1[h[1[h[1[hX00<:dZ<:dZ<:dZ<:dZ<:dZ<:dZ<6cYl6cYl:f
Z/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL2dZ<2dZ<2dZ<2dZ<2d
Z<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ;jbY[jbY[jbY[jbY[ncYkncYl2dZ<2dZ;nc
YkncYkncYkncYkncYkncYkncYkncYl2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ;ncYkncYkncYkncYknc
YkncYkncYkncYkneY;neY;neY;neY;neY;neY;neY;neY;ncYkncYkncYkncYkncYkncYkncYkncYkne
Y;neY;neY;neY;neY;neY;neY;neY;neY;neY;neY;neY;neY;neY;neY;neY;jdX[jdX[jdX[jdX[ne
XkneXl2fY<2fY<6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6e
Xl6eXl6eXl6eXl6eXl6eXl6eXl6eXl2dX/2dX/2dX/2dX[ncXKncXKncXKncXL2dX/2dX/2dX/2dX/2d
X/2dX/2dX/2dX[jbX;ncXKncXKfaWk^_WKb`W[jbX;ncXL2bX<BfY;nbXZZRTHN2LfAQDda:?d92=Rdj
<QdX9A<L7aTR9R@Z;bT`<c<l>Ci8@U1FBeIMCU]TD5aWCEUUBEUTBUiXDF=/EfE]EV9VCFa_EFa^F69Y
FT9@CQ`c>bU5ES5BHDm`OgbKZY^haj6jbYnfaZVmc[[<gI^`/W>4P6I`HfacGV=[E5EQCDUKCSI>A1U9
CAm?Db1@E1];CaU<Cb5DEbAIG2=HFbTk?2Tl>CY>@U9UDUQ[DU9QAU=PAUmZD6AfFCi>=gJ2MV9ZJB<Y
;V9XKj2V[I>IWW9iO69ZJFA_ID]GBci9?b/c<`034@`=8@<=7P0030083Ql/:Se;@3i>?3Q8<CI7;3i?
A3e=@Se;@3m8?Si6?413>T11>40n=S/m<DU9?EiMCgA`GXN0KIZ?NjZMQk>US[J^UkVaV[fcVkjcV;^_
TkZ/SkV[S[b]SKZ_TkZ_TkZ_TkR]TKJ[SkN/T;Z_TkfbU[^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_TkZ^
T[Z^T[Z^T[Z^T[^_Tk^_Tkb`U;b`U;^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tkb`U;b`
U;faUKfaUKfaUKb`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`
U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;^_Tk^_TkZ^T[Z^T[Z^T[Z^T[Z_TKZ_TKZ_TKZ_TKZ_
TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_
Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_
Skj_Skj_Skj_Skb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SK^/S;b]SKf^S[f^S[f^S[f^S[b]SK^/S;f^
S[f^S[b]SK^/S;^/S;b]SKf^S[f^S[b]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb^R[b^R[b^R[b^R[b^
R[b^R[b^R[b^R[b^R[b^R[b^R[b^R[b^R[b^R[b^R[b^R[b/Qkf]R;j^RKj^RKj^RKj^RKf]R;b/Qkf]
RKf]RKf]RKf]RKf]RKf]RKf]RKf]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RKZ/R;Z/R;Z/R;Z/R;Z/
R;Z/R;Z/R;Z/R;b/Qkb/Qkb/Qkb/Qkb/Qkb/Qkb/Qkb/Qk^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[
Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Qk^[Qk^[Qk^[Qk^[Qk^[Qk^[Qk^[QkZZQKZZQKZZQKZZQKZZ
QKZZQKZZQKZZQK^[QkZZQ[VYQKVYQKVYQKVYQKZZQ[^[QkZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKj^
RKf]R;ZZQKRXPkNWP[NWP[RXPkRXPkBSP[JUQ;RWQ[b[R[j]S;f/RkRWQ[BSPX=mFW=aCf9UAEeRAEaR
BEeSC69TDFMWEFm_GFi^G6a/FVa/FVi^G79bH7IfI7UiIgenKWenKWioKh21LH62LX>4M8B5MHB5MH>3
LhZ:NY2@P96API2@P9FEQJ6QTJb/W:bbWijTTj2VUI^PTK6fYiVMTJb`YJFYWZBXWIjRUk^o]:^_Y;Nk
/:6UVZBXWJFYWZZZWZ6SUjZ[XK:cZZFXWinQVjjb[<;6`MSKd][Me<74^jf`Yj^^YJ:UW;:e[;k1^;:b
Y[>gZjfeZZff[;[3^LK=a]7CcMoLf;Fj/JjcZ[6f[JZ]Y;Zk/]oPemOEcKFcZkFf[;Ff[;BeZkBeZk>d
Z[>dZ[>dZ[>dZZn`Y[:cZKFf[;Jg[KFf[;BeZkFf[;Jg[KRi[kRi[kVj/;Vj/;Zk/KZk/KZk/KZk/KVj
/;Zk/KZk/KZk/K^l/[^l/[^l/[bm/kbm/kbm/kbm/kfn];fn];fn];jo]Kjo]L30/[jo]Kbo][^o^Kk0
^/;0^<G1]/S1//6jWkbdU[Z^S;j]Q/>aR<>cRKj_R;R[QL2_R<2_R<2_R<2_R<2_R<2_R<2_R<2_R<2_
R<2_R<2_R<2_R<2_R<2_R<2_R<2_R;n^Qkn^Ql2_R<6`RL:aR/:aR/6`RL6`RL6_Q/6_Q/6_Q/:`Ql:`
Ql:`Ql:`Ql:`Ql2_R<2_R<2_R<2_R<2_R<2_R<2_R<2_R<2_R<6`RL6`RL6`RL:aR/:aR/:aR/>bRl2^
RL2^RL6_R/:`Rl>aS<BbSLFcS/FcS/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/6_R/6_R/6_R/6_R/6_
R/6_RP00`K>W`K>W`K>W`K>W`K>W`K>W`[BX`[BX`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`;BX`;BX
`;BX`;BX`;BX`;BX`;BX`;BX_k>W_k>W_k>W_k>W_k>W_k>W_k>W_k>W_k>W_k>W_k>W_k>W_k>W_k>W
_k>W_k>W_K6U_K6U_[:V_[:V_[:V_k>W_k>W_k>W_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_k>W_k>W
_k>W_k>W_k>W_k>W_k>W_k>W_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[BS_[BS_[BS_[BS_[BS_[BS
_[BS_[BS_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[BS_[BS_[BS_[BS_[BS_[BS_[BS_[BS_[BS_[BS
_[BS_[BS_[BS_[BS_[BS_[BS_K>Q_K>Q_[BR_[BR_[BR_kFS_kFS_kFS`;BR`;BR`;BR`;BR`;BR`;BR
`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR_k>Q_k>Q
_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_;2N_K6O`;BR`;BR_K6O^JfK
^JfK_;2N`kBQ_jnN_:jL_k>Q_[BSZJ6@PW]/H5]<Adm4<CT_9R`W<CHd?TE2@DQ3A4e3BU=9C5=6CUI5
D5U4DEa2Dei4EV19FV=>GVMCHf]DGV99IVU?IfYAHFUH@e=<630f73U7=5MUFWf;O9f/RjRgV;;2Z<7A
Ykk>VJfnX[RfIgadDV9AGVMBFfA:GFM@GVeHC5i=;DY7=eAA>UUF<eA@:da8:Da8;U=?=EYF>dm3B5]<
D6=>CV56BU`oC5/oD5e3DEi6DVA5Cf15H6iLEf9JEUiMCUAID5IMVInVQh^@NGioNH1kEemH@dY5;c@g
0P@?2@TI1@LO000>00<B8bT`@4I5@DY0>T@d>D@`;S``;S``<3X^<CL/>CX`BdHmH5U@LFQOPh1bSX]l
XIZ9[jFC]jVF_:bE`K2FaK6H]:N=]JR>]ZV?]j^?^J^?_:jA`K6Da;BG]Z^?^:fA^ZnC^k2D^ZnC^JjB
^k2D_K:F^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^JfA^JfA^ZjB^ZjB^ZjB^jnC^jnC^jnC^ZjB^ZjB
^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^jnC^jnC_;2D_;2D_;2D^jnC^jnC^jnC^jnC^jnC^jnC
^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC
^jnC^ZjB^ZjB^ZjB^JfA^JfA^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@
^Jj@^Jj@_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj=_Jj=_Jj=_Jj=_Jj=_Jj=_Jj=_Jj=_Jj>_Jj>
_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_:f=_:f=_:f=_:f=_:f=_:f=
_:f=_:f=^jb<^jb<_:f=_Jj>_Jj>_:f=^jb<^jb<_Jj>_:f=^jb<^jb<^jb<^jb<_:f=_Jj>_:f=_:f=
_:f=_:f=_:f=_:f=_:f=_:f=_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:
_:j:_:j:_:b7_:b7_Jf8_Zj9_Zj9_Jf8_:b7_:b7_Jf9_Jf9_Jf9_Jf9_Jf9_Jf9_Jf9_Jf9^jf9^jf9
^jf9^jf9^jf9^jf9^jf9^jf9^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8_:b7_:b7_:b7_:b7_:b7_:b7
_:b7_:b7^j^6^j^6^ZZ5^ZZ5^ZZ5^ZZ5^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^7^j^7
^j^7^j^7^j^7^j^7^j^7^j^7^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ6^ZZ6^JV5^:R4^:R4^JV5
^ZZ6^ZZ6^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4_:b7_:b7_:b7_Jf8_Jf8_Zj9_Zj9_jn:_JZ7_:V6
^jR5^jR5^jR5^JJ3]Z>0/j1mZZ5kUi5/PH1NLgQIKGAIKG=LLgERNGUYOGe]OWi^Ogm_PH5aPh=cQHEe
QhMgR8QhS8n0S8n0SI21SI21SY62SY62Si:3Si:3Shj0UIB6VIR:UYF7TI22TI22VYV;Xj:DYZ^LZJjO
ZZnP/[JZ`lNlZjnT^[fdZZfT/[J[XJFJ_<2e][Z_aLVn^;baZZjS[K6V_Kbb[JbR[ZnV/kJ]Yj^UYjfX
/;JaZk:]/kF_eMOA_/2j[JnYYJNQYjVS/;:/YJNQ];R]XjVN/KZ`YK2VJgI^I6]VXZJQd]??`<Rn[kN]
SY>:Ada3FEaC_;fddmC;]kR_]KJ/]KJ/]KJ/];F[];F[/kBZ/[>Y/[>Y/[>Y];F[][N]][N]]KJ/]KJ/
][N]^;V_^;V_^;V_^;V_^KZ`^KZ`^KZ`^[^a^[^a^KZ`^KZ`^KZ`^[^a^[^a^kbb^kbb^kbb^kbb^kbb
_;fc_;fc_;fc_Kjd_Kjd_Kjd_L2`_<2d^[nf^;nh^kni_l2ga<:hbL>f`knW_[NL^Zn?_Zj9`[6:`k>9
`:n8^ZZ5`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8_Zf6_Zf6
_jj7`:n8`K29`K29`:n8`:n8`Jn6`Jn6`Jn6`Jn6`Jn6`:j5`:j5`:j5`:n8`:n8`:n8`:n8`:n8`:n8
`:n8`:n8`:n8`:n8`:n8`K29`K29`[6:`[6:`[6:_jf8`:j9`Jn:`[2;`k6<a;:=a;:=aK>>`K29`K29
`K29`K29`K29`K29`K29`K29`[2;`[2;`[2;`[2;`[2;`[2;0030/ZK0/ZK0/ZK1/jO1/jO1/jO2]:S2
]:S1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:Ro/jNo/jNo/jNo
/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNm/JFm/JFm/JFm/JFn/ZJn/ZJo/jNo
/jNn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNn/ZJn/ZJn/ZJn
/ZJn/ZJn/ZJn/ZJn/ZJn]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>n/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn
/ZJn]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>m/j6m/j6m/j6m
/j6n]::n]::o]J>o]J?0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0
]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]::n/Z2n/Z2n/Z2n/Z2o/j6o/j6o/j70]::o/j6o/j6o/j6o
/j6o/j6o/j6o/j6o/j6j[Ybk[ifo/j73]jG2]ZBm/Inl/9jo/j70/Ijm[ibk[IZk/9c1]Z:o]Z:`ZIFP
VHEeMfAGF4Pj>R``<RHa=BXf>Rlj@3E2Achj@CA0AcQ8DCe?FD9CGDIDGDUBFTUAF4]GHE1EG4MOHdYL
H4MNI558F4dM<S<E<SLWCUMFNXAnXJ^9ZKBC/KbW`Lf/a=2Q^LF2VY1HKEi=GTUJIdmII4YLIdeMJe=>
GTM5EDY=GE9BHeQ<GE8oDdLjCT8mDdM4FTi8FdI;GdQ7FSloDCA3ECQBHDI@G4I3CSXoDCAHJDi3DSdo
C3i]Mg5>EUDP9bYIGfBAUIZEVYfAUiI`MgAAEeH[<3<000L000X201@000d60a8O7RLf=SHj?3Hi>S0i
>blX<1li?biCE4AWIeMjMFJ?QWRTVH^cYYRc[9Re[YZh[i^j[iVj[INl[9FmZiBn[9Fm[YBn[iFo/9K0
/INn[iFl[I>iZhngZHfi[Y:l/IFo]9Ro]9Rm/YJk/9Bj[i>j[i>j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j
[Y:i[I6i[I6i[I6i[I6j[Y:j[Y:k[i>k[i>j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:i[I6i[I6j[Y:j
[Y:j[Y:k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k
[i>i[I6i[I6j[Y:j[Y:j[Y:k[i>k[i>k[i>k[i>k[i>j[Y:j[Y:i[I6i[I6i[I6i[I6i[Y2i[Y2i[Y2i
[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2m[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm
[Xjm[Xfm[Xfm[Xfm[Xfm[Xfm[Xfm[Xfm[Xfm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm
[Xjm[Xjm[Xjm[Xjm[Xjk[8bk[8bk[8bk[8bk[8bk[8bk[8bk[8bjZh^k[8bl[Hfl[Hfl[Hfl[Hfk[8bj
Zh^l[Hfl[Hfk[8bjZh^jZh^k[8bl[Hfl[Hfk[8bk[8bk[8bk[8bk[8bk[8bk[8bk[8bk[HVk[HVk[HVk
[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVkZhJl[8Nm[HRm[HRm[HRm[HRl[8Nk
ZhJl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8RiZhNiZhNiZhNi
ZhNiZhNiZhNiZhNiZhNkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJjZXFjZXFiZHBiZHBjZXFjZXFk
ZhJjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXFjZXFjZXFj
ZXFjZXFjZXFjZXFjZXFjZXJiZHFiZHFhZ8BhZ8BiZHFiZHFjZXJiZHBiZHBiZHBiZHBiZHBiZHBiZHBi
ZHBbXWfcXgjeYH2gYh:hZ8>hZ8>hZ8>hZ8>dY7ncXgjbXWfeYH2jZXFn[XVo[h[0/8_2]8Z`YWjKV7:>
Sfn4QfeoPVb3Pg68R7R7QgN9RGV<S7b?SgnATH6ATH6ATH6@T82?U8F?U8F?U8F?U8F?U8F@UHJ@UHJ@
UHJCTXBFUHNHUhVFUHNAT8:@Sh6EU8JKVXbFWI2Y/:>EVi2TZYnVZj:VZZBn`[ba]JnGW9>6Rh:DVI2@
UHbTZJ36bl:^/jZ^/jZUY9ZXYYja/ZV][jVZ/:^g_[V>Ui@i@Sm<D4[1aKoGfmG9cLNX[:Jf^[C>d/bo
`kg?eLZla;[BgM>b`KU5Ddd`>SB@UI?RiN?<eL^maK^=UH/R9ah^<bZa]:_Gf<nl_KBe]Zbe]Zbd]J^c
]:Za/ZR_/:J/[J>[[::/[J>_/:Ja/ZRc]:Zc]:Zd]J^g^:jj^k6g^:jh^Jnh^Jnh^Jni^[2i^[2i^[2i
^[2i^[2i^[2i^[2i^[2j^k6j^k6j^k6k_;:k_;:k_;:k_;:l_K>l_K>l_K>m_[Bm_[Bl`:fl`K:h`;Fh
_kRg_KRk_KO3`KO7`kS3`Zk0_:Bn]9Jo/Hg2/H[2/XS0[hRl[HJo[XNo[XNo[XNo[XNo[XNo[XNo[XNo
[XNo[XNo[XNo[XNo[XNo[XNo[XNo[XNo[XNm[8Fm[8Fo[XO0[hS0[hS0[hRo[XNo[XO1[hK1[hK0[XG0
[XG0[XFo[HBo[HBo[HBo[XNo[XNo[XNo[XNo[XNo[XNo[XNo[XO0[hS0[hS0[hS0[hS1/8W1/8W1/8W2
/H[0[XW0[XW1[h[1[h[2/8_3/Hc3/Hc3/Hc1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1[h[1[h[1[h[1
[h[1[h[1[hX00;naYKnaYL2bY/2bY/6cYl6cYl:dZ<:dZ<6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL2d
Z<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ;jbY[jbY[jbY[jbY[jbY[jbY[jbY[jbY[jbY[jbY[jbY[jbY[jb
Y[jbY[jbY[jbY[b`Y;b`Y;faYKfaYKjbY[jbY[jbY[jbY[faYKfaYKfaYKfaYKfaYKfaYKfaYKfaYKjb
Y[jbY[jbY[jbY[jbY[jbY[jbY[jbY[faYKfaYKfaYKfaYKfaYKfaYKfaYKfaYKfcX[fcX[fcX[fcX[fc
X[fcX[fcX[fcX[faYKfaYKfaYKfaYKfaYKfaYKfaYKfaYKfcX[fcX[fcX[fcX[fcX[fcX[fcX[fcX[fc
X[fcX[fcX[fcX[fcX[fcX[fcX[fcX[bbX;bbX;fcXKfcXKjdX[jdX[jdX[jdX[ncXKncXKncXKncXKnc
XKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKfa
WkfaWkfaWkjbX;ncXKncXKncXL2dX[jbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;Z^W;b`W/:fY<>g
YKjbX;faWl2dX[RZUl2eXL>hY;^`V[6YT[J^UkngX<>mY/>nYJ^WShR6KVUUDU9?@4=1=S`j<S/h<cY0
=Cm6>DE=?4UB?T]D@4U@@DQ>@dM<@d=AAD]EAEIMB55E?5IMB4mLC2Ll=1hf=2Q?EdI]MFjCVhNX/H^Z
/h^X/I6/]Ybe_f9fHe5TCe5QBEUVC5ARAU5NA51NATYG@D]LAdeNBDiOBT]LAdQG@TAC?TIE@4YIA4=F
?D9C>3i@<ca>;dAC=dYH@4IB@41:>S];<ci>=cM6<D1=?DQDB4QBC49:BBL_;f9UJXR;T96EUXfATWIj
NdM:Cb0R:P@53`800`L41Q@?42@Q7CHd:TI3=Di;?5=??GUgGhV5KIbHP:jVSkN/U[R[UKFXT[BVT;N/
TKFZSk:WS;>WSkFYTKR[UKZ]UkZ]UkJYSkNZT;V[U;b^Ukj`VKncVkjaVkf`V[Z_TkbaUKjcUkfbU[^`
U;V^T[V^T[Z_TkV]TKV]TKV]TKV]TKV]TKV]TKV]TKV]TKR/T;R/T;V]TKV]TKZ^T[Z^T[Z^T[Z^T[V]
TKV]TKV]TKV]TKV]TKV]TKV]TKV]TKR/T;V]TKV]TKV]TKZ^T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^
T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^T[R/T;R/T;V]TKV]TKZ^T[Z^T[^_Tk^_TkZ^
T[Z^T[Z^T[Z^T[V]TKV]TKR/T;R/T;R]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]
SkR]SkR]SkR]Skb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb^R[b^R[b^R[b^R[b^R[b^R[b^R[b^R[b]
SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SK^/S;^/S;^/S;^/S;^/
S;^/S;^/S;^/S;Z[Rk^/S;^/S;b]SKb]SK^/S;^/S;Z[Rkb]SK^/S;^/S;Z[RkZ[Rk^/S;^/S;b]SK^/
S;^/S;^/S;^/S;^/S;^/S;^/S;^/S;^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]
RK^]RK^]RK^]RK^[Q[b/Qkb/Qkf]R;f]R;b/Qkb/Qk^[Q[b/R;b/R;b/R;b/R;b/R;b/R;b/R;b/R;Z/
R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;V[QkV[QkV[QkV[QkV[QkV[QkV[QkV[Qk^[Q[^[Q[^[Q[^[Q[^[
Q[^[Q[^[Q[^[Q[^[Q[ZZQKVYQ;RXPkRXPkVYQ;ZZQK^[Q[ZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZ
Q[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQ[VYQKRXQ;RXQ;RX
Q;RXQ;VYQKZZQ[VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;f]R;b/Qkb/Qk^[Q[ZZQK^[Q[^[Q[^[Q[b_
RKZ]QkR[QKR[QKR[QKV/Q[NZQ;FXP/2]P[RXOZ^RO:>NOIJENHb;MXb8MY2;O8f<OXj=Oi2?PI:APi:A
Pi:APi:APi6@PXjBQXjBQXjBQXnCQhnCQi2DR92DR92DR9BBQiFCR9JDRIBBQi>AQY>AQYFCR9RFRibR
UhfCR51EC7MlLfAXHVQ/IiRLUl75`5mTFgUnMHR=Q75fKFY_I[g2^JR]Y:Z_Y/?0^<g;`mgMemCHd/oE
d=[Sh9fXYBHd<3Tm>;Jj]M?Gd]SLejZ^ZJZ^ZM3DcmSLel[Bb<C=`lCAbIj]YDYHDRdh=FedLKBi]loH
c/G>a:6YWblg;CLl<kVl/mKId;bo][>dZ[BeZkBeZk>dZ[:cZK2aYjf^Y:b]Xjb]Xjj_YK2aYk6bZ;6b
Z;>dZ[Jg[KRi[kNh[[Nh[[Ri[kRi[kRi[kVj/;Vj/;Vj/;Ri[kRi[kVj/;Vj/;Vj/;Zk/KZk/KZk/KZk
/K^l/[^l/[^l/[bm/kbm/kbm/kfn];[1[;[2/KS0]KJn]kBj]KVk]L2n]/K1^<?3/L:oZ/:jWL2dT/2a
R/2`Q/2_R<6`RKn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkb[
Q;f/QKj]Q[n^Qkn^Qkn^Qkn^Qkj]Q/2^QL2^QL2^QKn]Q;n]Q;j/Pkj/Pkj/Pkn^Qkn^Qkn^Qkn^Qkn^
Qkn^Qkn^Qkn^Qkn^Qkn^Ql2_R<2_R<2_R<6`RL6`RL6`RL6_R/6_R/6_R/6_R/6_R/:`Rl:`Rl:`Rl2_
R<2_R<2_R<2_R<2_R<2_R<2_R<2_R;n]R;n]R;n]R;n]R;n]R;n]R000_k6U_k6U_k6U`;:V`K>W`K>W
`[BX`[BX`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY_k>W_k>W_k>W_k>W_k>W_k>W_k>W_k>W_[:V_[:V
_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_;2T_;2T_K6U_K6U_K6U_[:V
_[:V_[:V_K6U_K6U_K6U_K6U_K6U_K6U_K6U_K6U_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_K6U_K6U
_K6U_K6U_K6U_K6U_K6U_K6U_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K6U_K6U_K6U_K6U_K6U_K6U
_K6U_K6U_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_;:P_;:P
_K>Q_K>Q_K>Q_[BR_[BR_[BR_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q
_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_;2N_K6O_K6O_[:P_[:P_k>Q_k>Q`;BR_[:P_[:P
_[:P_[:P_[:P_[:P_[:P_[:Pa;RV_;2N^JfK_[:P`;BR^jnM^JfK_;2N^k:N_KBP^k>L]ZjG^;2I_[NN
^[FL/ZfD/ZZ<^[:E^[>HZZB=ShUfL6YODde6@3/h>d0g>d4f>T4b>D4`>D0a?D@g@dM1B4a7=4Dl@dm3
DEY6AddfCUHoDUi<<T<h:3hi<U]NBW=fHhV=LiRLQZJ[RJN/JhR=@f1U@eHmAUHnBeXoCE/oBUPlB5Dk
BUQ0Be]4?ePn?58i>4he>Tlf?U4h@50h@U0h@U0h=dP]>4X]?e4bB5Pi@U4e=d@^>D@dADm3=dL`>DPc
=TD`@Dlm<Sla@di4J79/>D5061XRG5mTOH24X:>WXZFYNWf2I6I^@dA>928G=S8WB4DgFeM5L6aISHQc
XIf5ZjJ=^K6D]Jf@/jR</ZN;]ZZ>^:b@^JfA^jfA_K:B^ZnA^:b@^JjC^[2H^k2J]JbH/JNE_[2I^ZbE
]JN@/JB>/ZF?/jRD]Z^G]jbH]Z^?]jb@^:fA]jb@]Z^?]jb@^ZnC_K:F^JfA^JfA^JfA^JfA^JfA^JfA
^JfA^JfA^:b@^:b@^JfA^JfA^JfA^ZjB^ZjB^ZjB^JfA^JfA^JfA^JfA^JfA^JfA^JfA^JfA^:b@^:b@
^:b@^JfA^JfA^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB
^ZjB^ZjB]j^?^:b@^:b@^JfA^JfA^ZjB^ZjB^jnC^ZjB^ZjB^ZjB^JfA^JfA^JfA^:b@^:b@^:f?^:f?
^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?_:f=_:f=_:f=_:f=_:f=_:f=
_:f=_:f=_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=
_:f=_:f=_:f=_:f=_:f=_:f=^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jb<^Z^;^jb<^jb<_:f=_:f=^jb<
^jb<^Z^;_:f=^jb<^jb<^Z^;^Z^;^jb<^jb<_:f=^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jf9^jf9
^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^j^6^j^6_:b7_Jf8_Jf8_:b7
^j^6^j^6_:b8_:b8_:b8_:b8_:b8_:b8_:b8_:b8^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^J^7^J^7
^J^7^J^7^J^7^J^7^J^7^J^7^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^ZZ5^JV4^:R3^:R3^JV4
^ZZ5^j^6^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ5^ZZ5
^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^JV5^JV5^:R4]jN3]jN3^:R4^JV5^JV5^:R3^:R3^:R3^:R3^:R3^:R3
^:R3^:R3^JV4^:R3]ZJ1]JF0]ZJ1^JV4_:b7_Zj9]:V3]:V3]:V3]Z^5^:f7^:f7]JZ4/jR2_:Eh^JEl
]ZV3/:V8Y:24Ui9mTX]jU8aoT8n1T8n1Shj0Shj0T8n1T8n1TI22TI22SI65SI65SY:6Si>7TIF9TYJ:
TiN;TiN;UiF:UiF:UYB9UI>8UI>8UI>8UYB9UiF:SYJ;LWY`B516^L2iUifHH6IQJg1^[[>aB4m8U9^D
[kJ_O8=lBE19/;N`WjJOYjjW[JZRY::JZJVSVYjIQhj9T9VFKgei7BXX6R0KLGMbTiVDg>;M`LO2Q8Z5
HVQSBU1;@d]1BEA:?4]3;Cdf8c</5R@P:C8_EeaKc=G;^lBjV:6G9blU:c0WZ:fTbLc3^kje/;6W/K:X
/kBZ]KJ/][N]]KJ/];F[];F[/[>Y/kBZ/kBZ/[>Y/K:X/K:X/kBZ]KJ/]kR^]kR^]kR^^;V_^;V_^;V_
^KZ`^KZ`^;V_^;V_^;V_^KZ`^KZ`^[^a^[^a^[^a^[^a^[^a^kbb^kbb^kbb_;fc_;fc_;fc^/6/^/:a
^<6d]Kff/kVd]kRd_kbgaKnh`lBd`l:]a;fR`[JD_k29_jn5`:n8`k:;_jj7_jj7_jj7_jj7_jj7_jj7
_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_:^4_:^4_Zf6_Zf6_jj7_jj7_Zf6_Zf6`:j5`:j5
`:j5_jf4_Zb3_Zb3_J^2_J^2_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7`:n8`:n8`K29
`K29`K29`[2;`[2;`Jn:`Jn:`Jn:`Jn:`Jn:`Jn:`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8_Zb7_Zb7
_Zb7_Zb7_Zb7_Zb70032]JG2]JG2]JG2]JG2]JG2]JG2]JG2]JG0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0
/ZK2]:S2]:S2]:S2]:S2]:S2]:S2]:S2]:Rn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJo/Z:o/Z:o/Z:o
/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/JFo/JFo/JFo/JFo/JFo/JFo/JFo
/JFm/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:o/Z:o/Z:o/Z:o
/Z:o/Z:o/Z:o/Z:o/Z:l/Z6l/Z6l/Z6l/Z6l/Z6l/Z6l/Z6l/Z6o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o
/Z:n/Z2n/Z2o/j6o/j70]:;0]:;0]:;0]::o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o
/j6o/j6o/j6o/j6o/j6m/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inn/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n
/Z2n/inn/inn/inn/inn/inn/inn/inn/inm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm
/Yjm/Yjm/Yjm/Yjm/Yjl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/IffZiNcZ9BfZiNj[i^eZYJUVXJH
SGUMEdaCCdA6A3Xl>c4g>2lj?3Ho@ce5BD=2AS]2AS/oAc`oBCdlBShjC3liCD0gCT13GU]8Hf1=J6A@
K6I>Jf97IEXnG4lhEdQ7D3a7D3a6Cc]6Cc]5CSY4CCU4CCU4CCU6D3U5CSU4CCQ2BcM0B3LnASDl@c@l
@c@hA3PjA3PjA3Pj@SLk@CHk@CHl@3Dl@3DT>c<V>c<X>S<Z>38^>38c>SDl@3]0A3m9BD=3@3]9AcmZ
J5jEThR^ZifXYIJIU8F]XXN^XhRaYX^cZ8feZXng[96g[96h[I:g[96g[96g[96g[96g[96g[96g[96g
[96i[Y>i[Y>i[Y>i[Y>i[Y>i[Y>i[Y>i[Y>h[I6h[I6h[I6i[I6k[I6k[I6m[96m[96j[Y:j[Y:i[I6h
[92h[92i[I6j[Y:j[Y:j[i6j[i6j[i6j[i6i[Y2i[Y2h[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh
[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hni[Y2j[i6j[i6j[i6j[i6i[Y2h[Hni[Y2i[Y2i[Y2i
[Y2i[Y2i[Y2i[Y2i[Y2k/9:k/9:j[i6j[i6i[Y2h[Hnh[Hnh[Hni[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i
[Y2g[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jkZhjkZhjkZhjkZhjkZhjkZhjkZhjkZhjjZh^jZh^k[8bk
[8bk[8bl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[HfiZXZjZh^jZh^k[8bk[8bl[Hfl[Hfm
[Xjk[8bk[8bk[8bk[8bk[8bk[8bk[8bk[8bjZh^jZh^jZh^jZh^jZh^jZh^jZh^jZh^k[HVk[HVk[HVk
[HVk[HVk[HVk[HVk[HVl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rl[8RiZhNiZhNiZhNj[8Rj[8Rk[HVk[HVk
[HVl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rm[HVl[8Rl[8Rk
ZhNkZhNl[8Rl[8Rm[HVl[8Nl[8Nl[8Nl[8Nl[8Nl[8Nl[8Nl[8NkZhJkZhJkZhJkZhJkZhJkZhJkZhJk
ZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFj
ZXFjZXFjZXFjZXFjZXFiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBi
ZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBhZ8>hZ8>hZ8>hZ8>iZHBiZHBiZHBjZXFiZHBiZHBiZHBi
ZHBiZHBiZHBiZHBiZHBgYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:iZX>iZX>iZX>iZX>iZX>iZX>iZX>i
ZX>iZX>iZX>iZX>iZX>iZX>iZX>iZX>iZX>l[86iZh6hZH:gZHFbYhN/XXBTVGjKTWN;S7R@T7jEUH>E
UXJBTXB@T8BAT8JDThVAU8FAU8FAU8FBUHJBUHJBUHJCUXNCUXNAU8FAU8FAU8FAU8FAU8F@ThB@ThB@
ThB=UhMnQgYBFdiEGE96CT<lA3ZDW9:l`kadNgPf?CYKHUe:D4]AEDo;d<N_/ZVc]Ze:FED]?3PS<B/H
9Adh@cTT;R8E7Q4S:Q/G7aD[<2MoPWW3a[fd^K20Rh4B8QLR=RXS9aa1Ac`/=RXF81@V<2@V;24g=Ra^
K6;>a[n//JRL[J8U=BXX;BBVXi_Jfm:g`;Je]Zbe]Zbe]Zbe]Zbe]Zbe]Zbe]Zbe]Zb^/:B_/JFa/jNb
]:Rb]:Ra/jN`/ZJ_/JFh^Jng^:jg^:jg^:jh^Jni^[2j^k6k_;:h^Jnh^Jni^[2i^[2i^[2j^k6j^k6j
^k6j^k6j^k6k_;:k_;:l_K>l_K>l_K>l_K>m_[Bm_[Bm_[Bm_[Bn_kFn_kFo`;Jo`;K4a;S5aKW1`K>j
^:Jb[IBeZHNn[H;7/h>n[HJn[HJn[HJn[HJn[HJn[HJn[HJn[HJo[HBo[HBo[HBo[HBo[HBo[HBo[HBo
[HBo[HBo[HC0[XG0[XG0[XG1[hK1[hK1[hJo[HBo[HBo[HBo[HBo[HBo[HBo[HBo[HBn[8>n[8>n[8>o
[HBo[HC0[XG0[XG0[XFn[8>n[8>n[8>o[HBo[HBo[HC0[XG0[XG3/X_2/H[1/8W0[hRo[XNo[XNo[XNo
[XNm[8Fn[HJo[XO1/8W1/8W0[hRo[XNn[HJo[XNn[HJn[HJn[HJn[HJn[HH00<6dY<6dY<6dY<6dY<6d
Y<6dY<6dY<6dY<2bY/2bY/2bY/2bY/2bY/2bY/2bY/2bY/6cYl6cYl6cYl6cYl6cYl6cYl6cYl6cYkjb
Y[jbY[jbY[jbY[jbY[jbY[jbY[jbY[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nb
X[nbX[nbX[nbX[naYKnaYKnaYKnaYKnaYKnaYKnaYKnaYKfcX[fcX[fcX[fcX[fcX[fcX[fcX[fcX[fc
X[fcX[fcX[fcX[fcX[fcX[fcX[fcX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[bbXKbbXKbbXKbbXKbb
XKbbXKbbXKbbXKnbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[jbX;jbX;ncXKncXKncXL2dX/2dX/2dX[nc
XKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKfaWkfaWkfaWkfaWkfa
WkfaWkfaWkfaWkjbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;jcWkjcWkjcWkjcWkjcWkjcWkjcWkjcWkfb
W[fbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[baWKbaWKbaWKbaWKba
WKbaWKbaWKbaWKjcWkZ_VkR]VK^`W;ndX;ndX;R]VK6VTZnXVIjGR85kKV9NDd]9?Sln=3`k<C/l<cXj
;STi;CPj;SHm<3M1=3]8>Si=?d1A@ba1?Rm5@3=9A3I=ACE=@c59?Ba5=bU2=3a<>Sa<>Sa<>Sa<>Sa<
>S];>C];>C];>CA6;cA5<3A5<3A4<S=3<C=3<S=3<S=2=352=2m0<Rhm;b/j;2Pe9bLa92@^8B8/7b@e
:2Le:BTe:BXb9b/a9S4b:3Lf;3/i;e9@AU]ICfeYGX9lKi>>Oj6JRJRQT:^TTK:WS;>XSKFZSkN/TKV^
TkZ_U;Z_U;Z_U;N/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKV^TkV^TkV^TkV^TkV^TkV^TkV^TkV^TkR]
TKR]TKR]TKV]TK^]TK^]TKf/TKf/TKZ^T[Z^T[V]TKR/T;R/T;V]TKZ^T[Z^T[Z_TKZ_TKZ_TKV^T;V^
T;V^T;R]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]
SkV^T;Z_TKZ_TKZ_TKZ_TKV^T;R]SkV^T;V^T;V^T;V^T;V^T;V^T;V^T;V^T;^`T[Z_TKZ_TKV^T;V^
T;R]SkR]SkR]SkV^T;V^T;V^T;V^T;V^T;V^T;V^T;V^T;N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[^[
S[^[S[^[S[^[S[^[S[^[S[^[S[^[S[Z[RkZ[RkZ[Rk^/S;^/S;^/S;b]SKb]SKb]SKb]SKb]SKb]SKb]
SKb]SKb]SKb]SKZ[RkZ[Rk^/S;^/S;^/S;^/S;^/S;b]SK^/S;^/S;^/S;^/S;^/S;^/S;^/S;^/S;Z[
RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[Rk^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RKb/R;b/R;b/R;b/R;b/
R;b/R;b/R;b/R;V[QkV[QkV[QkZ/R;Z/R;Z/R;^]RK^]RKb/R;b/R;b/R;b/R;b/R;b/R;b/R;b/R;Z/
R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;f]RKb/R;^[Qk^[Qk^[Qk^[Qkb/R;f]RKb/Qkb/Qkb/Qkb/Qkb/
Qkb/Qkb/Qkb/Qk^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[ZZ
QKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKRXPkRXPkRXPkRXPkRX
PkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkNW
P[RXPkRXPkRXPkVYQ;VYQ;VYQ;VYQ;RXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkNWP[NWP[NWP[NWP[NW
P[NWP[NWP[NWP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[b/
PKV[PKRYP[NYQKJZR;6VR:ZOPjFJOi>BOI>BOY>BOY:BP9>CPiBCQI>CQi>BR96DQI6DQI6DQI6DQI:E
QY:EQY>FQi>FQi2CQ92CQ96DQI:EQY:EQY>FQiBGR9BGR9NNShjER3@k;XjDRJ>YWUaQF4mDBlgAbgIm
N6ifKk:i/XF=PdI;@Z>WW:R/X:N[WeUWH`4?2A<O6Ci9@E5JD49<@45:?AlX6b4Z85iVG:NZXL33^ZR]
Y8bERbHf:`/L4EQLDIVQUZbfZW^7Nd==@BH/8EmPE/S6_<k6_jbaZ9f^XbXj;bT^9J:OUm[Kd[O0][Ff
[;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;2bY[2bY[6cYk6cYk6cYk2bY[2bYZnaYKJg[KJg[KNh[[Ri[kRi
[kVj/;Vj/;Vj/;Ri[kRi[kVj/;Vj/;Vj/;Zk/KZk/KZk/KZk/KZk/K^l/[^l/[bm/kbm/kbm/kbm/kfn
];fn];fn];fn];jo]Kjo]Ko0][o0]/;2]/C4^<;2];fkZKJaV;J[Rkf]PlFaP[j]Q[j]Q[j]Q[j]Q[j]
Q[j]Q[j]Q[j]Q[n]Q;n]Q;n]Q;n]Q;n]Q;n]Q;n]Q;n]Q;n]Q;n]Q;n]Q<2^QL2^QL2^QL6_Q/6_Q[n]
Q;n]Q;n]Q;n]Q;n]Q;n]Q;n]Q;n]Q;j/Pkj/Pkj/Pkn]Q;n]Q;n]Q<2^QL2^QKj/Pkj/Pkj/Pkn]Q;n]
Q;n]Q<2^QL2^QL:aR/6`RL6`RL2_R;n^Qkn^Qkn^Qkn^Qkf/QKj]Q[n^Ql2_R<6`RL2_R;n^Qkj]Q[j]
Q[j]Q[j]Q[j]Q[j]Q[j]QP00`KBT`KBT`KBT`KBT`KBT`KBT`KBT`KBT`;:V`;:V`;:V`;:V`;:V`;:V
`;:V`;:V`K>W`K>W`K>W`K>W`K>W`K>W`K>W`K>W_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_k:R_k:R
_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k6U_k6U_k6U_k6U_k6U_k6U
_k6U_k6U_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_k:R_k:R
_k:R_k:R_k:R_k:R_k:R_k:R_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_k:R_k:R_k:R_k:R_k:R_k:R
_k:R_k:R_[:P_[:P_[:P_k>Q_k>Q_k>Q`;BR`;BR_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q
_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_[:P_[:P_[:P_[:P_[:P_[:P
_[:P_[:P_[>O_[>O_[>O_[>O_[>O_[>O_[>O_[>O_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N
_K:N_K:N_K:N_K:N_K:N_K:N^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^JjJ]jbH^:fI^k2L_[>O
_kBP_[>O^K2L^k6O^K:O/JVHWiR7QGi_JVAGFeE8D4XmBdDh@Sla>CPZ<SDV;S<T;C@U;cHW<3de<Chf
=48g=dDj>TPl>dXl>dXl>dXl:cd/:cd/:cd/:cd/:cd/;3h];3h];3h]:C`W:C`W:3/X9cTX9cTX9SLY
9SLY9CHY838Q8c<R9CDT:CHV;CPX;cXZ<S`/<cd];2lO<cHV@44aCd`mGUU:KFIGNG1RPgQZUXmnXIZ9
[JFD/:VF[jJB/JJB]jbF_[>M]JZ?]Z^@]jbA^JjC^ZnD^ZnD^ZnD^ZnD]jbA]jbA]jbA]jbA]jbA]jbA
]jbA]jbA^JjC^JjC^JjC^JjC^JjC^JjC^JjC^JjC^:fA^:fA^:fA^JfA^jfA^jfA_JbA_JbA^ZjB^JfA
^:b@^:b@^:b@^:b@^JfA^ZjB^ZnA^ZnA^Jj@^Jj@^Jj@^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?
^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^Jj@^ZnA^ZnA^Jj@^:f?^:f?^Jj@^Jj@
^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^ZnA^ZnA^Jj@^Jj@^Jj@^:f?^:f?^:f?^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@
^Jj@^Jj@]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>^j^>^j^>^j^>^j^>^j^>^j^>^j^>^j^>^Z^;^Z^;
^Z^;^Z^;^jb<^jb<^jb<_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=^jb<^jb<^jb<^jb<^Z^;^Z^;
^Z^;^Z^;^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jb<^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^jf9^jf9
^jf9^jf9^jf9^jf9^jf9^jf9^j^7^j^7^j^7^j^7^j^7^j^7^j^7^j^7^:Z6^J^7^J^7^J^7^Zb8^Zb8
^Zb8^Zb8^j^7^j^7^j^7^j^7^j^7^j^7^j^7^j^7^J^7^J^7^J^7^J^7^J^7^J^7^J^7^J^7_:b8_:b8
^j^7^ZZ6^ZZ6^j^7_:b8_:b8^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5
^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4
^JV4^JV4^JV4^JV4^JV4^JV4^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3
^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3]jN2]jN2]jN2^:R3^:R3^JV4^JV4^JV4^:R3^:R3
^:R3^:R3^:R3^:R3^:R3^:R3]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2^:V2^:V2^:V2^:V2^:V2^:V2
^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^J^1^:Z0^:V2]jZ4]ZZ8]ZV9/JJ8[jB6Wi^2VIEl
U91hTXikUI>1V9F6UIB6TY25T9>4T9>4TIB5TIB5TYF6TYF6TYF6TYF6Si:3T9>4TIB5TYF6TiJ7UIR9
UYV:UYV:OhIgQHaoF5mBYjfRU9Z?FEiECU=:YJVSK7E[FV9HQHf2LgY]@dXmU9V:][VZZZfMMH5k5B4K
;CP`Q8n7`/_1]l6eSiN<<c/`92dSTi^AcM37^kjeXJBKWZJLE69G31`A@DLlWJFJen7EZ;BXBeE98RPM
KFiTgMcBc/JoZk2WWJjS<d<h:RlVVYN?f]_B]l2f]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/]KJ//kFY/[BX
/K>W/;:V[k6U[k6U[k6U/;:V/kBZ]KJ/]kR^^;V_^KZ`^KZ`^;V_^;V_^;V_^;V_^KZ`^KZ`^KZ`^[^a
^[^a^[^a^[^a^[^a^kbb^kbb_;fc_;fc_;fc_;fc_Kjd_Kjd_Kjd_Kjd_[ne_[ne_l2f_l2f`Knd`l>g
a<Bh`Kj__;NR^[2B_:b7_Jb1_Jb5_Jb5_Jb5_Jb5_Jb5_Jb5_Jb5_Jb5_Zb3_Zb3_Zb3_Zb3_Zb3_Zb3
_Zb3_Zb3_Zb3_Zb3_jf4_jf4_jf4`:j5`:j5`:j5_Zb3_Zb3_Zb3_Zb3_Zb3_Zb3_Zb3_Zb3_J^2_Zb3
_Zb3_Zb3_jf4_jf4_jf4_jf4_Zb3_Zb3_Zb3_jf4_jf4_jf4`:j5`:j5`K29`K29`:n8`:n8_jj7_jj7
_jj7_jj7_Zf6_Zf6_jj7`:n8`:n8_jj7_Zf6_Jb5_Zf6_Zf6_Zf6_Zf6_Zf6_Zf60031]:C1]:C1]:C1
]:C1]:C1]:C1]:C1]:C0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK1/jO1/jO1/jO1/jO1/jO1/jO1/jO1
/jNn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6n
/J6n/J6n/J6n/J6n/J6n/:Bn/:Bn/:Bn/:Bn/:Bn/:Bn/:Bn/:Bl/Z6l/Z6l/Z6l/Z6l/Z6l/Z6l/Z6l
/Z6l/Z6l/Z6l/Z6l/Z6l/Z6l/Z6l/Z6l/Z6n/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6k/J2k/J2k/J2k
/J2k/J2k/J2k/J2k/J2n/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6m/Inm/Inn/Z2n/Z2o/j6o/j6o/j6o
/j6n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z2m/Inm/Inm/Inm
/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm
/Yjl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifk/9bk/9bk/9bk
/9bk/9bk/9bk/9bk/9bi[YZi[YZh[IVg[9RfZiNg[9Rj[i^l/Ifk[iNl/9Rl/YZm/Ybl/Ifi[YZfZYRd
Z9J>PgF7O6iiL69ZHeAJEDI?BS]6@cA3@34l?c0j?Bhg>R/e>2Tc=RLc=RHd=bLd=bL`=bP`=bP`=bPa
>2Tb>BXb>BXc>R/c>R/V;a/W<1`X<1lZ<B8/<b@^=BP`=bXa=b`c=b@f>RLo@Bi7BCIBDT1LFTQSHDmY
IE>BRgNGT7bQV8B[X8bcYI:jZiRo/9g5]:6n/ifk/9Zh[YJj[YJl[YNk[IJiZI:eYHjeZXnfZi2g[96h
[I:h[I:h[I:g[96g[96g[96g[96g[96g[96g[96g[96g[96g[96i[Y>i[Y>i[Y>i[Y>i[Y>i[Y>i[Y>i
[Y>g[92g[92g[92h[92j[92j[92lZi2lZi2i[I6i[I6h[92gZhngZhnh[92i[I6i[I6i[Y2i[Y2i[Y2i
[Y2h[Hnh[Hng[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jg
[8jg[8jh[Hni[Y2i[Y2i[Y2i[Y2h[Hng[8jh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hni[Y2i[Y2i[Y2h
[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[HnfZhffZhffZhffZhffZhffZhffZhff
ZhfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfiZXZiZXZjZh^jZh^jZh^k[8bk[8bk[8bk[8bk[8bk[8bk
[8bk[8bk[8bk[8bk[8bl[Hfk[8bk[8bjZh^jZh^iZXZiZXZiZXZjZh^jZh^jZh^jZh^jZh^jZh^jZh^j
Zh^iZXZiZXZiZXZiZXZiZXZiZXZiZXZiZXZj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8RkZhNkZhNkZhNk
ZhNkZhNkZhNkZhNkZhNhZXJhZXJhZXJiZhNiZhNj[8Rj[8Rj[8RkZhNkZhNkZhNkZhNkZhNkZhNkZhNk
ZhNiZhNiZhNiZhNiZhNiZhNiZhNiZhNiZhNl[8RkZhNkZhNjZXJjZXJkZhNkZhNl[8RkZhJkZhJkZhJk
ZhJkZhJkZhJkZhJkZhJjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFj
ZXFiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBhZ8>hZ8>hZ8>h
Z8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>h
Z8>gYh:gYh:gYh:gYh:hZ8>hZ8>iZHBiZHBhZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>gYh:gYh:gYh:g
Yh:gYh:gYh:gYh:gYh:hZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:h
ZH:iZh6hZX2gZ86gYh:fZ8BgZ8NgZ8NgZ8R[XhFUWH2LUGZGTGZGTWfFTX2DTH:DTH>@ThB@ThB@ThBA
U8FAU8FAU8FBUHJBUHJ@ThB@ThBAU8FAU8FBUHJCUXNCUXNCUXNBUhR:SX9aMFUIGE8m@CHo@SV4QgjO
XI^RZii_N6]TJeibNFZ0QWFUZ9R_/j2UZIJBVY=<E4dE7AHa>S2V[jG>elfRZZ0k@cTL9A^NYYcDeljj
^k:WZ9n^/jZ9TXPnBClB6Q1SK6:jaK^jb;eTKfDY<BMWJV7Dd/[?al2[/:NN[j@mCD8[<2N@SHGKg=>g
`;Je]Zbe]Zbe]Zbe]Zbe]Zbe]Zbe]Zbe]Zbf^:bd]ZZb]:R`/ZJ_/JF_/JF`/ZJ`/ZJa/ZRc]:Zf]jfi
^[2j^k6i^[2g^:jf]jfh^Jnh^Jni^[2i^[2i^[2j^k6j^k6j^k6j^k6j^k6k_;:k_;:l_K>l_K>l_K>l
_K>m_[Bm_[Bm_[Bm_[Bn_kFn_kFo`;Jo`;Jo_K?2`;K4`kW3`[C0_:Vn]IZj[XbjZ8>m[8Fm[8Fm[8Fm
[8Fm[8Fm[8Fm[8Fm[8Fn[8>n[8>n[8>n[8>n[8>n[8>n[8>n[8>mZh:mZh:n[8>n[8>n[8>o[HBo[HBo
[HBn[8>n[8>n[8>n[8>n[8>n[8>n[8>n[8>mZh:mZh:mZh:n[8>n[8>o[HBo[HBo[HBn[8>n[8>n[8>o
[HBo[HBo[HC0[XG0[XFo[XNo[XO0[hS0[hS0[hRo[XNo[XNn[HJn[HJo[XNo[XNo[XNn[HJn[HJm[8Fm
[8Fm[8Fm[8Fm[8Fn[HJn[HJn[HH00<2cXl2cXl2cXl2cXl2cXl2cXl2cXl2cXl2bY/2bY/2bY/2bY/2b
Y/2bY/2bY/2bY/2bY/2bY/2bY/2bY/2bY/2bY/2bY/2bY[faYKfaYKfaYKfaYKfaYKfaYKfaYKfaYKja
XKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKj`Y;j`Y;j`Y;j`Y;j`
Y;j`Y;j`Y;j`Y;bbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKja
XKjaXKjaXKjaXKjaXKjaXKjaXKjaXK^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;jaXKjaXKjaXKjaXKja
XKjaXKjaXKjaXKfaWkfaWkfaWkjbX;jbX;jbX;ncXKncXKjbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;jb
X;jbX;jbX;jbX;jbX;jbX;jbX;jbX;faWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfa
WkfaWkfaWkfaWkfbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[baWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKba
WKbaWKbaWKbaWKbaWKbaWKbaWKbaWK^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;Z_VkbaWKjcWkfbW[Z_
VkV^V[Z_VkbaWKfbU[baU[^`UKZ^U[b^Ukf_VKn`WL2aW[j_Wk^/W;BWUjjQTJBJRIbBPIF;NXn7MX1k
IW]fHG=]FV]UDVANBemIAUeGA5eGA597>E97>E=8>U=8>UA9>eA9>eE:?5E:?65GAF=IAfUOCVmUE7I[
GGeaIH9fJXEiKJ>EPZFGQ:VJQjjOS;FTTKbXU/2/V/:^W;:TSKBVSkVYT[VYT[JVSkFSS;BRRkBRRkV^
T[>XS;2TR;>VS;f^U<>bV<2_UK^ZT;J[T;N/TKR]T[R]T[R]T[R]T[N/TKN/TKN/TKN/TKN/TKN/TKN/
TKN/TKN/TKN/TKR]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[N/T;N/T;N/T;R/T;Z/T;Z/T;b[T;b[T;V]
TKR/T;N[SkN[SkN[SkN[SkR/T;V]TKV^T;V^T;R]SkR]SkR]SkN/S[N/S[N/S[N/S[N/S[N/S[N/S[N/
S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[R]SkV^T;V^T;R]SkN/S[N/S[R]
SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]
SkR]SkR]SkR]SkJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKZZSKZZSKZZSKZZSKZZSKZZSKZZSKZZSKVZ
R[VZR[VZR[VZR[Z[RkZ[Rk^/S;^/S;^/S;^/S;^/S;^/S;^/S;^/S;^/S;^/S;^/S;^/S;^/S;Z[RkVZ
R[VZR[RYRKRYRKZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkVZR[VZR[VZR[VZR[VZR[VZR[VZR[VZR[Z/
R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;^[Qk^[Qk^[Qk^[Qk^[Qk^[Qk^[Qk^[QkNYQKRZQ[RZQ[RZQ[V[
QkV[QkV[QkZ/R;^[Qk^[Qk^[Qk^[Qk^[Qk^[Qk^[Qk^[QkV[QkV[QkV[QkV[QkV[QkV[QkV[QkV[Qk^[
Qk^[QkZZQ[ZZQ[ZZQ[ZZQ[^[Qk^[Qk^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[VYQ;VYQ;VYQ;VYQ;VY
Q;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;RXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRX
PkRXPkRXPkRXPkRXPkRXPkRXPkRXPkNWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NW
P[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[JVPKJVPKNWP[NWP[NWP[RXPkRXPkRXPkNW
P[NWP[NWP[NWP[NWP[NWP[NWP[NWP[JVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKNXPKNXPKNXPKNXPKNX
PKNXPKNXPKNXPKNXPKNXPKNXPKNXPKNXPKNXPKNXPKNXPKV[PKRYP[NXPKJWP;FUP;FUP;RUP[VVPkBV
P[6UPj^PP::JOIVANYB>NiB@OYNBPhnBPhnBPi2CQ92CQ96DQI6DQI6DQI6DQI6DQI6DQI6DQI2CQ8nB
PhnBPhjAPXjAPX^@PIVMTI6ERI6ERYbPUHjAR9:ES9bNV:fdYjR_XYVPTinTUKVl[:V/W:2RSjj`WK6i
[i>KTD59?`hF35iVG;[1^/G=aU=KE1TT6XjFS<c?a[bm];6bZJnbZJN/Xgf6O20W834i<X6>Q/ODc8RE
SB4Y8U5CCM_KeM;:`j^`Yij_Y4QHCBX_9XB1NMcMe;W2^;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Jh
[;FgZk:dZ;2bYZnaYJnaYK2bY[6cYjn`Y[6bZ;Ff[;Nh[[Vj/;Ri[kNh[[Jg[KRi[kRi[kVj/;Vj/;Vj
/;Zk/KZk/KZk/KZk/KZk/K^l/[^l/[bm/kbm/kbm/kbm/kfn];fn];fn];fn];jo]Kjo]Ko0][o0]/6l
/l6o]L?2^<G3^<K1//:jXkbaTkRYR;f/QKf/QKf/QKf/QKf/QKf/QKf/QKf/QKj/Pkj/Pkj/Pkj/Pkj/
Pkj/Pkj/Pkj/PkbZPKbZPKf[P[f[P[f[P[j/Pkj/Pkj/Pkj/Pkj/Pkj/Pkj/Pkj/Pkj/Pkj/Pkj/PkbZ
PKf[P[f[P[f[P[j/Pkj/Pkj/Pkn]Q;j/Pkj/Pkj/Pkn]Q;n]Q;n]Q<2^QL2^QKf/QKj]Q[n^Ql2_R<2_
R<2_R;j]Q[j]Q[n^Qkn^Qkj]Q[j]Q[f/QKf/QKf/QKf/QKb[Q;f/QKf/QKj]Q[j]Q[n^Q`00`;>S`;>S
`;>S`;>S`;>S`;>S`;>S`;>S`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V
`;:V`;:V_K6U_K6U_K6U_K6U_K6U_K6U_K6U_K6U_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P
_K2P_K2P_K2P_K2P_K2P_K2P_JnS_JnS_JnS_JnS_JnS_JnS_JnS_JnS^k6P^k6P^k6P^k6P^k6P^k6P
^k6P^k6P^k6P^k6P^k6P^k6P^k6P^k6P^k6P^k6P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P^[2O^[2O
^[2O^[2O^[2O^[2O^[2O^[2O_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_;2N_K6O_K6O_K6O_[:P_[:P
_[:P_[:P_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O
_K6O_K6O_K6O_K6O_K6O_K6O_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;6M_;6M_;6M_;6M_;6M_;6M
_;6M_;6M^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^ZnK^ZnK
^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK]JZF^:fI_;6M_K:N_;6M^k2L^k2L_;6M]:b?^:nD_KBI`[JN`K>L_:jH
]jJC/Z6>^jfJ_JnL_k6N`K>P`K>P`;:O_JnL_:jK_KBI^k:G]jjC/jVA/JJ@/:F?/JJB/ZNC]In=]In=
]Z2>]Z2>]Z2>]Z2>]Z2>]j6?/ij8]9n9]Z6<^ZBB_JNE`:VI`jbLa:fN_ZVC_ZVC`:VC`JZD`ZZDa:VD
aJZEaJZE]:F;^:V?_JjD`;6G`K:H`[>Ia;FKa[NM]J^=^[2B_k>G_K2F_:fC_ZbE`k6JbKNP^:fB^JjC
^ZnD^ZnD^k2E^ZnD^ZnD^JjC]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA^:fB^:fB^:fB^:fB^:fB^:fB
^:fB^:fB]Z^?]Z^?]Z^?]j^?^J^?^J^?^jZ?^jZ?^:b@^:b@]j^?]ZZ>]ZZ>]j^?^:b@^:b@^:f?^:f?
^:f?^:f?]jb>]jb>]jb>]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=
]Z^=]Z^=]Z^=]jb>^:f?^:f?^:f?^:f?]jb>]Z^=]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>]Z^=]jb>
]jb>]jb>^:f?^:f?^:f?^:f?]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>]JZ<]JZ<]JZ<]JZ<]JZ<]JZ<
]JZ<]JZ<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^:V9^:V9^JZ:^JZ:^JZ:^Z^;^Z^;^Z^;^Z^;^Z^;
^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:
^JZ:^JZ:^:V9^:V9^:V9^:V9^:V9^:V9^:V9^:V9^J^7^J^7^J^7^J^7^J^7^J^7^J^7^J^7^ZZ6^ZZ6
^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6]jV5]jV5]jV5^:Z6^:Z6^J^7^J^7^J^7^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6
^ZZ6^ZZ6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^j^7^ZZ6^ZZ6^JV5^JV5^ZZ6^ZZ6^j^7^ZZ5^ZZ5
^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4
^JV4^JV4^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3]jN2]jN2
]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2
]jN2]jN2]ZJ1]ZJ1]ZJ1]ZJ1]jN2]jN2^:R3^:R3]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]ZJ1]ZJ1
]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1
]jR1]jR1]JV1]ZZ2^:V2]ZN0]JAm]J9l]jAn^JJ0^JMn^ZV2]ZR4[:61X9MlVI5jUY1mUi>1Si:3Si:3
Si:3T9>4T9>4TIB5TIB5TIB5TYF6TIB5T9>4Si:3SY62SI21S8n0RhioS8n0TI>7RH]o[JjTQ8EkW9fD
WIjE]kNaUIZA^l2g`lNlXZBH/K>WZ:RJY:BF]kNWWZ:GUIV>NX1e=CXa72<LMWefd=OBGFAO7bXPOHIl
c<o6_kfe][B/[:ZRZZfTXjROHFUR5B0H:CH^U:>KSibD82PQ?D4kg=cFeLg6Zk2WWZnTD61E:2dTN7E]
g]oF_<Fk]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/];JZ];JZ/kFY/K>W/K>W/K>W/K>W/K>W[k2V/;6W
/kBZ]KJ/]kR^]kR^]kR^]kR^^;V_^;V_^KZ`^KZ`^KZ`^[^a^[^a^[^a^[^a^[^a^kbb^kbb_;fc_;fc
_;fc_;fc_Kjd_Kjd_Kjd_Kjd_[ne_[ne_l2f_l2f`[fd`;fe`;jf`l:ha/>ea;j[_[BL^:f?_:^4_:^4
_:^4_:^4_:^4_:^4_:^4_:^4_J^2_J^2_J^2_J^2_J^2_J^2_J^2_J^2^jV0^jV0_:Z1_:Z1_J^2_J^2
_J^2_J^2_J^2_J^2_J^2_J^2_J^2_J^2_J^2_J^2_:Z1_:Z1_:Z1_J^2_J^2_Zb3_Zb3_Zb3_Zb3_Zb3
_Zb3_jf4_jf4_jf4`:j5`:j5^jZ3_Jb5_jj7`:n8`K29`:n8_Zf6_Jb5`:n8_jj7_Zf6_Jb5_:^4_:^4
_:^4_:^4_:^4_:^4_Jb5_Jb5_Zf6_jj7002o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z;0/ZK0/ZK0/ZK0
/ZK0/ZK0/ZK0/ZK0/ZJo/JFo/JFo/JFo/JFo/JFo/JFo/JFo/JFl/:Bl/:Bl/:Bl/:Bl/:Bl/:Bl/:Bl
/:Bm/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m[j>m[j>m[j>m
[j>m[j>m[j>m[j>m[j>k/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2k
/J2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2j/9nj/9nj/9nj/9nj/9nj/9nj/9nj/9nm/:2m/:2m/:2m
/:2m/:2m/:2m/:2m/:2l/9jl/9jm/Inm/Inm/Inn/Z2n/Z2n/Z2m/Inm/Inm/Inm/Inm/Inm/Inm/Inm
/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inl/9jl/9jl/9jl
/9jl/9jl/9jl/9jl/9jl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifk/9bk/9bk/9bk/9bk/9bk/9bk/9bk
/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bj[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^dZIFeZYJeZYJg
[9Ri[YZi[YZi[YZh[IVo^ini]9^bZi:^XhfaY8jjZiS6]J;=^jZ`YHnaYY2eZ9:gZYBgZYBhZiFhZYBh
ZYBcZ8RdZHVeZXbgZhnj[I>m[iRo/I[0/Ybo/9Jn[iFn[iFn[iFn[iFn[iFm[YBm[YBn/9>m[i>l[Y:k
[9:jZi6iZI:hYi:gYY6gZY2gZY2gZY2jZi6m[9:m[9;0[9?0[9>fZ96gZI:hZY>fZY:cYhn`Y8b`Y8ba
YHf`Z8Zf[Y6m/YJi[Y>aXhb`WhZdXi2kZYNg[96g[96i[Y>j[iBj[iBj[iBj[iBi[Y>g[96g[96g[96g
[96g[96g[96g[96g[96g[96g[96g[96g[96g[96g[96g[96g[96fZhnfZhnfZhngZhniZhniZhnkZXnk
ZXnh[92gZhngZhnfZXjfZXjgZhngZhnh[92h[Hnh[Hnh[Hng[8jg[8jg[8jfZhffZhffZhffZhffZhff
ZhffZhffZhffZhffZhffZhffZhffZhffZhffZhffZhffZhffZhffZhfg[8jg[8jh[Hnh[Hng[8jg[8jf
Zhfg[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jfZhffZhffZhfg[8jg[8jh[Hnh[Hni[Y2g[8jg[8jg[8jg
[8jg[8jg[8jg[8jg[8jeZXbeZXbeZXbeZXbeZXbeZXbeZXbeZXbiZHbiZHbiZHbiZHbiZHbiZHbiZHbi
ZHbhZHVhZHVhZHViZXZiZXZiZXZjZh^jZh^jZh^jZh^jZh^jZh^jZh^jZh^jZh^jZh^hZHVhZHVhZHVi
ZXZiZXZiZXZiZXZiZXZiZXZiZXZiZXZiZXZiZXZiZXZiZXZiZXZhZHVhZHVhZHVhZHVhZHVhZHVhZHVh
ZHViZhNiZhNiZhNiZhNiZhNiZhNiZhNiZhNjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJgZHFgZHFgZHFh
ZXJhZXJhZXJiZhNiZhNjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJh
ZXJkZhNjZXJiZHFiZHFiZHFiZHFjZXJkZhNjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFiZHBiZHBiZHBi
ZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBgYh:gYh:gYh:gYh:gYh:gYh:gYh:g
Yh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6f
YX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6eYH2eYH2fYX6fYX6gYh:gYh:gYh:g
Yh:fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6eYH2eYH2eYH2eYH2eYH2eYH2eYH2eYH2fYh2fYh2fYh2f
Yh2fYh2fYh2fYh2fYh2fYh2fYh2fYh2fYh2fYh2fYh2fYh2fYh2bYWjdZ82hZH:iZ86gYGbhY7^jYWfn
Z7nkYgRkZ7fiZ86dYHB/X8BTVX:LUH:ITX6?TX>?TX>?TX>?TX>@ThB@ThB@ThBAU8FAU8FAU8F@ThB@
ThB?TX>>TH:>TH:=T86;SWnGVHfXZYkCe<ZKW9:TYIbOX9O4a;jXZJF^/:[=clVVYijUXi^[ZZ2_[J:X
YY^`/ZJSYIVLX9EUJV4E71D_=C2TZjIaN7DL9aedOG?JgMBk^K6b[jN_[:BWZ9n^/JROYZ50BT@>71I:
FU=VM6h/=S19Cd[@dLgIdLZ//JRM[Z=FIU/V:b9_K6CPhMRob;je]Zbe]Zbe]Zbe]Zbe]Zbe]Zbe]Zbe
]Zbb]:Rb]:Rc]JVc]JVc]JVb]:Rb]:Ra/jN_/:J`/JNa/ZRc]:Ze]Zbf]jfg^:jh^Jnh^Jnh^Jni^[2i
^[2i^[2j^k6j^k6j^k6j^k6j^k6k_;:k_;:l_K>l_K>l_K>l_K>m_[Bm_[Bm_[Bm_[Bn_kFn_kFo`;Jo
`;K3_[Fo_;Bn_;C1_kO5`kS6`[31^J:m/YNlZhBlZhBlZhBlZhBlZhBlZhBlZhBlZhBmZh:mZh:mZh:m
Zh:mZh:mZh:mZh:mZh:kZH2kZH2kZH2kZH2lZX6lZX6mZh:mZh:mZh:mZh:mZh:mZh:mZh:mZh:mZh:m
Zh:lZX6lZX6lZX6mZh:mZh:mZh:n[8>n[8>n[8>n[8>n[8>o[HBo[HBo[HC0[XG0[XFjZH:lZhBn[HK0
[hS1/8W0[hRn[HJm[8G1/8W0[hRn[HJlZhBkZX>kZX>kZX>lZhBkZX>lZhBlZhBm[8Fn[HJo[XL00;nb
X[nbX[nbX[nbX[nbX[nbX[nbX[nbX/2bY/2bY/2bY/2bY/2bY/2bY/2bY/2bY[naYKnaYKnaYKnaYKna
YKnaYKnaYKnaYKb`Y;b`Y;b`Y;b`Y;b`Y;b`Y;b`Y;b`Y;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`
X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f_Xkf_Xkf_Xkf_Xkf_Xkf_Xkf_Xkf_Xk^aX;^aX;^aX;^aX;^a
X;^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;Z`
WkZ`WkZ`WkZ`WkZ`WkZ`WkZ`WkZ`Wkf`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;b`W[b`W[b`W[faWkfa
WkfaWkjbX;jbX;faWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfa
WkfaWkfaWkfaWkfaWkfaWkfaWkfaWkb`W[b`W[b`W[b`W[b`W[b`W[b`W[b`W[baWKbaWKbaWKbaWKba
WKbaWKbaWKbaWK^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;Z_
VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkfbW[V^V[J[UkJ[UkR]VKV^V[V^V[N/V;2/Tk>_U[VcW;jfWknd
X;f_WKVYV;NTUKZbVk^`V[V^V;R]UkZ]Uk^^V;j`V[naVknfTKneTkndU;jcUKfaUK^^U;V[U;RZTkNb
TkJaT[JaT[F`TKF`TKB_T;B_T;>^Sk2[R[6/Rk:]S;>^SkB^TKF_T[J_U;N`UK>aTk>aTk>aTkB`TkJ`
TkJ`TkR`TkR`TkFYTKJZT[J/U;J/U;>/Tk>/TkF^UKF`UkB^TK>]T;F/TKV]UKb_VKj_W;f]W;j/Vk>X
SKBYS[FZSkJ[T;N/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/
TKN/TKN/TKN/TKJ[SkJ[SkJ[SkN[SkV[SkV[Sk^ZSk^ZSkR/T;N[SkN[SkJZS[JZS[N[SkN[SkR/T;R]
SkR]SkN/S[N/S[N/S[J[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[
SKJ[SKJ[SKJ[SKJ[SKN/S[N/S[R]SkR]SkN/S[N/S[J[SKN/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[FZ
S;FZS;J[SKN/S[N/S[R]SkR]SkV^T;N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[FZS;FZS;FZS;FZS;FZ
S;FZS;FZS;FZS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;RYRKRYRKRYRKRYRKVZR[VZR[Z[RkZ[RkZ[
RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkNXR;NXR;RYRKRYRKVZR[Z[RkZ[RkZ[RkVZR[VZR[VZR[VZR[VZ
R[VZR[VZR[VZR[RYRKRYRKRYRKRYRKRYRKRYRKRYRKRYRKV[QkV[QkV[QkV[QkV[QkV[QkV[QkV[QkZZ
Q[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[JXQ;NYQKNYQKNYQKRZQ[RZQ[RZQ[V[QkZZQ[ZZQ[ZZQ[ZZQ[ZZ
Q[ZZQ[ZZQ[ZZQ[RZQ[RZQ[RZQ[RZQ[RZQ[RZQ[RZQ[RZQ[^[QkZZQ[VYQKVYQKVYQKVYQKZZQ[^[QkZZ
QKZZQKZZQKZZQKZZQKZZQKZZQKZZQKRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRX
PkRXPkRXPkRXPkNWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[JV
PKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJV
PKJVPKJVPKJVPKFUP;FUP;JVPKJVPKJVPKNWP[NWP[NWP[JVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKFU
P;FUP;FUP;FUP;FUP;FUP;FUP;FUP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JW
P;JWP;JWP;JWP:nSNk>WOkRYP[ZYP[VWO[ZVOKjXO/2ZP;fWMkZVMkNUO;NWPk>XRZfSRj2IQIRBOhjA
PXnBPhnBPhnBPi2CQ92CQ92CQ92CQ92CQ92CQ92CQ96DQI6DQI6DQI6DQI6DQI>CQIBDR79bIWmnM;Vh
[WEcJe=ABL[7`XN8QVQYIkZi]KRg/jZWXZj[XkNd[:FRVZJVV:f]XJRYWiJIT4iBC00503<j=c4j=`hL
4G1iKnKYh;FcZjfZX[Re[J^YXK2aZ:B^Z7f9PcE3?ALW824_:AXT7T]AC;bm^M_Cc:baZ9f^XeUYGRDZ
8FYWGn7RfL7:`;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;2bY[6cYk>eZKBfZ[BfZ[BfZ[:dZ;6cYjn`
Y[2aYk2aYk6bZ;>dZ[Jg[KRi[kVj/;Ri[kRi[kVj/;Vj/;Vj/;Zk/KZk/KZk/KZk/KZk/K^l/[^l/[bm
/kbm/kbm/kbm/kfn];fn];fn];fn];jo]Kjo]Ko0][o0]/O0]l6k];bi];nl]lG3^LS3]<>lZ;jdW;b[
Q;b[Q;b[Q;b[Q;b[Q;b[Q;b[Q;b[Q;f[P[f[P[f[P[f[P[f[P[f[P[f[P[f[P[ZXOkZXOk^YP;^YP;bZ
PKbZPKbZPKbZPKf[P[f[P[f[P[f[P[f[P[f[P[f[P[f[P[^YP;bZPKbZPKbZPKf[P[f[P[f[P[j/Pkj/
Pkj/Pkj/Pkn]Q;n]Q;n]Q<2^QL2^QKVXPK^ZPkj]Q/2_R<6`RL2_R;j]Q[f/QL6`RL2_R;f/QK^ZPkZY
P[ZYP[^ZPkb[Q;^ZPkb[Q;b[Q;f/QKj]Q[n^Q`00`kBT`kBT`[>S`[>S`K:R`;6Q`;6Q`;6Q_k:R_k:R
_k:R_k:R_k:R_k:R_k:R_k:R_[2T_[2T_[2T_[2T_[2T_[2T_[2T_[2T_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q
_[6Q_[6Q_k:R_[6Q_K2P_:nO_:nO_:nO_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P
_K2P_K2P_K2P_K2P_K2P_K2P^jjN^jjN^jjN_:nO_:nO_K2P_K2P_K2P_:nO_:nO_:nO_:nO_:nO_:nO
_:nO_:nO_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N^jnM^jnM
^jnM_;2N_;2N_K6O_K6O_K6O_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M
_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M
_;6M_;6M_;6M_;6M_;6M_;6M^ZnK^ZnK^k2L_;6M_;6M^k2L^ZnK^ZnK^ZnK^ZnK^ZnK^k2L^k2L^k2L
_;6M_;6M^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK^JbF^JbF
^JbF^JbF^JbF^JbF^JbF^JbF^jjH^jjH^jjH^jjH^jjH^jjH^jjH^jjH^jjH^jjH^jjH^jjH^jjH^jjH
^jjH^jjH^k2E^k2E^k2E^k2E^k2E^k2E^k2E^k2E^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB
^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@
]jZ@]jZ@]jbA^:fB^JjC^JjC^JjC^JjC^:fB]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jZ@]jZ@
]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>
]ZZ>]ZZ>^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^JV<^JV<
^JV<^JV<^JV<^JV<^JV<^JV<]JZ<]JZ<]JZ<]JZ<]JZ<]JZ<]JZ<]JZ<^JV<^JV<^JV<^JV<^JV<^JV<
^JV<^JV<^JV<^JV<^JV<^ZZ=^ZZ=^j^>^j^>^j^>^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^Z^;^Z^;
^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:V9^:V9^:V9^:V9^:V9^:V9
^:V9^:V9^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:V9^:V9
^:V9^:V9^:V9^:V9^:V9^:V9^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6
^ZZ6^ZZ6]jV5]jV5]jV5^:Z6^:Z6^:Z6^J^7^J^7^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^ZZ6^ZZ6
^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5
^JV5^JV5^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^jV4^jV4^jV4^jV4^jV4^jV4^jV4^jV4^JV4^JV4
^JV4^JV4^JV4^JV4^JV4^JV4]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2^JN2^JN2^:J1]jF0]jF0^:J1
^JN2^JN2^:N0^:N0^:N0^:N0^:N0^:N0^:N0^:N0]jF0]jF0]jF0]jF0]jF0]jF0]jF0]jF0^:J1^:J1
^:J1^:J1^:J1^:J1^:J1^:J1]jF0]jF0]jF0]jF0]jF0]jF0]jF0]jF0^JR1^JR1^:N0^:N0]jIo]ZEn
]ZEn]ZEn]jF0]jF0]jF0]jF0]jF0]jF0]jF0]jF0]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo
]jIo]jIo]jIo]jIo]jIo]jIo]ZEn]ZEn]jIo]jIo]jIo^:N0^:N0^:N0]jIo]jIo]jIo]jIo]jIo]jIo
]jIo]jIo^ZV2^JR1^:N0]jIo]ZEn]ZEn]ZEn]jIoViAkVIAoTi>3T9:6Si65TY:2Ui9mVI9iSY61SY61
Si:2SY9oSY9oSI5nRi1kRXmjPXQeUif<OX=d=SX_J6]R<S<_DE9@d=3@Q8b5CeM@c=C=_LBmblo9a<S2
XJ>MY:JP[ZbQYZJJXJ>GY:^NQi64<d0b0A846BXL8RLHGf=Ggn;I]kNa][>^[jfU/JnTZJRJ[ZjRYj^O
LWa_4R4C4R4C:S@W@4@h`/:feMOA/K>]YjVSMgUc;2hXEEMAkNoY_/2j];F[];F[];F[];F[/kBZ/kBZ
/kBZ/kBZ/[BX/kFY/kFY/kFY];JZ];JZ];JZ]KN[/;6W/K:X/[>Y/K:X/K:X/[>Y]KJ/]kR^^;V_^;V_
]kR^][N]]kR^^;V_^[^a^kbb^[^a^[^a^kbb^kbb_;fc_;fc_;fc_;fc^kbb_;fc_;fc_;fc_Kjd_Kjd
_Kjd_[ne_[ne_[ne_[ne_[ne_[ne_[ne_[ne_[ne^jnC]ZN7^:F0`J^2aJj1_ZUl^jQm_:^0_:Z1_:Z1
_:Z1_:Z1_:Z1_:Z1_:Z1_:Z1^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo_J^2_J^2_J^2_:Z1^jV0^jV0
^ZQo^ZQo_:Im_JMn_ZQo_jV0`:Z1_jV0_jV0_jV0_:Z1_:Z1_:Z1_:Z1^jV0^jV0^jV0^jV0_Jf3_jn5
`K67`K67_jn5_:b2_:b2_:b2_:Z1_:Z1_:Z1_:Z1_:Z1_:Z1_:Z1_:Z1_:Z1_:Z1_:Z1_J^2_J^2_J^2
0033]:C2/j?2/j?1/Z;1/Z;0/J70/J70/J6o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:n/:Bn/:Bn/:Bn
/:Bn/:Bn/:Bn/:Bn/:Bn/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6m/:2m/:2l[inl[inl[inm/:2m
/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2k[Yjk[Yjk[Yjl
[inl[inl[inm/:2m/:2l[inl[inl[inl[inl[inl[inl[inl[inl/9jl/9jl/9jl/9jl/9jl/9jl/9jl
/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jk[ifk[ifk[ifl/9jl/9jl/9jm/Inm/Inl/Ifl/Ifl/Ifl
/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl
/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifj[i^j[i^k/9bl
/Ifl/Ifk/9bj[i^j[i^j[i^j[i^j[i^j[i^k/9bk/9bl/Ifl/Ifj[i^j[i^j[i^j[i^j[i^j[i^j[i^j
[i^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^i[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Jj[INj[INj[INj
[INj[INj[INj[INj[INj[INj[INj[INj[INj[INj[INj[INj[INj[iBj[iBj[iBj[iBj[iBj[iBj[iBj
[iBh[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h
[I:h[I:h[I:h[I:h[I:gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2g[96h[I:i[Y>i[Y>i[Y>i[Y>h[I:g
[96g[96g[96g[96g[96g[96g[96g[96g[96gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2g
ZY2gZY2gZY2gZY2gZY2fZXjfZXjfZXjfZXjfZXjfZXjfZXjfZXjjZXfjZXfjZXfjZXfjZXfjZXfjZXfj
ZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbeZXbeZXbeZXbe
ZXbeZXbeZXbeZXbeZXbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbgYhZgYhZhZ8^hZ8^iZHbiZHbiZHbi
ZHbjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZh^jZh^jZh^jZh^jZh^jZh^jZh^jZh^hZ8^hZ8^hZ8^h
Z8^hZ8^hZ8^hZ8^hZ8^hZHVhZHVhZHVhZHVhZHVhZHVhZHVhZHVhZXJhZXJhZXJhZXJhZXJhZXJhZXJh
ZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZHVhZHVhZHVhZHVhZHVhZHVhZHVhZHVjZXJjZXJjZXJj
ZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJfZ8BgZHFgZHFgZHFhZXJhZXJhZXJi
ZhNhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJhZ8BhZ8BhZ8Bh
Z8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>h
Z8>jZ8>jZ8>jZ8>jZ8>jZ8>jZ8>jZ8>jZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>gYh:gYh:gYh:g
Yh:gYh:gYh:gYh:gYh:iYh:iYh:hYX6gYH2gYH2hYX6iYh:iYh:hYh2hYh2hYh2hYh2hYh2hYh2hYh2h
Yh2gYH2gYH2gYH2gYH2gYH2gYH2gYH2gYH2hYX6hYX6hYX6hYX6hYX6hYX6hYX6hYX6gYH2gYH2gYH2g
YH2gYH2gYH2gYH2gYH2hYh2hYh2hYh2gYWngYWnfYGjfYGjfYGjgYH2gYH2gYH2gYH2gYH2gYH2gYH2g
YH2gYWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWnfYGjfYGjfYGjg
YWngYWnhYh2hYh2hYh2gYWngYWngYWngYWngYWngYWngYWngYWniZ86iZ86gYWnfYGjfYGjfYGjfYGjg
YWnWW7jSVWnKUX6CTh>ATH>BTX:GTh2JUH2>TH6>TH6?TX:?Th2>TWn=TGj<T7f;Sgb?UH:<TX62QgQM
HEF6RH1]KVZ>Shf/[J^6ShDK91YPJ5iEGE>7S8>d]jjY[:>RYIbWYIZUYIVTYYZW[Z6IXYEQKV0S<R@6
5`TS:1URIU[NhMRg]k6]ZZFVY9ba[jBc/ZBXZYj//:BGXIA9ETPT<B<F81<e>Bg2a;SCe/fi_;>Y[:=^
LFPN8APn@CSGf]7<clJd]J^d]J^d]J^c]:Zc]:Zc]:Zc]:Zc]:Zb]:Rc]JVc]JVc]JVd]ZZd]ZZd]ZZe
]j^a/ZRc]:Ze]Zbe]Zbd]J^c]:Ze]Zbg^:jh^Jng^:jf]jff]jfg^:jh^Jnj^k6k_;:j^k6j^k6k_;:k
_;:l_K>l_K>l_K>l_K>k_;:l_K>l_K>l_K>m_[Bm_[Bm_[Bn_kFn_kFn_kFn_kFn_kFn_kFn_kFn_kFn
_kG1]Y^iZhjiYX>nZX72[H30ZgjmZWnm[86kZH2kZH2kZH2kZH2kZH2kZH2kZH2kZH2jZ7njZ7njZ7nj
Z7njZ7njZ7njZ7njZ7nmZh:mZh:lZX6lZX6kZH2kZH2jZ7njZ7nlYWfmYgjnZ7noZH2oZH2oZH2oZH2n
Z7nkZH2kZH2kZH2kZH2kZH2lZX6lZX6lZX6kZh6m[H>o[hFo[hFm[H>kZh6jZX2kZh6kZH2kZH2kZH2k
ZH2kZH2kZH2kZH2kZH2kZH2lZX6lZX6lZX6mZh:mZh800<:cXl:cXl6bX/6bX/6bX/2aXL2aXL2aXKnb
X[nbX[nbX[nbX[nbX[nbX[nbX[nbX[j`Y;j`Y;j`Y;j`Y;j`Y;j`Y;j`Y;j`Y;jaXKjaXKjaXKjaXKja
XKjaXKjaXKjaXKf`X;f`X;b_Wkf`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`
X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;Z]WK^^W[^^W[^^W[b_Wkb_Wkb_Wkb_Wk^^W[^^W[^^W[^^W[^^
W[^^W[^^W[^^W[^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WKZ^
W;^_WK^_WK^_WKb`W[b`W[b`W[b`W[^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`
W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`
W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;V^V[Z_Vk^`W;^`W;^`W;^`W;Z_VkV^V[V^V[V^V[Z_VkZ_Vk^`
W;^`W;^`W;^`W;Z_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_Vk^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[V/
U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[Z]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]
UkZ]UkZ]UkZ]UkZ_U;Z_U;Z_U;Z_U;Z_U;Z_U;Z_U;Z_U;R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]
T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[NZT;NZT;NZT;NZT;NZ
T;NZT;NZT;NZT;N/TKN/TKR]T[V^TkV^TkR]T[N/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKNZ
T;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;FYSKFYSKFYSKFYSKFY
SKFYSKFYSKFYSKVYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;ZZ
SKZZSKZZSKZZSKZZSKZZSKZZSKZZSKBYRkBYRkBYRkBYRkBYRkBYRkBYRkBYRkRXRkRXRkRXRkRXRkRX
RkRXRkRXRkRXRkJVRKJVRKJVRKNWR[NWR[RXRkRXRkRXRkVYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VZ
R[VZR[VZR[VZR[VZR[VZR[VZR[VZR[NWR[NWR[NWR[NWR[NWR[NWR[NWR[NWR[NXR;NXR;NXR;NXR;NX
R;NXR;NXR;NXR;NYQKNYQKNYQKNYQKNYQKNYQKNYQKNYQKNYQKNYQKNYQKNYQKNYQKNYQKNYQKNYQKNX
R;NXR;NXR;NXR;NXR;NXR;NXR;NXR;VYQKVYQKVYQKVYQKVYQKVYQKVYQKVYQKVYQKVYQKVYQKVYQKVY
QKVYQKVYQKVYQKJXQ;JXQ;NYQKNYQKNYQKRZQ[RZQ[RZQ[RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;VY
QKVYQKVYQKVYQKVYQKVYQKVYQKVYQKRXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RX
Q;RXQ;RXQ;RXQ;RXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkZXPkZXPkZXPkZXPkZXPkZXPkZXPkZXPkRX
PkRXPkRXPkRXPkRXPkRXPkRXPkRXPkNWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[VWP[RVPKNUP;NUP;NU
P;NUP;RVPKVWP[RWP;RWP;RWP;RWP;RWP;RWP;RWP;RWP;NUP;NUP;NUP;NUP;NUP;NUP;NUP;NUP;RV
PKRVPKRVPKRVPKRVPKRVPKRVPKRVPKNUP;NUP;NUP;NUP;NUP;NUP;NUP;NUP;RWP;NVOkNVOkNVOkJU
O[JUO[JUO[JUO[NUP;NUP;NUP;NUP;NUP;NUP;NUP;NUP;NVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNV
OkNVOkNVOkNVOkNVOkNVOkNVOkNVOkJUO[JUO[JUO[JUO[NVOkNVOkRWP;RWP;NVOkNVOkNVOkNVOkNV
OkNVOkNVOkNVOkVXPKRWP;NVOkJUO[JUO[JUO[JUO[NVOkFUPJfPP:BKP9ZEP9BBP9BBP9JDPYRFQ92B
Oi2BOi6CP96CP92BOi2BOhj@OHj@OHV?O8B:NHbAPVmcIemSF61RG;Ri]JFVXX:;PDaDB[Jn];6f[JN/
XjnbZK6bZJn`YjBTV:BTV:JXW:N[WjB]X9FOTUMTEPlL3P/@0E9FB]3Cb[jn^;Fb[JNUWJj/XJj]WjJX
W:FYWJffZH6;OTUCAR4Z7Ca0=;Vk[lO:`KVl/jR[XW]nMCi1>4e@Al74^lS;`[>dZ[>dZ[>dZ[>dZ[>d
Z[>dZ[>dZ[>dZ[:dZ;>eZK>eZK>eZKBfZ[BfZ[BfZ[FgZjj_YK2aYk:cZK:cZK2aYk2aYk6bZ;>dZ[Jg
[KJg[KJg[KJg[KNh[[Ri[kZk/K^l/[Zk/KZk/K^l/[^l/[bm/kbm/kbm/kbm/k^l/[bm/kbm/kbm/kfn
];fn];fn];jo]Kjo]Kjo]Kjo]Kjo]Kjo]Kjo]Kjo]Kjo]LRmYkjaUkRYRK^XP[n/PKn/PKn/PKj/Pk^Y
P;^YP;^YP;^YP;^YP;^YP;^YP;^YP;ZXOkZXOkZXOkZXOkZXOkZXOkZXOkZXOkbZPKbZPKbZPK^YP;^Y
P;^YP;ZXOkZXOkbVOKfWO[jXOknYP;nYP;nYP;jXOkjXOkVWO[ZXOkZXOk^YP;^YP;bZPKbZPKf[P[ZZ
P;b/P[f]Pkf]Pk^[PKVYOkVYOkZZP;^YP;^YP;^YP;^YP;^YP;^YP;^YP;^YP;^YP;^YP;bZPKbZPKbZ
PKf[PP00`K:R`K:R`K:R`;6Q`;6Q`;6Q`;6Q`;6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_JnS_JnS
_JnS_JnS_JnS_JnS_JnS_JnS_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P^jjN^jjN_:nO_K2P_K2P_K2P
_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO^ZfM^ZfM
^ZfM^jjN^jjN_:nO_:nO_:nO^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jnM^jnM^jnM^jnM^jnM^jnM
^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^ZjL^ZjL^ZjL^jnM^jnM_;2N_;2N_;2N^k2L^k2L
^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L
^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^JjJ^JjJ
^ZnK^k2L^k2L^ZnK^JjJ^JjJ^JjJ^JjJ^JjJ^ZnK^ZnK^ZnK^k2L^k2L^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK
^ZnK^ZnK^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^ZfG^ZfG
^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZnD^ZnD^ZnD^ZnD^ZnD^ZnD
^ZnD^ZnD^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA
]jbA]jbA]jbA]jbA]jbA]jbA]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]Z^@]jbA^:fB^:fB^:fB^:fB
]jbA]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?
]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=^JV<^JV<^JV<^JV<^JV<^JV<
^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=]:V;]:V;
]:V;]:V;]:V;]:V;]:V;]:V;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;]ZJ9]ZJ9]jN:]jN:]jN:^:R;
^:R;^:R;^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^:V9^:V9^:V9^:V9^:V9^:V9^:V9^:V9]jN:]jN:
]jN:]jN:]jN:]jN:]jN:]jN:]jR8]jR8]jR8]jR8]jR8]jR8]jR8]jR8]jV5]jV5]jV5]jV5]jV5]jV5
]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jR8]jR8]jR8]jR8]jR8]jR8]jR8]jR8^JV5^JV5
^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5]ZR4]ZR4]ZR4]jV5]jV5]jV5
^:Z6^:Z6^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^:R4^:R4
^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R3^:R3^:R3^:R3^:R3^:R3
^:R3^:R3^ZR3^ZR3^ZR3^ZR3^ZR3^ZR3^ZR3^ZR3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3]jN2]jN2
]jN2]jN2]jN2]jN2]jN2]jN2^:J1^:J1]jF0]ZAo]ZAo]jF0^:J1^:J1]jIo]jIo]jIo]jIo]jIo]jIo
]jIo]jIo]ZAo]ZAo]ZAo]ZAo]ZAo]ZAo]ZAo]ZAo]jF0]jF0]jF0]jF0]jF0]jF0]jF0]jF0]ZAo]ZAo
]ZAo]ZAo]ZAo]ZAo]ZAo]ZAo]jIo]jIo]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZAo]ZAo]ZAo]ZAo]ZAo]ZAo
]ZAo]ZAo]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]JAm]JAm
]ZEn]ZEn]ZEn]jIo]jIo]jIo]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn^:N0]jIo]ZEn]JAm]JAm]ZEn
]ZEn]jIo^jMn]ZAo[YmnYIYnW9IoV9B1Ti>3U9B4Si5mT99nTI>0TI>0TI>0T961Si20Si20PhIfRXem
TIB5MgU]@T<i@T<i]kR_YJJMQhn4BE56UI^@VInDU9R=ZZ^Q]kR^ZJZPYZJJXj>GYZRLXZJJX:NJZ[>V
RI:5@T`o:BhOGF5E_l:i^[Zd]K:]ZjVQ[ZbQZ:NI[;2TW:2DZ[6TXJRKP8MjH6MJJFeQ[;2T^;V_/[>Y
YjRNXJ:HRX^1RX^1^;V_];F[/[>Y/[>Y/[>Y/[>Y/kBZ/kBZ/kBZ/kBZ/[BX/kFY/kFY/kFY];JZ];JZ
];JZ]KN[/K:X/[>Y/K:X[k2V[JjT[ZnU/K:X/kBZ]KJ/]KJ/]KJ/][N]]kR^^KZ`^[^a^[^a^[^a^[^a
^kbb^kbb_;fc_;fc_;fc_;fc^kbb_;fc_;fc_;fc_Kjd_Kjd_Kjd_[ne_[ne_[ne_[ne_[ne_[ne_[ne
_[ne_[nebL>`_kNP^J^>^JJ3^ZQo_Z^0_Jb1_J^2^jV0^jV0^jV0^jV0^jV0^jV0^jV0^jV0^ZQo^ZQo
^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^jV0^jV0^jV0^jV0^jV0^ZQo^ZQo^ZQo^jEl_:Im_JMn_ZQo_jV0_ZQo
_ZQo_ZQo^:Im^:Im^JMn^ZQo^jV0_:Z1_J^2_J^2^ZZ0_:b2_Jf3_:b2^j^1^JUo^ZZ0_:b2^jV0^jV0
^jV0^jV0^jV0^jV0^jV0^jV0^jV0^jV0^jV0_:Z1_:Z1_:Z10030/J70/J70/J70/J70/J70/J70/J70
/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6m[j>m[j>m[j>m[j>m[j>m[j>m[j>m[j>m/:2m/:2m/:2m
/:2m/:2m/:2m/:2m/:2i[9bj[Ifk[Yjm/:2m/:2m/:2l[inl[inl[inl[inl[inl[inl[inl[inl[inl
[inl[inl[inl[inl[inl[inl[inl[inl[ini[9bj[Ifj[Ifj[Ifk[Yjk[Yjk[Yjl[ink[Yjk[Yjk[Yjk
[Yjk[Yjk[Yjk[Yjk[Yjk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifk
[ifi[I^j[Ybj[Ybj[Ybk[ifk[ifk[ifl/9jk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk
/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk
/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bh[IVi[YZj[i^j[i^j[i^j[i^i[YZh[IVh[IVh[IVi[YZi
[YZj[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj
[9Vi[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji
[9Ji[9Ji[9Ji[9Ji[9Ji[Y>i[Y>i[Y>i[Y>i[Y>i[Y>i[Y>i[Y>h[I:h[I:h[I:h[I:h[I:h[I:h[I:h
[I:g[96g[96g[96g[96g[96g[96g[96g[96g[96g[96g[96g[96g[96g[96g[96g[96gZY2gZY2gZY2g
ZY2gZY2gZY2gZY2gZY2fZi2fZi2g[96h[I:h[I:g[96fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2f
Zi2fZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHneZHfeZHfeZHfe
ZHfeZHfeZHfeZHfeZHfiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbi
ZHbjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfcZ8ZcZ8ZcZ8ZcZ8ZcZ8ZcZ8ZcZ8ZcZ8ZgYhZgYhZgYhZg
YhZgYhZgYhZgYhZgYhZgYhZgYhZhZ8^hZ8^hZ8^iZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbi
ZHbgZ8RgZ8RgZ8RgZ8RgZ8RgZ8RgZ8RgZ8RfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYhNfYhNfYhNf
YhNfYhNfYhNfYhNfYhNfZ8BfZ8BfZ8BfZ8BfZ8BfZ8BfZ8BfZ8BfZ8BfZ8BfZ8BfZ8BfZ8BfZ8BfZ8Bf
Z8BfYhNfYhNfYhNfYhNfYhNfYhNfYhNfYhNhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8Bh
Z8BhZ8BhZ8BhZ8BhZ8BeYh>eYh>fZ8BfZ8BfZ8BgZHFgZHFgZHFgYh>gYh>gYh>gYh>gYh>gYh>gYh>g
Yh>hZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BgYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>g
Yh>gYh>gYh>gYh>gYh>gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:iYh:iYh:iYh:iYh:iYh:iYh:iYh:i
Yh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6hYX6gYH2fY7nf
Y7nfY7nfY7ngYH2hYX6gYWngYWngYWngYWngYWngYWngYWngYWnfY7nfY7nfY7nfY7nfY7nfY7nfY7nf
Y7ngYH2gYH2gYH2gYH2gYH2gYH2gYH2gYH2fY7nfY7nfY7nfY7nfY7nfY7nfY7nfY7neY7feY7ffYGjf
YGjfYGjfYGjfYGjfYGjfY7nfY7nfY7nfY7nfY7nfY7nfY7nfY7nfYGjfYGjfYGjfYGjfYGjfYGjfYGjf
YGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjeY7feY7feY7ffYGjfYGjfYGjgYWngYWnfYGjfYGjfYGjf
YGjfYGjfYGjfYGjfYGjfYGjfYGjeY7feY7feY7ffYGjfYGjgYWnhY7^hY7^eXgj_X7nWW82MUh2GTh2@
T82@TWbATgfBTgnCTh6CTh>BTH>BTH>AShB?T82FUhN;Rgf;RgefMVYTI5RUYIV?SXB=ThQ1AcaAEdaF
FTmOH5J5QWbUY9ZDThVNWY:JW92VZ9bWZIfLX9BX[:2SZYf1R7^6Rgb?ThNc]ZfYZJ>WY9nXYYja[jB[
ZYb`]:RPY9RZ[:2_/JF[[J6TYYZNXYJ//:B`[jFa/:J[ZZ2j^Jng]Zbb/JNd/jV^[J>a/ZRa/ZRa/ZRb
/jVb/jVc]:Zc]:Zd]J^b]:Rc]JVc]JVc]JVd]ZZd]ZZd]ZZe]j^h^Jng^:je]Zba/ZR_/:J`/JNd]J^g
^:jc]:Zd]J^e]Zbf]jfh^Jni^[2i^[2j^k6j^k6j^k6k_;:k_;:l_K>l_K>l_K>l_K>k_;:l_K>l_K>l
_K>m_[Bm_[Bm_[Bn_kFn_kFn_kFn_kFn_kFn_kFn_kFn_kFn_kG5`[C0^ZNi/9FfYhJgYWnjZ7nlZX6k
Zh6jZ7njZ7njZ7njZ7njZ7njZ7njZ7njZ7niYgjiYgjiYgjiYgjiYgjiYgjiYgjiYgjjZ7njZ7njZ7nj
Z7njZ7njZ7njZ7njZ7nkYGblYWfmYgjnZ7nnZ7nnZ7nmYgjmYgjgYGbhYWfiYgjjZ7nkZH2lZX6lZX6m
Zh:kZh6l[8:m[H>m[H>kZh6kZh6l[8:n[XBjZ7njZ7njZ7njZ7njZ7njZ7njZ7njZ7njZ7njZ7nkZH2k
ZH2kZH2lZX400;j_Wkn`X;n`X;n`X<2aXL2aXL2aXL2aXKf`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;b^
X[b^X[b^X[b^X[b^X[b^X[b^X[b^X[b_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_WkNZV[V/W;^^W[f`X;ja
XKf`X;b_Wk^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[V/
W;V/W;V/W;Z]WKZ]WK^^W[^^W[^^W[Z]WKZ]WKZ]WKZ]WKZ]WKZ]WKZ]WKZ]WKZ^W;Z^W;Z^W;Z^W;Z^
W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;V]VkV]VkV]VkZ^W;Z^W;^_WK^_WK^_WKZ_
VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_
VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkR]
VKV^V[V^V[Z_VkZ_VkV^V[V^V[R]VKR]VKR]VKR]VKV^V[V^V[Z_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_
VkZ_VkZ_VkZ_VkZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKV/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/
U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V^TkV^TkV^TkV^TkV^
TkV^TkV^TkV^TkR]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[J[T;J[T;J[T;J[T;J[T;J[T;J[T;J[T;J[
T;J[T;J[T;J[T;J[T;J[T;J[T;J[T;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;FZSkJ[T;N/TKN/TKN/
TKN/TKJ[T;FZSkFZSkFZSkFZSkFZSkFZSkFZSkFZSkFZSkFXS[FXS[FXS[FXS[FXS[FXS[FXS[FXS[FX
S[FXS[FXS[FXS[FXS[FXS[FXS[FXS[BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;RXRkRXRkRXRkRXRkRX
RkRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkVYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;>X
R[>XR[>XR[>XR[>XR[>XR[>XR[>XR[NWR[NWR[NWR[NWR[NWR[NWR[NWR[NWR[NWR[NWR[RXRkRXRkVY
S;VYS;VYS;VYS;RXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkJWQkJWQkJWQkJWQkJWQkJWQkJWQkJWQkJV
RKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJWQkJWQkJWQkJWQkJWQkJWQkJWQkJWQkJXQ;JXQ;JXQ;JXQ;JX
Q;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JWQkJWQkJWQkJWQkJWQkJWQkJWQkJWQkRX
Q;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;FWPkFWPkFWPkJXQ;JX
Q;JXQ;NYQKNYQKNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkRXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;NW
PkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWP[NWP[NWP[NWP[NW
P[NWP[NWP[NWP[VWP[VWP[VWP[VWP[VWP[VWP[VWP[VWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[JV
PKJVPKJVPKJVPKJVPKJVPKJVPKJVPKNUP;NUP;JTOkFSO[FSO[JTOkNUP;NUP;JUO[JUO[JUO[JUO[JU
O[JUO[JUO[JUO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[JTOkJTOkJTOkJTOkJTOkJTOkJTOkJTOkFS
O[FSO[FSO[FSO[FSO[FSO[FSO[FSO[BSO;FTOKFTOKFTOKJUO[JUO[JUO[JUO[FSO[FSO[FSO[FSO[FS
O[FSO[FSO[FSO[FTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKBS
O;BSO;FTOKFTOKJUO[JUO[JUO[JUO[FTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKBSO;BSO;FT
OKFTOKNVOkNVOkBQNkFRO;NTO[NTO[:ROZRMOijGOYRCOY2CNY6DNi:DOY>CPI>CPi>BQ9:@QI:@QY6A
PiVIRhJ6N92@PYFEQh20LY>CQHf=OhZAQ7^2MIBHS9^MTHB6NX>3MiJFRXn=PXj@Q9:DR::TV:Z/X:>U
VJ:TV:RZWZNYWJfbXj:VVZNZXJJVX:RUX:^YXK:`YJJUUj:YW:N[Wjf]XJj/XK:`YKJfZ[2dZ:^bYJn_
XkBdZ;2`Y;Zj[Zf]XK6aYJn_XkVi[K2aYk2aYk6bZ;6bZ;:cZK>dZ[>dZ[BeZk:dZ;>eZK>eZK>eZKBf
Z[BfZ[BfZ[FgZkFf[;Ff[;BeZk:cZJn`YZj_YJn`Y[:cZK6bZ;:cZKBeZkJg[KRi[kVj/;Vj/;Vj/;Zk
/KZk/K^l/[^l/[bm/kbm/kbm/kbm/k^l/[bm/kbm/kbm/kfn];fn];fn];jo]Kjo]Kjo]Kjo]Kjo]Kjo
]Kjo]Kjo]Kjo]Kbm/l2m[kngX;N/S[FUP;NVOkZZP;ZZP;ZXOkZXOkZXOkZXOkZXOkZXOkZXOkZXOkVW
O[VWO[VWO[VWO[VWO[VWO[VWO[VWO[VWO[VWO[VWO[VWO[ZXOkZXOkZXOk^YP;^UO;^UO;bVOKfWO[jX
OkjXOkfWO[fWO[RVOKRVOKVWO[VWO[ZXOk^YP;^YP;^YP;^[PKb/P[f]Pkb/P[^[PK^[PKf]Pl2`Q[ZX
OkZXOkZXOkZXOkZXOkZXOkZXOkZXOkZXOkZXOkZXOk^YP;^YP;^YP000_ZnO_ZnO_ZnO_k2P_k2P`;6Q
`;6Q`K:R_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_:jR_:jR_:jR_:jR_:jR_:jR_:jR_:jR_:nO_:nO
_:nO_:nO_:nO_:nO_:nO_:nO]ZVI^:^K^ZfM_K2P_[6Q_K2P_:nO^jjN^jjN^jjN^jjN^jjN^jjN^jjN
^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^JbL^JbL^JbL^ZfM^ZfM^ZfM^jjN^jjN^ZfM^ZfM
^ZfM^ZfM^ZfM^ZfM^ZfM^ZfM^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL
^ZjL^ZjL^JfK^JfK^JfK^ZjL^ZjL^ZjL^jnM^jnM^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK
^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK
^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^:fI^:fI^JjJ^ZnK^ZnK^JjJ^:fI^:fI^:fI^:fI
^:fI^:fI^JjJ^JjJ^JjJ^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^J^H^J^H^J^H^J^H^J^H^J^H
^J^H^J^H^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^:^E^:^E^:^E^:^E^:^E^:^E^:^E^:^E^:^E^:^E
^:^E^:^E^:^E^:^E^:^E^:^E^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB
^:fB^:fB]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]jZ@]jZ@
]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]JZ?]Z^@]Z^@]jbA]jbA]Z^@]Z^@]JZ?]JZ?]JZ?]JZ?]JZ?]JZ?]JZ?
]JZ?]JZ?]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]:R<]:R<
]:R<]:R<]:R<]:R<]:R<]:R<^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;
^:R;^:R;]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jN:/jR:/jR:/jR:/jR:/jR:/jR:/jR:/jR:]jN:]jN:
]jN:]jN:]jN:]jN:]jN:]jN:]ZJ9]ZJ9]ZJ9]jN:]jN:]jN:^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;
^:R;^:R;]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JJ6]JJ6
]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JN3]JN3]JN3]JN3]JN3]JN3]JN3]JN3]JN3]JN3]JN3]JN3]JN3]JN3
]JN3]JN3]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3
]jN3]jN3]jN3]jN3]jN3]jN3]:J2]JN3]JN3]JN3]ZR4]ZR4]ZR4]jV5]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2
]ZJ2]ZJ2]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2
]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1^:J1^:J1^:J1^:J1^:J1^:J1
^:J1^:J1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]JF0]JF0]JF0]JF0]JF0]JF0]JF0]JF0]jF0]ZAo
]ZAo]J=n]J=n]ZAo]ZAo]jF0]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]J=n]J=n]J=n]J=n]J=n]J=n
]J=n]J=n]ZAo]ZAo]ZAo]ZAo]ZAo]ZAo]ZAo]ZAo]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]:=l]:=l
]:=l]JAm]JAm]ZEn]ZEn]ZEn]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]JAm]JAm]JAm]JAm]JAm]JAm
]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]:=l]:=l]:=l]JAm]JAm]ZEn]ZEn]ZEn]JAm]JAm
]JAm]JAm]JAm]JAm]JAm]JAm]JAm]:=l]:=l]:=l]:=l]JAm]jIo]jIo/j=o]ZAo^ZIm_:Il^JEl/J5m
ZIj0Y9^0TY=iTi=kU9=nUIB0UY>4UY:7UI27UI27S8]mU9>5T8n1SHemR8QhQHEeRh]kUYJ6S924Rhn3
Qh]oVifAXJ6EW9b@X9jCTY25Rhf1TI>7UIN;WZ2DZZZNYZJJXj>G[JfQXZNHW:2DWj:I/;2Z[jbW[:ZR
/:jSY:>EVj:E[K6UZjVNZZJK/JfR[J^PZJfQZ[6T[jfR];:W/[2U^;J[XZ2E];:W/:jS^kV^[k2V[k2V
/;6W/K:X/[>Y/kBZ/kBZ];F[/[BX/kFY/kFY/kFY];JZ];JZ];JZ]KN[/;6W];F[^KZ`^KZ`][N]/K:X
[JjTZjbR/;6W/K:X];F[][N]^;V_^KZ`^KZ`^KZ`^[^a^[^a^kbb^kbb_;fc_;fc_;fc_;fc^kbb_;fc
_;fc_;fc_Kjd_Kjd_Kjd_[ne_[ne_[ne_[ne_[ne_[ne_[ne_[ne_[ne][Rb`<2daKn/_K:F]JN3]jIo
^ZZ0_:b2^JMn^JMn^JMn^JMn^JMn^JMn^JMn^JMn^:Im^:Im^:Im^:Im^:Im^:Im^:Im^:Im^:Im^:Im
^JMn^JMn^ZQo^ZQo^jV0^jV0^ZAk^jEl_:Im_JMn_JMn_JMn_JMn_:Im^JMn^JMn^JMn^JMn^JMn^ZQo
^ZQo^ZQo^ZZ0^j^1^j^1^ZZ0^JUo^JUo_:b2_jn5^JMn^JMn^JMn^JMn^JMn^JMn^JMn^JMn^JMn^ZQo
^ZQo^ZQo^jV0^jV0002m[Yjm[Yjn[ino/:2o/:30/J70/J71/Z:m/:2m/:2m/:2m/:2m/:2m/:2m/:2m
/:2l[Z:l[Z:l[Z:l[Z:l[Z:l[Z:l[Z:l[Z:l[inl[inl[inl[inl[inl[inl[inl[ineZ9RgZYZj[Ifm
/:2n/J6m/:2l[ink[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk
[YjhZi^i[9bi[9bi[9bj[Ifj[Ifj[Ifk[Yjj[Ifj[Ifj[Ifj[Ifj[Ifj[Ifj[Ifj[Ifj[Ybj[Ybj[Ybj
[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybh[9Zi[I^i[I^i[I^j[Ybj[Ybj[Ybk
[ifj[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j
[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j
[i^g[9Rh[IVi[YZi[YZi[YZi[YZh[IVg[9Rg[9Rh[IVh[IVh[IVi[YZi[YZi[YZi[YZj[i^j[i^j[i^j
[i^j[i^j[i^j[i^j[i^iZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRi[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji
[9JhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFh[I:h[I:h[I:h
[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:fZi2fZi2fZi2fZi2fZi2fZi2fZi2f
Zi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2eZXnfZi2fZi2g
[96g[96fZi2fZi2eZXneZXneZXneZXneZXneZXneZXneZXneZXneZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8je
Z8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bhZ8^hZ8^hZ8^h
Z8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^fYXVfYXVfYXVfYXVfYXVfYXVfYXVf
YXVbYhVbYhVbYhVbYhVbYhVbYhVbYhVbYhVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVdY8NdY8NeYHRe
YHReYHRfYXVfYXVfYXVhZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^eYXJeYXJeYXJeYXJeYXJeYXJeYXJe
YXJeYHReYHReYHReYHReYHReYHReYHReYHReYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYh>eYh>eYh>e
Yh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>eYXJeYXJeYXJeYXJeYXJeYXJeYXJe
YXJgYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>dYX:dYX:eYh>e
Yh>eYh>fZ8BfZ8BfZ8BfYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:gYh>gYh>gYh>gYh>gYh>gYh>gYh>g
Yh>fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX6fYX6fYX6f
YX6fYX6fYX6fYX6fYX6hYX6hYX6hYX6hYX6hYX6hYX6hYX6hYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6f
YX6eYH2eYH2eYH2eYH2eYH2eYH2eYH2eYH2gYH2fY7nfY7neXgjeXgjfY7nfY7ngYH2fYGjfYGjfYGjf
YGjfYGjfYGjfYGjfYGjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjfY7nfY7nfY7nfY7nfY7nfY7nfY7nf
Y7neXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjcXW^cXW^dXgbdXgbeY7ffYGjfYGjfYGjeXgjeXgjeXgje
XgjeXgjeXgjeXgjeXgjeY7feY7feY7feY7feY7feY7feY7feY7feY7feY7feY7feY7feY7feY7feY7fe
Y7fdXgbdXgbdXgbeY7feY7feY7ffYGjfYGjeY7feY7feY7feY7feY7feY7feY7feY7fdXgbdXgbcXW^c
XW^dXgbeY7fgYWngYWnbYHFfYX:jYWfmYWVmYWViYGbdY82`Xh>BTgVCU7ZDTgjEU82FThBFTXNFTHRE
ShR?SX2=S7jJVH^FUXJ=SGfJVXR?Sgf6QWB8SGjDVHZ1Q7F?TX>FUXR?SX2DThFAT8:AThNEUh^8RWj<
SX:YZIf[ZinQWiBYYib//J:VZYjRYIba/J^WY9nSXIVa[jB_[Z2PZIbd^:bXYY^]Yibk]JZ^[:6VZYj[
]:N/Zif/Zif_[Z2l^jfZZI_5a;Jd/jF`[j6^[jF_/:J`/JNa/ZRb/jVc]:Zc]:Zd]J^b]:Rc]JVc]JVc
]JVd]ZZd]ZZd]ZZe]j^e]Zbl_K?5a[c9b/36akfm_[Bd]J^^[jF_/:Ja/ZRd]J^f]jfh^Jni^[2i^[2i
^[2j^k6j^k6k_;:k_;:l_K>l_K>l_K>l_K>k_;:l_K>l_K>l_K>m_[Bm_[Bm_[Bn_kFn_kFn_kFn_kFn
_kFn_kFn_kFn_kFn_kFa]K30`KO9aK?3^9fhZHRhYh2kZX>m[H>iYgjiYgjiYgjiYgjiYgjiYgjiYgji
YgjhYWfhYWfhYWfhYWfhYWfhYWfhYWfhYWfgYGbhYWfhYWfiYgjiYgjjZ7nkZH2kZH2jY7^kYGblYWfm
YgjmYgjmYgjmYgjlYWfjZ7njZ7niYgjiYgjiYgjiYgjiYgjiYgjhZ7jiZGniZGnhZ7jgYgfhZ7jkZh6n
[XBiYgjiYgjiYgjiYgjiYgjiYgjiYgjiYgjiYgjiYgjjZ7njZ7njZ7nkZH000;j`W[j`W[j`W[j`W[j`
W[j`W[j`W[j`W[n`X;n`X;n`X;n`X;n`X;n`X;n`X;n`X;b_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb`
W[b`W[b`W[b`W[b`W[b`W[b`W[b`W[^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WKZ^W;Z^W;Z^W;^_WK^_
WK^_WKb`W[b`W[Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^
W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^
W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;b^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^
Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^VkZ/VKZ/VKZ/VKZ/VK^]
V[^]V[^]V[b^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vk^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]
V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^^V;^^V;^^V;^^V;^^V;^^V;^^V;^^V;V[V;V[V;V[V;V[V;V[
V;V[V;V[V;V[V;V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[R[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKZ]
UkZ]UkV/U[V/U[R[UKNZU;NZU;NZU;V/T[V/T[V/T[V/T[V/T[V/T[V/T[V/T[R[TKR[TKR[TKR[TKR[
TKR[TKR[TKR[TKNZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;N[SkN[SkN[SkN[SkN[SkN[SkN[SkN[SkJY
SkJYSkJYSkJYSkJYSkJYSkJYSkJYSkBXS;FYSKFYSKJZS[JZS[N[SkN[SkR/T;JYSkJYSkJYSkJYSkJY
SkJYSkJYSkJYSkFYSKFYSKFYSKFYSKFYSKFYSKFYSKFYSKFYSKFYSKFYSKFYSKFYSKFYSKFYSKFYSKVY
S;VYS;VYS;RXRkNWR[NWR[JVRKJVRKRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkNWR[NWR[NWR[NWR[NW
R[NWR[NWR[NWR[NWR[NWR[NWR[NWR[NWR[NWR[NWR[NWR[NXR;NXR;NXR;NXR;NXR;NXR;NXR;NXR;FV
Q[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[NXR;JWQkFVQ[BUQKBUQKFVQ[JWQkNXR;FVQ[FVQ[FVQ[FVQ[FV
Q[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[BUQKBUQKBUQKBUQKBUQKBUQKBUQKBUQKBU
QKBUQKBUQKBUQKBUQKBUQKBUQKBUQKJVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JV
P[JVP[JVP[JVP[FUPKFUPKJVP[JVP[NWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkJV
P[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[BTP;FUPKJVP[NWPkRX
Q;NWPkNWPkJVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[VYQKJVP[BTP;BTP;JVP[NWPkNWPkJVP[JV
PKJVPKJVPKJVPKJVPKJVPKJVPKJVPKRVPKRVPKNUP;JTOkJTOkNUP;RVPKRVPKNVOkNVOkNVOkNVOkNV
OkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkJUO[JUO[JUO[JUO[JUO[JUO[JUO[JUO[JU
O[JUO[JUO[JUO[JUO[JUO[JUO[JUO[FTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKBSO;BSO;BSO;FTOKFT
OKJUO[JUO[JUO[BSO;BSO;BSO;FTOKFTOKJUO[JUO[JUO[BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BS
O;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BS
O;BSO;BSO;BSO;BSO;BSO;BSO;FRO;NRO;NRO;VRO;VRO;FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FS
N[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FSN[FS
N[FSN[FSN[FSNZbSOZNNO:2HNYNCNY6@O8f@PHf@QhfARhnAQHnAQHnAQI2@PY2@PY6API2@P92@P8^:
O8b;OHf<OXj=Oi2?PI6@PY:APi>BQ96DQI2CQ92CQ8nBPi6DQINJRinRTjJYVZJXW:JXW:NYWJRZWZV[
WjZ/X:^]XJ^]XJF/WJ6XVjnfZJb`YJN[X:j_YZj_Y/;2_;_1_:ne/<;8`l77`[k4_lO=b;g3_[_1_=7>
b]3=bMoNf/K5`M;CcmOHe=7Ed;k2_KBd[[Jc[[Jb[KRb[KFa[;:b[:faZjZbZkS9_]7Oe=3Hc];Ec>cZ
h/2n]Zn`YkVl/jnaYJnaYK2bY[:dZ;BfZ[Jh[;Vk[kZl/;Ri[kRi[kVj/;Zk/KZk/KZk/KVj/;Ri[kbm
/kbm/kbm/kbm/kfn];fn];fn];jo]Kjo]Ko0][o0][o0][jo]Kfn];bm/k^l/[bi/L6n]/?1]l6l[K^c
W;JYRKRVOKfVN;FSN[JTNkRVOKVWO[VWO[RVOKJTNkFSN[bWN[bWN[bWN[bWN[bWN[bWN[bWN[bWN[RX
N[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[VYNkVYNkVYNkVYNkVY
NkVYNkVYNkVYNkVWO[ZXOk^YP;ZXOkVWO[^YP;j/Pl6_Q[f[P[^YP;VWO[NUO;JTNkRVOKZXOk^YP<:`
Qkn]Q;bZPKVWO[NUO;NUO000_[2N_[2N_[2N_[2N_[2N_[2N_[2N_[2N_k2P_k2P_k2P_k2P_k2P_k2P
_k2P_k2P_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N^jnM^jnM
^jnM^jnM^jnM^jnM^jnM^jnM^ZjL^ZjL^ZjL^ZjL^jnM^jnM_;2N_;2N^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL
^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL
^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL
^ZjL^ZjL_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK
_:jK_:jK_:jK_:jK_:jK_:jK^J^H^ZbI^ZbI^ZbI^jfJ^jfJ^jfJ^jfJ_:jK_:jK_:jK_:jK_:jK_:jK
_:jK_:jK^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZfG^ZfG
^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^JbF^JbF^JbF^JbF^JbF^JbF
^JbF^JbF^:^E^:^E^:^E^:^E^:^E^:^E^:^E^:^E^ZfG^JbF^JbF^:^E^:^E]jZD]jZD]jZD^JbB^JbB
^JbB^JbB^JbB^JbB^JbB^JbB^:^A^:^A^:^A^:^A^:^A^:^A^:^A^:^A]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@
]jZ@]jZ@]j^?]j^?]j^?]j^?]j^?]j^?]j^?]j^?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]:R<]JV=
]JV=]JV=]ZZ>]j^?]j^?]j^?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]JV=]JV=]JV=]JV=]JV=]JV=
]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=^JV<^JV<^:R;^:R;]jN:]jN:]ZJ9]ZJ9^:R;^:R;
^:R;^:R;^:R;^:R;^:R;^:R;]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9
]ZJ9]ZJ9]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]jR8]ZN7
]JJ6]:F5]:F5]JJ6]ZN7]jR8]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6
]JJ6]JJ6]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]ZJ2]ZJ2
]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]JF1]JF1]ZJ2]ZJ2]ZJ2]jN3
]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2
]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]:B0]JF1]ZJ2]jN3]jN3]jN3]jN3]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2
]ZJ2]ZJ2^:R4]ZJ2]:B0]:B0]ZJ2]jN3]jN3]ZJ2]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1^:J1]jF0
]jF0]ZAo]ZAo]jF0]jF0^:J1]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo
]jIo]jIo]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]JAm]JAm
]JAm]JAm]JAm]JAm]JAm]JAm]:=l]:=l]:=l]JAm]JAm]JAm]ZEn]ZEn]:=l]:=l]:=l]JAm]JAm]JAm
]ZEn]ZEn]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l
]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]J9l]j9l]j9l
^J9l^J9l]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j
]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j/:Al[:5kY9]iW9IiUi=kTi5o
TI63TI>7TY:4TI63TI63TI63T922TI61TI61T920S8]mS8]mSHanShj0T8n1TI22TY63Ti:4T9>4T9>4
T9>4Si:3TIB5UIR9W9n@XZFFZ:ZNZ:ZNYjVMYjVMYjVMZ:ZNZZbPZjfQ/;NXXjZMZ:bPX:BIXjNL/[F/
][N^alO1emkIcmKAbm;=a<_6`l[5bm;=cmKAe]gH`<Bo_L6la<S3[K6//kB`_[nkgMkJc/o;];F/]K>[
][>[^;:[]K:Z/K:Y[K:YZ[>YIWM/HW1UH6QNQXV0fmWAblW1/[>Z[K2W[k6U/;:V/;:V/K>W/kFY][R/
^;Z^^K^_^;V_^KZ`^[^a^[^a^kbb^[^a^[^a^KZ`^kbb_;fc_;fc_;fc_Kjd_Kjd_Kjd_Kjd_[ne_[ne
_l2f_l2f_[ne_Kjd_;fc^kbb_KZb_kfe`Kne`;f__;FQ^:f?^JR1^ZEh]J=j]ZAk^:Im^JMn^JMn^:Im
]ZAk]J=j_:Mj_:Mj_:Mj_:Mj_:Mj_:Mj_:Mj_:Mj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj
^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^JUk^JUk^JUk^JUk^JUk^JUk^JUk^JUk^JMn^ZQo^jV0^ZQo^JMn^jV0
_Zb3`Jn6_J^2^jV0^JMn]jEl]ZAk^:Im^JMn^jV0`:j5_Zb3^jV0^:Im]jEl]jEl002m[ifm[ifm[ifm
[ifm[ifm[ifm[ifm[ifo/:2o/:2o/:2o/:2o/:2o/:2o/:2o/:2k[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk
[Yjk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybi[I^i[I^j[Ybj
[Ybk[ifk[ifk[ifk[ifi[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i
[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i
[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^k[IZk[IZk[IZk[IZk[IZk[IZk[IZk
[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZiZiRiZiRiZiRj
[9Vj[9Vk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj
[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[INj[INj[INj[INj[INj[INj[INj[INiZiRiZiRiZiRi
ZiRiZiRiZiRiZiRiZiRi[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9JhZiFhZiFhZiFhZiFhZiFhZiFhZiFh
ZiFi[9Ji[9JhZiFhZiFhZiFgZYBgZYBgZYBi[9:i[9:i[9:i[9:i[9:i[9:i[9:i[9:hZi6hZi6hZi6h
Zi6hZi6hZi6hZi6hZi6gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZhngZhngZhngZhngZhngZhngZhng
ZhneZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jdZ8beZHfeZHfeZHffZXjfZXjfZXjfZXjeZ8jeZ8jeZ8je
Z8jeZ8jeZ8jeZ8jeZ8jdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bd
Z8bhZ8^hZ8^hZ8^gYhZgYhZgYhZfYXVfYXVgYhZgYhZgYhZgYhZgYhZgYhZgYhZgYhZfYXVfYXVfYXVf
YXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYhNfYhNfYhNfYhNfYhNfYhNfYhNf
YhNeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJfYhNeYXJeYXJdYHFdYHFeYXJeYXJfYhNeYXJeYXJeYXJe
YXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJdYHFdYHFdYHFdYHFdYHFdYHFdYHFd
YHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFfYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:f
YX:fYX:fYX:fYX:fYX:eYH6eYH6eYH6fYX:fYX:fYX:gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>g
Yh>fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:dY82eYH6fYX:g
Yh>gYh>gYh>fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:hZ8BfYX:dY82dY82fYX:gYh>gYh>e
YH6fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6hYX6gYH2fY7nfY7nfY7nfY7ngYH2hYX6gYWngYWngYWng
YWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWnfYGjfYGjfYGjfYGjfYGjfYGjfYGjf
YGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbcXW^dXgbdXgbd
XgbeY7feY7feY7feY7fcXW^dXgbdXgbdXgbeY7feY7feY7feY7fcXW^cXW^cXW^cXW^cXW^cXW^cXW^c
XW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^c
XW^cXW^cXW^cXW^cXW^cXgVcXgVcXgVdXWVfXWVfXWVhXWVhXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVd
XWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVdXWVd
XWVdXWVdXWVdXWVdXWVfYWRcXgR/X7RXW7ZPV7^MUWfIU7nGTh2CTh>CTh>BTX:BTX:BTX:ATH6ATH6A
TH6=S7j=S7j>SGn?SX2@Sh6AT8:BTH>CTXB>TH:?TX>@ThB@ThBAU8FCUXNHVhbLWi2WZIfWZIfWZIfW
ZIfXZYjXZYjYZinYZin^/jBSYi^//:BX[:6[[jBXZj:5R7mfN79SKVIZMFeHHe]BGEE@Fe=3CTI3CTI3
CTHf@c/d@CTg@SXe?CI1ACmXJVC<c<K;blFc]:^e/j^e/ZZg/JZe/ZZa/ZV]/ZVZ/jTiBSlI9a`J8QQI
G5?He/kFe<bf]jjZ[JB`/ZJ`/ZJ`/ZJa/jNc]JVe]j^g^Jfh^Zjh^Jni^[2j^k6k_;:l_K>k_;:k_;:j
^k6k_;:k_;:k_;:l_K>l_K>m_[Bm_[Bm_[Bm_[Bn_kFn_kFn_kFn_kFm_[Bl_K>k_;:l^k6m_;:m_;:n
_Jo0^ZNn/iNjZXJfXgffY7^gYGbgYGbhYWfhYWfgYGbgYGbfY7^lYgZlYgZlYgZlYgZlYgZlYgZlYgZl
YgZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZiZG^iZG^iZG^i
ZG^iZG^iZG^iZG^iZG^iYgjjZ7nkZH2kZH2jZ7njZ7nmZh:o[HBlZX6kZH2iYgjgYGbgYGbgYGbiYgjj
Z7nmZh:kZH2iYgjhYWfgYGbhYWd00;f_WKf_WKf_WKf_WKf_WKf_WKf_WKf_WKj_Wkj_Wkj_Wkj_Wkj_
Wkj_Wkj_Wkj_Wk^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WKZ^
W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;V]VkV]VkV]VkZ^W;Z^W;Z^W;^_WK^_WKV]VkV]VkV]VkV]VkV]
VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]
VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]
VkV]VkV]VkV]Vk^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]
V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[V[V;V[V;V[V;V[V;Z/VKZ/VK^]V[^]V[^]V[^]V[^]V[^]V[^]
V[^]V[^]V[^]V[Z/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ]
UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkV[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V/U[V/U[V/U[V/U[V/
U[V/U[V/U[V/U[NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;R[UKR[UKR[UKNZU;NZU;NZU;NZU;NZU;R[
TKR[TKR[TKR[TKR[TKR[TKR[TKR[TKNZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;JYSkJYSkJYSkJYSkJY
SkJYSkJYSkJYSkJZS[JZS[JZS[JZS[JZS[JZS[JZS[JZS[FXS[FXS[FXS[FXS[FXS[FXS[FXS[FXS[FY
SKFYSKFYSKFYSKFYSKFYSKFYSKFYSKFXS[FXS[FXS[FXS[FXS[FXS[FXS[FXS[BXS;BXS;BXS;BXS;BX
S;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;NWR[NWR[NWR[NWR[NWR[NWR[JVRKJVRKNW
R[NWR[NWR[NWR[NWR[NWR[NWR[NWR[JVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJV
RKJVRKJVRKJVRKJWQkJWQkJWQkJWQkJWQkJWQkJWQkJWQkFVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FV
Q[FVQ[BUQKBUQKBUQKBUQKFVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FV
Q[FVQ[FVQ[FVQ[>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;FU
PKFUPKFUPKFUPKFUPKFUPKFUPKFUPKFUPKFUPKFUPKFUPKFUPKFUPKFUPKFUPKBTP;BTP;FUPKFUPKJV
P[JVP[JVP[JVP[NWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkFUPKFUPKFUPKFUPKFUPKFUPKFUPKFUPKFU
PKFUPKFUPKFUPKFUPKFUPKFUPKFUPK>SOkBTP;FUPKJVP[NWPkJVP[JVP[FUPKFUPKFUPKFUPKFUPKFU
PKFUPKFUPKFUPKRXQ;FUPK>SOkBTP;FUPKNWPkJVP[FUPKFUP;FUP;FUP;FUP;FUP;FUP;FUP;FUP;NU
P;NUP;JTOkFSO[FSO[JTOkNUP;NUP;JUO[JUO[JUO[JUO[JUO[JUO[JUO[JUO[JUO[JUO[JUO[JUO[JU
O[JUO[JUO[JUO[FTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKBS
O;BSO;BSO;BSO;BSO;BSO;BSO;BSO;>RNk>RNk>RNkBSO;BSO;FTOKFTOKFTOK>RNk>RNk>RNkBSO;BS
O;FTOKFTOKFTOK>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>R
Nk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>SNK>SNK>SNKBRNKJR
NKJRNKRRNKRRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBR
NKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKZVM[NUM[BSN;6PNJ^M
NJFJNZ:GNj6FNiNCP9FCPIFCPIBBP9:BPY:BPY2@PY2@PXj=Ohj=Ohn>P92?PI2?PI6@PY:APi:APhf@
PHnBPi2CQ96DQI2CQ96DQIBGR9JIRYnQUJ6SUjFWVjRZWZZ/X:Z/X:V[WjRZWZZ]WZBVV[:dZ;6eZ[6e
ZYNLTdeBBA/O6@PE3APU7@TF3PhK4aHS6`XG3`dJ4P`I4@lS5`dN4`PH3A0K4AHN54Q;@]KDc=[Hd;:c
ZKBcZKFcZKNbZKBbZ;6bZ:fcZ:ZdZ3a=@Q0N4adU6eQKD]gKdmCBb[Ff[KFh[k6cYk6cYk6cYk6cYk:d
Z;BfZ[FgZkJh[;Ri[kVj/;Zk/K^l/[bm/kbm/kbm/k^l/[^l/[^l/[^l/[^l/[bm/kbm/kfn];fn];bm
/kfn];fn];jo]Kjo]Kfn];bm/k^l/[fl/[^j/;Vj/;fm/L:m[/6iX[^]T;FTPkNUO;NUO;NUO;NUO;NU
O;NUO;NUO;NUO;^VNK^VNK^VNK^VNK^VNK^VNK^VNK^VNKNWNKNWNKNWNKNWNKNWNKNWNKNWNKNWNKNW
NKNWNKNWNKNWNKNWNKNWNKNWNKNWNKRXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RVOKZXOk^YP;^YP;ZX
OkZXOkbZPKj/Pk^YP;ZXOkRVOKNUO;NUO;NUO;RVOKVWO[ZXOkVWO[RVOKNUO;NUO;RVO@00_JnM_JnM
_JnM_JnM_JnM_JnM_JnM_JnM_ZnO_ZnO_ZnO_ZnO_ZnO_ZnO_ZnO_ZnO^jjN^jjN^jjN^jjN^jjN^jjN
^jjN^jjN^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^:bJ^:bJ
^JfK^JfK^ZjL^ZjL^ZjL^ZjL^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ
^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ
^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI
^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^:ZG^:ZG
^J^H^J^H^J^H^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^J^H^J^H^J^H^J^H^J^H^J^H
^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^:ZG^:ZG
^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:^E^:^E^:^E^:^E^:^E^:^E^:^E^:^E]jZD]jZD]jZD]jZD]jZD]jZD
]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD^:^A^:^A^:^A^:^A^:^A^:^A^:^A^:^A]jZ@]jZ@
]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>
]ZZ>]ZZ>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JV=]JV=]JV=]JV=]:R<]:R<]:R<]:R<]JR>]JR>
]JR>]JR>]JR>]JR>]JR>]JR>/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;
/jN;/jN;]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]jN:]jN:]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]JF8]JF8
]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6
]JJ6]JJ6]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5
]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5/jB4/jB4/jB4/jB4/jB4/jB4
/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1
]JF1]JF1]JF1]JF1]JF1]JF1]:B0]:B0]:B0]JF1]JF1]JF1]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2
]ZJ2]ZJ2]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1/j=o]:B0
]JF1]ZJ2]ZJ2]ZJ2]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]jN3]JF1/j=o/j=o]JF1]ZJ2
]ZJ2]JF1]JF0]JF0]JF0]JF0]JF0]JF0]JF0]JF0]jF0]ZAo]J=n]J=n]J=n]J=n]ZAo]jF0]ZEn]ZEn
]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]JAm]JAm]JAm]JAm]JAm]JAm
]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l/Z5j/j9k
/j9k/j9k]:=l]:=l]:=l]JAm/Z5j/j9k/j9k/j9k]:=l]:=l]:=l]JAm/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j
/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j
/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z9g/Z9g/Z9g/j9g]J9g]J9g]j5g]j5g/j5h/j5h/j5h/j5h/j5h/j5h
/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h
/j5h/j5h/j5h/j5h/j5h/j5h^jIc^JEe]jEf]:=h/Z5j[YijZIYiZ9UiVYF0VYF0Ui>0Ui>0UI>1TY:2
TI63TI63Shj0Shj0T8n1T8n1TI22TI22TY63TY63S8n0Si:3TIB5TIB5T9>4T9>4TIB5TiJ7TiF9VI^?
XJ>GZ:ZN[:jR[:jRZZbPYjVM/k>UZJVM[:jRYZZO[;2UVIjEBU983aH?2A@:4A`B31L=3AP>3aX@3QT?
5b8H72LM3B0A3Ah@3ah@72HI7B@G@48f_[jb_K^`/K:X/k:X];:X][6X];:X/K:X[K>XZ[BX?4e21aD:
7BDKCU58fMO?d<k6/kB[^[fd/[BX/K>W/K>W/K>W/K>W/kFY];JZ]KN[]kR^^;V_^KZ`^kbb_;fc_;fc
_;fc_;fc^[^a^[^a^kbb^kbb^kbb_;fc_;fc_;fc^kbb_;fc_;fc_Kjd_Kjd_Kjd_;fc_;fc_Kfa^;Z^
]kR^^kbb`;na`[^Z^k2J]:N=]jEl]jEl]jEl]jEl]jEl]jEl]jEl]jEl^jIi^jIi^jIi^jIi^jIi^jIi
^jIi^jIi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi^:Qj^:Qj
^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Im^ZQo^jV0^jV0^ZQo^JMn^ZQo_:Z1^ZQo^JMn^:Im]jEl]jEl]jEl
]jEl]jEl]jEl]jEl]jEl]jEl]jEl^:Im002l[Ybl[Ybl[Ybl[Ybl[Ybl[Ybl[Ybl[Ybm[Yjm[Yjm[Yjm
[Yjm[Yjm[Yjm[Yjm[Yjj[Ifj[Ifj[Ifj[Ifj[Ifj[Ifj[Ifj[Ifj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj
[Ybi[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^h[9Zh[9Zh[9Zi[I^i[I^j[Ybj[Ybj[Ybh[9Zh[9Zh[9Zh
[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh
[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh
[9Zh[9Zh[9Zh[9Zh[9Zj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj
[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9VhZYNhZYNhZYNhZYNiZiRiZiRj[9Vj[9Vj[9Vj[9Vj[9Vj
[9Vj[9Vj[9Vj[9Vj[9ViZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRi
ZiRi[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9JhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZiFhZiFhZiFh
ZiFhZiFhZiFhZiFhZiFfZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>eZ9:fZI>fZI>fZI>gZYBgZYBgZYBg
ZYBgZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2fZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHneZ8jeZ8jeZ8je
Z8jeZ8jeZ8jeZ8jeZ8jeZHfeZHfeZHfeZHfeZHfeZHfeZHfeZHfdYhfdYhfdYhfdYhfdYhfdYhfdYhfd
YhfeZHfeZHfeZHfdZ8bdZ8bdZ8bcYh^cYh^dYhfdYhfdYhfdYhfdYhfdYhfdYhfdYhfcYh^cYh^cYh^c
Yh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^eYHReYHReYHRfYXVfYXVfYXVgYhZg
YhZfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVeYHReYHReYHReYHReYHReYHReYHReYHReYHReYHReYHRe
YHReYHReYHReYHReYHReYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJdYHFdYHFdYHFdYHFdYHFdYHFdYHFd
YHFcY8BcY8BdYHFeYXJeYXJdYHFcY8BcY8BdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFd
YHFdYHFdYHFdYHFdYHFbXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>b
Xh>dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82cXgndY82dY82d
Y82eYH6eYH6eYH6eYH6fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:dY82dY82dY82dY82dY82dY82dY82d
Y82dY82dY82dY82dY82dY82dY82dY82dY82bXWjcXgndY82eYH6fYX:eYH6eYH6dY82dY82dY82dY82d
Y82dY82dY82dY82dY82gYh>eYH6bXWjcXgndY82fYX:eYH6dY82dY7ndY7ndY7ndY7ndY7ndY7ndY7nd
Y7nfY7nfY7neXgjdXWfdXWfeXgjfY7nfY7neY7feY7feY7feY7feY7feY7feY7feY7feY7feY7feY7fe
Y7feY7feY7feY7feY7fdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbd
XgbcXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^bXGZbXGZbXGZcXW^cXW^dXgbdXgbdXgbbXGZbXGZbXGZc
XW^cXW^dXgbdXgbdXgbbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZb
XGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXWNbXWNbXWNc
XWNeXWNeXWNgXGNgXGNcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRc
XGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRhY7BhY7BfY7Ff
XgRcXGRaX7V`WWV_W7VMUWfMUWfKUGjGTh2ETh6CTh>ATH>?THF@Sh6@Sh6@Sh6AT8:AT8:BTH>BTH>B
TH>=T86?TX>@ThB@ThB?TX>?TX>AU8FCUXN>T8BCUHVKWI6TYYZYZin[[J6Z[:2YZinb/J>ZZ9f][J6V
Yif//ZNQZImBFe4B6Q<840DC6a16CT=>ET/nAS]0B3dlA3U1BCiFHE5HHe=WLF5`MfQbMFIlO6k5a;Jh
]jV`/ZJb/ZJc/JJe/JJd/ZNa/jN]]:N[]JQ9FTl240DE7A<k?SGGeLgFe<bd]Jbc]Zfb]:Rb]:Ra/jNa
/jNa/jNa/jNb]:Rc]JVe]Zbf]jfh^Jni^[2k_;:k_;:k_;:k_;:j^k6j^k6j^k6j^k6k_;:k_;:l_K>l
_K>j^k6k_;:l_K>m_[Bm_[Bm_[Bl_K>l_K>m_Jnh^Zjf^Znh^k:n_kG0_Jnl]:>h[IVhYWfgYGbgYGbf
Y7^fY7^gYGbgYGbhYWfjYGRjYGRjYGRjYGRjYGRjYGRjYGRjYGRfYWRfYWRfYWRfYWRfYWRfYWRfYWRf
YWRfYWRfYWRfYWRfYWRfYWRfYWRfYWRfYWRgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYGbjZ7nlZX6l
ZX6jZ7niYgjiYgjjZ7nhYWfhYWfhYWfhYWfgYGbgYGbgYGbfY7^fY7^fY7^fY7^gYGbgYGbgYG`00;b^
W;b^W;b^W;b^W;b^W;b^W;b^W;b^W;f^W[f^W[f^W[f^W[f^W[f^W[f^W[f^W[Z]WKZ]WKZ]WKZ]WKZ]
WKZ]WKZ]WKZ]WKZ^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;V]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkR/
V[R/V[R/V[R/V[V]VkV]VkV]VkZ^W;N[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[
VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[
VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKN[VKV[V;V[V;V[V;V[V;V[
V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;NY
U[NYU[RZUkRZUkV[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;RZUkRZUkRZUkRZUkRZ
UkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkR[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKNY
U[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;JYTkJYTkJYTkJYTkJY
TkJYTkJYTkJYTkFXT[FXT[FXT[JYTkJYTkNZU;NZU;R[UKNZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;JY
SkJYSkJYSkJYSkJYSkJYSkJYSkJYSkFXS[FXS[FXS[FXS[FXS[FXS[FXS[FXS[FYSKFYSKFYSKFYSKFY
SKFYSKFYSKFYSKBWSKBWSKBWSKBWSKBWSKBWSKBWSKBWSKFYSKFYSKFYSKBXS;>WRk>WRk>WRk:VR[BW
SKBWSKBWSKBWSKBWSKBWSKBWSKBWSK>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>W
Rk>WRk>WRk>WRkBTQkBTQkFUR;FUR;JVRKJVRKNWR[NWR[FUR;FUR;FUR;FUR;FUR;FUR;FUR;FUR;BT
QkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBUQKBUQKBUQKBUQKBU
QKBUQKBUQKBUQK>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;:SPk>TQ;BUQKFVQ[FVQ[BUQK>TQ;:SPk>T
Q;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;:SPk:SPk:SPk:SPk:S
Pk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPkBTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BT
P;BTP;BTP;BTP;BTP;BTP;BTP;BTP;>SOk>SOkBTP;BTP;BTP;FUPKFUPKFUPKFUPKFUPKFUPKFUPKFU
PKFUPKFUPKFUPKBTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;:R
O[>SOkBTP;FUPKFUPKFUPKFUPKBTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;JVP[BTP;:RO[:RO[BT
P;FUPKFUPKBTP;BTOkBTOkBTOkBTOkBTOkBTOkBTOkBTOkJTOkFSO[FSO[BROKBROKFSO[FSO[JTOkFT
OKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKBSO;BSO;BSO;BSO;BS
O;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk:Q
N[:QN[:QN[>RNk>RNk>RNkBSO;BSO;:QN[:QN[:QN[>RNk>RNk>RNkBSO;BSO;:QN[:QN[:QN[:QN[:Q
N[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:Q
N[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:SMK:SMK:SMK>SMKFRMKFRMKNRMKNRMK>QN;>QN;>QN;>QN;>Q
N;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>Q
N;>QN;>QN;>QN;>QN;>QN;>QN;>QN;FSM;FSM;BQM;:QM[>QN;:QN[:PNk:OO:2GO9nFNifFOIZEP9FC
PI>CPi:BQ8nAQI6@PY6@PY6@PY6@PY6@PY:APi:APi:APhjAPXnBPi2CQ8nBPhjAPXnBPi:EQYFHRI6C
Qi>ERIJHS9^MTJ6SUjJXW:Z/X:b^XZbYVj^WW;:bYZ^/X[2fZjB/XTmJD0TD314E2R``9K2dZLgAaZfa
Y[Vm/Z^_Y;Jj[kJgYk2aXKfn[[:cXk6bXZRXV;ViZJVYVJnaYK6aYK:`YKFaY[BbYk6cYjfdYj^eZ5Y[
H0XH3A/S6C0c:]?AbM_IdKJg[ZnbZK>eZK:dZ;6cYk6cYk2bY[2bY[6cYk:dZ;>dZ[BeZkJg[KRi[kVj
/;Zk/KZk/KZk/KVj/;Vj/;Zk/KZk/K^l/[^l/[^l/[^l/[Vj/;Zk/K^l/[bm/kfn];fn];bm/kbm/kbm
[KVl[KNk/;Jj];Zm];jl/[fgZ[bcYKVWO[RVOKJTNkFSN[FSN[JTNkRVOKVWO[ZUN;ZUN;ZUN;ZUN;ZU
N;ZUN;ZUN;ZUN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;NW
NKNWNKNWNKNWNKNWNKNWNKNWNKNWNKNUO;VWO[bZPKbZPKZXOkRVOKRVOKVWO[RVOKRVOKRVOKRVOKNU
O;NUO;JTNkFSN[JTNkJTNkJTNkNUO;NUO;JTN`00_:jL_:jL_:jL_:jL_:jL_:jL_:jL_:jL_JjN_JjN
_JjN_JjN_JjN_JjN_JjN_JjN^ZfM^ZfM^ZfM^ZfM^ZfM^ZfM^ZfM^ZfM^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL
^ZjL^ZjL^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ^:bJ]j^I^:bJ^:bJ^:bJ^JfK^JfK^JfK^JfK]j^I]j^I
]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I
]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I
]j^I]j^I]j^I]j^I]j^I]j^I^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H
^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H]jVF]jVF^:ZG^:ZG^:ZG^J^H^J^H^J^H^J^H^J^H
^J^H^J^H^J^H^J^H^J^H^J^H^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG
^:ZG^:ZG^:^E^:^E^:^E^:^E^:^E^:^E^:^E^:^E]jVF]jVF]jVF]jVF]jVF]jVF]jVF]jVF]jZD]jZD
]jZD]jZD]jZD]jZD]jZD]jZD]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]:NA]:NA]JRB]ZVC]ZVC]jZD
]jZD^:^E]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]JR>]JR>
]JR>]JR>]JR>]JR>]JR>]JR>]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]:N=]:N=]:N=]:N=]:N=]:N=
]:N=]:N=]JV=]JV=]:R<]:R</jN;/jN;/ZJ:/ZJ:]:N=]:N=]:N=]:N=]:N=]:N=]:N=]:N=/ZJ:/ZJ:
/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:]:B7]:B7]:B7]JF8]ZJ9]ZJ9
]jN:]jN:]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JF8]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7
]:B7]:B7]:B7]:B7]:B7]:B7]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5/jB4/jB4/jB4/jB4/jB4/jB4
/jB4/jB4/J:2/Z>3]:F5]JJ6]JJ6]:F5/Z>3/J:2/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4
/jB4/jB4/jB4/jB4/jB4/jB4/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3
/Z>3/Z>3]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0/j=o/j=o
/j=o]:B0]:B0]:B0]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]:B0]:B0]:B0]:B0]:B0]:B0
]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0/Z9n/j=o]:B0]JF1]JF1]JF1]:B0]:B0]:B0]:B0
]:B0]:B0]:B0]:B0]:B0]:B0]ZJ2]:B0/Z9n/Z9n]:B0]JF1]JF1]:B0]:Ao]:Ao]:Ao]:Ao]:Ao]:Ao
]:Ao]:Ao]ZAo]J=n]:9m]:9m]:9m]:9m]J=n]ZAo]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm
]JAm]JAm]JAm]JAm]JAm]JAm]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l
]:=l]:=l/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/J1i/Z5j/Z5j/Z5j/j9k/j9k/j9k]:=l/J1i/Z5j
/Z5j/Z5j/j9k/j9k/j9k]:=l/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i
/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J9d/J9d
/J9d/Z9d]:5d]:5d]Z5d]Z5d/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g
/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z9d/Z9d
/J1e/Imf/J1i/Z1k]:9m]J9oXYMkX9MlWIImVYF0V9B1Ti>3TY:4T9:6TI22TI22TI22TI22TY63TY63
TY63TY63Si:3T9>4T9>4Si:3SY62T9>4TiJ7UYV:UYR<U9J:TiF9UIN;VI^?XJ>GZJ^O[[2T/J^N[JVN
/JnTY:FKZJnTXjbRF6=I5B8J40l59bHLbl[0gMcBXZ6G/:nUX9nE];>Y]k2QZJBE^KBUYjBE^;FV]KFU
][JV/K:R[[6R/K6S/[6S]K:T/k:T/KBU[KBUZkJVE6EJ2AL<7bLM:B`SbLNoe=;:][N^];N^/kFY/kFY
/K>W/;:V/;:V/;:V/;:V/K>W/[>Y/kBZ]KJ/]kR^^;V_^KZ`^KZ`^KZ`^KZ`^KZ`^[^a^[^a^[^a^kbb
^kbb^kbb^KZ`^KZ`^kbb_;fc_Kjd_Kjd_;fc_;fc_;f]^[f^]K^`][Zd^K^e_;Zb_KV^_kNZ^JMn^:Im
]ZAk]J=j]J=j]ZAk^:Im^JMn^ZEh^ZEh^ZEh^ZEh^ZEh^ZEh^ZEh^ZEh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh
]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jEl^JMn
_:Z1_:Z1^ZQo^:Im^:Im^:Im]jEl]jEl^:Im^:Im^:Im]jEl]ZAk]J=j]ZAk]ZAk]jEl]jEl]ZAk]J=j
002l[Ybl[Ybl[Ybl[Ybl[Ybl[Ybl[Ybl[YbiZiVj[9Zj[9Zj[9Zk[I^k[I^k[I^l[Ybl[Ybl[Ybl[Ybl
[Ybl[Ybl[Ybl[Ybl[Ybk[I^k[I^k[I^k[I^k[I^k[I^k[I^k[I^j[9Zj[9ZiZiVhZYRhZYRiZiVj[9Zj
[9ZiZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiVhZYRhZYRhZYRh
ZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRgZINgZINhZYRhZYRiZiViZiViZiVi
ZiVhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNh
ZYNhZYNhZYNhZYNhZYNhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFgZYBgZYBhZiFhZiFi[9Ji[9Ji[9Ji
[9JhZYBhZYBiZiFiZiFj[9Jj[9Jj[9Jj[9JgZYBgZYBgZYBgZYBgZYBgZYBgZYBgZYBgZYBgZYBgZYBg
ZYBgZYBgZYBgZYBgZYBfZI>fZI>gZYBgZYBgZYBhZiFhZiFhZiFhZYBhZYBhZYBhZYBhZYBhZYBhZYBh
ZYBgZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>fZ9:fZ9:fZ9:f
Z9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZXjfZXjfZXjfZXjfZXjfZXjfZXjf
ZXjjZHjjZHjjZHjjZHjjZHjjZHjjZHjjZHjiZ8fiZ8fiZ8fiZ8fiZ8fiZ8fiZ8fiZ8fhYhbhYhbhYhbh
YhbhYhbhYhbhYhbhYhbhYhbhYhbhYhbhYhbhYhbhYhbhYhbhYhbgYX^gYX^fYHZfYHZfYHZfYHZgYX^g
YX^cYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^eY8VeY8VeY8Ve
Y8VeY8VeY8VeY8VeY8VeYHReYHReYXJeYXJeYXFeYXFeYh>eYh>dYHFdYHFdYHFdYHFdYHFdYHFdYHFd
YHFfY8FfY8FfY8FfY8FfY8FfY8FfY8FfY8FbXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>eXhBeXhBeXhBe
XhBeXhBeXhBeXhBeXhBdXX>dXX>eXhBeXhBeXhBfY8FfY8FfY8FeXhBeXhBeXhBeXhBeXhBeXhBeXhBe
XhBdXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>d
XX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>cXgncXgncXgncXgncXgncXgncXgnc
XgncXgjcXgjdY7ndY7ndY7neYH2eYH2eYH2dY82dY82dY82dY82dY82dY82dY82dY82eXgjeXgjeXgje
XgjeXgjeXgjeXgjeXgjeYH2dY7ndY7ncXgjcXgjbXWfbXWfaXGbfXh2fXh2fXh2fXh2fXh2fXh2fXh2f
Xh2eXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgje
XgjeXgjeXgjeXgjeXgjeY7feY7feY7feY7feY7feY7feY7feY7feXgjeXgjeXgjeXgjeXgjeXgjeXgje
XgjcXW^cXW^cXW^dXgbdXgbdXgbeY7feY7fdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbcXW^cXW^cXW^c
XW^cXW^cXW^cXW^cXW^cXgVcXgVcXgVcXgVcXgVcXgVcXgVcXgVcXgVcXgVcXgVcXgVcXgVcXgVcXgVc
XgVbXWRbXWRbXWRbXWRaXGNaXGNaXGNaXGNcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRbXWRbXWRbXWRb
XWRbXWRbXWRbXWRbXWRaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJa
WgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>a
XG>aXG>aXG>aXG>aXG>aWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJ`WWF`WWFaWgJbX7NcXGRc
XGRaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJeY7f`X7^YVWVP
UGNKTGVJTGfITX6KU8FHUh>FUH6DTX2BT7jASgfATH6CTh>DU8BCTXBCTXBCTXBBTH>BTH>BTH>BTH>B
TH>FVHZGVX^GVX^EV8VDUhRGVX^OXY>UZ9V`/:BXZibUZ9RY[ibTZYVSZYejOgH:40/14PLF9aZ]_[73
d/BU]:JR[inZ]ZBMZIN[ZIjj^:f`[Z>^[:6`[Z>a[jBi]jbWYIZ][j>][j>][j>^/:B^/:B^/:B_/JF_
/JEQLVL?7A8R:R0T9ak5`k_GeLff]jjb]Jbc]:Zc]:Za/ZR`/JN`/JN`/JNa/ZRa/ZR`/JNb/jVd]J^f
]jfh^Jni^[2j^k6j^k6j^k6j^k6i^[2i^[2j^k6k_;:l_K>l_K>i^[2j^k6k_;:l_K>m_[Bl_K>l_K>l
_K>k_;:k_;:k_;:j^k6j^k6j^k6i^[2i^[2l^JBaYhnaWWfmXg_2Yg^jXgJbXGJaYG^kYWVkYWVjYGRi
Y7NhXgJhXgJgXWFgXWFiY7NiY7NiY7NiY7NiY7NiY7NiY7NiY7NiY7NiY7NiY7NiY7NiY7NiY7NiY7Ni
Y7NdY7JdY7JdY7JeYGNeYGNeYGNfYWRfYWRlYgZlYgZlYgZkYWVkYWVkYWVkYWVkYWVhZ7ZgYgVgYgVf
YWRfYWReYGNeYGNdY7JeXgZeXgZeXgZeXgZeXgZeXgX00;b^W;b^W;b^W;b^W;b^W;b^W;b^W;b^W;V[
VKZ/V[Z/V[Z/V[^]Vk^]Vk^]Vkb^W;b^W;b^W;b^W;b^W;b^W;b^W;b^W;b^W;Z/V[Z/V[Z/V[Z/V[Z/
V[Z/V[Z/V[Z/V[Z/V[Z/V[V[VKRZV;RZV;V[VKZ/V[Z/V[V[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[
VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKRZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZ
V;RZV;RZV;RZV;NYUkNYUkRZV;RZV;RZV;V[VKV[VKV[VKRZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZ
UkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkR[UKR[UKR[UKR[UKR[
UKR[UKR[UKR[UKNZU;NZU;R[UKR[UKR[UKV/U[V/U[V/U[RZU;RZU;V[UKV[UKV[UKZ/U[Z/U[Z/U[NZ
U;NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;JYTkJYTkJYTkNZU;NZ
U;R[UKR[UKR[UKRZU;RZU;RZU;RZU;RZU;RZU;RZU;RZU;NYTkNYTkNYTkNYTkNYTkNYTkNYTkNYTkNY
TkNYTkNYTkNYTkNYTkNYTkNYTkNYTkJXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JX
T[JXT[JXT[JXT[JZS[JZS[JZS[JZS[JZS[JZS[JZS[JZS[ZYS[ZYS[ZYS[ZYS[ZYS[ZYS[ZYS[ZYS[VX
SKVXSKVXSKVXSKVXSKVXSKVXSKVXSKRWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RW
S;RWS;RWS;RWS;NVRkNVRkJUR[JUR[JUR[JUR[NVRkNVRk:VR[:VR[:VR[:VR[:VR[:VR[:VR[:VR[JU
R[JUR[JUR[JUR[JUR[JUR[JUR[JUR[FTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFUR;FUR;FVQ[FVQ[FV
QKFVQKFWPkFWPkBUQKBUQKBUQKBUQKBUQKBUQKBUQKBUQKJTQKJTQKJTQKJTQKJTQKJTQKJTQKJTQK:S
Pk:SPk:SPk:SPk:SPk:SPk:SPk:SPkFSQ;FSQ;FSQ;FSQ;FSQ;FSQ;FSQ;FSQ;BRPkBRPkBRPkFSQ;FS
Q;JTQKJTQKJTQKFSQ;FSQ;FSQ;FSQ;FSQ;FSQ;FSQ;FSQ;BRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBR
PkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBR
PkBRPkBRPkBRPk>SOk>SOk>SOk>SOk>SOk>SOk>SOk>SOk>SO[>SO[>SO[BTOkBTOkBTOkFUP;FUP;BT
P;BTP;BTP;BTP;BTP;BTP;BTP;BTP;FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[BTOkBTOkBTOk>SO[:R
OK:ROK:ROK6QO;JSP;JSP;JSP;JSP;JSP;JSP;JSP;JSP;FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FS
O[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FTOKFTOKFTOKFTOKFT
OKFTOKFTOKFTOKFSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[>RNk>RNk>RNk>RNkBSO;BSO;FTOKFTOKBS
O;BSO;BSO;BSO;BSO;BSO;BSO;BSO;>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>SNK>SNK>SNK>SNK>S
NK>SNK>SNK>SNK>SNK>SNK>SNK>SNK>SNK>SNK>SNK>SNK:RN;:RN;:RN;6QMk6QMk6QMk6QMk6QMk:P
Mk:PMk:PMk:PMk:PMk:PMk:PMk:PMk6QMk6QMk6QMk6QMk6QMk6QMk6QMk6QMk6OM[6OM[6OM[6OM[6O
M[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6Q
Lk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6OM[6OM[6OM[6OM[6O
M[6OM[6OM[6OM[6OM[6OM[2NMK2NMK6OM[6OM[>QN;>QN;6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6O
M[6OM[6OM[6OM[6OM[6OM[6OM[6OM[:RN:nPNJ^MNJNJNZ:GNifFOIVBOYVBOiNDQIJCQ9BAPY6API6A
PI2API6BPY:CPi>BQ9>BQ9>BQ9>BQ9>BQ9>BQ9>BQ9>BQ96DQI:EQY>FQi6DQI2CQ9>FQiRKS9fPTJNW
VjBWV:NZVZbbWj>YV:2WVWYoMPhD3`dD3AXQ6ZjcZ]KId;^o]:j`Y;6cYk2`Y;FcZ;NeZZFSV:bZWk>a
YZn]X[NeZ[2^Xjf_Xjf_Xjf_Xjj`Y:j`Y:j`Y:naYJnaYFUjKa8P5AdU6alR6Kjl]=SFc[Vj/KBg[[>d
Z[>dZ[:cZK:cZK6bZ;2aYk2aYjn`Y[6bZ;6bZ;:cZKBeZkJg[KNh[[Vj/;Zk/KZk/KZk/KVj/;Vj/;Vj
/;Zk/K^l/[bm/kVj/;Zk/K^l/[bm/kbm/kbm/kbm/k^l/[^l/[^l/[^l/[Zk/KZk/KZk/KVj/;Vj/;bk
YkF^UKBRPkVRO;fTN[^TMkFTNK>VN[RSM[RSM[RSM[VTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVT
MkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkBTM[BTM[BTM[BTM[FUMkFUMkJVN;JVN;^V
NK^VNK^VNK^VNK^VNK^VNKZUN;ZUN;NWNKNWNKNWNKJVN;FUMkFUMkFUMkBTM[FSN[FSN[FSN[FSN[FS
N[FSNP00^jfK^jfK^jfK^jfK^jfK^jfK^jfK^jfK^J^I^ZbJ^ZbJ^ZbJ^jfK^jfK^jfK_:jL^jfK^jfK
^jfK^jfK^jfK^jfK^jfK^jfK^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^J^I^J^I^:ZH^:ZH^J^I
^J^I^ZbJ^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^:ZH^:ZH
^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH]jVG]jVG]jVG^:ZH^:ZH^:ZH
^J^I^J^I^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG
^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:^E^:^E^:^E^:^E^:^E^:^E^:^E^:^E]jZD]jZD]jZD^:^E^:^E^:^E
^JbF^JbF^:ZD^:ZD^:ZD^J^E^J^E^J^E^ZbF^ZbF]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD
]jZD]jZD]jZD]jZD]jZD]jZD]ZVC]ZVC]ZVC]ZVC]jZD]jZD^:^E^:^E^:ZD^:ZD^:ZD^:ZD^:ZD^:ZD
^:ZD^:ZD]jVC]jVC]jVC]jVC]jVC]jVC]jVC]jVC]jVC]jVC]jVC]jVC]jVC]jVC]jVC]jVC]ZRB]ZRB
]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JV=]JV=]JV=]JV=]JV=]JV=
]JV=]JV=^JR=^JR=^JR=^JR=^JR=^JR=^JR=^JR=^:N<^:N<^:N<^:N<^:N<^:N<^:N<^:N<]jJ;]jJ;
]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]ZF:]ZF:]ZF:]ZF:
]jJ;]jJ;/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]JB9]JB9
]JB9]JB9]JB9]JB9]JB9]JB9]JF8]JF8]JJ6]JJ6]JJ5]JJ5]JN3]JN3]:F5]:F5]:F5]:F5]:F5]:F5
]:F5]:F5]ZB5]ZB5]ZB5]ZB5]ZB5]ZB5]ZB5]ZB5/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3]J>4]J>4
]J>4]J>4]J>4]J>4]J>4]J>4]::3]::3]::3]::3]J>4]J>4]ZB5]ZB5]J>4]J>4]J>4]J>4]J>4]J>4
]J>4]J>4]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3
]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3/j=o/j=o/j=o/j=o/j=o/j=o
/j=o/j=o/j=n/j=n/j=n/j=n]:Ao]:Ao]:Ao]JF0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:9m]:9m
]:9m]:9m]:9m]:9m]:9m]:9m/j=n/j=n/j=n/j=n/Z9m/Z9m/Z9m/J5l]Z>0]Z>0]Z>0]Z>0]Z>0]Z>0
]Z>0]Z>0]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m
]:9m]:9m]:9m]:9m]:9m]:9m]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:9m]:9m]:9m]:9m]:9m]:9m
]:9m]:9m/Z5j/Z5j/j9k/j9k]:=l]:=l]:=l]:=l/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/Z5j/Z5j
/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z9h/Z9h/Z9h/Z9h/Z9h/Z9h/Z9h/Z9h/Z9h/Z9h/Z9h/Z9h/Z9h/Z9h
/Z9h/Z9h/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/J5g/J5g
/J5g/J5g/J5g/J5g/J5g/J5g/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf
/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c
/J5c/J5c/J5c/J5c/J5c/J5c/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/9ie/9ie/9ie/9ie/Imf
/Z1g/j5h/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf[Yma/:1e
/:9h[J9lZImmY9YlWYIiVI9gUY:7UY:7Ti66TY:4TY:4Si:2Si:2SI>2U9>5U9>5U9>5U9>5U9>5U9>5
U9>5U9>5Si:3T9>4TIB5TIB5T9>4TIB5U9N8UYV:Vi^?WZ6BYZVI[K>PXZRGWjJIO85h51XE3@T861@C
XIjJh=_Hem7<b/Bmc/Jod/_2d<k3blVn[ZbQ/[2U^KN/[:ZO/:jS/JnT[JnS[JnS[JnS[[2T[[2T[[2T
[k6U[k6UM8Ej5B<H5alE6QdD];:ZfMO?_;fd/kJ]/kBZ/kBZ];F[];F[/kBZ/K:X[k2V[JjT/K:X/;6W
/;6W/K:X/[>Y]KJ/]kR^^KZ`^[^a^KZ`^KZ`^KZ`^KZ`^[^a^kbb_;fc^KZ`^[^a^kbb_;fc_;fc_;fc
^kbb^kbb^kbb^kbb^kbb^[^a^[^a^[^a^KZ`^KZ`_K^Y^kBP]jV=/iml]Imf^ZAj^:Ml/JAh]Z5d]Z5d
]j9e^:=f^JAg^ZEh^ZEh^jIi^:=f^:=f^:=f^:=f^:=f^:=f^:=f^:=f^:=f^:=f^:=f^:=f^:=f^:=f
^:=f^:=f/j=e/j=e]:Af]:Af]JEg]JEg]JEg]JEg^ZEh^ZEh^ZEh^ZEh^ZEh^ZEh^ZEh^ZEh]ZIh]ZIh
]ZIh]ZIh]JEg]JEg]JEg]:Af]J=j]J=j]J=j]J=j]J=j]J=j002k[I^k[I^k[I^k[I^k[I^k[I^k[I^k
[I^iZiVj[9Zj[9Zj[9Zk[I^k[I^k[I^l[Ybk[I^k[I^k[I^k[I^k[I^k[I^k[I^k[I^j[9Zj[9Zj[9Zj
[9Zj[9Zj[9Zj[9Zj[9ZiZiViZiVhZYRhZYRhZYRhZYRiZiViZiViZiViZiViZiViZiViZiViZiViZiVi
ZiViZiViZiViZiViZiViZiViZiViZiViZiVgZINgZINgZINgZINgZINgZINgZINgZINgZINgZINgZINg
ZINgZINgZINgZINgZINfZ9JfZ9JgZINgZINhZYRhZYRhZYRhZYRgZINgZINgZINgZINgZINgZINgZINg
ZINgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZYBgZYBgZYBg
ZYBgZYBgZYBgZYBgZYBfZI>fZI>gZYBgZYBhZiFhZiFhZiFhZiFgZI>gZI>hZYBhZYBiZiFiZiFiZiFi
ZiFfZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>eZ9:eZ9:fZI>f
ZI>fZI>gZYBgZYBgZYBgZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:f
Z9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:eYi6eYi6eYi6e
Yi6eYi6eYi6eYi6eYi6eZHfeZHfeZHfeZHfeZHfeZHfeZHfeZHfiZ8fiZ8fiZ8fiZ8fiZ8fiZ8fiZ8fi
Z8fhYhbhYhbhYhbhYhbhYhbhYhbhYhbhYhbgYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^g
YX^gYX^gYX^gYX^gYX^gYX^gYX^fYHZfYHZfYHZfYHZgYX^gYX^bYXZbYXZbYXZbYXZbYXZbYXZbYXZb
YXZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeYHReYHReYXJe
YXJeYXFeYXFeYh>eYh>cY8BcY8BcY8BcY8BcY8BcY8BcY8BcY8BeXhBeXhBeXhBeXhBeXhBeXhBeXhBe
XhBbXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>cXH:cXH:dXX>d
XX>dXX>eXhBeXhBeXhBdXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>cXH:cXH:cXH:cXH:cXH:cXH:cXH:c
XH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:c
XH:cXH:cXH:cXH:cXH:cXgncXgncXgncXgncXgncXgncXgncXgnbXWfbXWfcXgjcXgjcXgjdY7ndY7nd
Y7ncXgncXgncXgncXgncXgncXgncXgncXgndXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfbXWfbXWfbXWfb
XWfbXWfbXWfbXWfbXWfeXWneXWneXWneXWneXWneXWneXWneXWndXWfdXWfdXWfdXWfdXWfdXWfdXWfd
XWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXgbdXgbdXgbd
XgbdXgbdXgbdXgbdXgbdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfbXGZbXGZbXGZcXW^cXW^cXW^dXgbd
XgbcXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^bXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXWRbXWRbXWRb
XWRbXWRbXWRbXWRbXWRbXWRbXWRbXWRbXWRbXWRbXWRbXWRbXWR`X7J`X7J`X7J`X7JaXGNaXGNaXGNa
XGNbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NaXGNaXGNaXGNaXGNaXGNaXGNaXGNaXGNaWgJaWgJaWgJa
WgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJa
WgJaXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aWgJaWgJaWgJa
WgJaWgJaWgJaWgJaWgJ`WWF`WWF`WWF_WGB`WWFaWgJbX7NcXGRaWgJaWgJaWgJaWgJaWgJaWgJaWgJa
WgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJ^X6n`XW:`XgFaXgV^XWZYWGVSVGNQUgFGTHJFTXNFTXNE
U8JAU8F>U8>=Th::TX6DThFDThFEU8JEU8JEU8JEU8JFUHNFUHNBUHJCUXNDUhRDUhRDUhRDUhRDUhRD
UhREUHVGVX^PXi>Y[ibSZIRSZYeoQ7/F71LB51@J71b6QXK9b/S>cLWFdloIe]7Ge<o=bl3Ielbl^Znb
/:Fh]Z^]Zj2^[:6_[J:][j>][j>][j>^/:B^/:B^/:B_/JF_/JEmSX<G9AXC6a4I71>ZZ:3Lf]:n_kJ`
/jZb/jVc]:Ze]Zbf]jfd]J^b/jV^[jF/[J>a/ZR`/JN^[jF^[jF_/:Jb/jVf]jfh^Jni^[2i^[2h^Jnh
^Jni^[2j^k6k_;:k_;:h^Jni^[2j^k6k_;:l_K>k_;:k_;:k_;:k_;:k_;:k_;:j^k6j^k6j^k6i^[2i
^[2k^j^n^ZNk[iN`WX6^VWNhY7^hZ7ZaXWBgXWFgXWFgXWFhXgJhXgJiY7NiY7NiY7NhXgJhXgJhXgJh
XgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJcXgFcXgFcXgFdY7JdY7JdY7JeYGNe
YGNiY7NiY7NiY7NiY7NiY7NjYGRjYGRjYGReYGNeYGNeYGNeYGNeYGNeYGNeYGNeYGNeXgZeXgZeXgZe
XgZeXgZeXgX00;Z/V[Z/V[Z/V[Z/V[Z/V[Z/V[Z/V[Z/V[V[VKZ/V[Z/V[Z/V[^]Vk^]Vk^]Vkb^W;Z/
V[Z/V[Z/V[Z/V[Z/V[Z/V[Z/V[Z/V[V[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKRZV;RZV;NYUkNY
UkRZV;RZV;V[VKRZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;NY
UkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkJXU[JXU[JXU[NYUkNY
UkNYUkRZV;RZV;NYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYU[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NY
U[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;JYTkJYTkJYTkNZU;NZ
U;NZU;R[UKR[UKNYTkNYTkNYTkRZU;RZU;RZU;V[UKV[UKJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkJY
TkJYTkJYTkJYTkJYTkJYTkJYTkJYTkFXT[FXT[FXT[JYTkJYTkJYTkNZU;NZU;NYTkNYTkNYTkNYTkNY
TkNYTkNYTkNYTkJXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JX
T[JXT[JXT[JXT[JXT[JXT[JXT[JXT[FWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFYSKFYSKFYSKFYSKFY
SKFYSKFYSKFYSKVXSKVXSKVXSKVXSKVXSKVXSKVXSKVXSKNVRkNVRkNVRkNVRkNVRkNVRkNVRkNVRkJU
R[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[NVRkNVRkJUR[JUR[JU
R[JUR[NVRkNVRk6URK6URK6URK6URK6URK6URK6URK6URKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKBS
R;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BTQkBTQkBUQKBUQKBUQ;BUQ;BVP[BVP[>TQ;>TQ;>TQ;>TQ;>T
Q;>TQ;>TQ;>TQ;FSQ;FSQ;FSQ;FSQ;FSQ;FSQ;FSQ;FSQ;:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPkBR
PkBRPkBRPkBRPkBRPkBRPkBRPkBRPk>QP[>QP[>QP[BRPkBRPkBRPkFSQ;FSQ;BRPkBRPkBRPkBRPkBR
PkBRPkBRPkBRPk>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>Q
P[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>SOk>SOk>SOk>SOk>S
Ok>SOk>SOk>SOk:ROK:ROK:ROK:ROK>SO[>SO[BTOkBTOk>SOk>SOk>SOk>SOk>SOk>SOk>SOk>SOkBR
OKBROKBROKBROKBROKBROKBROKBROK6QO;6QO;6QO;6QO;:ROK:ROK:ROK:ROKFROkFROkFROkFROkFR
OkFROkFROkFROkBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBR
OKBROKBROKBROKBROKBROKBROKBROKBSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BROKBROKBROKBROKBR
OKBROKBROKBROK6PNK6PNK:QN[:QN[>RNk>RNk>RNk>RNk:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[6P
NK6PNK6PNK6PNK6PNK6PNK6PNK6PNK6QMk6QMk6QMk6QMk6QMk6QMk6QMk6QMk6QMk6QMk6QMk6QMk6Q
Mk6QMk6QMk6QMjnOMJnOMJnOMK2PM[2PM[6QMk6QMk:RN;6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[2P
M[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2N
MK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2PL[2PL[2PL[2PL[2PL[2PL[2PL[2PL[2P
L[2PL[2PL[2PL[2PL[2PL[2PL[2PL[2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMJnMM:nMM:nM
M;2NMK6OM[:PMk2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK:S
L[6SLk6SLk2QLjjPMZfNMjZNMZZMMi^DPI^CPY^DPiNEPiFEQI6DQ8jCQ8^BPiBCQIBCQIBCQIFDQYFD
QYJEQiJEQiJEQi>FQiBGR9BGR9FHRIJIRYJIRYBGR9>FQiFERI:EQYJIRJ:XUJ:XUjN^XH>8OaHL5`8@
3P081Ql]:cI4@2Lc;Blk=B/f;QTT7::PUM7?a;nm/ZRVVjn]X[2^Xk>aY[6_Y:f_Xjf_Xjf_Xjj`Y:j`
Y:j`Y:naYJnaYH>DRATW714I3a/N5J6OUmgKdko0]jb_Y[:cZK>dZ[Ff[;Jg[KFf[;>dZZn`YZf^Y;6b
Z:n`YZj_YJf^Y:j_YK6bZ;BeZkJg[KVj/;Ri[kRi[kRi[kRi[kVj/;Zk/K^l/[Ri[kVj/;Zk/K^l/[^l
/[^l/[Zk/KZk/K^l/[^l/[^l/[Zk/KZk/KZk/KVj/;Vj/;NjZkjk[;ZcX:jPRJbJNk>RNkJVN;6QL[VT
MkVTMkRSM[RSM[NRMKNRMKJQM;JQM;NRMKNRMKNRMKNRMKNRMKNRMKNRMKNRMKNRMKNRMKNRMKNRMKNR
MKNRMKNRMKNRMK:RM;:RM;>SMK>SMKBTM[BTM[BTM[BTM[NRMKNRMKNRMKRSM[VTMkVTMkVTMkZUN;BT
M[BTM[BTM[BTM[FUMkFUMkFUMkFUMkFSN[FSN[FSN[FSN[FSN[FSNP00^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ
^ZbJ^ZbJ^J^I^ZbJ^ZbJ^ZbJ^jfK^jfK^jfK_:jL^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^J^I^J^I
^J^I^J^I^J^I^J^I^J^I^J^I^J^I^:ZH]jVG]jVG]jVG]jVG^:ZH^J^I^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH
^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF
]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]JNE]ZRF]ZRF]ZRF]jVG]jVG]jVG]jVG]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF
]ZRF]ZRF]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZVC]ZVC
]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]JRB]ZVC]ZVC]ZVC]jZD]jZD]jZD]jZD]ZRB]jVC]jVC]jVC^:ZD^:ZD
^:ZD^:ZD]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]:NA]:NA
]JRB]JRB]ZVC]ZVC]ZVC]ZVC]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]JNA]JNA]JNA]JNA]JNA]JNA
]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]:J@]:J@
]:J@]:J@]:J@]:J@]:J@]:J@]:R<]:R<]:R<]:R<]:R<]:R<]:R<]:R<^:N<^:N<^:N<^:N<^:N<^:N<
^:N<^:N<]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:
]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]jJ;]jJ;]ZF:]ZF:]ZF:]ZF:]jJ;]jJ;/JF9/JF9/JF9/JF9/JF9/JF9
/JF9/JF9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:B7]:B7
]:F5]:F5]:F4]:F4]:J2]:J2/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3]::3]::3]::3]::3]::3]::3
]::3]::3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/j62/j62/j62/j62/j62/j62/j62/j62/Z21/Z21
/j62/j62]::3]::3]::3]::3/j62/j62/j62/j62/j62/j62/j62/j62/Z21/Z21/Z21/Z21/Z21/Z21
/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21
/Z21/Z21/Z21/Z21/Z21/Z21/j=o/j=o/j=o/j=o/j=o/j=o/j=o/j=o/J5l/J5l/Z9m/Z9m/Z9m/j=n
/j=n/j=n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/:1k/:1k
/J5l/J5l/J5l/Z9m/Z9m/Z9m]:5n]:5n]:5n]:5n]:5n]:5n]:5n]:5n/j5l/j5l/j5l/j5l/j5l/j5l
/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j9k/j9k
/j9k/j9k/j9k/j9k/j9k/j9k/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/J1i/J1i/J1i/Z5j/Z5j/j9k
/j9k/j9k/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J5g/J5g
/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g[Yid[Yid[ime[ime/:1f/J5g
/J5g/Z9h/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/:1f/:1f/:1f/:1f/:1f/:1f/:1f/:1f/9ie/9ie
/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie
/9ie/9ie/:1b/:1b/:1b/:1b/:1b/:1b/:1b/:1b/:1b/:1b/:1b/:1b/:1b/:1b/:1b/:1b/9ie/9ie
/9ie/9ie/9ie/9ie/9ie/9ie/9ie[ied[ied[Yac[ied/9ie/Imf/Z1g/9ie/9ie/9ie/9ie/9ie/9ie
/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/j=d/J5c/:1b[Yeb[Yeb[ied/Iih/YmiY9UkXYQj
X9MlViEnV9B1U9B4Ti>5T9:6TY63TY63Ti:4U9>5UIB6UIB6UYF7UYF7TiJ7TYF6TIB5TiJ7UIR9UIR9
TiJ7TIB5UiN;T9>4T9>3VZ2=WJ>BYZfPQHZ16AlJ014<00P300/311TA00d45RLL7RlT4bDHRhUnd<k3
a<:gYJ>H[ZbQ/JnT/JnT[J^P[JnS[JnS[JnS[[2T[[2T[[2T[k6U[k6UR9V>72XO41P>71lFUI>;fmWA
`<6h[:nV/[>Y/kBZ];F[]KJ/]KJ//kBZ/[>Y/K:X/;6W[k2V[k2V[ZnU[k2V/K:X/kBZ];F[^;V_^;V_
]kR^]kR^^;V_^KZ`^[^a^[^a^;V_^;V_^KZ`^[^a^kbb^kbb^[^a^[^a^kbb^kbb^kbb^[^a^[^a^[^a
^KZ`^KZ`]KV]^k^_^kJW]:ZH[Z67/J5m/j=e]:=`^JAg^JAg^:=f]j9e]Z5d]Z5d]J1c]J1c]j9e]j9e
]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e/Z9d/Z9d/Z9d/j=e/j=e]:Af
]:Af]:Af]J1c]Z5d]Z5d]j9e^:=f^JAg^JAg^JAg/j=e/j=e]:Af]:Af]:Af]JEg]JEg]JEg]J=j]J=j
]J=j]J=j]J=j]J=j002iZiViZiViZiViZiViZiViZiViZiViZiViZiVj[9Zj[9Zj[9Zk[I^k[I^k[I^l
[YbiZiViZiViZiViZiViZiViZiViZiViZiVhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRgZINf
Z9JfZ9JgZINhZYRhZYRgZINgZINgZINgZINgZINgZINgZINgZINgZINgZINgZINgZINgZINgZINgZINg
ZINfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JeYiFeYiFfZ9Jf
Z9JfZ9JgZINgZINgZINfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9Ff
Z9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>eZ9:eZ9:fZI>f
ZI>fZI>gZYBgZYBgZYBfZ9:fZ9:gZI>gZI>gZI>hZYBhZYBhZYBeZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:e
Z9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:dYi6dYi6dYi6eZ9:eZ9:fZI>fZI>fZI>fZ9:fZ9:fZ9:f
Z9:fZ9:fZ9:fZ9:fZ9:eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6e
Yi6fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dZ8bdZ8bdZ8bd
Z8bdZ8bdZ8bdZ8bdZ8bhYhbhYhbhYhbhYhbhYhbhYhbhYhbhYhbgYX^gYX^gYX^gYX^gYX^gYX^gYX^g
YX^eY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VgYX^gYX^fYHZf
YHZfYHZfYHZgYX^gYX^`Y8R`Y8R`Y8R`Y8R`Y8R`Y8R`Y8R`Y8RdXhRdXhRdXhRdXhRdXhRdXhRdXhRd
XhRcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXhJcXhJcY8BcY8BcY8>cY8>cYH6cYH6bXh>bXh>bXh>b
Xh>bXh>bXh>bXh>bXh>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>bXh>bXh>bXh>bXh>bXh>bXh>bXh>b
Xh>cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:bX86bX86bX86cXH:cXH:dXX>dXX>dXX>cXH:cXH:cXH:c
XH:cXH:cXH:cXH:cXH:bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86b
X86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86cXgncXgncXgnc
XgncXgncXgncXgncXgnaXGbaXGbaXGbbXWfbXWfbXWfcXgjcXgjbXWjbXWjbXWjbXWjbXWjbXWjbXWjb
XWjcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGb_WgZ`X7^`X7^`X7^aXGbbXWfbXWfbXWfdXGjdXGjdXGjd
XGjdXGjdXGjdXGjdXGjcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbc
XGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXGbcXGbcXGbc
XGbcXGbcXGbcXGbcXGbaX7VaX7VaX7VaX7VbXGZbXGZbXGZcXW^bXGZbXGZbXGZbXGZbXGZbXGZbXGZb
XGZ`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`X7J`X7J`X7J`X7J`X7J`X7J`X7J`X7J`X7J`X7J`X7J`
X7J`X7J`X7J`X7J`X7J]WG>]WG>^WWB_WgF`X7JaXGNaXGNbXWR`WWF`WWF`WWF`WWF`WWF`WWF`WWF`
WWF_WgF_WgF_WgF_WgF_WgF_WgF_WgF_WgF_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_
WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_Wg6_Wg6_Wg6_Wg6_Wg6_Wg6_Wg6_
Wg6_Wg6_Wg6_Wg6_Wg6_Wg6_Wg6_Wg6_Wg6_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB^W7>^
W7>^W7>_WGBaWgJaWgJ_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_
WGB`WgB`WgB_WW>`W7>`W7>aW7JcWWRdWgV]WW2ZW7:UVGFPUWRLU7fITX>GThRETXZAT8:AT8:BTH>C
TXBDThFDThFEU8JFUHNCUXNAU8F?TX>AU8FDUhREV8VDUhRBUHJHV8bAU8F?TX:FW8VEVhZPYiZ5RX4O
9B065`h34PX03`@I9a`03P8750H84PD53`::R7g=bl2o_K:VY9Vd/ZN`[Z>ZZ9f]Zj2][j>][j>][j>^
/:B^/:B^/:B_/JF_/JF?X9DP;R<?5`dJ7AB7QGgGeLg2`kZ`/jZb/jVb/jVc]:Zc]:Zd]J^d]J^d]J^d
]J^_/:J_/:J`/JN`/JNa/ZRb/jVb/jVc]:Zh^Jnh^Jng^:jg^:jg^:jh^Jni^[2j^k6g^:jh^Jni^[2j
^k6j^k6j^k6j^k6i^[2k_;:k_;:k_;:j^k6j^k6j^k6i^[2i^[2f^Znh^Jnk^Jjm]ZNh[9B`XH2cX7>i
YW>gXWFgXWFgXWFgXWFfXGBfXGBfXGBfXGBgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFg
XWFgXWFgXWFgXWFgXWFbXWBbXWBbXWBbXWBcXgFcXgFcXgFdY7JdWg:eX7>eX7>fXGBgXWFhXgJiY7Ni
Y7NbXWBcXgFcXgFcXgFdY7JeYGNeYGNeYGNeXgZeXgZeXgZeXgZeXgZeXgX00;V[VKV[VKV[VKV[VKV[
VKV[VKV[VKV[VKV[VKZ/V[Z/V[Z/V[^]Vk^]Vk^]Vkb^W;V[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKRZ
V;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;NYUkNYUkJXU[JXU[NYUkNYUkRZV;NYUkNYUkNYUkNYUkNY
UkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkJXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JX
U[JXU[JXU[JXU[JXU[JXU[JXU[JXU[FWUKFWUKFWUKJXU[JXU[JXU[NYUkNYUkJXU[JXU[JXU[JXU[JX
U[JXU[JXU[JXU[JXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJY
TkJYTkJYTkJYTkJYTkJYTkJYTkJYTkFXT[FXT[FXT[JYTkJYTkJYTkNZU;NZU;JXT[JXT[JXT[NYTkNY
TkNYTkRZU;RZU;FXT[FXT[FXT[FXT[FXT[FXT[FXT[FXT[FXT[FXT[FXT[FXT[FXT[FXT[FXT[FXT[BW
TKBWTKBWTKFXT[FXT[FXT[JYTkJYTkJXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[FWTKFWTKFWTKFWTKFW
TKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKJXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[BV
T;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;RWS;RWS;RWS;RWS;RW
S;RWS;RWS;RWS;JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[FTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFT
RKFTRKFTRKFTRKFTRKFTRKFTRKFTRKNVRkNVRkJUR[JUR[JUR[JUR[NVRkNVRk2TR;2TR;2TR;2TR;2T
R;2TR;2TR;2TR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>S
Q[>SQ[>TQ;>TQ;>TPk>TPk>UPK>UPK:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPkBRPkBRPkBRPkBRPkBR
PkBRPkBRPkBRPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[:P
PK:PPK:PPK>QP[>QP[>QP[BRPkBRPk>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[:PPK:PPK:PPK:PPK:P
PK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:P
PK:PPK:PPK:PPK:PPK:PPK:PPK:PPK>SOk>SOk>SOk>SOk>SOk>SOk>SOk>SOk6QO;6QO;6QO;6QO;:R
OK:ROK>SO[>SO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO:nO
NZnON[2PNk2PNk6QO;6QO;:ROK:ROKBQO[BQO[BQO[BQO[BQO[BQO[BQO[BQO[>QO;>QO;>QO;>QO;>Q
O;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>R
Nk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;2ON;6PNK6PNK6PNK:Q
N[:QN[:QN[:QN[6PNK6PNK6PNK6PNK6PNK6PNK6PNK6PNK2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2P
M[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2PMZbLLZfMLjjNM:nOMK2P
M[6QMk6QMk:RN;2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMJnOMJnOMJnOMJnOMJnOMJnOMJnOMJnOMJnM
M:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nM
M:nMM:nMM:nMM:nOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnM
M:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:jLLjjLLjjLLjnMM;2NMK6OMZnMM:nMM:nMM:nMM:nM
M:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:fKLZjLLk6MM;6LM[:MMkBMMkBMMkBMMk:R
KJjOKZRKKj:FM9fCNiZBPIVBRIVCSY2?PI2?PI6@PY:APi>BQ9BCQIFDQYFDQYJIRY:EQY2CQ96DQIFH
RINJRiNJRiFHRINGRi>FQi:EQIFKR8nEQ9VPThB9P2D[9P8:018J3bhd:G=gJfQ/H6Q[G6Q[FgEfIX1n
LkZh[J^YWZ2NTkRfZjn]XZRVVkFcZ:f_Xjf_Xjf_Xjj`Y:j`Y:j`Y:naYJnaYIBUVR<a9PlG3APK4Wil
M=CBb/C5_;Fh[k:cZK:cZK:cZK:cZK>dZ[BeZkJg[KNh[Zn`Y[2aYk6bZ;:cZK:cZK:cZK:cZK:cZKRi
[kNh[[Nh[[Nh[[Nh[[Ri[kVj/;Zk/KNh[[Ri[kVj/;Zk/KZk/KZk/KZk/KVj/;^l/[^l/[^l/[Zk/KZk
/KZk/KVj/;Vj/;Jl/KJi/;fl//Bn/KjcWK6RPK>PLkjYMKBOL[FPLkFPLkJQM;NRMKRSM[RSM[RSM[JQ
M;JQM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;6QLk:RM;:RM;:RM;>S
MK>SMK>SMK>SMKBOL[BOL[FPLkJQM;NRMKRSM[VTMkVTMk:RM;:RM;>SMK>SMKBTM[BTM[FUMkFUMkFS
N[FSN[FSN[FSN[FSN[FSNP00^JZG^JZG^JZG^JZG^JZG^JZG^JZG^JZG^:ZH^J^I^ZbJ^ZbJ^ZbJ^ZbJ
^J^I^:ZH^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^J^I^J^I
^:ZH^:ZH]jVG]ZRF]ZRF]ZRF]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF
]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF
]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE
]ZRE]ZRE]:JC]JND]JND]ZRE]ZRE]jVF]jVF^:ZG]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZRB]ZRB
]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]JNA]JNA]JNA]JNA]JNA]JNA
]JNA]JNA]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]JNA]JNA
]JNA]JNA]JNA]JNA]JNA]JNA]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JNA]JNA]JNA]JNA]JNA]JNA
]JNA]JNA]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]:N=]:N=]:N=]:N=]:N=]:N=]:N=]:N=]jJ;]jJ;
]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;
]jJ;]jJ;]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9
]JB9]JB9]JB9]JB9]JB9]JB9]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:B7]:B7]:B7]:B7]:B7]:B7
]:B7]:B7/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4]::3]::3
]::3]::3]::3]::3]::3]::3/j=o/j=o/j=o/j=o/j=o/j=o/j=o/j=o/Z9n/j=o/j=o]:B0]:B0/j=o
/j=o/Z9n/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n
/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m
/J5m/J5m/J5l/J5l/J5l/J5l/J5l/J5l/J5l/J5l/J5m/J5m/J5m/J5m/J5m/:1l/:1l/:1l/j1o/j1o
/j1o/j1o/j1o/Ymn/Ymn/Ymn/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/J5l/J5l/J5l/J5l/J5l/J5l
/J5l/J5l/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j9k/j9k
/j9k/j9k/j9k/j9k/j9k/j9k/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/j9k/j9k/j9k/j9k/j9k/j9k
/j9k/j9k/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh
/9mh/9mh/9mh/9mh/9mh/9mh/J5g/J5g/Z9h/j=i/j=i/Z9h/J5g/J5g/Imf/Imf/Imf/Imf/Imf/Imf
/Imf/Imf/9ie/9ie/Imf/Imf/Z1g/Z1g/j5h/j5h[Yid[Yid[Yid[Yid[Yid[Yid[Yid[Yid/9ie/9ie
/9ie/9ie/9ie/9ie/9ie/9ie[Yid[Yid[ime[ime/:1f/:1f/:1f/:1f/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g
/Z1g/Z1g[ied[ied[ied[ied[ied[ied[ied[ied[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[Yac[Yac
[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[ied/9ie/9ie/Imf/Imf[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`
[Yi`[Yi`[Ie_[Ie_[Yi`[Yi`[Yi`[ima[ima[ima[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`
[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[ima[Yi`[Yi`[Ie_[Ie_[Yi`[Yi`[ima[ima[ima[ima[ima[ima[ima
[ima[ima/:1b/:1b[ima[Yi`[Yi`[ima/:1b/:1b[Ii][9i^ZiibYY]eXYUhW9EjVI=lUi5nU9J2TiF2
T9B1Si:2Si:3T9:6TY>9TIF:UIB6UIB6UYF7UiJ8V9N9V9N9VIR:VIR:V9R6Ti>1Vib<TY>3UYV:UY^<
RXj29b/O00`800P5DEMBbLW3_KZb/ZfTZjVNYZJHYJFE/;2PZJVI[JjN/K:RYZNGYZVIZZfM[JjN]KJV
Zj^K/K2R]k>XZZJK[jZQ^[>ZWjZR:SD]51dC41D<If]PgMoCc<c0/:nQ_;jXYjRD/K>P/kBT/kJW]KJ/
][N^]kR_/[BX/K>W[k6U[[2T[[2T[k6U/K>W/[BX/kFY];JZ][R/]kV]^;Z^^;Z^][R/][R/][N]]kR^
^;V_^KZ`^KZ`^KZ`^;V_^;V_^[^a^[^a^KZ`^KZ`^KZ`^KZ`^KZ`^;V_`;Z]_;^a^K^e]k^e][VZ];2D
/:Al[IUY]ia`^ZAd]JMcZZ=/ZJ9[/:Ec]Z=f]9ie]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]J1c]J1c
]J1c]J1c]J1c]J1c]J1c]J1c]j=d]j=d]j=d]j=d]j=d]j=d]j=d]j=d]Z5d]Z5d]j9e^:=f^:=f]j9e
]Z5d]Z5d]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j5h]j5h]j5h^:9i^:9i^:9i002iZYNiZYNiZYNi
ZYNiZYNiZYNiZYNiZYNhZYRiZiVj[9Zj[9Zj[9Zj[9ZiZiVhZYRiZiViZiViZiViZiViZiViZiViZiVi
ZiVhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRgZINgZINfZ9JfZ9JfZ9JgZINgZINgZINg
ZINgZINgZINgZINgZINfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9Jf
Z9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9FfZ9FfZ9Ff
Z9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FeYiBeYiBfZ9FfZ9FfZ9FfZ9FfZ9Fg
ZIJfZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:f
Z9:fZ9:fZ9:fZ9:fZ9:eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:f
Z9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eZ8jeZ8jeZ8je
Z8jeZ8jeZ8jeZ8jeZ8jeYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8je
Z8jdYhfdYhfdYhfdYhfdYhfdYhfdYhfdYhffYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZf
YHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZeY8VeY8VeY8VeY8VeY8VeY8VeY8Ve
Y8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VdXhRdXhRdXhRd
XhRdXhRdXhRdXhRdXhRdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NcXhJcXhJcXhJcXhJcXhJcXhJcXhJc
XhJcY8BcY8BcY8BcY8BcY8BcY8BcY8BcY8BdXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>cXgncXgncXgnc
XgncXgncXgncXgncXgnbXWjbXWjcXgndY82dY82cXgnbXWjbXWjbX86bX86bX86bX86bX86bX86bX86b
X86bXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjaXGfaXGfaXGfa
XGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGbaXGbaXGbaXGbaXGbaXGbaXGba
XGbaXGfaXGfaXGfaXGf`X7b`X7b`X7b`X7bcX7fcX7fcX7fcX7fbWgbbWgbbWgbbWgbcXGbcXGbcXGbc
XGbcXGbcXGbcXGbcXGbaXGbaXGbaXGbaXGbaXGbaXGbaXGbaXGbcXW^cXW^cXW^cXW^cXW^cXW^cXW^c
XW^cXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^aX7VaX7VaX7Va
X7VaX7VaX7VaX7VaX7VcXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^aX7VaX7VaX7VaX7VaX7VaX7VaX7Va
X7V`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`X7JaXGNbXWRb
XWRbXWRbXWRaXGN`X7JaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJ`WWF`WWF`WWFaWgJbX7NbX7NbX7Nc
XGR^WWB^WWB^WWB^WWB^WWB^WWB^WWB^WWB`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF^WWB^WWB_WgF_
WgF_WgF`X7J`X7J`X7J`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF_WGB_WGB_WGB_WGB_WGB_WGB_WGB_
WGB]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>]Vg:]Vg:]Vg:]
Vg:^W7>^W7>^W7>^W7>^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2]WFn]WFn]WFn^WW2^WW2^WW2_Wg6_
Wg6^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2_Wg6^WW2^WW2]
WFn]WFn^WW2^WW2_Wg6_Wg6_Wg6_Wg6_Wg6_Wg6_Wg6_Wg6_Wg6`X7:_Wg6_Wg6^WW2^WW2_Wg6_Wg6`
X7:`Wfj^WVn]WG:YWGFVVWJQV7NNUWVKUGRBU7jBTgnBU82CUH:CU8BAU8FAThNATXREU8JEU8JFUHNF
UHNGUXRHUhVIV8ZIV8ZHV8JCTh6KW8bBTh>FVHZFVhb;Sh<[;b<6510;5@m=DDcFdlk4_[N/YijXYY^W
YIZYZIf[ZinVYYZZZYj^[Z:/[Z:c]JVb]:RSY9BYZYZVYIN^[Ind/ZN]Zj6d[jJm^:nPZZ@^>38B6A@@
5a1AE4_<cLC3`[R/Zj6f]ZRa/J>n_[2i^Jf][j>a/ZRb/jV][ZBc]JVb]:Ra/jN`/ZJ`/ZJa/jNb]:Rc
]JVb]:Rc]JVe]j^g^Jfh^Zjh^Zjg^Jff^:bf]jfg^:jh^Jni^[2i^[2i^[2h^Jnh^Jnj^k6i^[2i^[2i
^[2i^[2i^[2i^[2i^[31^jjk^[2g^[6g_;>i_:fh]9^bYh6]WFngWW:iYGJeZ7B/YFj[XfjbY7>eXWFc
WGBfXGBfXGBfXGBfXGBfXGBfXGBfXGBfXGBeX7>eX7>eX7>eX7>eX7>eX7>eX7>eX7>fXW>fXW>fXW>f
XW>fXW>fXW>fXW>fXW>eX7>fXGBgXWFgXWFgXWFgXWFfXGBeX7>fXGBfXGBfXGBfXGBfXGBfXGBfXGBf
XGBeWgJeWgJfX7NfX7NfX7NgXGP00;VZUkVZUkVZUkVZUkVZUkVZUkVZUkVZUkRZV;V[VKV[VKZ/V[Z/
V[V[VKV[VKRZV;V[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKRZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZ
V;NYUkNYUkNYUkJXU[JXU[JXU[JXU[NYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkJXU[JXU[JXU[JXU[JX
U[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JX
U[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJX
UKJXUKJXUKJXUKJXUKJXUKJXUKJXUKFWU;FWU;FWU;FWU;JYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkFW
TKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKBVT;BVT;BVT;BVT;BV
T;BVT;BVT;BVT;FWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKBV
T;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BWSKBWSKBWSKBWSKBWSKBWSKBWSKBWSKBVT;BVT;BVT;BVT;BV
T;BVT;BVT;BVT;BWSKBWSKBWSKBWSKBWSKBWSKBWSKBWSK>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;JU
R[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JU
R[JUR[JUR[JUR[FTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFT
RKFTRKFTRKFTRKFTRKFTRKFTRKFTRKBSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BTQkBTQkBTQkBTQkBT
QkBTQkBTQkBTQk>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;BR
PkBRPkBRPkBRPkBRPkBRPkBRPkBRPk:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[6QOK:RO[>SOk>SOk>S
Ok>SOk:RO[6QOK6OP;6OP;6OP;6OP;6OP;6OP;6OP;6OP;6QOK6QOK6QOK6QOK6QOK6QOK6QOK6QOK6Q
OK6QOK6QOK6QOK6QOK6QOK6QOK6QOK2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2P
O;2PO;2PO;2PO;2PNk2PNk2PNk2PNk2PNk2PNk2PNk2PNk2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;:O
O;:OO;:OO;:OO;:OO;:OO;:OO;:OO;:PNk:PNk:PNk:PNk:PNk:PNk:PNk:PNk2PNk2PNk2PNk2PNk2P
Nk2PNk2PNk2PNk:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:PNk:PNk:PNk:PNk:PNk:PNk:PNk:PNk:Q
N[:QN[:QN[:QN[:QN[:QN[:QN[:QN[6PNK6PNK6PNK6PNK6PNK6PNK6PNK6PNK:QN[:QN[:QN[:QN[:Q
N[:QN[:QN[:QN[6PNK6PNK6PNK6PNK6PNK6PNK6PNK6PNK2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2O
N;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2PM[6QMk6QMk:RN;:RN;6QMk6QMk2PM[6OM[6OM[6OM[6OM[6O
M[6OM[6OM[6OM[2NMK2NMK2NMK6OM[6OM[6OM[:PMk:PMjjNM:jNM:jNM:jNM:jNM:jNM:jNM:jNM;2N
MK2NMK2NMK2NMK2NMK2NMK2NMK2NMJjNM:jNM:jNM:nOMJnOMJnOMK2PM[2PMZjLLjjLLjjLLjjLLjjL
LjjLLjjLLjjLLjnMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:fKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZjL
LjjLLjjLLjjLLjjLLjjLLjjLLjjLLjfKLZfKLZfKLZbJLJbJLJbJLJbJLJbJLJjNL:jNL:jNL:jNL:jN
L:jNL:jNL:jNL:fMKjfMKjfMKjfMKjjNL:jNL:jNL:nOLJjNL:jNL:jNL:jNL:jNL:jNL:jNL:jNL:jN
L:jNL:jNL:jNL:jNL:jNL:jNL:jNL:nOLJjNL:fMKjfMKjfMKjfMKjjNL:nOLJnOLJnOLJnOLJnOLJnO
LJnOLJnOLJnOLK2PLZnOLJjNL:jNL:jNL:jNL:nOLK2PL[:ML;>NLK6NLJnNLj^MLjRLM:BJLZ>ILIBC
NIFDNYFEOIJEPIFEPiBEQI>CQI6CQiBCQIBCQIFDQYJEQiNFR9NFR9RGRIRGRIRHQY:BP9ZKRi>DQ9JI
RYBIRXfAQC4e:@0:10X@2cHf<=WEd<c4_J^TVjfXWjf[XK6bZJRYX:VZXJVZXJBUW:RYX:RYX9bMU;Jg
Yk6aXjn_XK2`Y;6aYJf/XZZXX:bZXY^VY2de=0hE4RDZ:5EIE=[Le/k>b;:_ZZf]YkJf/;no^Ko0]jf^
YKBeZk^l/[Jg[KBfZ[>eZK>eZK:dZ;:dZ;>eZK>eZKBfZ[2bY[6cYk>eZKFgZkNi[KNi[KRj[[Rj[[Jg
[KNh[[Ri[kVj/;Vj/;Vj/;Ri[kRi[kVj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/<6n/;^k[kFh[kJk/[jn
/;jjX[N/S;2PNkJPMkNTMkBVMJnTL:nTL;BUM;FRMK>MLkJQM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;FP
LkFPLkFPLkFPLkFPLkFPLkFPLkFPLkJRLkJRLkJRLkJRLkJRLkJRLkJRLkJRLkFPLkJQM;JQM;NRMKNR
MKJQM;JQM;FPLkJQM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;BNM;BNM;BNM;BNM;FOMKFOM@00^:VF^:VF
^:VF^:VF^:VF^:VF^:VF^:VF^:ZH^:ZH^J^I^J^I^J^I^J^I^:ZH^:ZH^J^I^J^I^J^I^J^I^J^I^J^I
^J^I^J^I]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF
]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE
]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JND]JND
]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]jVF]ZRE]ZRE]JND]JND]:JC
]:JC]:JC]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA
]JNA]JNA]JNA]JNA]JNA]JNA]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]JNA]JNA]JNA]JNA]JNA]JNA
]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:N=]:N=
]:N=]:N=]:N=]:N=]:N=]:N=]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:N=]:N=]:N=]:N=]:N=]:N=
]:N=]:N=/jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ<]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:
]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]JB9]JB9]JB9]JB9]JB9]JB9
]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9/j:7/j:7
/j:7/j:7/j:7/j:7/j:7/j:7/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5
/Z:5/Z:5/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/j62/j62/j62/j62/j62/j62/j62/j62/Z9n/Z9n
/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/J5m/Z9n/Z9n/j=o/j=o/Z9n/Z9n/J5m/In0/In0/In0/In0/In0/In0
/In0/In0/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/:1l/:1l
/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1k/:1k/:1k/:1k/:1k/:1k
/:1k/:1k[imk[imk[imk/:1l/:1l/:1l/:1l/:1l/Imj/Imj/Imj/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k
/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k/:1k/:1k/:1k/:1k/:1k/:1k/:1k/:1k/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j
/Z5j/Z5j/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/J1i/J1i
/J1i/J1i/J1i/J1i/J1i/J1i/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/J1i/J1i/J1i/J1i/J1i/J1i
/J1i/J1i/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/:1f/:1f
/J5g/Z9h/Z9h/J5g/:1f/:1f/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/9ie/9ie/9ie/9ie/Imf/Imf
/Imf/Imf[Yid[Yid[Yid[Yid[Yid[Yid[Yid[Yid[ied[ied[ied[ied[ied[ied[ied[ied[Iec[Iec
[Yid[Yid[ime[ime[ime[ime[ied[ied[ied[ied[ied[ied[ied[ied[Yac[Yac[Yac[Yac[Yac[Yac
[Yac[Yac[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[Yac[Yac
[I]b[I]b[9YaZiU`ZiU`ZiU`[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[9a^[9a^[Ie_[Ie_[Ie_[Yi`
[Yi`[Yi`[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Yi`[Yi`
[Ie_[9a^[9a^[Ie_[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[ima[ima[Yi`[Ie_[Ie_[Yi`
[ima[ima]Iec]Iia/iia/Iia[im`[Yi_[9i^Zie/W9MhViEhVIEiUi=kUY=nUI>1U9B4U9B6Ti:4Ti:4
U9>5UIB6UYF7UYF7UiJ8UiJ8UiN5TI5oVY^;TiB4UIR9TiR9T9B8>Cda21094aLA9RHPfM?<d/c5[:JO
[Z^SZJNOZ:jYWZBO/KF`]k^f][Nc_l2l^kbh]KB`[jnQX:2BZ:ZN/;:V^kndc<o6blk5blk5bMGGADm?
00412@l><3<acLk<gmkJdm;>f=[Ke]SHd]?AhN;Na<Bn]KJ/];JZ];BX/kFY/kFY/kFY/kFY/kFY/kFY
/kFY/kFY[k6U/;:V/K>W/kFY]KN[]kV]^;Z^^;Z^][N]]kR^^;V_^KZ`^KZ`^KZ`^;V_^;V_^;V_^KZ`
^KZ`^KZ`^KZ`^[^a^[^a^[^a`;na^k^_][N^]kZa`<2d`[j[_;:J/jR:/Iih/Imf/:5c/:9a/jEa]ZEd
]j9e]9id]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]J1c]J1c]J1c]J1c]J1c]J1c]J1c]J1c]Z9c]Z9c
]Z9c]Z9c]Z9c]Z9c]Z9c]Z9c]J1c]J1c]Z5d]j9e]j9e]Z5d]J1c]J1c]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d
]Z5d]Z5d]9id]9id]9id]Ime]Ime]Ime002hZIJhZIJhZIJhZIJhZIJhZIJhZIJhZIJgZINhZYRhZYRi
ZiViZiVhZYRhZYRgZINhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRgZINgZINgZINgZINgZINgZINgZINg
ZINeYiFeYiFfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JeYiFeYiFeYiFe
YiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFe
YiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBe
YiBeYiBeYiBeYiBeYiBfZ9FfZ9FfZ9FeYiBdYY>dYY>cYI:cYI:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:e
Z9:eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6cYHncYHncYHnc
YHncYHncYHncYHncYHneYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6e
Yi6cYHncYHncYHncYHncYHncYHncYHncYHncYXbcYXbcYXbcYXbcYXbcYXbcYXbcYXbcYHncYHncYHnc
YHncYHncYHncYHncYHncYXbcYXbcYXbcYXbcYXbcYXbcYXbcYXbbYH^bYH^bYH^bYH^bYH^bYH^bYH^b
YH^eY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8Ve
Y8VeY8VeY8VeY8VeY8VdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRd
XhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXhJcXhJcXhJc
XhJcXhJcXhJcXhJcXhJbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXh>bXh>bXh>bXh>bXh>bXh>bXh>b
Xh>cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:bXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjaXGfaXGfbXWjb
XWjbXWjbXWjaXGfaXGf`WWn`WWn`WWn`WWn`WWn`WWn`WWn`WWn`X7b`X7b`X7b`X7b`X7b`X7b`X7b`
X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_
Wg^_Wg^_Wg^_Wg^_Wg^_WgZ_WgZ_WgZ_WgZ_WgZ_WgZ_WgZ_WgZ^WWZ^WWZ^WWZ_Wg^`X7b`X7b`X7ba
XGf`WWV`WWV`WWVaWgZbX7^bX7^bX7^cXGbaWgZaWgZaWgZaWgZaWgZaWgZaWgZaWgZ_WgZ_WgZ_WgZ_
WgZ_WgZ_WgZ_WgZ_WgZaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaWgZaWgZaWgZaWgZaWgZaWgZaWgZa
WgZaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7V`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgRaX7VaX7VaX7Va
X7VaX7VaX7VaX7VaX7V`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`
WgR_WWN_WWN_WWN_WWN_WWN_WWN_WWN_WWN_WgF`X7JaXGNaXGNaXGNaXGN`X7J_WgF`WWF`WWF`WWF`
WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF^WWB^WWB^WWB^WWB^WWB^WWB^WWB^
WWB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB]WG>]WG>]WG>^WWB^WWB^WWB_WgF_WgF`WWF`WWF`WWF`
WWF`WWF`WWF`WWF`WWF^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]
Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:_WGB_WGB^W7>^W7>]Vg:/VW6/VW6/VW6]WFn]WFn]WFn]
WFn]WFn]WFn]WFn]WFn/W6j/W6j/W6j/W6j]WFn]WFn^WW2^WW2]WFn]WFn]WFn]WFn]WFn]WFn]WFn]
WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn^WW2]WFn/W6j/W6j/W6j/W6j]WFn^WW2^WW2^WW2^WW2^
WW2^WW2^WW2^WW2^WW2_Wg6^WW2]WFn]WFn]WFn]WFn^WW2_Wg6dW7:dW7:cWW6cWg2aX6n`Wfj_WV^]
Wf^UW7NRV7JMU7>GTGBDT7RDT7fFU8:GUhNBTH>CTXBCTXBDThFEU8JEU8JFUHNFUHNGUhF@T7jJVh^D
UHFDUhRAUXNBUXY1ACT<5@/G7aDX:B3CdLWZimoAc/WIfmG@e<k?f=G1b/OEg=WAe]C:cL_?d]3=c/cP
hMoCdlNc]JVm_k>h_;6i_[G@f<k8d<W3blBmbL]EHF4?6ATJ8R4V:bVPXj6_/:b_[ZZKX:6EVYVDVIOM
hMc=clVd]J^/[:2a/JFa/jNb]:Rb]:Rb]:Rb]:Rb]:Rb]:Ra/jN_/JF_/JF`/ZJb]:Rd]ZZf^:bg^Jfh
^Zjf]jfg^:jh^Jni^[2i^[2i^[2h^Jnh^Jnh^Jnh^Jnh^Jni^[2i^[2j^k6j^k6k_;:o_k>k^[2f]jfj
^k71`KG3`;:o]jJh[i^]Wg^/WGJ/W76_Wg2dXg:gXg>fXGBfX7JeX7>eX7>eX7>eX7>eX7>eX7>eX7>e
X7>dWg:dWg:dWg:dWg:dWg:dWg:dWg:dWg:eXG:eXG:eXG:eXG:eXG:eXG:eXG:eXG:dWg:eX7>fXGBf
XGBfXGBfXGBeX7>dWg:eX7>eX7>eX7>eX7>eX7>eX7>eX7>eX7>eX7>eX7>eX7>fXGBfXGBfXG@00;NX
UKNXUKNXUKNXUKNXUKNXUKNXUKNXUKNYUkNYUkRZV;V[VKV[VKRZV;NYUkNYUkRZV;RZV;RZV;RZV;RZ
V;RZV;RZV;RZV;JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[BVU;FWUKFWUKFWUKJXU[JXU[JXU[JXU[FW
UKFWUKFWUKFWUKFWUKFWUKFWUKFWUKBVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BV
U;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BV
TkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkFWU;FWU;FWU;BVTkBV
TkBVTkBVTkBVTkBWTKBWTKBWTKBWTKBWTKBWTKBWTKBWTKBVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BV
T;BVT;BVT;BVT;BVT;BVT;BVT;BVT;>USk>USk>USk>USk>USk>USk>USk>USkBVT;BVT;BVT;BVT;BV
T;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;>USk>USk>USk>USk>USk>USk>USk>USk>V
S;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>USk>USk>USk>USk>USk>USk>USk>USk>VS;>VS;>VS;>VS;>V
S;>VS;>VS;>VS;:URk:URk:URk:URk:URk:URk:URk:URkFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFT
RKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKBSR;BSR;BSR;BSR;BS
R;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;:Q
Q[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK6QQ;6QQ;6QQ;6QQ;6Q
Q;6QQ;6QQ;6QQ;6RP[6RP[6RP[6RP[6RP[6RP[6RP[6RP[:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK6Q
OK6QOK6QOK6QOK6QOK6QOK6QOK6QOK2PO;6QOK6QOK:RO[:RO[6QOK6QOK2PO;2NOk2NOk2NOk2NOk2N
Ok2NOk2NOk2NOk2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO:nO
NjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONZnONZnONZnONZnO
NZnONZnONZnONZfMNJfMNJjNNZjNNZnONk2PO;6QOK6QOJnNMjnNMk2ON;2ON;6PNK:QN[>RNk>RNk6O
N[6ON[6ON[6ON[6ON[6ON[6ON[6ONZnONZnONZnONZnONZnONZnONZnONZnON[6PNK6PNK6PNK6PNK6P
NK6PNK6PNK6PNK6ON[6ON[6ON[6ON[6ON[6ON[6ON[6ON[6PNK6PNK6PNK6PNK6PNK6PNK6PNK6PNK2O
N;2ON;2ON;2ON;2ON;2ON;2ON;2ON;6PNK6PNK6PNK6PNK6PNK6PNK6PNK6PNK2ON;2ON;2ON;2ON;2O
N;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON:nNMjnNMjnNMjnNMjnNMjnNMjnNMjnNMjnO
MJnOMK2PM[6QMk6QMk2PMZnOMJnOMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK6OM[2NMK2NMK2NMJnM
M:nMM:nMM:nMM:jNM:jNM:jNM:jNM:jNM:jNM:jNM:jNM:jLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjbL
LZfMLjfMLjfMLjjNM:jNM:jNM:jNM;2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMJfKLZfKLZfKLZfKLZfK
LZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJjL
LjjLLjjLLjjLLjfKLZfKLZfKLZfKLZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZ^KKJ^KKJbLKZbLKZbL
KZfMKjfMKjfMKjbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZfM
KjfMKjbLKZ^KKJ^KKJbLKZfMKjfMKjfMKjfMKjfMKjfMKjfMKjfMKjfMKjfMKjjNL:jNL:fMKjbLKZbL
KZfMKjjNL:jNL:nLLJnLLK2ML;2ML;2NKk2NKjnNKJjMK:fOMJZKM:6ELI^BLIJ?M9FANIJBOiJDPY6@
PY:APi:APi>BQ9BCQIFDQYFDQYFDQYNGQHn?OIVJRYBEQI>FQi2EQYFISDU=@@4?0`/E2APN4hf@Qjna
ZifQVjV`ZifWXIZZXhbJU9JRW8B>R7f4Oh65P8^<R=;Ccm7Caj>UVInSV7=hKdYCBDiIDCQ5?Bhj=2Dc
<@TF500;218K60L>2CDl=B/_:B`^:1hY8B8]9CU1>[g5^lc?a[Nh[[6`Y[Vh[[6cYk6cYk:dZ;>eZK>e
ZK:dZ;6cYk6cYjnaYJnaYK2bY[2bY[:dZ;BfZ[Jh[;Ni[KJg[KNh[[Ri[kVj/;Vj/;Vj/;Ri[kRi[kNh
[[Nh[[Ri[kVj/;Zk/KZk/K^l/[^l/[^m/KVj/;Zi[kbk/L2n]<:n/kjj[k^eZ[2UQJbNNZ^KLK2ML;NQ
LKNQLKJRLkNRMKFPLkFPLkFPLkFPLkFPLkFPLkFPLkFPLkBOL[BOL[BOL[BOL[BOL[BOL[BOL[BOL[FQ
L[FQL[FQL[FQL[FQL[FQL[FQL[FQL[BOL[BOL[FPLkJQM;JQM;FPLkBOL[BOL[FPLkFPLkFPLkFPLkFP
LkFPLkFPLkFPLkFQL[FQL[FQL[JRLkJRLkNSM000]jRE]jRE]jRE]jRE]jRE]jRE]jRE]jRE]ZRF]jVG
^:ZH^:ZH^:ZH^:ZH]jVG]ZRF]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF
]ZRF]ZRF]:JD]:JD]:JD]JNE]JNE]ZRF]ZRF]ZRF]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]:JD]:JD
]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD
]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC
]:JC]:JC]:JC]:JC]:JC]:JC/jFB/jFB/jFB]:JC]:JC]:JC]:JC]:JC]:NA]:NA]:NA]:NA]:NA]:NA
]:NA]:NA]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@/jF?/jF?
/jF?/jF?/jF?/jF?/jF?/jF?]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@
]:J@]:J@/jF?/jF?/jF?/jF?/jF?/jF?/jF?/jF?/jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jF?/jF?
/jF?/jF?/jF?/jF?/jF?/jF?/jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</JB:/JB:/JB:/JB:/JB:/JB:
/JB:/JB:]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8
]:>8]:>8]:>8]:>8]:>8]:>8/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7
/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/Z66/Z66/Z66/Z66/Z66/Z66/Z66/Z66/Z:5/Z:5
/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/J64/J64/J64/J64/J64/J64/J64/J64/J:2/J:2/J:2/J:2/J:2/J:2
/J:2/J:2/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/:1l/:1l
/J5m/Z9n/Z9n/J5m/:1l/:1l/9io/9io/9io/9io/9io/9io/9io/9io/:1l/:1l/:1l/:1l/:1l/:1l
/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij
[Yij[Yij[Yij[Yij[Yij[Yij[Yii[Yii[Yii[Yii[Yii[Yii[Yii[Yii[9ah[9ah[Iei[Yij[imk/:1l
/J5m/J5m[Yef[Yef[iig/9mh/J1i/Z5j/j9k/j9k/9ii/9ii/9ii/9ii/9ii/9ii/9ii/9ii[Yii[Yii
[Yii[Yii[Yii[Yii[Yii[Yii/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9ii/9ii/9ii/9ii/9ii/9ii
/9ii/9ii/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh[iig[iig[iig[iig[iig[iig[iig[iig/9mh/9mh
/9mh/9mh/9mh/9mh/9mh/9mh[iig[iig[iig[iig[iig[iig[iig[iig/9mh/9mh/9mh/9mh/9mh/9mh
/9mh/9mh[Yef[Yef[Yef[Yef[Yef[Yef[Yef[Yef[Yid[ime/:1f/:1f/:1f/:1f[ime[Yid[ied[ied
[ied[ied[ied[ied[ied[ied/Imf/9ie/9ie/9ie[ied[Yac[Yac[Yac[Yid[Yid[Yid[Yid[Yid[Yid
[Yid[Yid[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[9ab[9ab[Iec[Iec[Iec[Yid[Yid[Yid[Yac[Yac
[Yac[Yac[Yac[Yac[Yac[Yac[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b
[I]b[I]b[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9YaZiU`[9Ya[9Ya[9Ya[9Ya[9Ya[I]b[I]b[9a^[9a^
[9a^[9a^[9a^[9a^[9a^[9a^Zi]]Zi]]Zi]][9a^[9a^[9a^[Ie_[Ie_[9a^[9a^[9a^[9a^[9a^[9a^
[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[Ie_[9a^Zi]]Zi]]Zi]]Zi]][9a^[Ie_[Ie_[Ie_
[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Yi`[Ie_[Ie_[9a^[9a^[Ie_[Ie_[Yi`ZY]]Zia^[9aa[9aa[Iaa[Iaa
[9Ya[9Ya/9i_[IaaZ9UbXYIdVi=fUY5hU8ikTXilTI22TI22TY63TY63Ti:4U9>5U9>5UIB6UiN5Shmm
VIZ:UIJ6TiJ7SiB5Ui^?Ce=70aH70A021A458b`R=3`e5b<M7BdV3b0L3R4H2QdD6R/R31TA620I7RDN
>cli^kfgcm36XZ>IX:JKGfMM6RDM62DM21H@2ATB1aL@1QH?118<1A8:1a065QhD5Q`A:BlT3b4@7BdL
;c`/_/NjbM33^KZ`/[6W];:X/[BX/[BX];JZ]KN[]KN[];JZ/[BX/[BX/K>W/;:V[k6U[k6U/;:V/[BX
];JZ]KN[][N]]kR^^;V_^KZ`^KZ`^KZ`^;V_^;V_]kR^]kR^^;V_^KZ`^[^a^kbb^kbb_;fc^KZ`^[b`
_Kfa_[bb_[bb_KZb_[Ze_[Ze^K6C/JF3[Yef/iia^:1b]j1`]Yma]j9e]9mb]9mb]9mb]9mb]9mb]9mb
]9mb]9mb/iia/iia/iia/iia/iia/iia/iia/iia]:1a]:1a]:1a]:1a]:1a]:1a]:1a]:1a/iia]9mb
]J1c]J1c]J1c]J1c]9mb/iia]9mb]9mb]9mb]9mb]9mb]9mb]9mb]9mb]:1a]:1a]:1a]:1a]J5b]J5b
002gZ9FgZ9FgZ9FgZ9FgZ9FgZ9FgZ9FgZ9FfZ9JgZINgZINhZYRhZYRgZINgZINfZ9JgZINgZINgZINg
ZINgZINgZINgZINgZINfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JcYI>cYI>dYYBdYYBeYiFfZ9JfZ9Jf
Z9JeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBd
YYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBd
YYBdYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>bY96bY96cYI:c
YI:dYY>eYiBeYiBeYiBdYi6dYi6dYi6dYi6dYi6dYi6dYi6dYi6dYY2dYY2dYY2dYY2dYY2dYY2dYY2d
YY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2bY8jbY8jbY8jbY8jbY8jbY8jbY8jbY8jdYY2dYY2dYY2d
YY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2bY8jbY8jbY8jbY8jbY8jbY8jbY8jb
Y8jbYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bY8jbY8jbY8jbY8jbY8jbY8jbY8jbY8jbYH^bYH^bYH^b
YH^bYH^bYH^bYH^bYH^aY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZdXhRdXhRdXhRdXhRdXhRdXhRdXhRd
XhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRcXXNcXXNcXXNc
XXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNc
XXNbXHJbXHJbXHJbXHJbXHJbXHJbXHJbXHJbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFaXHBaXHBaXHBa
XHBaXHBaXHBaXHBaXHBaXX:aXX:aXX:aXX:aXX:aXX:aXX:aXX:bX86bX86bX86bX86bX86bX86bX86b
X86aXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGf`X7b`X7baXGfbXWjbXWjaXGf`X7b`X7b_WGj_WGj_WGj_
WGj_WGj_WGj_WGj_WGj_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_
Wg^^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWV^WWV^WWV^
WWV^WWV^WWV^WWV^WWV/W7R/W7R]WGV^WWZ_Wg^`X7baXGfaXGf^WWB^WWB_WgF`X7JaXGNbXWRcXgVc
XgV`WWV`WWV`WWV`WWV`WWV`WWV`WWV`WWV^WWV^WWV^WWV^WWV^WWV^WWV^WWV^WWV`WgR`WgR`WgR`
WgR`WgR`WgR`WgR`WgR`WWV`WWV`WWV`WWV`WWV`WWV`WWV`WWV`WgR`WgR`WgR`WgR`WgR`WgR`WgR`
WgR_WWN_WWN_WWN_WWN_WWN_WWN_WWN_WWN`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR_WWN_WWN_WWN_
WWN_WWN_WWN_WWN_WWN`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ^
WGJ^WWB_WgF`X7J`X7J`X7J`X7J_WgF^WWB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGBaWgJ`WWF`WWF_
WGB_WGB^W7>^W7>]Vg:^WWB^WWB^WWB^WWB^WWB^WWB^WWB^WWB^W7>^W7>^W7>^W7>^W7>^W7>^W7>^
W7>/W7:/W7:/W7:]WG>]WG>]WG>^WWB^WWB]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]
Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:/VW6/VW6/VW6/VW6/VW6/VW6/VW6/
VW6YUfjYUfjZV6nZV6n[VG2[VG2/VW6/VW6/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j[Vff[Vff[Vff[
Vff/W6j/W6j]WFn]WFn/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/
W6j]WFn/W6j[Vff[Vff[Vff[Vff/W6j]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn^WW2]WFn/W6j/
W6j/W6j/W6j]WFn^WW2UVfbVW6fYW72YVg6/VgB[VW>[VGB[V7>_Vf^^W6f/W7:XVWJQUgVHTGRAS7N<
R7F@Sh6AT8:AT8:BTH>CTXBCTXBDThFDThFFUXB>SWbIVXZEUXJBUHJ>ThBHW91CEd/05@<03`0:60`0
200>6a<030D<81/671L46Ph77A4I:Ql450T=60h840HQ9Qfl_kK=c/BSYib[/:MOJ5h:5@d75@l14@X<
7QL35Pd96Q4450T13`@H91PH8A@?5PTM91DC:0lV>R<_?RVb_Zbi`;6d]J^d/ZZe/ZZc]JVd]ZZe]j^g
^Jfg^Jfe]j^d]ZZc]JVa/jNa/jN_/JF_/JF`/ZJa/jNc]JVd]ZZf]jfg^:jh^Jni^[2i^[2i^[2h^Jnh
^Jnf]jfg^:jh^Jni^[2j^k6k_;:k_;:l_K>f^Znj_;2n_[:n_;6l^[2k]k:m^[Jo_Kc1^ijfZh^aWgZg
WgFkXG>fWfneWW2dXGBdWg:dWg:dWg:dWg:dWg:dWg:dWg:dWg:cWW6cWW6cWW6cWW6cWW6cWW6cWW6c
WW6dX76dX76dX76dX76dX76dX76dX76dX76cWW6dWg:eX7>eX7>eX7>eX7>dWg:cWW6dWg:dWg:dWg:d
Wg:dWg:dWg:dWg:dWg:bWVnbWVnbWVncWg2cWg2dX7400;NXUKNXUKNXUKNXUKNXUKNXUKNXUKNXUKJX
UKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKFWUKFWUKFWUKFWUKFW
UKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKBVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;JX
UKFWU;FWU;BVTkBVTk>UT[:TTK:TTKBVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVTkBVTkBVTkBVTkBV
TkBVTkBVTkBVTk>TTK>TTKBUT[FVTkFVTkJWU;JWU;JWU;FVTkFVTkFVTkFVTkFVTkFVTkFVTkFVTkFV
TkFVTkFVTkFVTkFVTkFVTkFVTkFVTkBVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;>USk>USkBVT;FWTKFW
TKBVT;>USk>USkBVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>V
S;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>V
S;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>V
S;>VS;>VS;>VS;>VS;>VS;>VS;>VS;6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[FTRKFTRKFTRKFTRKFT
RKFTRKFTRKFTRKBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQk>S
Q[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>S
Q[>SQ[>SQ[>SQ[:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:R
QK:RQK:RQK:RQK:RQK:RQK:RQK:RQK>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ:nRPZnRP[6RP[6RP[>Q
P[FQP[FQP[FQP[:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[6QOK6QOK6QOK6QOK6QOK6QOK6QOK6QOK6Q
OK6QOK6QOK6QOK6QOK6QOK6QOK6QOK2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO:fMNJjNNZjNNZjNNZnO
NjnONjnONk2PO:jNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZfMNJbLN:bLN:fMNJjNNZjNNZfM
N:fMN:fMN:fMN:fMN:fMN:fMN:fMN:nONjnONjjNNZjNNZfMNJbLN:bLN:bLN:bLMjbLMjfMN:fMN:jN
NJjNNJjNNJjNNK2NNK2NNJnMN:jLMjjLMjnMN;2NNK2NNJfLMJjMMZnNMk2ON;6PNK2ON;2ON:nNMjjM
MZjMMZnNMjnNMk2ON;2ON;2ON;2ON;:QNZnNMjfLMJjMM[6PNK:QN[2ON:fLMJnNMjnNMjnNMjnNMjnN
MjnNMjnNMjnNMjjMMZnNMk2ON;2ON;2ON;2ON:nNMjjMMZjMMZnNMk2ON;2ON;2ON;2ON:nNMjjMMZjM
MZjMMZnNMjnNMk2ON;2ON;2ON;2ON:nNMjnNMjnNMjnNMjnNMjnNMjnNMjnNMjjMMZjMMZjMMZjMMZjM
MZjMMZjMMZjMMZnMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:jLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLk2N
MK2NMJnMM:jLLjjLLjfKLZfKLZbJLJjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjL
LjjLLjjLLjjLLjfKLZjLLjjLLjnMM:nMM:jLLjjLLjfKLZbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJ
LJbJLJbJLJbJLJbJLJbJLJbJLJbJLJfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZ^IL:^IL:^IL:bJLJbJ
LJbJLJfKLZfKLZbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbL
KZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZ^KKJ^KKJ^KKJ^KKJ^K
KJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZ^K
KJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZ^KKJ^KKJ^KKJbLKZbL
KZbLKZfMKjfMKk2ML:nLKjfLLJfMLjbNM:RLM:6GKifBK8n>P8b?P8V@PHJBP8NCPHbBOi6AOiJBP8j=
Oi6@PY6@PY:APifLSZ6PTXf<OW9aH`PC0`/F1PhI2A0K2a4L31<N3QHQ4ATT52X`6AXP2AHK1RDZ5BDY
5QXM3DU<?9ZMS[BfZ[2bYYjPU7]mLEIHC4=5>DQ:?UAFBV1NDf=QEVUWG71^HgQfJgmmLXF3N8R6Ni:@
QIZHSJJTVJn]X[BbYkFcZ;BbYkBbYkFcZ;JdZKNeZ[RfZkZh[K^i[[bj[kfk/;2cY;2cY;2cY;6dYK6d
YK:eY[:eY[:eY[Jg[KNh[[Ri[kVj/;Vj/;Vj/;Vj/;Vj/;Nh[[Nh[[Nh[[Ri[kRi[kVj/;Vj/;Vj/;Zk
/KZk/KZk/KZk/KZk/KZk/KZk/KZk/Kfk/;J`WJjRQZnMN;JQM;^TM[RSM[>PLk:ML;:ML;:ML;>NLKBO
L[JQM;NRMKRSM[:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;>NLK>NLK>NLK>NLK>NLK>NLK>NLK>NLKBM
KkBMKkFNL;FNL;FNL;JOLKJOLKJOLKJOL[JOL[JOL[JOL[JOL[JOL[JOL[JOL[BPLKBPLKFQL[JRLkNS
M;NSM000]jRE]jRE]jRE]jRE]jRE]jRE]jRE]jRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE
]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE
]JNE]JNE]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]JND]JND]:JC]:JC/jFB/jFB/ZBA/ZBA]:JD]:JD
]:JD]:JD]:JD]:JD]:JD]:JD]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:FB]:FB]:FB]JJC]JJC]JJC
]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]:J@]:J@
]:J@]:J@]:J@]:J@]:J@]:J@/jF?/jF?]:J@]JNA]JNA]:J@/jF?/jF?]:J@]:J@]:J@]:J@]:J@]:J@
]:J@]:J@/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;
/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;
/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/JB:/JB:
/JB:/JB:/JB:/JB:/JB:/JB:]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]:B7]:B7]:B7]:B7]:B7]:B7
]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6
/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5
/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/j64/j64
/j64/j64/j64/j64/j64/j64[j:2[j:2/J:2/J:2/j62]J62]J62]J62/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n
/Z9n/Z9n/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m[imk[imk
[imk[imk[imk[imk[imk[imk[Iei[Iei[Yij[Yij[Yij[imk[imk[imk[Yij[Yij[Yij[Yij[Yij[Yij
[Yij[Yij[Yij[Yij[Iei[9ah[9ah[Iei[Yij[Yij[Ieh[Ieh[Ieh[Ieh[Ieh[Ieh[Ieh[Ieh[imk[Yij
[Yij[Iei[Iei[9ah[9ah[9ah[9ag[9ag[Ieh[Ieh[Ieh[Yii[Yii[Yii/9ii/9ii[ieh[Yag[Yag[ieh
/9ii/9ii[Iae[Yef[iig/9mh/9mh/9mh/9mh[iig[Yef[Yef[iig[iig[iig/9mh/9mh/9mh/J1i[iig
[Iae[Yef/9mh/J1i/9mh[Iae[iig[iig[iig[iig[iig[iig[iig[iig[Yef[iig/9mh/9mh/9mh/9mh
[iig[Yef[Yef[iig/9mh/9mh/9mh/9mh[iig[Yef[Yef[Yef[iig[iig[iig/9mh/9mh/9mh[iig[iig
[iig[iig[iig[iig[iig[iig[Yef[Yef[Yef[Yef[Yef[Yef[Yef[Yef[ied[ied[ied[ied[ied[ied
[ied[ied[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[ied[ied[ied[Yac[Yac[I]b[I]b[9Ya[Yac[Yac
[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[I]b[Yac[Yac[ied[ied[Yac
[Yac[I]b[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[I]b[I]b
[I]b[I]b[I]b[I]b[I]b[I]bZiU`ZiU`ZiU`ZiU`[9Ya[9Ya[I]b[I]b[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya
[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^
[9a^[9a^[9a^[9a^[9a^[9a^Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/
ZYY/ZYY/[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]][9a^[9a^
[9a^[9a^[9a^[9a^[9a^[9a^Zi]]Zi]]Zi]]Zi]][9a^[9a^[Ie_[Ie_[ia_[Y]^[9]`[Ieb[9idZ9ad
Y9Q`WiE]ThejShijRi1kQi1lQi9nS9:1TY>3U9B4SHanU9>5UIB6TY63UiJ8W9^=U9>5Q8=eFf9CG6=D
GFAEH6MHHVUJIFaMIVeNIfiOLGMPNWmZQHYeTiN4UYZ7QhYjSi:3/KBUYZRLZ:ZNZ:ZNXjFIWZ2DXJ>G
[JnS^;Z^YJ>HYZBIZ:JKZjVN[ZbQ/:jS/[2U/k6VYZBIZjVN/:jS/k6V];:W/k6V];:W]K>X]K>X][BY
]kFZ^;J[^KN/^kV^_;Z__;Z_/KBU/KBU/KBU/KBU/KBU/KBU/KBU/KBU]KJ/][N]]kR^^;V_^KZ`^KZ`
^KZ`^KZ`]kR^]kR^]kR^^;V_^;V_^KZ`^KZ`^KZ`^[^a^[^a^[^a^[^a^[^a^[^a^[^a^[^aa<:g_KJU
/JJ;ZYYfZYM/[YU//Ia_/9e`^JAg^:=f]j9e]J1c]9mb/iia/iia/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`
/Ye`/Ye`/iia/iia/iia/iia/iia/iia/iia/iia]9e_]9e_]9e_]Ii`]Ii`]Yma]Yma]Yma]Ymb]Ymb
]Ymb]Ymb]Ymb]Ymb]Ymb]Ymb/im`/im`]J5b]J5b]Z9c]Z9c002gZ9FgZ9FgZ9FgZ9FgZ9FgZ9FgZ9Fg
Z9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FdYYBdYYBdYYBd
YYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBcYI>cYI>cYI>cYI>cYI>cYI>cYI>c
YI>dYY>dYY>dYY>dYY>cYI:cYI:cYI:bY96cYI>cYI>cYI>cYI>cYI>cYI>cYI>cYI>cYI:cYI:cYI:c
YI:cYI:cYI:cYI:cYI:eYY>eYY>eYY>dYI:dYI:dYI:dYI:dYI:dYI:dYI:dYI:dYI:dYI:dYI:dYI:d
YI:dYI:dYI:dYI:dYI:dYI:dYI:dYI:dYI:cYHncYHncYHncYHncYHncYHncYHncYHnbY8jcYHndYY2d
YY2dYY2dYY2cYHnbY8jcYHncYHncYHncYHncYHncYHncYHncYHnbYH^bYH^bYH^bYH^bYH^bYH^bYH^b
YH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^b
YH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^b
YH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^aY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZeY8VeY8VeY8Ve
Y8VeY8VeY8VeY8VeY8VdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8Nd
Y8NcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJc
XhJcXhJcXhJcXhJcXhJbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFb
XXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>^XH6^XH6`XH6`
XH6bX86dX86dX86dX86aXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGf`X7b`X7b`X7b`X7b`X7b`X7b`X7b`
X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^]WGV]WGV]WGV^
WWZ^WWZ_Wg^_Wg^_Wg^^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ]WGV/W7R/W7R/W7R/W7R]WGV^
WWZ]WGR]WGR]WGR]WGR]WGR]WGR]WGR]WGR^WWZ^WWZ]WGV]WGV]WGV/W7R/W7R/W7R/W7N/W7N/W7N]
WGR]WGR]WGR^WWV^WWV`WWV_WGR^W7N^W7N^W7N^W7N_WGR`WWV]W7F^WGJ_WWN`WgR`WgR`WgR_WWN_
WWN^WGJ^WGJ^WGJ_WWN_WWN_WWN`WgR`WgR`WgR_WWN]W7F^WGJ`WgR`WgR_WWN^WGJ_WWN_WWN_WWN_
WWN_WWN_WWN_WWN_WWN^WGJ^WGJ_WWN`WgR`WgR_WWN^WGJ^WGJ^WGJ^WGJ_WWN`WgR`WgR_WWN^WGJ^
WGJ^WGJ^WGJ^WGJ_WWN_WWN_WWN`WgR`WgR_WWN_WWN_WWN_WWN_WWN_WWN_WWN_WWN^WGJ^WGJ^WGJ^
WGJ^WGJ^WGJ^WGJ^WGJ_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB^W7>^W7>^W7>^W7>^W7>^W7>^W7>^
W7>_WGB^W7>^W7>^W7>]Vg:]Vg:]Vg:]Vg:^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^
W7>^W7>^W7>^W7>^W7>]Vg:]Vg:^W7>_WGB_WGB^W7>]Vg:]Vg:/VW6/VW6/VW6/VW6/VW6/VW6/VW6/
VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6ZV6nZV6n[VG2[
VG2/VW6/VW6/VW6/VW6[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[
VG2[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[VffZVVbZVVbZVVbZ
VVbZVVbZVVbZVVbZVVbYVF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^[Vff[Vff[Vff[Vff[Vff[Vff[Vff[
Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff[VffZVVbZVVb[Vff[
Vff/W6j/W6j/W6j/W6j]Vfb/VFb[Vff/Vg2]WG>[WG>XVG:UUVnJT7:GSg:BSg><SgJ;T7^<TX6>ThB@
U8R=S7jFUHNHUhVAT8:@Sh6GUXRJVH^GUXRGVX^DUhRCUXNFVHZKWXnNXI:MX96KWXnDVHBUZYFX[9VV
ZYN_/Z:_/Z>WZY^XZib^/:B/[Z:[[J6Z[:2Z[:2Z[:2YZinXZYje/jRe/jRd/ZNd/ZNc/JJb/:Fb/:Fa
[jBe/jRf]:Vf]:Vd/ZNb/:Fc/JJe/jRh]Z^e/jRf]:Vg]JZh]Z^i]jbj^:fk^Jjk^Jjc]ZNc]ZNc]ZNb
]JJa]:Fa]:F`/jB`/jBd]J^e]Zbf]jfh^Jni^[2i^[2i^[2h^Jng^:jg^:jg^:jh^Jnh^Jni^[2i^[2i
^[2j^k6j^k6j^k6j^k6j^k6j^k6j^k6j^k72`;G0_:Zl/YZfYhN`WgRaWW>fXgJkZ7^aW6naW6naW6nb
WG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2cWW6cWW6cWW6cWW6cWW6cWW6cWW6c
WW6dWFndWFndWFndWFneWW2eWW2fWg6fWg6eWW6eWW6eWW6eWW6eWW6eWW6eWW6eWW6aWFjbWVncWg2d
X76dX76dX7400;JWU;JWU;JWU;JWU;JWU;JWU;JWU;JWU;FWU;FWU;FWU;FWU;FWU;FWU;FWU;FWU;FW
U;FWU;FWU;FWU;FWU;FWU;FWU;FWU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BV
U;BVU;BVU;BVU;>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UT[>UT[>UT[>UT[>UT[>UT[>UT[>UT[>U
Tk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UT[>UT[>UT[>UT[>UT[>UT[>UT[>UT[FVTkFVTkFVTkBUT[BU
T[>TTK>TTK:ST;BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[>U
Sk>USk>USk>USk>USk>USk>USk>USk:TS[:TS[>USkBVT;BVT;>USk:TS[:TS[>USk>USk>USk>USk>U
Sk>USk>USk>USk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:U
Rk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:U
Rk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk6T
R[6TR[6TR[6TR[6TR[6TR[6TR[6TR[FTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRK>SQ[>SQ[>SQ[>SQ[>S
Q[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:R
QK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:R
QK:RQK:RQK:RQK6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;:P
Pk:PPk:PPk:PPk:PPk:PPk:PPk:PPjjQPJjQPK2QPK2QPK:PPKBPPKBPPKBPPK6QOK6QOK6QOK6QOK6Q
OK6QOK6QOK6QOK2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO:nO
NjnONjnONjnONjnONjnONjnONjnONjbLN:fMNJfMNJfMNJjNNZjNNZjNNZnONjjNNZjNNZjNNZjNNZjN
NZjNNZjNNZjNNZfMNJfMNJbLN:^KMj^KMjbLN:fMNJfMNJbLMjbLMjbLMjbLMjbLMjbLMjbLMjbLMjfM
NJfMNJfMNJbLN:bLN:bLN:bLN:bLN:^KMZ^KMZbLMjbLMjfMN:fMN:fMN:fMN:nMN:nMN:jLMjfKMZfK
MZjLMjnMN:nMN:bKM:fLMJjMMZnNMk2ON:nNMjnNMjjMMZfLMJfLMJjMMZjMMZnNMjnNMjnNMjnNMjnN
MjjMMZjMMZjMMZnNMjnNMjjMMZjMMZjMMZjMMZjMMZjMMZjMMZjMMZjMMZjMMZfLMJjMMZnNMjnNMjnN
MjnNMjjMMZfLMJfLMJjMMZnNMjnNMjnNMjnNMjjMMZfLMJfLMJfLMJjMMZjMMZnNMjnNMjnNMjnNMjjM
MZjMMZjMMZjMMZjMMZjMMZjMMZjMMZfLMJfLMJfLMJfLMJfLMJfLMJfLMJfLMJjLLjjLLjjLLjjLLjjL
LjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfK
LZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZbJLJfKLZjLLjjLLjjL
LjjLLjfKLZbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJ
LJbJLJbJLJbJLJbJLJbJLJbJLJbJLJZHKjZHKjZHKj^IL:^IL:^IL:bJLJbJLJ^IL:^IL:^IL:^IL:^I
L:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^K
KJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:RHJZRHJZRHJZRHJZRH
JZRHJZRHJZRHJZ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^K
KJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJZJK:ZJK:ZJK:^KKJ^KKJ^KKJbLKZbLKZZJJjVIJZVIJj^KKJfL
LJjLLj^KLJRHKZFEJj2CKIZAKi>?LXn?Mhb@OHbAPXbCQXj=OiFDQYNFR96@PXj=OiFDQY^JS9bKSIfL
SYVHRYJEQiVHRZ2OTJ>RU:6PTYbKSIVNRJ>WU9ZNRi6DQ9jQTZV/WJNYWJJXW:V[WjRZWZRZWZV[WjZ/
X:RZWZBVVZ2RUZj/XJj/XJj/XJj/XJj/XJn]XZn]XZn]X[BbYkBbYkBbYk>aY[:`YK>aY[NeZ[Zh[KFc
Z;JdZKJdZKNeZ[RfZkVg[;Zh[KZh[KFhZKFhZKBgZ;>fYk6dYK2cY:nbXjnbXk:cZK>dZ[Ff[;Nh[[Ri
[kRi[kRi[kRi[kNh[[Nh[[Nh[[Ri[kRi[kVj/;Vj/;Vj/;Zk/KZk/KZk/KZk/KZk/KZk/KZk/KZk/KFc
Z;bgZ;ffX[R]TJjOOZVHLJ^JKk6NLK6LKk6LKk:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:M
L;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;>LK[>LK[BMKkBMKkBMKkFNL;FNL;FNL;BM
L;BML;BML;BML;BML;BML;BML;BML;2LKK6MK[:NKk>OL;>OL;>OL000]ZND]ZND]ZND]ZND]ZND]ZND
]ZND]ZND]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]JND]:JD]:JD
]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD/ZBB/ZBB/ZBB/ZBB/ZBB/ZBB
/ZBB/ZBB/ZBA/ZBA/ZBA/ZBA/ZBA/jFB/jFB/jFB/ZBB/ZBB/ZBB/ZBB/ZBB/ZBB/ZBB/ZBB/ZBA/ZBA
/ZBA/ZBA/ZBA/ZBA/ZBA/ZBA]JJC]JJC]:FB]:FB/jBA/Z>@/Z>@/Z>@/jBA/jBA/jBA/jBA/jBA/jBA
/jBA/jBA/jBA/jBA/jBA/jBA/jBA/jBA/jBA/jBA/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>/J>=/ZB>
/jF?/jF?/jF?/jF?/ZB>/J>=/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>/JB:/JB:/JB:/JB:/JB:/JB:
/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:
/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:
/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9]:>8]:>8
]:>8]:>8]:>8]:>8]:>8]:>8/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6
/j>6/j>6/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5
/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/J64/J64/J64/J64/J64/J64
/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23[Z61[Z61
/:61/:61/Z21]:21]:21]:21/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l[imk[imk[imk[imk[imk[imk
[imk[imk[imk[imk[imk[imk[imk[imk[imk[imk[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[9ah[9ah
[9ah[Iei[Iei[Yij[Yij[Yij[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[9ahZi]gZi]gZi]gZi]g
[9ah[Iei[9ag[9ag[9ag[9ag[9ag[9ag[9ag[9ag[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ahZi]fZi]f
Zi]f[9ag[9ag[9ag[Ieh[Ieh[ieh[Yag[I]f[I]f[I]f[I]f[Yag[ieh[9]d[Iae[Yef[iig[iig[iig
[Yef[Yef[Iae[Iae[Iae[Yef[Yef[Yef[iig[iig[Iae[Yef[Yef[Yef[Yef[Iae[Yef[Yef[Yef[Yef
[Yef[Yef[Yef[Yef[Yef[Yef[Iae[Iae[Yef[iig[iig[Yef[Iae[Iae[Iae[Iae[Yef[iig[iig[Yef
[Iae[Iae[Iae[Iae[Iae[Yef[Yef[Yef[iig[iig[Yef[Yef[Yef[Yef[Yef[Yef[Yef[Yef[Iae[Iae
[Iae[Iae[Iae[Iae[Iae[Iae[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac
[Yac[Yac[9Ya[9Ya[9Ya[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b
[I]b[I]b[I]b[I]b[I]b[I]b[9Ya[9Ya[I]b[Yac[Yac[I]b[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya
[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9YaZIM^ZIM^
ZYQ_ZYQ_ZiU`ZiU`ZiU`ZiU`ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_
ZYQ_ZYQ_ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZIU[ZIU[
ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[Z9QZZ9QZZ9QZZ9QZZ9QZZ9QZZ9QZZ9QZZYY/ZYY/ZYY/ZYY/ZYY/ZYY/
ZYY/ZYY/Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZIU[ZIU[
ZYY/ZYY/Zi]]Zi]]Zi]]Zi]]ZIYYZ9UXZ9QYZYY/[Y]^[iaa[Y]`[9Q_[9]ZZIU[Y9I/W99`UY1cShii
RhmlR8n0T8n1TY63TY63T8n1TY63UYF7UiJ8UYF7WIZ<VIJ8UY>5VIJ8X9f?Xj2BXIj@W9V;UIV6WJ6>
Vij>W9n?YjZKZ:ZNYJNKZjbRY:JJZ:ZN[:jR[[2T[k6U/;:V/[BX];JZ[ZbQ[jfR/:jS/[2U];:W]K>X
]kFZ^;J[/:jS/[2U]K>X]K>X];:W];:W][BY^;J[][BY][BY][BY]kFZ^;J[^;J[^KN/^KN/]kZ[][VZ
]KRY/kJW/[FV/;>T[k:S[k:S/K:X/[>Y];F[][N]]kR^^;V_^;V_^;V_]kR^]kR^]kR^^;V_^;V_^KZ`
^KZ`^KZ`^[^a^[^a^[^a^[^a^[^a^[^a^[^a^[^a_[ba`[na`Kf[^;:K[J:6YiUeZYY`/Iia]j9e^:=f
^:=f]j9e]J1c/iia/Ia_[iY]/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`
/Ye`/Ye`/ia^/ia^/ia^]9e_]9e_]9e_]Ii`]Ii`]9e`]9e`]9e`]9e`]9e`]9e`]9e`]9e`/9a]/9a]
/Ie^/Yi_/im`/im`002eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>d
YY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>cYI>cYI>cYI>cYI>cYI>cYI>cYI>cYI>cYI>cYI>cYI>c
YI>cYI>cYI>cYI>cYI>bY9:bY9:bY9:bY9:bY9:bY9:bY9:bY9:aXi2aXi2aXi2bY96bY96bY96cYI:c
YI:bY9:bY9:bY9:bY9:bY9:bY9:bY9:bY9:bY96bY96bY96bY96bY96bY96bY96bY96dYI:cY96cY96c
Y96cY96cY96bXi2bXi2cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96c
Y96bY8jbY8jbY8jbY8jbY8jbY8jbY8jbY8jaXhfaXhfbY8jcYHncYHnbY8jaXhfaXhfbY8jbY8jbY8jb
Y8jbY8jbY8jbY8jbY8jaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8Za
Y8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8Za
Y8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8Za
Y8Z`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhVdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRbXXFbXXFbXXFb
XXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFaXHBaXHBaXHBaXHBaXHBaXHBaXHBa
XHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBbXXFbXXFbXXFb
XXFbXXFbXXFbXXFbXXF`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`
X8>aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:]X82]X82_X82_X82aWh2cWh2cWh2cWh2`X7b`X7b`X7b`
X7b`X7b`X7b`X7b`X7b_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_
Wg^^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ/W7R/W7R/W7R/W7R]WGV]WGV]WGV^WWZ]WGV]WGV]WGV]
WGV]WGV]WGV]WGV]WGV/W7R/W7R[VgNZVWJZVWJ[VgN/W7R/W7R[VgJ[VgJ[VgJ[VgJ[VgJ[VgJ[VgJ[
VgJZVWJ[VgN[VgN[VgN/W7R/W7R/W7R/W7RZVWF[VgJ[VgJ[VgJ/W7N/W7N/W7N/W7N^W7N^W7N]VgJ/
VWF/VWF]VgJ^W7N^W7N[VW>/VgB]W7F^WGJ_WWN^WGJ^WGJ]W7F/VgB]W7F]W7F]W7F^WGJ^WGJ^WGJ^
WGJ/VgB^WGJ_WWN^WGJ]W7F/VgB]W7F_WWN]W7F]W7F]W7F]W7F]W7F]W7F]W7F]W7F/VgB]W7F^WGJ^
WGJ^WGJ^WGJ]W7F/VgB/VgB]W7F^WGJ^WGJ^WGJ^WGJ]W7F/VgB/VgB]W7F]W7F]W7F^WGJ^WGJ^WGJ^
WGJ]W7F]W7F]W7F]W7F]W7F]W7F]W7F]W7F/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB]Vg:]Vg:]Vg:]
Vg:]Vg:]Vg:]Vg:]Vg:^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>[VG2[VG2/VW6/VW6/VW6]Vg:]Vg:]
Vg:/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6[VG2/VW6]Vg:]
Vg:]Vg:]Vg:/VW6[VG2/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/
VW6[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2YUfjYUfjYUfjZV6nZV6n[VG2[VG2[VG2ZV6nZV6nZV6nZ
V6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZVVbZVVbZVVbZVVbZVVbZVVbZVVbZ
VVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbYVF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^Y
VF^YVF^YVF^YVF^YVF^ZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVb[Vff[Vff[Vff[Vff[Vff[Vff[Vff[
VffZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbYVF^YVF^YVF^ZVVbZVVb[Vff[Vff[VffZVfZXVFRWV6N[
VFZ_VVf`VfjbVW2`V6j_W6V_Vf^/VFbXUg2PTg>GT7F?SgN9SgR@Sh6?SX2>SGnAT8:EU8JGUXRDThF@
Sh6KVXbIV8ZHUhVKVXbPWi6SXYBRXI>OWY2FVHVKWXjHVh^JWHjOXIFJW92KW9:/[J>YZin][j>_/JF[
[J6TYYZPXYJSYIVWZIf[ZIj/ZYn]Zj2^[:6`[Z>a[jBb/:Fc/JJd/ZNf]:Vi]jbi]jbg]JZe/jRd/ZNd
/ZNf]:Vf]:Vf]:Vg]JZg]JZh]Z^h]Z^h]Z^g^Z^f^JZe^:Vd]jRb]JJa]:F`/jB_/Z>_/:Ja/ZRb/jVe
]Zbf]jfg^:jg^:jg^:jg^:jg^:jg^:jh^Jnh^Jni^[2i^[2i^[2j^k6j^k6j^k6j^k6j^k6j^k6j^k6j
^k6e/jRc/JJ][9jXY9:RWHBVVg^aX7VhYGRWTVFYU6N]V6^`VfjcWW6eX7>eX7>eX7>bWG2bWG2bWG2b
WG2bWG2bWG2bWG2bWG2aW6naW6naW6naW6naW6naW6naW6naW6nbVffbVffcW6jcW6jdWFndWFndWFnd
WFncW6ncW6ncW6ncW6ncW6ncW6ncW6ncW6n`W6faWFjbWVncWg2cWg2cWg000;FVTkFVTkFVTkFVTkFV
TkFVTkFVTkFVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTk>U
Tk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk:TT[:TT[:TT[:TT[:T
T[:TT[:TT[:TT[2RSk2RSk6ST;6ST;:TTK:TTK>UT[>UT[:TT[:TT[:TT[:TT[:TT[:TT[:TT[:TT[:T
TK:TTK:TTK:TTK:TTK:TTK:TTK:TTK:ST;:ST;:ST;:ST;>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>T
TK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK6SSK6SSK6SSK6SSK6SSK6SSK6SSK6SSK2R
S;6SSK:TS[:TS[:TS[:TS[6SSK2RS;6SSK6SSK6SSK6SSK6SSK6SSK6SSK6SSK2SRK2SRK2SRK2SRK2S
RK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2S
RK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2S
RK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRJnRR:nRR:nRR:nRR:nRR:nRR:nRR:nRR;>R
Qk>RQk>RQk>RQk>RQk>RQk>RQk>RQk:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:R
QK:RQK:RQK:RQK6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6Q
Q;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK2PPk2PPk2PPk2PPk2P
Pk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OPZfP
P:fPP:nPP:nPP;6OP;>OP;>OP;>OP;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO:jNNZjNNZjNNZjNNZjN
NZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJ^K
Mj^KMjbLN:bLN:bLN:fMNJfMNJfMNJbLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:^KMj^KMjZJMZZJ
MZ^KMj^KMjbLN:^KMZ^KMZ^KMZ^KMZ^KMZ^KMZ^KMZ^KMZZJMZZJMZZJMZ^KMj^KMjbLN:bLN:fMNJZJ
MJZJMJ^KMZ^KMZ^KMZbLMjbLMjbLMjjLMjfKMZfKMZbJMJbJMJfKMZfKMZjLMj^JLjbKM:fLMJjMMZjM
MZjMMZjMMZfLMJbKM:bKM:fLMJfLMJfLMJjMMZjMMZjMMZ^JLjjMMZnNMjjMMZbKM:^JLjfLMJnNMjfL
MJfLMJfLMJfLMJfLMJfLMJfLMJfLMJbKM:fLMJfLMJjMMZjMMZfLMJfLMJbKM:bKM:fLMJfLMJjMMZjM
MZfLMJfLMJbKM:bKM:bKM:fLMJfLMJfLMJjMMZjMMZjMMZfLMJfLMJfLMJfLMJfLMJfLMJfLMJfLMJbK
M:bKM:bKM:bKM:bKM:bKM:bKM:bKM:fKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZjLLjjLLjjLLjjLLjjL
LjjLLjjLLjjLLjZHKj^IL:^IL:bJLJbJLJfKLZfKLZfKLZbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJ
LJbJLJbJLJbJLJbJLJbJLJbJLJbJLJ^IL:^IL:bJLJfKLZfKLZbJLJ^IL:^IL:bJLJbJLJbJLJbJLJbJ
LJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJ^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:VG
KZVGKZVGKZVGKZZHKjZHKjZHKj^IL:ZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZH
KjZHKjZHKjZHKjZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:RH
JZRHJZRHJZRHJZRHJZRHJZRHJZRHJZZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJ
K:ZJK:ZJK:ZJK:^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:VI
JjVIJjVIJjVIJjZJK:ZJK:ZJK:^KKJZMJJVKIjNHIjZIJ:jJJk6JKK:IKK6HKZbKJ:fLJk2KK[2JLJVG
LYnDM9FBLhj@LXj=Ohf<OXj=Oi:APiFDQYFDQYBCQIBCQIBDQYFEQiJFR9VIRi^KSIfMSinOTJ2PTZ:U
UJR[Vj2SU9RJSY^MTI^LTYnPUZj_YZ:TV:JXW:Z/X:^]XJZ/X:Z/X:f_Xk6cYk2^Xk6_Y;:`YK>aY[Bb
YkFcZ;JdZKJdZKJdZKNeZ[Vg[;RfZkJdZKBbYkBbYkFcZ;JdZKJdZKJdZKJdZKNeZ[NeZ[NeZ[NeZ[Ji
Z[JiZ[FhZKBgZ;>fYk:eY[6dYK6dYJj_YJn`Y[:cZKBeZkJg[KNh[[Nh[[Nh[[Nh[[Nh[[Nh[[Ri[kRi
[kVj/;Vj/;Vj/;Zk/KZk/KZk/KZk/KZk/KZk/KZk/KZk/J6OU9fMTIZJSY^JS:6LQjJLOZRILZVFJIb7
FZ2;GZJAI:bGJ[6LKkFPLkNRMKNRMK:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;6LKk6LKk6LKk6LKk6L
Kk6LKk6LKk6LKk:KKK:KKK:KKK>LK[>LK[BMKkBMKkBMKk:KK[:KK[:KK[:KK[:KK[:KK[:KK[:KK[6M
K[6MK[:NKk>OL;BPLKBPL@00]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]:JC]:JC]:JC]:JC]:JC]:JC
]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC
/jFC/jFC/jFC/jFC/jFC/jFC/J>A/J>A/J>A/J>A/J>A/J>A/J>A/J>A/::?/::?/::?/J>@/ZBA/ZBA
/jFB/jFB/J>A/J>A/J>A/J>A/J>A/J>A/J>A/J>A/J>@/J>@/J>@/J>@/J>@/J>@/J>@/J>@/J:?/J:?
/J:?/Z>@/jBA/jBA]:FB]:FB/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@
/Z>@/Z>@/J>=/J>=/J>=/J>=/J>=/J>=/J>=/J>=/::</J>=/ZB>/ZB>/ZB>/ZB>/J>=/::</J>=/J>=
/J>=/J>=/J>=/J>=/J>=/J>=/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9
/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9
/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9
/:>9/:>9[j:8[j:8[j:8[j:8[j:8[j:8[j:8[j:8/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/Z:5/Z:5
/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/J64/J64/J64/J64/J64/J64
/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/Z:5/Z:5
/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/:23/:23/:23/:23/:23/:23/:23/:23/:23/:23/:23/:23/:23/:23
/:23/:23/In2/In2/In2/In2/In2/In2/In2/In2[J20[J20[j20[j20/In0/in0/in0/in0[imk[imk
[imk[imk[imk[imk[imk[imk[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij
[Yij[Yij[Iei[Iei[Iei[Iei[Iei[Iei[Iei[IeiZi]gZi]gZi]g[9ah[9ah[Iei[Iei[Iei[9ah[9ah
[9ah[9ah[9ah[9ah[9ah[9ah[9ahZi]gZi]gZYYfZYYfZi]gZi]g[9ahZi]fZi]fZi]fZi]fZi]fZi]f
Zi]fZi]fZIUeZIUeZYYfZi]gZi]g[9ah[9ah[IeiZYYeZYYeZYYeZi]fZi]fZi]f[9ag[9ag[Yag[I]f
[I]f[9Ye[9Ye[I]f[I]f[YagZiYc[9]d[Iae[Yef[Yef[Yef[Iae[Iae[9]d[9]d[9]d[Iae[Iae[Iae
[Yef[YefZiYc[Iae/9mh[YefZiYcZYUb[9]d[iig[Iae[Iae[Iae[Iae[Iae[Iae[Iae[Iae[9]d[Iae
[Iae[Yef[Yef[Iae[Iae[9]d[9]d[Iae[Iae[Yef[Yef[Iae[Iae[9]d[9]d[9]d[9]d[Iae[Iae[Iae
[Yef[Yef[Iae[Iae[Iae[Iae[Iae[Iae[Iae[Iae[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[I]b[I]b
[I]b[I]b[I]b[I]b[I]b[I]b[Yac[Yac[Yac[Yac[Yac[Yac[Yac[YacZYQ_ZYQ_ZiU`ZiU`[9Ya[I]b
[I]b[I]b[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9YaZiU`ZiU`
[9Ya[I]b[I]b[9YaZiU`ZiU`[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya
[9Ya[9YaZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`Z9I]ZIM^ZIM^ZIM^ZYQ_ZYQ_ZYQ_ZYQ_ZIM^ZIM^
ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[
ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[Z9QZZ9QZZ9QZZ9QZZ9QZZ9QZZ9QZZ9QZZi]]Zi]]
Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]
Zi]]Zi]]ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[Z9QZZIU[ZIU[ZIU[ZYY/ZYY/ZYY/ZYY/ZYeYZI]W
YiQWZYUX[iQZ/YU]/IQ//YM[YiUUZiYY/9a]]9ab[iYdYYQdViEbU9=aS8]mSHanShj0Ti:4Ti:4Ti:4
UYF7ViZ<Si:3TYF6UIR9UiZ;V9^<VYf>WJ2AX:>DUiZ:ZZfNZJbMWj6EXjBJY:FKWIjEW9fDXZBHXjFI
YZRLZJ^OZZbPZZbPZJ^OZJ^O[:ZO[J^P[ZbQ/:jS/[2U];:W]K>X][BY/k6V];:W];:W/k6V/[2U/k6V
][BY^;J[][BY][BY][BY][BY][BY]kFZ]kFZ]kFZ][VZ]KRY]KRY];NX/kJW/[FV/[FV/KBU[ZnU[k2V
/K:X/kBZ]KJ/][N]]kR^]kR^]kR^]kR^]kR^^;V_^;V_^KZ`^KZ`^KZ`^[^a^[^a^[^a^[^a^[^a^[^a
^[^a^[^a_[ba_;b`^kbb`L6ea/:_`;RK/j=nYiAW/9]^/Ia_/iia]J1c]J1c/iia/Ia_[iY]/Ye`/Ye`
/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ia_/Ia_/Ia_/Ia_/Ia_/Ia_/Ia_/Ia_/Y]]/Y]]/Y]]/ia^/ia^/ia^
]9e_]9e_/Y]^/Y]^/Y]^/Y]^/Y]^/Y]^/Y]^/Y]^/Ie^/Yi_/im`]:1a]:1a]:1a002fYiBeYY>dYI:d
YI:dYI:dYI:eYY>fYiBfYiBfYiBfYiBfYiBfYiBfYiBfYiBfYiBeYY>eYY>eYY>eYY>eYY>eYY>eYY>e
YY>dYI:dYI:dYI:dYI:dYI:dYI:dYI:dYI:cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96c
Y96cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96aXXnaXXnaXXnaXXnaXXnaXXnaXXna
XXncY96cY96cY96cY96cY96cY96cY96cY96bY8jbY8jaXhf`XXb`XXbaXhfbY8jbY8jaXXnaXXnaXXna
XXnaXXnaXXnaXXnaXXnaXhfaXhfaXhfaXhfaXhfaXhfaXhfaXhfaXXnaXXnaXhfaXhfaXhbaXhbaY8Za
Y8Z`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhVeY8ZeY8ZeY8ZeY8ZeY8ZeY8ZeY8ZeY8ZdXhVdXhVdXhVd
XhVdXhVdXhVdXhVdXhVaY8ZaY8Z`XhV_XXR_XXR^XHN^XHN]X8JdXhVdXhVdXhVdXhVdXhVdXhVdXhVd
XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV_XXR_XXR_XXR_XXR_XXR_XXR_XXR_XXRbXHNcXXRdXhVd
XhVdXhVdXhVcXXRbXHN^XHN^XHN^XHN^XHN^XHN^XHN^XHN^XHNcXXNcXXNcXXNcXXNcXXNcXXNcXXNc
XXNdXhRcXXNaX8F`WhB`WhBaX8FcXXNdXhRcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBdXXFdXXFdXXFd
XXFdXXFdXXFdXXFdXXFcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBc
XHBbX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>cXHBbX8>aWh:a
Wh:aWh:aWh:bX8>cXHBbX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>`WX6`WX6aWh:bX8>bX8>aWh:`WX6`
WX6/WX6/WX6^Wgn^Wgn`WgjbWgjbWgbbWgb/W7R^WWZ_Wg^^WWZ/W7R/W7R]WGV_Wg^]WGV]WGV]WGV]
WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV^W7N^W7N^W7N^W7N^W7N^W7N^W7N^
W7N]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ/W7N[VgJ[VgJZVWFZVWF[VgJ[VgJ/W7N/VWF/VWF/VWF/
VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWFXV7>XV7>XV7>YVGBYVGBYVGBZVWFZ
VWFZVWFZVWFZVWFZVWFZVWFZVWFZVWFZVWF/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB]W7F]W7F]W7F]
W7F]W7F]W7F]W7F]W7F/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB]W7F]W7F^WGJ^WGJ]W7F]W7F/
VgB[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/
VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/
VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VG2[VG2[VG2/
VW6/VW6/VW6]Vg:]Vg:/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6^W7>]Vg:[VG2ZV6nZV6n[VG2]Vg:^
W7>ZV6nZV6n[VG2/VW6/VW6[VG2ZV6nZV6n[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2ZV6nZV6nZV6nZ
V6nZV6nZV6nZV6nZV6nYUfjYUfjYUfjYUfjZV6nZV6nZV6n[VG2ZV6nZV6nZV6nZV6nZV6nZV6nZV6nZ
V6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6n[VG2ZV6nYUfjYUfjYUfjYUfjZV6n[VG2XUVfXUVfXUVfX
UVfXUVfXUVfXUVfXUVf/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ^VFb^VFb^VFb^VFb]V6^]V6^]V6^]
V6^^VFb^VFb]V6^]V6^/UfZ/UfZ[UVV[UVV]V6^]V6^/UfZ/UfZ[UVVZUFRZUFRZUFR[UVV/UfZ/UfZ/
UfZ]V6^]V6^]V6^^VFb]Ufj]Ufj]Ufj]Ufj^V6n^V6n^V6n_VG2ZVVbZVVbZVVbZVVbZVVbZVVbZVVbZ
VVb^VFb^VFb^VFb^VFb^VFb^VFb^VFb^VFb/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ]V6^^
VFb_VVf_VVf^VFb^VFbQSg:KSWBDSGZ@SGj>SX2?T82BTgnGUGfCTHJDTXNFU8VHUhVJVH^KVh^KVh^K
Vh^NWHnQX9:TXiFTXiFRXI>OWY2MW8jMW8jLWY:NX9BRY9RVZ9bYZinZ[:2[[J6[[J6[ZIj/ZYn]Zj2^
[:6_[J:`[Z>a[jBb/:Fb/Z:c/j>c/ZBc/ZBc/JJd/ZRf]:Zg]J_=_:W3]jFd[Ib][Ifj^Zk7aK_2^KFb
YZ:h]j:i^:Bi^:Bh]ZBd]:Bc/ZBc/jFd]:Rf]:Va[jB^[:6_[J:d/ZNg]JZg]JZe/jRg^:jg^:jf]jff
]jff]jfg^:jh^Jnh^Jng^:jg^:jh^Jni^[2j^k6j^k6k_;:k_;;0_Jnj_;2c_:nd_[6m`k;1_ZViZY2[
UGVgXG6`W6b^VfjaWW>bWgBaVg6cW6ngWW:aW6naW6naW6naW6naW6naW6naW6naW6nbVffbVffbVffb
VffbVffbVffbVffbVffdWFndWFndWFndWFndWFndWFndWFndWFnbVffcW6jcW6jdWFndWFncW6jcW6jb
VffcW6ncW6ncW6ncW6ncW6ncW6l00;JWU;FVTkBUT[BUT[BUT[BUT[FVTkJWU;JWU;JWU;JWU;JWU;JW
U;JWU;JWU;JWU;FVTkFVTkFVTkFVTkFVTkFVTkFVTkFVTkBUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[:S
T;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:S
T;:ST;:ST;:ST;6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:T
S[:TS[6SSK2RS;2RS;6SSK:TS[:TS[6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6SSK6SSK6SSK6SSK6S
SK6SSK6SSK6SSK6RSk6RSk6SSK6SSK6SS;6SS;6TR[6TR[2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRKFT
R[FTR[FTR[FTR[FTR[FTR[FTR[FTR[BSRKBSRKBSRKBSRKBSRKBSRKBSRKBSRK6TR[2SRK2SRJnRR:nR
R:jQQjjQQjjQQkBSRKBSRKBSRKBSRKBSRKBSRKBSRKBSRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRJnR
R:nRR:nRR:nRR:nRR:nRR:nRR:nRR;:QQk>RR;>RR;BSRKBSRK>RR;>RR;:QQjjQQjjQQjjQQjjQQjjQ
QjjQQjjQQjjQQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk6PQK2OQ;2OQ;6PQK>RQk>RQk>Q
Q;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;BRQKBRQKBRQKBRQKBRQKBRQKBRQKBRQK>QQ;>QQ;>QQ;>QQ;>Q
Q;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk2P
Pk2PPk2PPk2PPk2PPk2PPk2PPk2PPk>QQ;:PPk6OP[6OP[6OP[6OP[:PPk>QQ;:PPk:PPk:PPk:PPk:P
Pk:PPk:PPk:PPk2NPK2NPK6OP[:PPk:PPk6OP[2NPK2NPJ^MP:^MP:fNOZfNOZnNOK6NOK6NNk6NNjbL
N:jNNZnONjjNNZbLN:bLN:fMNJnONjfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJfM
NJfMNJfMNJfMNJjLMjjLMjjLMjjLMjjLMjjLMjjLMjjLMjfKMZfKMZfKMZfKMZfKMZfKMZfKMZfKMZbL
Mj^KMZ^KMZZJMJZJMJ^KMZ^KMZbLMjbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJ
MJbJMJbJMJbJMJRHLjRHLjRHLjVIM:VIM:VIM:ZJMJZJMJZJMJZJMJZJMJZJMJZJMJZJMJZJMJZJMJbK
M:bKM:bKM:bKM:bKM:bKM:bKM:bKM:fLMJfLMJfLMJfLMJfLMJfLMJfLMJfLMJbKM:bKM:bKM:bKM:bK
M:bKM:bKM:bKM:bKM:fLMJfLMJjMMZjMMZfLMJfLMJbKM:^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLjbK
M:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bK
M:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:^J
Lj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^IL:^IL:^IL:^IL:bJLJbJLJfKLZfKLZbJLJbJLJbJLJbJLJbJ
LJbJLJbJLJbJLJfKLZbJLJ^IL:ZHKjZHKj^IL:bJLJfKLZZHKjZHKj^IL:bJLJbJLJ^IL:ZHKjZHKj^I
L:^IL:^IL:^IL:^IL:^IL:^IL:^IL:VGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZRFKJVGKZVGKZVGKZZH
KjZHKjZHKjZHKjVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZZH
KjZHKjVGKZRFKJRFKJVGKZZHKjZHKjRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJbGJZbGJZbGJZbGJZbG
JZbGJZbGJZbGJZjIK:jIK:jIK:fHJjfHJjfHJjfHJjfHJjjIK:fHJjfHJjfHJjbGJZ^FJJ^FJJ^FJJbG
JZbGJZbGJZ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJbGJZbGJZbGJZfHJjfHJjfHJjbFKJfGKZfGKZfGKZjH
KjjHKjjHKjjHKjVIJjVIJjVIJjVIJjVIJjVIJjVIJjVIJjfHJjfHJjfHJjfHJjfHJjfHJjfHJjfHJjbG
JZbGJZbGJZbGJZbGJZbGJZbGJZbGJZ^FJJbGJZfHJjjIK:nJKJjIK:jIK:fHJjJALJ2@LiV?Mi:>O8n?
Ohn@P96BOYBCOY>BQ9BCQIJEQiRGRIZIRi^KRi^KRi^KRiZIRijMSj:QTj>RU::QTj2OTJ2OTJ2OTIfO
TijPU:6SUjBVVZNYWJV[WjZ/X:^]XJf[X:f[X:f[X:j/XJn]X[2^Xk6_Y;:`YK>cXkBdY;FdY[BcYK6_
Y;2^Y;6_YK:`Y[:UUkN^X;VfZ;jn//W:`M[FdN3Ge=_?cKbl[;FeYJj^WZn^X;BcYKJeYk6`XZ^YW[Fc
Z;>aY[6_Y;6_Y;>aY[FcZ;NeZ[NeZ[Nh[[Jg[KJg[KJg[KJg[KNh[[Ri[kRi[kNh[[Nh[[Ri[kVj/;Zk
/KZk/K^l/[^l/[jm[kZl/;>l[kBm/;c2/L:nZk^]U[6LPK6OL:fKK:bIK;2ML[6NLk6KLK:KK[FNLK6L
Kk6LKk6LKk6LKk6LKk6LKk6LKk6LKk:KKK:KKK:KKK:KKK:KKK:KKK:KKK:KKK>LK[>LK[>LK[>LK[>L
K[>LK[>LK[>LK[:KKK:KKK>LK[BMKkBMKk>LK[:KKK:KKK>LKk>LKk>LKk>LKk>LKk>LK`00]JJC]JJC
]:FB/jBA/jBA]:FB]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]:FB]:FB]:FB]:FB]:FB]:FB
]:FB]:FB/jBA/jBA/jBA/jBA/jBA/jBA/jBA/jBA/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@
/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/J:?/J:?/J:?/J:?/J:?/J:?
/J:?/J:?/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/ZB>/J>=/J>=/::</::</J>=/J>=/ZB>/J:?/J:?
/J:?/J:?/J:?/J:?/J:?/J:?/J>=/J>=/J>=/J>=/J>=/J>=/J>=/J>=/J:?/J:?/J>=/J>=/J></J><
/JB:/JB:/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9]JB:]JB:]JB:]JB:]JB:]JB:]JB:]JB:]:>9]:>9
]:>9]:>9]:>9]:>9]:>9]:>9/:>9/:>9/:>9[j:8[j:8[j:8[Z67[Z67]:>9]:>9]:>9]:>9]:>9]:>9
]:>9]:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9[j:8[j:8[j:8[j:8[j:8[j:8[j:8[j:8/Z67/Z67
/j:8]:>9]:>9/j:8/Z67/Z67[Z67[Z67[Z67[Z67[Z67[Z67[Z67[Z67/j:7/j:7/j:7/j:7/j:7/j:7
/j:7/j:7/j:7/Z66/J25/J25/J25/J25/Z66/j:7/j64/j64/j64/j64/j64/j64/j64/j64]::5]::5
]::5]::5]::5]::5]::5]::5/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23
/Z23/Z23/In2/In2/In2/In2/In2/In2/In2/In2/:23/:23/:23/:23/:23/:23/:23/:23/Z23/Z23
/In2/9j1/9j1/In2/Z23/Z23/In2/In2/In2/In2/In2/In2/In2/In2[if0/9j1/In2/In2/In2/In2
/9j1[if0Zif0Zif0[Iin[Iin[iim/Iim/Iik/Iik[9ah[Yij[imk[Yij[9ah[9ah[Iei[imk[Iei[Iei
[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Yag[Yag[Yag[Yag[Yag[Yag
[Yag[Yag[I]f[I]f[I]f[I]f[I]f[I]f[I]f[I]f[9agZi]fZYYeZYYeZYYeZYYeZi]f[9ag[9Ye[9Ye
[9Ye[9Ye[9Ye[9Ye[9Ye[9YeZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZ9QcZ9QcZ9QcZIUdZIUdZIUd
ZYYeZYYeZIUdZIUdZIUdZIUdZIUdZIUdZIUdZIUdZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYc[Iae[Iae
[Iae[Iae[Iae[Iae[Iae[IaeZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYc[9]d[9]d[Iae[Yef[Yef[Iae
[9]d[9]dZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYc
ZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYc
ZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYQ_ZYQ_
ZiU`ZiU`[9Ya[9Ya[9Ya[9YaZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`[9Ya[9YaZiU`ZYQ_ZYQ_ZiU`
[9Ya[9YaZIM^ZYQ_ZiU`ZiU`ZiU`ZiU`ZYQ_ZIM^ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZIM^ZIM^
ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^Z9I]Z9I]Z9I]ZIM^ZIM^ZYQ_ZYQ_ZYQ_ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^
ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZYQ_ZIM^ZIM^Z9I]Z9I]ZIM^ZIM^ZYQ_Z9I]Z9I]
Z9I]Z9I]Z9I]Z9I]Z9I]Z9I][9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[IQ[[IQ[[IQ[[IQ[[IQ[[IQ[
[IQ[[IQ[[IQ[[IQ[[9MZ[9MZ[9MZZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIY[9MZ[9MZ[9MZZiIYZiIY
ZiIY[9MZ[9MZ[IQ[[IQ[[IQ[[9I/[9I/[9I/[IM][IM][YQ^[YQ^[YQ^ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[
ZIU[ZIU[[IQ[[IQ[[IQ[[IQ[[IQ[[IQ[[IQ[[IQ[[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZZiIY[9MZ
[IQ[[YU/[YU/[YU/[YU/[IQ[ZiE/YiA_Wi9bV95hThmlShmmSi5nT99oTi>3U9B4UYJ6V9R8VIV9VYZ:
Vi^;Vi^;UiJ8VYV;Wij@XJ2BXJ2BXJ2BXZ6CY:>EWZ2DWj6EX::FXZBHY:JJYjVMZJ^OZZbP/:jS[jfR
[ZbQ[J^P[ZbQ/:jS/JnT/k6V/k>S]KFU][FW];>U/:jS[ZbR/:jT/k6W_;B]`kffb/S0d=3:e]GAg=OD
g=CDf]3@emS?cm37a<>i][F[[ZbQ[ZbQ]K>X_[^]];:W];:W];:W/k6V/JnT/[2U]K>X^;J[]KJ/]KJ/
][N]][N]]kR^]kR^]kR^^;V_]kR^]kR^^;V_^KZ`^[^a^[^a^kbb^kbb_Kb^^[f^];^^/kb_^l2aa<2^
`KBN^:N=[IebZIQ]Z9QZ[ia_/iia/9]^/IU_/i]a/9]^/9]^/9]^/9]^/9]^/9]^/9]^/9]^/IY//IY/
/IY//IY//IY//IY//IY//IY//Y]]/Y]]/Y]]/Y]]/Y]]/Y]]/Y]]/Y]]/IY//Y]]/ia^/ia^/ia^/ia^
/Y]]/IY//Y]^/Y]^/Y]^/Y]^/Y]^/Y]^002eYY>dYI:cY96cY96cY96cY96dYI:eYY>eYY>eYY>eYY>e
YY>eYY>eYY>eYY>eYY>dYI:dYI:dYI:dYI:dYI:dYI:dYI:dYI:cY96cY96cY96cY96cY96cY96cY96c
Y96bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2b
Xi2bXi2bXi2bXi2bXi2aXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnbXi2bXi2bXi2bXi2bXi2bXi2bXi2b
Xi2aXhfaXhf`XXb`XXb`XXb`XXbaXhfaXhfaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXhfaXhfaXhfa
XhfaXhfaXhfaXhfaXhfaXXnaXXnaXhfaXhfaXhbaXhbaY8ZaY8Z`XhV`XhV`XhV`XhV`XhV`XhV`XhV`
XhVeY8ZeY8ZeY8ZeY8ZeY8ZeY8ZeY8ZeY8ZcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXR_XXR_XXR_XXR_
XXR_XXR_XXR_XXR_XXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXR_XXR_XXR_XXR_XXR_XXR_XXR_XXR_
XXR^XHN^XHN^XHN^XHN^XHN^XHN^XHN^XHNaX8JbXHNcXXRcXXRcXXRcXXRbXHNaX8J^XHN^XHN^XHN^
XHN^XHN^XHN^XHN^XHNbXHJbXHJbXHJbXHJbXHJbXHJbXHJbXHJaX8FaX8FaX8FaX8FaX8FaX8FaX8Fa
X8FcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBbX8>bX8>bX8>b
X8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>aWh:aWh:aWh:aWh:aWh:aWh:aWh:a
Wh:`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>bX8>aWh:`WX6`WX6`WX6`WX6aWh:bX8>aWh:aWh:aWh:a
Wh:aWh:aWh:aWh:aWh:_WH2_WH2`WX6aWh:aWh:`WX6_WH2_WH2[WH2[WH2]WWj]WWj_WWfaWWfaWW^a
WW^/W7R^WWZ_Wg^^WWZ/W7R/W7R]WGV_Wg^/W7R/W7R/W7R/W7R/W7R/W7R/W7R/W7R/W7R/W7R/W7R/
W7R/W7R/W7R/W7R/W7R]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ/VWF/VWF/VWF/VWF/VWF/VWF/VWF/
VWF[VgJ[VgJZVWFYVGBYVGBZVWF[VgJ[VgJ/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF[VGB[VGB[VGB[
VGB[VGB[VGB[VGB[VGBXV7>XV7>XV7>YVGBYVGBYVGBZVWFZVWFYVGBYVGBYVGBYVGBYVGBYVGBYVGBY
VGB[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB[VW>[VW>[VW>[
VW>[VW>[VW>[VW>[VW>[VW>/VgB]W7F]W7F]W7F]W7F/VgB[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[
VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[
VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[
VW>ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZV6nZV6nZV6n[VG2[VG2[VG2/VW6/VW6[VG2[VG2[VG2[
VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2YUfjYUfjZV6n[VG2[VG2ZV6nYUfjY
UfjZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjXUVfXUVfXUVfX
UVfYUfjYUfjZV6nZV6nYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjY
UfjZV6nYUfjXUVfXUVfXUVfXUVfYUfjZV6nXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVf/UfZ/UfZ/UfZ/
UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ]V6^]V6^]V6^]V6^/UfZ/UfZ/UfZ/UfZ[UVV[UVV[UVV[
UVVZUFRZUFRZUFR[UVV/UfZ/UfZ]V6^]V6^ZUFR[UVV[UVV[UVV/UfZ/UfZ/UfZ]V6^/UVb/UVb/UVb/
UVb]Uff]Uff^V6j^V6jYVF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^]V6^]V6^]V6^]V6^]V6^]V6^]V6^]
V6^/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ[UVV[UVV/UfZ]V6^^VFb^VFb]V6^]V6^`V6Z/UfZVUFjM
TW:HTGJCT7^@T7j?T82BTgnCTh6EUH>GUhFIVHVJVXZJVH^JVH^FUHNIV8ZMW8jOWY2PWi6PWi6RXI>T
XiFOXIFOXIFOXIFOXIFQXiNTYYZWZIfYZin`[Z>_[J:^[:6]Zj2]Zj2_[J:a[jBc/JJc/j>d]:Bd/jFb
/J>a[jBc/JNj^:k0_[C>b/WAcLcHeM7PfmSQg=WPemCLd<kJc/[Ie];Jem?Kf=?Kf=3Ed/[9a;^i]JZ^
ZYnb/:Fd/ZNe/jRc/JJ_[J:^[:6b/:Fg]JZd]J^d]J^e]Zbf]jfg^:jg^:jg^:jg^:jg^:jg^:jh^Jni
^[2j^k6j^k6k_;:k_;:l_Jfj_Jje_:nd^Znl_[;3`;72^jNn/I^ZWgVUVG6WUV^_VVfdWFnbVfj_VFn`
VW6`Vfj`Vfj`Vfj`Vfj`Vfj`Vfj`Vfj`VfjaVVbaVVbaVVbaVVbaVVbaVVbaVVbaVVbaVVbaVVbaVVba
VVbaVVbaVVbaVVbaVVbaVVbbVffbVffcW6jcW6jbVffbVffaVVbbVfjbVfjbVfjbVfjbVfjbVfh00;BU
T[BUT[>TTK:ST;:ST;>TTKBUT[BUT[FVTkFVTkFVTkFVTkFVTkFVTkFVTkFVTk>TTK>TTK>TTK>TTK>T
TK>TTK>TTK>TTK:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6R
Sk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk2QS[2QS[2QS[2QS[2Q
S[2QS[2QS[2QS[6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6SSK2RS;2RS:nQRjnQRk2RS;2RS;6SSK2Q
S[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2QS[2QS[2RS;2RS;2R
Rk2RRk2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRKBSRKBSRKBSRKBSRKBSRKBSRKBSRKBSRK>R
R;>RR;>RR;>RR;>RR;>RR;>RR;>RR:nRR:nRR:nRR:nRR:nRR:nRR:nRR:nRR;>RR;>RR;>RR;>RR;>R
R;>RR;>RR;>RR:nRR:nRR:nRR:nRR:nRR:nRR:nRR:nRR:jQQjjQQjjQQjjQQjjQQjjQQjjQQjjQQk6P
Q[6PQ[:QQk>RR;>RR;:QQk6PQ[6PQZjQQjjQQjjQQjjQQjjQQjjQQjjQQjjQQk:QQ[:QQ[:QQ[:QQ[:Q
Q[:QQ[:QQ[:QQ[2OQ;2OQ;6PQK6PQK6PQK6PQK2OQ;2OQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>Q
Q;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk:P
Pk:PPk:PPk:PPk2NPK2NPK2NPK2NPK2NPK2NPK2NPK2NPK2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk6O
P[6OP[2NPJnMP:nMP;2NPK6OP[6OP[2NPK2NPK2NPK2NPK2NPK2NPK2NPK2NPJjLOjnMP;2NPK2NPK2N
PK2NPJnMP:jLOjZLOjZLOjbMOJbMOJjMO;2MO;2MN[2MNZbLN:jNNZnONjjNNZbLN:bLN:fMNJnONjbL
N:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:fKMZfKMZfKMZfKMZfK
MZfKMZfKMZfKMZbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJ^KMZZJMJVIM:VIM:VIM:VIM:ZJMJ^KMZbJ
MJbJMJbJMJbJMJbJMJbJMJbJMJbJMJ^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:RHLjRHLjRHLjVIM:VI
M:VIM:ZJMJZJMJVIM:VIM:VIM:VIM:VIM:VIM:VIM:VIM:^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLjbK
M:bKM:bKM:bKM:bKM:bKM:bKM:bKM:^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLjbKM:fLMJfL
MJbKM:^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^J
Lj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^J
Lj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLjVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJVG
KZVGKZZHKjZHKj^IL:^IL:^IL:^IL:ZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKj^IL:^IL:^I
L:^IL:ZHKjZHKjRFKJVGKZZHKjZHKjZHKjZHKjVGKZRFKJVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZRF
KJRFKJRFKJRFKJRFKJRFKJRFKJRFKJNEK:NEK:RFKJRFKJRFKJVGKZVGKZVGKZRFKJRFKJRFKJRFKJRF
KJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJVGKZVGKZRFKJNEK:NEK:RFKJVGKZVGKZNE
K:NEK:NEK:NEK:NEK:NEK:NEK:NEK:^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJbGJZbG
JZfHJjfHJjjIK:^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJZEJ:ZEJ:ZEJ:^FJJbGJZbGJZfHJjfHJjZE
J:ZEJ:ZEJ:^FJJ^FJJbGJZbGJZbGJZ^FJJ^FJJbGJZbGJZbGJZfHJjfHJjfHJjRHJZRHJZRHJZRHJZRH
JZRHJZRHJZRHJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZZE
J:^FJJbGJZfHJjfHJjfHJjfHJjbGJ[2IIjjHJ:VFJJJEKYfCLIVBMiBAO9>BOY:DOY>EOiFFPYNHQ9VI
QiZJRYZIRiZIRiRGRIZIRifLSYjMSijMSijMSj2OTJ:QTinQUInQUIjPU9jPU:2RUZ:TV:FWVjJXW:j/
XJf[X:f[X:bZWjf[X:n]X[6_Y;:`YK>cXk6aXK2_XK6`X[NeZ/6o]Lc:`=?Aam7=c=SCd>GLfNSLf=g=
a];1^=W6_^SFbn_Pg=oDd=O<b=WAb^?Ke=oJdLk9`;^f[K:`YKBbYkBbYk6_Y:f[X:bZWk2^XkBbYk:c
ZK>dZ[Ff[;Jg[KNh[[Nh[[Nh[[Nh[[Nh[[Nh[[Ri[kVj/;Zk/KZk/K^l/[^l/[Vl[;Vn[kRl/;Jj[kZk
/L70//>o[L2iYJfVQJJMN:RHKZnKK;BMKK:KKJjHKZfHL[2KK[2KK[2KK[2KK[2KK[2KK[2KK[2KK[2I
Jk2IJk2IJk2IJk2IJk2IJk2IJk2IJk2IJk2IJk2IJk2IJk2IJk2IJk2IJk2IJk6JK;6JK;:KKK:KKK:K
KK:KKK6JK;6JK;:KK[:KK[:KK[:KK[:KK[:KKP00]:FB/jBA/jBA/Z>@/Z>@/jBA/jBA]:FB]:FB]:FB
]:FB]:FB]:FB]:FB]:FB]:FB/jBA/jBA/jBA/jBA/jBA/jBA/jBA/jBA/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@
/Z>@/Z>@/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?
/J:?/J:?/J:?/J:?/J:?/J:?/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>/J:?/J:?/J:?/J:?/J:?/J:?
/J:?/J:?/J>=/::<[j6;[j6;[j6;[j6;/::</J>=/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>/::</::<
/::</::</::</::</::</::</:6>/:6>/::</::</::;/::;/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9
/:>9/:>9]:>9]:>9]:>9]:>9]:>9]:>9]:>9]:>9/Z67/Z67/Z67/Z67/Z67/Z67/Z67/Z67[Z67[Z67
[j:8[j:8[j:8/:>9/:>9/:>9/Z67/Z67/Z67/Z67/Z67/Z67/Z67/Z67[Z67[Z67[Z67[Z67[Z67[Z67
[Z67[Z67[J26[J26[J26[J26[J26[J26[J26[J26/9n5/J26/Z67/Z67/Z67/Z67/J26/9n5[Z67[Z67
[Z67[Z67[Z67[Z67[Z67[Z67/J25/J25/J25/J25/J25/J25/J25/J25[ij3/9n4/J25/J25/J25/J25
/9n4[ij3/j64/j64/j64/j64/j64/j64/j64/j64/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23/In2/In2
/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2/9j1/9j1/9j1/9j1/9j1/9j1
/9j1/9j1/:23/:23/:23/:23/:23/:23/:23/:23/In2/9j1/9j1[if0[if0/9j1/9j1/In2/9j1/9j1
/9j1/9j1/9j1/9j1/9j1/9j1[Yao[Yao[if0/9j1/9j1[if0[Yao[YaoZYaoZYao[9em[9em[Yel/9el
/9ej/9ej[9ah[Yij[imk[Yij[9ah[9ah[Iei[imkZi]gZi]gZi]gZi]gZi]gZi]gZi]gZi]gZi]gZi]g
Zi]gZi]gZi]gZi]gZi]gZi]g[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9YeZiUdZiUdZiUdZiUdZiUdZiUd
ZiUdZiUdZYYeZYYeZIUdZ9QcZ9QcZIUdZYYeZYYe[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9YeZYQcZYQc
ZYQcZYQcZYQcZYQcZYQcZYQcZ9QcZ9QcZ9QcZIUdZIUdZIUdZYYeZYYeZ9QcZ9QcZ9QcZ9QcZ9QcZ9Qc
Z9QcZ9QcZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZYUbZYUb
ZYUbZYUbZYUbZYUbZYUbZYUbZYUbZiYc[9]d[9]d[9]d[9]dZiYcZYUbZiYcZiYcZiYcZiYcZiYcZiYc
ZiYcZiYcZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUb
ZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUb
ZYUbZYUbZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIM^ZIM^ZIM^ZYQ_ZYQ_ZiU`ZiU`ZiU`ZYQ_ZYQ_
ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZIM^ZYQ_ZYQ_ZiU`ZiU`ZYQ_ZYQ_ZIM^Z9I]Z9I]ZIM^ZYQ_ZYQ_ZIM^
Z9I]Z9I]ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]YiE/YiE/
YiE/YiE/Z9I]Z9I]ZIM^ZIM^Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]
Z9I]Z9I]ZIM^Z9I]YiE/YiE/YiE/YiE/Z9I]ZIM^YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/ZiIYZiIY
ZiIYZiIYZiIYZiIYZiIYZiIYZYEXZYEXZiIYZiIY[9MZ[IQ[[IQ[[YU/ZYEXZYEXZYEXZYEXZiIYZiIY
ZiIY[9MZZiIYZiIYZiIYZiIYZiIY[9MZ[9MZ[9MZZYEXZYEXZYEXZYEXZiIYZiIYZiIY[9MZZiMXZiMX
ZiMXZiMX[9QY[9QY[IUZ[IUZZ9QZZ9QZZ9QZZ9QZZ9QZZ9QZZ9QZZ9QZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ
[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZZYEXZYEX[9MZ[9MZ[IQ[[IQ[[9MZ[9MZZiYY[9QX
ZiMWZIMXYYI/XIEcWIEhVIAkTIAjTYEkU9MnUYN3V9R6VIV9VIR:VIN<VIR:ViZ<WIb>WIb>W9^=W9^=
WYf?X9nAWZ2DWZ2DWZ2DWZ2DWj6EX::FXZBHXZBHZJNLZZRMZjVN[:ZO[ZbQ[jfR[jfR/:jS/k>S[jnO
[ZfO];>U`/2ed<k4fMO=gM_AhmgFj=cFjMS?e[jbZHmoRfeLUGQS/YIng/FkiLo4j]O?imS?g]?;fM7:
fmG>gm_F]K>X]K>X/k6V/JnT[ZbQ[J^P[jfR/JnT/;6W/[>Y];F[][N]^;V_^;V_]kR^][N]]kR^]kR^
^;V_^KZ`^[^a^[^a^kbb^kbb][bY^Kj_^[jb^KZa^kVa_knc`<2`_kf[];6EZjB3ZIYc[i]/]Ya]/YY/
[YQ^ZiQb[iY][iY][iY][iY][iY][iY][iY][iY]/9U[/9U[/9U[/9U[/9U[/9U[/9U[/9U[/IY//IY/
/IY//IY//IY//IY//IY//IY//9U[/IY//IY//Y]]/Y]]/IY//IY//9U[/IY]/IY]/IY]/IY]/IY]/IY]
002dYI:cY96bXi2bXi2bXi2bXi2cY96dYI:dYI:dYI:dYI:dYI:dYI:dYI:dYI:dYI:cY96cY96cY96c
Y96cY96cY96cY96cY96aXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXn`XHj`XHj`XHj`XHj`XHj`XHj`XHj`
XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj_X8f_X8f_X8f_
X8f_X8f_X8f_X8f_X8f`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XXb`XXb_XH^^X8Z^X8Z_XH^`XXb`
XXb_X8f_X8f_X8f_X8f_X8f_X8f_X8f_X8f_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_X8f_X8f_XH^_
XH^_XHZ_XHZ_XXR_XXR`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhVcXXRcXXRcXXRcXXRcXXRcXXRcXXRc
XXRbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHN^XHN^XHN^XHN_XXR_XXR`XhV`XhVaY8ZbXHNbXHNbXHNb
XHNbXHNbXHNbXHNbXHN^XHN^XHN^XHN^XHN^XHN^XHN^XHN^XHN]X8J]X8J]X8J]X8J]X8J]X8J]X8J]
X8J`WhFaX8JaX8JbXHNbXHNaX8JaX8J`WhF^XHN^XHN^XHN^XHN^XHN^XHN^XHN^XHNaX8FaX8FaX8Fa
X8FaX8FaX8FaX8FaX8F^WH:_WX>`WhBaX8FaX8F`WhB_WX>^WH:cXHBcXHBcXHBcXHBcXHBcXHBcXHBc
XHBbX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:a
Wh:aWh:aWh:aWh:aWh:`WX6`WX6`WX6`WX6`WX6`WX6`WX6`WX6`X8>`X8>`X8>`X8>`X8>`X8>`X8>`
X8>aWh:`WX6_WH2_WH2_WH2_WH2`WX6aWh:`WX6`WX6`WX6`WX6`WX6`WX6`WX6`WX6]Vgj^W7n_WH2_
WH2_WH2_WH2^W7n]VgjYVgjYVgj[W7b[W7b]W7^_W7^_W7V_W7V/W7R^WWZ_Wg^^WWZ/W7R/W7R]WGV_
Wg^[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN/VWF/VWF/VWF/
VWF/VWF/VWF/VWF/VWF[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGBZVWFYVGBXV7>XV7>XV7>XV7>YVGBZ
VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWFZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>XV7>XV7>XV7>Y
VGBYVGBYVGBZVWFZVWFXV7>XV7>XV7>XV7>XV7>XV7>XV7>XV7>ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:Z
VG:[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:[VW>/
VgB/VgB[VW>ZVG:ZVG:[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:Z
VG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:Z
VG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:YV76YV76YV76YV76YV76YV76YV76Y
V76YUfjYUfjYUfjYUfjZV6nZV6nZV6n[VG2ZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nXUVfYUfjZV6n[
VG2[VG2ZV6nYUfjXUVfWUFbXUVfYUfjYUfjYUfjYUfjXUVfWUFbXUVfXUVfXUVfXUVfXUVfXUVfXUVfX
UVfWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbVU6^VU6^WUFbWUFbXUVfXUVfXUVfXUVfWUFbWUFbWUFbW
UFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbXUVfXUVfWUFbVU6^VU6^WUFbXUVfX
UVfVU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^ZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRYU6NYU6NZUFR[
UVV/UfZ]V6^]V6^^VFbYU6NYU6NYU6NZUFR[UVV[UVV[UVV/UfZ/UfZ/UfZ/UfZ[UVV[UVV[UVV[UVV[
UVVYU6NYU6NZUFRZUFRZUFR[UVV[UVV[UVVZUVNZUVN[UfR[UfR/V6V/V6V/V6V/V6VWUfVWUfVWUfVW
UfVWUfVWUfVWUfVWUfV[UVV[UVV[UVV[UVV[UVV[UVV[UVV[UVV/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/
UfZYU6NZUFR[UVV/UfZ]V6^/UfZ/UfZ[UVVUV6ZWUfR[V6F]V6F/V6RYUfjUUg>RUgNAUGRBUWVDUgfF
V8:HV8JIVHVIV8ZIUhbHUhVIV8ZKVXbKVXbKVXbLVhfOWY2QX9:LWY:MWi>NX9BOXIFOXIFOXIFOXIFO
XIFSXIJVY9VYYib/ZYn^[:6_[J:^[:6^[:6c/j>_[in_[Z2k^Zc>c<7KfLoMfm7Jf<kNd/K8]jZ`UXJD
Lf1aB35@:0]B:`]X@R1oG4RWQW?F^J[`f<c/fm;MdlcCc/_DdLfj^:fg]JZc/JJa[jBa[jBb/:Fa[jB`
[Z>_/:Ja/ZRd]J^g^:jh^Jnh^Jng^:jf]jfg^:jg^:jh^Jni^[2j^k6j^k6k_;:k_;:c_:Rj`:nn_kFj
^k:j^;2m_;:n_[:j_Jfl_:Bb[8n]WWNaVVbeW6ZbVf^_VG2[VGB_VVf_VVf_VVf_VVf_VVf_VVf_VVf_
VVf`VF^`VF^`VF^`VF^`VF^`VF^`VF^`VF^aVVbaVVbaVVbaVVbaVVbaVVbaVVbaVVb`VF^`VF^aVVbb
VffbVffaVVb`VF^`VF^aVVfaVVfaVVfaVVfaVVfaVVd00;>TTK>TTK:ST;6RSk6RSk:ST;>TTK>TTKBU
T[BUT[BUT[BUT[BUT[BUT[BUT[BUT[:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;6RSk6RSk6RSk6RSk6R
Sk6RSk6RSk6RSk2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2Q
S[2QS[2QS[2QS[2QS[2QS[2QS[2QSZnPSJnPSJnPSJnPSJnPSJnPSJnPSJnPSK2QS[2QS[2QS[2QS[2Q
S[2QS[2QS[2QS[2RS:nQRjnQRjjPRZjPRZnQRjnQRk2RS:nPSJnPSJnPSJnPSJnPSJnPSJnPSJnPSJnQ
RjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnPSJnPSJnQRjnQRjnQRZnQRZnRR:nRR;2SRK2SRK2SRK2SRK2S
RK2SRK2SRK2SRK>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQjfP
QZjQQjjQQjnRR:nRR;2SRK6TR[6TR[:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQjjQQjjQQjjQQjjQQjjQ
QjjQQjjQQjjQQjfPQZfPQZfPQZfPQZfPQZfPQZfPQZfPQ[2OQK2OQK6PQ[:QQk:QQk6PQ[2OQK2OQJjQ
QjjQQjjQQjjQQjjQQjjQQjjQQjjQQk6PQK6PQK6PQK6PQK6PQK6PQK6PQK6PQJjMPZnNPk2OQ;6PQK6P
QK2OQ:nNPjjMP[>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk6O
P[6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OPZnMP:nMP:nMP:nMP:nM
P:nMP:nMP:nMP;2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2NPK2NPJnMP:jLOjjLOjnMP;2NPK2NPJnM
P:nMP:nMP:nMP:nMP:nMP:nMP:nMP:fKOZjLOjnMP:nMP:nMP:nMP:jLOjfKOZVKOZVKOZ^LO:^LO:fL
NjnLNjnLNJnLNJbLN:jNNZnONjjNNZbLN:bLN:fMNJnONj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^K
Mj^KMj^KMj^KMj^KMj^KMj^KMj^KMjbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJ^IM:^IM:^IM:^IM:^I
M:^IM:^IM:^IM:ZJMJVIM:RHLjRHLjRHLjRHLjVIM:ZJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJZH
LjZHLjZHLjZHLjZHLjZHLjZHLjZHLjRHLjRHLjRHLjVIM:VIM:VIM:ZJMJZJMJRHLjRHLjRHLjRHLjRH
LjRHLjRHLjRHLjZILZZILZZILZZILZZILZZILZZILZZILZ^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLjZI
LZZILZZILZZILZZILZZILZZILZZILZZILZZILZ^JLjbKM:bKM:^JLjZILZZILZ^JLj^JLj^JLj^JLj^J
Lj^JLj^JLj^JLjZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZI
LZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZI
LZZILZZILZZILZRGL:RGL:RGL:RGL:RGL:RGL:RGL:RGL:RFKJVGKZVGKZVGKZZHKjZHKjZHKjZHKjVG
KZVGKZVGKZVGKZVGKZVGKZVGKZVGKZRFKJVGKZZHKj^IL:^IL:ZHKjVGKZRFKJNEK:RFKJVGKZVGKZVG
KZVGKZRFKJNEK:RFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJNEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:JD
JjJDJjNEK:NEK:NEK:RFKJRFKJRFKJNEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NE
K:NEK:NEK:NEK:RFKJRFKJNEK:JDJjJDJjNEK:RFKJRFKJJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjZE
J:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:RCIZVDIjZEJ:^FJJbGJZfHJjfHJjjIK:RCIZVDIjVDIjZEJ:ZE
J:^FJJ^FJJbGJZfHJjfHJjbGJZbGJZ^FJJZEJ:ZEJ:ZEJ:VDIjVDIjVDIjZEJ:ZEJ:^FJJ^FJJ^FJJZF
IjZFIj^GJ:^GJ:^GJ:bHJJbHJJbHJJNGJJNGJJNGJJNGJJNGJJNGJJNGJJNGJJ^FJJ^FJJ^FJJ^FJJ^F
JJ^FJJ^FJJ^FJJbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZVDIjZEJ:^FJJbGJZbGJZbGJZbGJZ^FJJ2G
JjBHJ:VHIJjHI:nHIZjJJj^HLZVIMI6FMi:FNIBGOIJHPYRIQIVIRIVHRYVGS9JEQiRGRIZIRiZIRi^J
S9bKSJ2OTJ>RU9^MTIbNTYjPU:2RUZ2RUYnQUIjPU9fOTj2NTj>QUZRVVjbZWjn]XZn]XZj/XJbZWk>c
Xjn_Wk:aXl70/]KDbN7OeMcJd=?AajbLRgeWEEHg8U@[4U/]3UTY1ET[0Uld2EL/4EP_66Q5<I1fI/:`
YN?GdNGPgMcJfKnm/[Zh[KBbYk>aY[FcZ;FcZ;>aY[2^Xjj_YK2aYkBeZkNh[[Ri[kRi[kNh[[Jg[KNh
[[Nh[[Ri[kVj/;Zk/KZk/K^l/[^l/[>lZ;_1/;o0][bj/[Zg/[bj/[^m/KNl[L32[[FaUJjRN[:LK;FL
J[:KJjnIL:bJMJnJKJnJKJnJKJnJKJnJKJnJKJnJKJnJKJnHJZnHJZnHJZnHJZnHJZnHJZnHJZnHJ[:K
KK:KKK:KKK:KKK:KKK:KKK:KKK:KKK2IJk2IJk6JK;:KKK:KKK6JK;2IJk2IJk6JKK6JKK6JKK6JKK6J
KK6JK@00]jB?]jB?]jB?]jB?]jB?]jB?]jB?]jB?/jF?/jF?/jF?/jF?/jF?/jF?/jF?/jF?/J:?/J:?
/J:?/J:?/J:?/J:?/J:?/J:?/J>=/J>=/J>=/J>=/J>=/J>=/J>=/J>=/::</::</::</::</::</::<
/::</::</::</::</::</::</::</::</::</::</::</::</::</::</::</::</::</::<[j6;[j6;
[j6;[j6;[j6;[j6;[j6;[j6;/::</::</::</::</::</::</::</::<[Z2:[j6;/::</::</::</::<
[j6;[Z2:[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;/j:8/j:8
/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/Z67/Z67/Z67/Z67/Z67/Z67
/Z67/Z67[Z:6[Z:6[Z:6[Z:6[Z:6[Z:6[Z:6[Z:6/Z66/Z66/Z66/Z66/Z66/Z66/Z66/Z66]:>8]:>8
/j:7/Z66/Z66/J25/J25/9n4/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25
/J25/J25/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4[ij3[ij3[ij3/9n4/9n4/9n4/J25/J25/9n4/9n4
/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4]::5/j64/j64/Z23/Z23/In2
/9j1/9j1/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/In0/9io/9io[ien[ien/In0/In0
/In0/In0/In0/In0/In0/In0/9io/9io/9io/9io/9io/9io/9io/9io[ien[ien[ien[ien/9io/9io
/9io/In0/9io/9io/9io/9io/9io/9io/9io/9io/9io[ien[ien[ien[Yam[Yam[Yam[I]l[I]l[I]l
[I]l[I]l[I]l[I]l[I]l[I]lZi]gZi]gZi]gZi]gZi]gZi]gZi]gZi]g[Yag[Yag[Yag[Yag[Yag[Yag
[Yag[Yag[I]f[I]f[I]f[I]f[I]f[I]f[I]f[I]f[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye
[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9YeZYQcZYQcZYQcZYQcZYQcZYQc
ZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZiUdZiUdZiUd[9Ye[9YeZYQcZYQc
ZYQcZYQcZYQcZYQcZYQcZYQcZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbYiI_Z9M`Z9M`Z9M`ZIQaZIQa
ZIQaZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZiQbZiQb
ZiQbZiQbZiQbZiQbZiQbZiQbZiYcZiYcZiYcZYUbZIQaZIQaZ9M`Z9M`ZYUbZYUbZYUbZYUbZYUbZYUb
ZYUbZYUbZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZiQbZiQbZiQbZiQbZiQbZiQbZiQbZiQbZiQbZiQb
ZiQbZiQbZiQbZiQbZiQbZiQbZYQ_ZIM^Z9I]Z9I]Z9I]ZIM^ZiU`[9YaZ9I]Z9I]Z9I]Z9I]Z9I]Z9I]
Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_Z9I]Z9I]
Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]ZYQ_ZYQ_ZIM^ZIM^Z9I]Z9I]
YiE/YiE/ZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIYYiMYYiMYYiMYYiMYYiMYYiMYYiMYYiMYZYEXZYEX
ZYEXZYEXZYEXZYEXZYEXZYEXZIAWZIAWZYEXZYEXZYEXZiIYZiIYZiIYYYA[YYA[YYA[YYA[YYA[YYA[
YYA[YYA[YYIXYYIXYYIXYYIXYYIXYYIXYYIXYYIXZIAWZIAWZYEXZYEXZYEXZiIYZiIYZiIYZYEXZYEX
ZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZIEVZIEVZYIWZYIWZYIWZiMX
ZiMXZiMXZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEV[9QY[9QYZiMXZiMXZYIWZIEVZIEVZIEVZYIWZYIW
ZYIWZYIWZYIWZYIWZYIWZYIWZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIYZYEXZYEXZiIYZiIY[9MZ[9MZ
[9MZ[9MZZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIYZYIWZYIWZYIWZYIWZYIWZYIWZYIWZYIWXIIZX9M/
WYIaViQiUYUoU9^6TYb;TYf=VIR3VIR4UiN5UiR8V9R<V9V?UiZAV9ZDW9Z?WI^@WifBX9jCXZ2EXZ2E
XZ2EXZ2EWYf?XJ2BY:>EYjJHZ:NIZZVK[JbN/:nQZk6H[K2P[JnY`[o1h=OJg/k?jMK?X8QlK3hEJSdL
=blB<U4fJfMESDa4ReM;L7eWK55DCT`j?C0@GbH<VEi?e<Fle=[?i]gCg=[?`l6f/:jS/JnT]K>X/JnT
[jfR/k6V[[2T[[2T/;:V/[BX/kFY]KN[]kV]]kV]]kR^]kR^]kR^^;V_^;V_^KZ`^KZ`^KZ`^KZ`^KZ`
^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`]kB__kV^_;2H[9ahY95VZYIV[Ia[ZIYY[i]/[i]/[i]/[i]/[i]/[i]/
[i]/[i]/[iQZ[iQZ[iQZ[iQZ/9U[/9U[/9U[/IY/[iQZ[iQZ/9U[/IY//IY//9U[[iQZ[iQZ/9U[/9U[
/9U[/9U[/9U[/9U[/9U[/9U[[iQZ[iQZ[iQZ[iQZ/9U[/9U[002fXhjfXhjfXhjfXhjfXhjfXhjfXhjf
XhjbY8jbY8jbY8jbY8jbY8jbY8jbY8jbY8jaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXhfaXhfaXhfa
XhfaXhfaXhfaXhfaXhf`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`
XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^`XXb`XXb`XXb`
XXb`XXb`XXb`XXb`XXb^X8Z_XH^`XXb`XXb`XXb`XXb_XH^^X8Z_XH^_XH^_XH^_XH^_XH^_XH^_XH^_
XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^cXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRc
XXRcXXRcXXRcXXRcXXRbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHN^XXJ^XXJ^XXJ^XXJ^XXJ^XXJ^XXJ^
XXJbXHJbXHJbXHJbXHJbXHJbXHJbXHJbXHJcXXNcXXNcXXNbXHJbXHJaX8FaX8F`WhBaX8FaX8FaX8Fa
X8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8F`WhB`WhB`WhB`WhB`WhB`WhB`WhB`
WhB_WX>_WX>_WX>_WX>`WhB`WhBaX8FaX8F`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`
WhB`WhB`WhB`WhB`WhBcXHBcXHBbX8>bX8>aWh:aWh:`WX6`WX6bX86bX86bX86bX86bX86bX86bX86b
X86bX86bX86aWh2aWh2`WWn`WWn_WGj_WGj`WWn`WWn`WWn`WWn`WWn`WWn`WWn`WWn_WGj_WGj_WGj_
WGj_WGj_WGj_WGj_WGj^W7f_WGj_WGj_WGj`WWn`WWn`WWn`WWn^W7f^W7f^W7f^W7f^W7f^W7f^W7f^
W7f_WGj_WGj_WGj^W7f^W7f^W7f]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb[VgN[VgN[VgN[
VgN[VgN[VgN[VgN[VgN^W7N^W7N^W7N^W7N^W7N^W7N^W7N^W7N]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]
VgJ/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/
VWF/VWF/VWF/VWF/VWFZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>Z
V7>ZV7>ZV7>ZV7>ZV7>[VGB[VGB/VWF/VWFZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZVG:ZVG:ZVG:Z
VG:ZVG:ZVG:ZVG:ZVG:WUVnXUg2XUg2XUg2YV76YV76YV76ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:Z
VG:YV76YV76YV76YV76YV76YV76YV76YV76[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:[VW>[VW>ZVG:Z
VG:YV76YV76XUg2XUg2ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZV6nZV6nZV6nZV6nZV6nZV6nZV6nZ
V6n[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:ZV6nYUfjXUVfX
UVfXUVfYUfj[VG2/VW6XUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfX
UVfYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfX
UVfXUVfXUVfXUVfXUVfZV6nYUfjYUfjYUfjXUVfWUFbWUFbWUFb[UVV[UVV[UVV[UVV[UVV[UVV[UVV[
UVVWUfVWUfVWUfVWUfVWUfVWUfVWUfVWUfVZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRYU6NYU6NYU6NZ
UFRZUFR[UVV[UVV[UVVVU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VUVRVUVRVUVRVUVRVUVRVUVRVUVRV
UVRYU6NYU6NYU6NZUFRZUFR[UVV[UVV[UVVZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZ
UFRZUFRZUFRZUFRZUFRYUFJYUFJYUFJZUVNZUVN[UfR[UfR[UfRYUFJYUFJYUFJYUFJYUFJYUFJYUFJY
UFJ[UfR[UfR[UfRZUVNZUVNYUFJYUFJYUFJZUVNZUVNZUVNZUVNZUVNZUVNZUVNZUVN[UVV[UVV[UVV[
UVV[UVV[UVV[UVV[UVVZUFRZUFR[UVV[UVV[UVV/UfZ/UfZ/UfZ[UVV[UVV[UVV[UVV[UVV[UVV[UVV[
UVVZUVNZUVNZUVNZUVNZUVNZUVNZUVNZUVNTU6VSUF^OUW2NUgJLVGfHVXBGVhREVhZHVHFHV8JHV8JH
VHVIVH^JVXjKVY2LVi6LVXnMVi2OWI:PWY>RX9FRX9FRX9FRX9FOWY2QX9:TXiFUY9JVYINYZ9Z/Zif`
[j6X[YF/[in`/JS7`/?Ug=oJcL_=^[=YDdMJ<1==>29`Nf^ca;W0ZZFoPH70ThnBTXJXVj>7UHYWJE=J
;aaS;R6ZVXk;c<;Zg]CIelc3`KJb/:Fd/ZNh]Z^d/ZNa[jBd/ZN^/:B^/:B`/ZJa/jNc]JVe]j^f^:bg
^Jfg^:jg^:jg^:jh^Jnh^Jni^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2j]k:o^Jjn/ifc
Y8>YUfjXUFRYVFZ[Vfb_Vfb_Vfb_Vfb_Vfb_Vfb_Vfb_Vfb_Vfb^UfV_V6Z_V6Z_V6Z`VF^`VF^`VF^`
VF^^UfV_V6Z`VF^`VF^`VF^`VF^_V6Z^UfV_V6Z_V6Z_V6Z_V6Z_V6Z_V6Z_V6Z_V6Z^UfV_V6Z_V6Z_
V6Z`VF^`VF/00;JSS[JSS[JSS[JSS[JSS[JSS[JSS[JSS[:TS[:TS[:TS[:TS[:TS[:TS[:TS[:TS[6R
Sk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6SSK6SSK6SSK6SSK6SSK6SSK6SSK6SSK2RS;2RS;2RS;2RS;2R
S;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS:nQ
RjnQRjnQRjnQRjnQRjnQRjnQRjnQRk2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS:jPRZnQRk2RS;2RS;2R
S;2RS:nQRjjPRZnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRk>R
R;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;:QQk:QQk:QQk:QQk:Q
Qk:QQk:QQk:QQjjRQZjRQZjRQZjRQZjRQZjRQZjRQZjRQ[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[>R
Qk:QQ[:QQ[:QQ[6PQK6PQK6PQK6PQK2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2O
Q;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ:jMPZjMPZnNPjnNPk2OQ;2OQ;2OQ;2OQ:nN
PjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPk:PPk:PPk:PPk:PPk6O
P[6OP[6OP[2NPK6OP;6OP;6OP;6OP;6OP;6OP;6OP;6OP;6OP;6OP;6OP;2NOk2NOk2NOjnMOZnMO[2N
Ok2NOk2NOk2NOk2NOk2NOk2NOk2NOjnMOZnMOZnMOZnMOZnMOZnMOZnMOZnMOZjLOJjLOJjLOJnMOZnM
O[2NOk2NOk2NOjfKO:fKO:fKO:fKO:fKO:fKO:fKO:fKO:nMOZnMOZnMOZjLOJjLOJfKO:fKO:fKO:fK
O:fKO:fKO:fKO:fKO:fKO:fKO:fKO:^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMjjLMjjLMjjLMjjLMjjL
MjjLMjjLMjjLMjfKMZfKMZfKMZfKMZfKMZfKMZfKMZfKMZ^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^I
M:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:ZHLjZHLjZHLjZHLjZH
LjZHLjZHLjZHLjVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZZHLjZHLj^IM:^IM:^IM:^IM:VG
LZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJNFKjRGL:RGL:RGL:VH
LJVHLJVHLJZILZVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJZG
LJZGLJZGLJZGLJZGLJZGLJZGLJZGLJZILZZILZZILZVHLJVHLJVHLJRGL:RGL:VHLJVHLJVHLJVHLJVH
LJVHLJVHLJVHLJZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZGLJZGLJZGLJZGLJZGLJZGLJZGLJZGLJZG
LJZGLJZGLJZGLJZGLJZGLJZGLJZGLJVGKZVGKZRFKJRFKJRFKJVGKZZHKj^IL:RFKJRFKJRFKJRFKJRF
KJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZRF
KJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJVGKZVGKZRFKJRFKJRF
KJNEK:NEK:NEK:^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJNGJJNGJJNGJJNGJJNGJJNGJJNGJJNGJJZE
J:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:VDIjVDIjVDIjVDIjZEJ:ZEJ:^FJJ^FJJJDJjJDJjJDJjJDJjJD
JjJDJjJDJjJDJjJFJ:JFJ:JFJ:JFJ:JFJ:JFJ:JFJ:JFJ:VDIjVDIjVDIjVDIjZEJ:ZEJ:^FJJ^FJJZE
J:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:VEIZVEIZVEIZVEIZZF
IjZFIj^GJ:^GJ:VEIZVEIZVEIZVEIZVEIZVEIZVEIZVEIZ^GJ:ZFIjZFIjZFIjVEIZVEIZVEIZVEIZZF
IjZFIjZFIjZFIjZFIjZFIjZFIjZFIj^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJZEJ:ZEJ:ZEJ:^FJJ^F
JJ^FJJbGJZbGJZ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJZFIjZFIjZFIjZFIjZFIjZFIjZFIjZFIjND
IjJEJZFFKj:FM9nGNIfHOibIQ9ZIQIJIRIRIRIVJRYZJRY^KRifJRijKSIjKSI^ISYfKT9jLTJ2NTj6O
U::PUJ:PUJ:PUJ2OTJ6PTZ>RU:>RU:BSUJNVV:^ZW:n^X:^^V:n`X:j_YL6m_>;Jf]O;akNVWC`Y74D[
7GfJTH:g^X:?WJAnR[b<T[BIW966RIBQ/Hff^HjZY7iWGeLY8IN6NL6n/=_6_]3>`knm/[>aY[FcZ;Rf
ZkBbYk2^Xk:`YJj`Y:j`Y;2bY[6cYk>eZKBfZ[FgZkJh[;Nh[[Nh[[Nh[[Ri[kRi[kVj/;Vj/;Vj/;Vj
/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;fj]Kjj[l2fY;b`U;6QOJFEJjJEJZfMKjjJJjjJJjjJJjjJJjjJ
JjjJJjjJJjjJJjjGJJjGJJjGJJnHJZnHJ[2IJk2IJk2IJjjGJJnHJZnHJ[2IJk2IJjnHJZnHJZjGJJnH
JZnHJZnHJZnHJZnHJZnHJZnHJZnHJZjGJJjGJJjGJJnHJZnHJ[2IJ`00]Z>>]Z>>]Z>>]Z>>]Z>>]Z>>
]Z>>]Z>>/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J>=/J>=
/J>=/J>=/J>=/J>=/J>=/J>=[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;
[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[j6;[j6;
[j6;[j6;[j6;[j6;[j6;[j6;[Z2:[j6;/::</::</::</::<[j6;[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:
[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:/Z67/Z67/Z67/Z67/Z67/Z67/Z67/Z67/Z67/Z67
/Z67/Z67/Z67/Z67/Z67/Z67/J26/J26/J26/J26/J26/J26/J26/J26[J65[J65[J65[J65[J65[J65
[J65[J65/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25/J25/9n4/9n4
/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4
/9n4/9n4[Yf2[Yf2[Yf2[ij3[ij3[ij3/9n4/9n4[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3
[ij3[ij3[ij3[ij3[ij3[ij3/In2/In2/In2/In2/In2/In2/In2/In2/In0/In0/In0/In0/In0/In0
/In0/In0/9io/9io/9io/9io/9io/9io[ien[ien[ien[ien[ien[ien[ien[ien[ien[ien[ien[ien
[ien[ien[ien[ien[ien[ien[Yam[Yam[Yam[Yam[ien[ien/9io/9io[I]l[I]l[I]l[I]l[I]l[I]l
[I]l[I]l[ien[Yam[Yam[Yam[I]l[I]l[I]l[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9YkZi]gZi]g
Zi]gZi]gZi]gZi]gZi]gZi]g[I]f[I]f[I]f[I]f[I]f[I]f[I]f[I]f[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye
[9Ye[9YeZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUd
ZiUdZiUdZiUdZiUdZiUdZiUdZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZIMbZIMbZIMbZIMbZIMbZIMb
ZIMbZIMbZIMbZIMbZIMbZYQcZYQcZYQcZiUdZiUdZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIQaZIQa
ZIQaZIQaZIQaZIQaZIQaZIQaYiI_Z9M`Z9M`Z9M`ZIQaZIQaZIQaZYUbZIQaZIQaZIQaZIQaZIQaZIQa
ZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZIQaZIQa
ZIQaZIQaZIQaZIQaZ9M`Z9M`ZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_
ZYQ_ZYQ_ZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZ9I]Z9I]
Z9I]Z9I]Z9I]ZIM^ZYQ_ZYQ_Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]
Z9I]Z9I]ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]
Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]YiE/YiE/YiE/YiE/ZYEXZYEXZYEXZYEXZYEXZYEX
ZYEXZYEXYYIXYYIXYYIXYYIXYYIXYYIXYYIXYYIXZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZ9=VZ9=V
ZIAWZIAWZIAWZYEXZYEXZYEXYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYIEWYIEWYIEWYIEWYIEWYIEW
YIEWYIEWZ9=VZ9=VZIAWZIAWZIAWZYEXZYEXZYEXZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAW
ZIAWZIAWZIAWZIAWZIAWZIAWZ9AUZ9AUZIEVZIEVZIEVZYIWZYIWZYIWZIEVZIEVZIEVZIEVZIEVZIEV
ZIEVZIEVZYIWZYIWZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVZYEXZYEX
ZYEXZYEXZYEXZYEXZYEXZYEXZIAWZIAWZYEXZYEXZiIYZiIYZiIYZiIYZYEXZYEXZYEXZYEXZYEXZYEX
ZYEXZYEXZYIWZYIWZYIWZYIWZYIWZYIWZYIWZYIW[9AV[9EXZIE/YiE`YIIeXIMiX9MlWiQoUYV9UiZ:
VIZ:Vi^;WYb:X9b:X9b:XIZ9ViV>W9Z?WYbAWifBXInDXInDXInDXInDX9nAXJ2BXZ6CXZ6CXZ6CY:>E
ZJRJ[JbN/K>M]KFS[:bP/ZnZdlg8d<Jo]jRO?B/PDeYGKL?9F<CLNYZm]IF^Vh>;Og^0THREP:>gKkC3
OK[4PhB8ARHPT7i]b<2_j<k7`l6f^;J[/JnT];:W][BY/[2U[ZbQ[ZbQ[[2T[k6U/;:V/K>W/[BX/kFY
];JZ]KN[]kR^]kR^]kR^^;V_^;V_^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`_[bd^kV_
`KZY`kRR]jV<YYIbXi9[[9Ya[YY[[YY[[YY[[YY[[YY[[YY[[YY[[YY[[YMY[YMY[YMY[YMY[iQZ[iQZ
/9U[/9U[[YMY[YMY[iQZ/9U[/9U[[iQZ[YMY[YMY[iQZ[iQZ[iQZ[iQZ[iQZ[iQZ[iQZ[iQZ[YMY[YMY
[YMY[YMY[iQZ[iQZ002eXXfeXXfeXXfeXXfeXXfeXXfeXXfeXXfaXhfaXhfaXhfaXhfaXhfaXhfaXhfa
XhfaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXn`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb_XH^_XH^_XH^_
XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_
XH^^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^^X8Z_XH^`XXb`
XXb`XXb`XXb_XH^^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^
X8ZbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHNaX8JaX8JaX8Ja
X8JaX8JaX8JaX8JaX8J]XHF]XHF]XHF]XHF]XHF]XHF]XHF]XHFaX8FaX8FaX8FaX8FaX8FaX8FaX8Fa
X8F`WhB`WhB`WhBaX8FaX8FaX8FaX8FaX8F`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`
WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB]W86]W86^WH:^WH:_WX>_WX>_WX>_
WX>^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:`WX6`WX6`WX6`
WX6`WX6aWh:aWh:aWh:`WWn`WWn`WWn`WWn`WWn`WWn`WWn`WWn_WGj_WGj_WGj_WGj_WGj_WGj`WWn`
WWn^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f]Vgb]Vgb^W7f^
W7f^W7f_WGj_WGj_WGj^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f]Vgb]Vgb/VW^/VW^/
VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN]VgJ]VgJ]VgJ]
VgJ]VgJ]VgJ]VgJ]VgJ/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF[VGB[VGB[VGB[VGB[VGB[VGB[VGB[
VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGBZV7>ZV7>ZV7>Z
V7>ZV7>ZV7>ZV7>ZV7>XUW6XUW6XUW6XUW6XUW6XUW6XUW6XUW6XUW6XUW6YUg:YUg:ZV7>ZV7>ZV7>Z
V7>XUW6XUW6XUW6XUW6XUW6XUW6XUW6XUW6XUg2XUg2XUg2XUg2XUg2XUg2XUg2XUg2WUVnXUg2XUg2X
Ug2YV76YV76YV76ZVG:XUg2XUg2XUg2XUg2XUg2XUg2XUg2XUg2YV76YV76YV76YV76YV76YV76YV76Y
V76YUW2YUW2YUW2YUW2YUW2YUW2YUW2YUW2XUg2XUg2XUg2XUg2XUg2XUg2YV76YV76XUg2XUg2XUg2X
Ug2XUg2XUg2XUg2XUg2ZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nYUW2YUW2YUW2YUW2YUW2YUW2YUW2Y
UW2YUW2YUW2YUW2YUW2YUW2YUW2YUW2YUW2WUFbWUFbXUVfXUVfYUfjYUfjYUfjYUfjXUVfXUVfXUVfX
UVfXUVfXUVfXUVfXUVfWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbXUVfXUVfXUVfXUVfXUVfXUVfXUVfX
UVfWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbW
UFbWUFbWUFbWUFbWUFbZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRVUVRVUVRVUVRVUVRVUVRVUVRVUVRV
UVRYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NXTfJXTfJXTfJYU6NYU6NYU6NZUFRZUFRUTfZUTfZUTfZU
TfZUTfZUTfZUTfZUTfZUUFNUUFNUUFNUUFNUUFNUUFNUUFNUUFNXTfJXTfJXTfJYU6NYU6NYU6NZUFRZ
UFRYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NXU6FXU6FXU6FY
UFJYUFJYUFJZUVNZUVNYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJXU6FXU6FYUFJYUFJYUFJYUFJYUFJY
UFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRYU6NYU6NYU6NZ
UFRZUFRZUFR[UVV[UVVZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUVNZUVNZUVNZUVNZUVNZUVNZUVNZ
UVN/UFF]UFNZUFRYUFbWUG2TUGBSUWJQUWRGV8BHVHFJVXRMVhVNW8ZPW8ZOVhVOVX^KVHjLVXnMVi2O
WI:PWY>QWiBQWiBQWiBOWY2QX9:RXI>QX9:QX9:RXI>VYINYZ9Z`[i^e]J>/[9jZZIo2`;K6_KBm/JMD
@cXoJFPGV:LB[MALZ]FBTZZ?RHZ=UIEoPY1hZ/1F/<QX_]J@YkIE@S^FR76m/j7D_;Jj^:fe/jRb/:Fd
/ZNe/jRb/:F`[Z>_[J:^/:B_/JF_/JF`/ZJb]:Rc]JVc]JVd]ZZg^:jg^:jg^:jh^Jnh^Jni^[2i^[2i
^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2l^[:i^:jn^jg3_:^j[iVYVgjSTfnZUg:]VFZ]VFZ]VFZ]
VFZ]VFZ]VFZ]VFZ]VFZ]UVR]UVR^UfV^UfV^UfV_V6Z_V6Z_V6Z]UVR^UfV_V6Z_V6Z_V6Z_V6Z^UfV]
UVR^UfV^UfV^UfV^UfV^UfV^UfV^UfV^UfV]UVR]UVR^UfV^UfV^UfV_V6X00;FRSKFRSKFRSKFRSKFR
SKFRSKFRSKFRSK6SSK6SSK6SSK6SSK6SSK6SSK6SSK6SSK6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk2R
S;2RS;2RS;2RS;2RS;2RS;2RS;2RS:jPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjP
RZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZfORJfORJfORJfORJfORJfORJfORJfORJjP
RZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZnQRk2RS;2RS;2RS;2RS:nQRjjPRZfORJfORJfORJfORJfO
RJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORK6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[6P
Q[6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[2OQK2OQK2OQK2OQK2OQK2OQK2OQK2OQJbPQ:bPQ:bPQ:bPQ:bP
Q:bPQ:bPQ:bPQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ:nNPjnNPk2OQ;2OQ;2OQ;6PQK6PQK6PQJnN
PjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPk2OQ;2OQ;2OQ;2OQ;2O
Q;2OQ;2OQ;2OQ:fLPJfLPJfLPJjMPZjMPZnNPjnNPjnNPjjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjM
PZjMPZjMPZjMPZjMPZjMPZjMPZjMPZnMP:nMP:nMP;2NPK2NPK2NPK6OP[6OP[2NOk2NOk2NOk2NOk2N
Ok2NOk2NOk2NOjjLOJjLOJjLOJnMOZnMOZnMO[2NOk2NOjfKO:fKO:fKO:fKO:fKO:fKO:fKO:fKO:jL
OJjLOJjLOJjLOJjLOJjLOJjLOJjLOJfKO:fKO:fKO:fKO:jLOJjLOJnMOZnMOZjLOJjLOJjLOJjLOJjL
OJjLOJjLOJjLOJjLOJfKO:fKO:fKO:bJNjbJNjbJNjbJNj^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^K
Mj^KMj^KMj^KMj^KMj^KMj^KMj^KMjbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJ^IM:^IM:^IM:^IM:^I
M:^IM:^IM:^IM:ZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZH
LjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjRFLJRFLJRFLJRFLJRF
LJRFLJRFLJRFLJRFLJRFLJRFLJVGLZVGLZZHLjZHLjZHLjRFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJRG
L:RGL:RGL:RGL:RGL:RGL:RGL:RGL:NFKjRGL:RGL:RGL:VHLJVHLJVHLJZILZRGL:RGL:RGL:RGL:RG
L:RGL:RGL:RGL:VHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJVFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:NF
KjNFKjNFKjRGL:RGL:RGL:VHLJVHLJRGL:RGL:RGL:RGL:RGL:RGL:RGL:RGL:ZHKjZHKjZHKjZHKjZH
KjZHKjZHKjZHKjVFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:JD
JjJDJjRFKJVGKZVGKZVGKZRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJNEK:NEK:NEK:NEK:NE
K:NEK:NEK:NEK:RFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJNEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NE
K:NEK:NEK:NEK:NEK:NEK:NEK:NEK:JDJjJDJjJDJjJDJjNEK:NEK:NEK:RFKJVDIjVDIjVDIjVDIjVD
IjVDIjVDIjVDIjFEIjFEIjFEIjFEIjFEIjFEIjFEIjFEIjRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZNB
IJNBIJRCIZRCIZVDIjVDIjVDIjVDIjBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBDIZBDIZBDIZBDIZBD
IZBDIZBDIZBDIZNBIJNBIJRCIZRCIZVDIjVDIjVDIjVDIjRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRC
IZRCIZRCIZRCIZRCIZRCIZRCIZRCIZNCI:NCI:RDIJRDIJVEIZVEIZVEIZVEIZVEIZVEIZVEIZVEIZVE
IZVEIZVEIZVEIZNCI:RDIJRDIJRDIJVEIZVEIZVEIZVEIZRDIJRDIJRDIJRDIJRDIJRDIJRDIJRDIJVD
IjVDIjVDIjVDIjVDIjVDIjVDIjVDIjRCIZVDIjVDIjVDIjZEJ:ZEJ:ZEJ:ZEJ:VDIjVDIjVDIjVDIjVD
IjVDIjVDIjVDIjZFIjZFIjZFIjZFIjZFIjZFIjZFIjZFIjbEIJ^EIJZFIjREJ:NEK:BEKZ:EKj>ELI^F
OI^GOYjJPYjJQijLRYjKS9^JS9^ISYZHSI^ISYfKT9nMTZ2NTj2NTj2NTj2NTifLSZ2OTJ:QTj:QTj6P
TZ6PTZ>RU:FTUZJRT;6_WJn_Wjb/W[VhZ[J`YKbbZ6IGCTn<R3[3f@FgiR2PbgVP[Z6MTZ6NUY>LYGF]
_TV`bEFogYS1efeTFj^PQ;6ZU[ZWY;JdZKJdZKJdZKNeZ[NeZ[JdZKFcZ;FcZ:j`Y:naYJnaYK2bY[6c
Yk:dZ;:dZ;>eZKNh[[Nh[[Nh[[Ri[kRi[kVj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Zh
/;Zh/;bk/Kjl/KbeY;:VSZVIO:RDLJfIJZfIJZfIJZfIJZfIJZfIJZfIJZfIJZfFJ:fFJ:fFJ:fFJ:jG
JJjGJJnHJZnHJZfFJ:fFJ:jGJJnHJZnHJZjGJJfFJ:fFJ:jGJJjGJJjGJJjGJJjGJJjGJJjGJJjGJJfF
J:fFJ:fFJ:fFJ:jGJJjGJ@00]:6<]:6<]:6<]:6<]:6<]:6<]:6<]:6</::</::</::</::</::</::<
/::</::</J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[Z2:[Z2:
[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:
[Z2:[Z2:[In9[In9[In9[In9[In9[In9[In9[In9[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[j6;
/::</::</::</::<[j6;[Z2:[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9
[In9[In9/J26/J26/J26/J26/J26/J26/J26/J26/J26/J26/J26/J26/J26/J26/J26/J26/9n5/9n5
/9n5/9n5/9n5/9n5/9n5/9n5[:24[:24[:24[:24[:24[:24[:24[:24/9n4/9n4/9n4/9n4/9n4/9n4
/9n4/9n4[Yf2[ij3[ij3/9n4/9n4/J25/J25/J25[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3
[ij3[ij3[ij3[ij3[ij3[ij3/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4[Ib1[Ib1[Ib1[Ib1[Yf2[Yf2
[Yf2[ij3[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yao[Yao
[if0[if0/9j1/9j1/In2/In2/9io/9io/9io/9io/9io/9io/9io/9io[I]l[I]l[Yam[Yam[ien[ien
/9io/9io[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[9Yk[9Yk
[I]l[I]l[Yam[Yam[Yam[Yam[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[9Yk[9Yk[9Yk
ZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZi]gZi]gZi]gZi]gZi]gZi]gZi]gZi]g[9Ye[9Ye
[9Ye[9Ye[9Ye[9Ye[9Ye[9YeZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZYQcZYQcZYQcZYQcZYQcZYQc
ZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQc
ZYQcZYQcZYQcZYQcZYQcZYQcYiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`Z9IaZ9IaZ9IaZ9IaZIMbZIMb
ZIMbZYQcYiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`YiI_YiI_YiI_YiI_YiI_YiI_YiI_YiI_YiI_Z9M`
Z9M`Z9M`ZIQaZIQaZIQaZYUbYiI_YiI_YiI_YiI_YiI_YiI_YiI_YiI_ZIQaZIQaZIQaZIQaZIQaZIQa
ZIQaZIQaZ9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_YYE^YYE^YiI_YiI_Z9M`Z9M`ZIQaZIQaYiI_YiI_
YiI_YiI_YiI_YiI_YiI_YiI_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_
Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_YI=ZYYA[YiE/ZIM^ZIM^ZIM^Z9I]YiE/Z9I]Z9I]
Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YiE/YiE/YiE/YiE/YiE/YiE/
YiE/YiE/YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YI=ZYI=Z
YI=ZYYA[YiE/YiE/YiE/Z9I]ZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWYIEWYIEWYIEWYIEWYIEWYIEW
YIEWYIEWZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VYi9UYi9UYi9UZ9=VZ9=VZIAWZIAWZIAWY99YY99Y
Y99YY99YY99YY99YY99YY99YY9AVY9AVY9AVY9AVY9AVY9AVY9AVY9AVYi9UYi9UYi9UZ9=VZ9=VZIAW
ZIAWZIAWZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VYi=TYi=T
Yi=TZ9AUZ9AUZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVYi=TYi=TYi=TZ9AUZ9AUZIEV
ZIEVZIEVZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZ9=VZ9=V
ZIAWZIAWZIAWZYEXZYEXZYEXZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZYIWZYIWZYIWZYIWZYIWZYIW
ZYIWZYIWZiISZIISZIEUYiEVY9EWXYEYXiE[XIE[WYAbWiEgWiQmWi^3WI^9Vi^?UYV@UINAVYR=ViV>
W9Z?WYbAWifBX9jCX9jCX9jCViZ<Wij@XZ6CXj:DXZ6CX9nAX9nAXJ2BXIZ9[:RF[:bJ[ZjL]KFU[ZRK
_kF[NVeUAH5g?Jk809_?3:gCLkRkIdhjAB<CK75`Q;[5Ck_C>joBLZJmEUA:[ZV8^;RPak^k/[2U]K>X
]kFZ]kFZ][BY]kFZ^;J[^;J[[k6U[k6U[k6U/;:V/K>W/K>W/[BX/[BX]kR^]kR^]kR^^;V_^;V_^KZ`
^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KR^^[^b^k^e_;Zb_KV^_[:P/j:7Yi9c[9QY[9QY
[9QY[9QY[9QY[9QY[9QY[9QY[9EW[9EW[IIX[IIX[YMY[YMY[YMY[YMY[9EW[IIX[YMY[YMY[YMY[YMY
[IIX[9EW[IIX[IIX[IIX[IIX[IIX[IIX[IIX[IIX[9EW[9EW[IIX[IIX[YMY[YMY002dXHbdXHbdXHbd
XHbdXHbdXHbdXHbdXHb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXbaXXnaXXnaXXnaXXnaXXnaXXnaXXna
XXn_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^
X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z]WhV]WhV]WhV]WhV]WhV]WhV]WhV]
WhV^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z_XH^`XXb`XXb`XXb`XXb_XH^^X8Z]WhV]WhV]WhV]
WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhVaX8JaX8JaX8JaX8JaX8JaX8JaX8Ja
X8JaX8JaX8JaX8JaX8JaX8JaX8JaX8JaX8J`WhF`WhF`WhF`WhF`WhF`WhF`WhF`WhF/X8B/X8B/X8B/
X8B/X8B/X8B/X8B/X8B`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB^WH:^WH:_WX>_WX>`WhBaX8FaX8Fa
X8F_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>`WhB`WhB`WhB`
WhB`WhB`WhB`WhB`WhB/Vh2]W86]W86]W86^WH:^WH:^WH:^WH:]W86]W86]W86]W86]W86]W86]W86]
W86]W86]W86]W86]W86]W86]W86]W86]W86^W7n^W7n^W7n_WH2`WX6`WX6aWh:aWh:_WGj_WGj_WGj_
WGj_WGj_WGj_WGj_WGj]Vgb]Vgb]Vgb^W7f_WGj_WGj`WWn`WWn/VW^/VW^/VW^/VW^/VW^/VW^/VW^/
VW^]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb/VW^/VW^]Vgb]Vgb]Vgb^W7f^W7f^W7f[VGZ[VGZ[VGZ[
VGZ[VGZ[VGZ[VGZ[VGZ]Vgb]Vgb]Vgb/VW^/VW^[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[
VGZ[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF[VGB[VGB[VGB[
VGB[VGB[VGB[VGB[VGBZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>Z
V7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>WUG2WUG2WUG2W
UG2WUG2WUG2WUG2WUG2WUG2XUW6XUW6XUW6YUg:YUg:YUg:YUg:WUG2WUG2WUG2WUG2WUG2WUG2WUG2W
UG2WUVnWUVnWUVnWUVnWUVnWUVnWUVnWUVnWUVnXUg2XUg2XUg2YV76YV76YV76ZVG:WUVnWUVnWUVnW
UVnWUVnWUVnWUVnWUVnYV76YV76YV76YV76YV76YV76YV76YV76XUFnXUFnXUFnXUFnXUFnXUFnXUFnX
UFnVUFjVUFjVUFjWUVnXUg2XUg2YV76YV76WUVnWUVnWUVnWUVnWUVnWUVnWUVnWUVnZV6nZV6nZV6nZ
V6nZV6nZV6nZV6nZV6nXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnX
UFnTTVVVU6^WUFbYUfjYUfjXUVfWUFbVU6^XUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfVU6^VU6^VU6^V
U6^VU6^VU6^VU6^VU6^WUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbVU6^VU6^VU6^VU6^VU6^VU6^VU6^V
U6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^TTVVUTfZUTfZVU6^VU6^WUFbWUFbXUVfYU6NYU6NYU6NY
U6NYU6NYU6NYU6NYU6NUUFNUUFNUUFNUUFNUUFNUUFNUUFNUUFNXTfJXTfJXTfJXTfJXTfJXTfJXTfJX
TfJWTVFWTVFWTVFXTfJXTfJXTfJYU6NYU6NTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTU6JTU6JTU6JT
U6JTU6JTU6JTU6JTU6JWTVFWTVFWTVFXTfJXTfJXTfJYU6NYU6NXTfJXTfJXTfJXTfJXTfJXTfJXTfJX
TfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJWTfBWTfBWTfBXU6FXU6FXU6FYUFJYUFJYUFJYUFJYUFJY
UFJYUFJYUFJYUFJYUFJVTV>VTV>WTfBWTfBXU6FYUFJYUFJYUFJXU6FXU6FXU6FXU6FXU6FXU6FXU6FX
U6FYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NXTfJXTfJXTfJYU6NYU6NYU6NZUFRZUFRYU6NYU6NYU6NY
U6NYU6NYU6NYU6NYU6NZUVNZUVNZUVNZUVNZUVNZUVNZUVNZUVNYUV>WUV>WUVFUUVFTUVJRUFNOU6RO
U6RPTffPU72QUgVOVH:MVhVHVHnDV9>@UiBJV8fKVHjLVXnNW96OWI:PWY>PWY>PWY>JVH^NWHnRXI>T
XiFSXYBPWi6OWY2NWHnRVXVWXi6XYYBZZYRa/InYYYS6_K>@Pg]2M6Q5X;/@/>H1/mHbQGeM<1EN7`]2
?3EZWZA;^<hj/]IaZ/=KG5:e/i2/[iJYXjB^[:6b/:Ff]:Vd/ZNc/JJe/jRg]JZh]Z^_/JF_/JF_/JF`
/ZJ`/ZJa/jNa/jNa/jNg^:jg^:jg^:jh^Jnh^Jni^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i
^[2i^:jm_[Fk_KNi^K>n_;;5^jZjZHnWTGF/V6V/V6V/V6V/V6V/V6V/V6V/V6V/V6V/UFN/UFN]UVR]
UVR]UVR^UfV^UfV^UfV/UFN]UVR^UfV^UfV^UfV^UfV]UVR/UFN]UVR]UVR]UVR]UVR]UVR]UVR]UVR]
UVR/UFN/UFN]UVR]UVR]UVR^UfT00;BQS;BQS;BQS;BQS;BQS;BQS;BQS;BQS:nRR:nRR:nQRZnQRZnQ
RjnQRjnPSJnPSJjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPR[:NS;:NS;:NS;:NS;:NS;:NS;:NS;:NS:fO
RJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJnQRjjPRZbNR:^MQj^M
QjbNR:jPRZnQRj^MQjbNR:fORJjPRZjPRZjPRZfORJfORJbNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:fO
RJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJbNR:bNR:bNR:bNR:bN
R:bNR:bNR:bNR:bOQJbOQJbOQJbOQJbOQJbOQJbOQJbOQK2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;:Q
Qk6PQ[6PQ[2OQK2OQJnNQ:jMPjjMPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnN
PjnNPjnNPjnNPjjMPZjMPZjMPZnNPjnNPjnNPk2OQ;2OQ:nNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnN
PjnNPjnNPjnNPjnNPjnNPjnNPjnNPjjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjM
PZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZbLOjbLOjbLOjbLOjbLOjbLOjbLOjbLOjjL
OJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJfKO:fKO:fKO:fKO:fK
O:fKO:fKO:fKO:bJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJ
NjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjVIMJZJMZZJMZ^KMj^K
MjbLN:bLN:fMNJVGN:VGN:VGN:ZHNJZHNJ^INZ^INZ^INZbIMZbIMZbIMZ^HMJZGM:ZGM:VFLjVFLjbJ
MJbJMJbJMJbJMJbJMJbJMJbJMJbJMJNJM:VIM:VIM:^IM:^IM:bIM:bIM:jHM:ZHLjZHLjZHLjZHLjZH
LjZHLjZHLjZHLjVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjVG
LZVGLZVGLZVGLZVGLZVGLZVGLZVGLZNEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:VGLZVGLZVGLZVGLZVG
LZVGLZVGLZVGLZNEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:JDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjNF
KjNFKjNFKjNFKjNFKjNFKjNFKjNFKjZGLJZGLJZGLJZGLJZGLJZGLJZGLJZGLJNDKZREKjREKjREKjVF
L:VFL:VFL:ZGLJREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjRF
KJRFKJRFKJRFKJRFKJRFKJRFKJRFKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJNDKZNDKZNDKZNDKZND
KZNDKZNDKZNDKZRFKJRFKJRFKJNEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:JD
JjJDJjNEK:NEK:RFKJRFKJRFKJRFKJNEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:ZEJ:ZEJ:ZEJ:ZEJ:ZE
J:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:VDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVD
IjVDIjVDIjVDIjVDIjVDIjVDIjVDIjRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRC
IZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRC
IZRCIZRCIZRCIZRCIZRCIZRCIZRCIZJAI:JAI:NBIJRCIZRCIZNBIJJAI:JAI:NCI:NCI:NCI:RDIJRD
IJVEIZVEIZVEIZNCI:RDIJRDIJVEIZVEIZRDIJRDIJNCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NC
I:NCI:NCI:NCI:NCI:NCI:NCI:NCI:JBHjJBHjJBHjNCI:NCI:NCI:RDIJRDIJRDIJNCI:JBHjFAHZFA
HZNCI:RDIJZFIjRDIJRDIJRDIJRDIJRDIJRDIJRDIJRDIJRDIJRDIJRDIJRDIJRDIJRDIJRDIJRDIJRD
IJRDIJRDIJRDIJRDIJRDIJRDIJRDIJRCIZRCIZVDIjVDIjVDIjZEJ:ZEJ:ZEJ:^DIZ^DIZ^DIZ^DIZ^D
IZ^DIZ^DIZ^DIZRDIJRDIJRDIJRDIJRDIJRDIJRDIJRDIJVFJjJDJj2BKYbAMIVCP9JDRIBFT9>FU9jG
SYbHSIbHSI^JS9bMSIfQSZ2UT:2WTZ2NTj2NTj2NTj2NTj2NTj2NTj2NTj2NTj:PSYVIQifNSYfNSZf/
W/>k[ZjOUYZ7Och^8W>AY3Zefc:Q`DhjAXTe:EPF0eTA2V=VI4jc_4VgcgEjSe`_8Z:RNZnlX/BQZkBb
YkFcZ;FcZ;FcZ;JdZKJdZKJdZKNeZ[>eZK6cYjj`Y:b^XZb^XZf_XjnaYK2bY[6bZ;:cZKFf[;Nh[[Ri
[kRi[kRi[kNh[[^i[k^i[kbj/;bj/;bj/;fk/Kfk/Kfk/KFo[kVo];Zk^Kbg^;ji^;ni[;FaV:VWQInC
KjFFKjRGK:jGJK6KJkFOKk6LKjZGK:bEIjbEIjbEIjbEIjbEIjbEIjbEIjbEIjjGJJjGJJnHJZnHJZjG
JJfFJ:bEIj^DIZnHJZnHJZjGJJjGJJfFJ:bEIjbEIjbEIj^DIZ^DIZ^DIZbEIjbEIjfFJ000]:6<]:6<
]:6<]:6<]:6<]:6<]:6<]:6<[j:8[j:8[j6:[j6:[j6;[j6;[j2=[j2=[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:
[Z2:[Z2:/Yj</Yj</Yj</Yj</Yj</Yj</Yj</Yj<[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9
[In9[In9[In9[In9[In9[In9[Z2:[In9[9j8Zif7Zif7[9j8[In9[Z2:Zif7Zif7[In9[Z2:[Z2:[Z2:
[In9[In9[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9
[In9[In9[In9[In9[In9[In9[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9n5[9n5[9n5[9n5[9n5[9n5
[9n5[9n5/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/J26/J26/9n5/9n5[ij4[ij4[Yf3[Yf3[ij3[ij3
[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[Ib1[Yf2[Yf2[Yf2[ij3[ij3
[ij3/9n4[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[Ib1[Ib1
[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1
[Ib1[Ib1[9ao[9ao[9ao[9ao[9ao[9ao[9ao[9ao[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam
[Yam[Yam[Yam[Yam[Yam[Yam[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk
[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk
[9Yk[9Yk[9Yk[9Yk[9Yk[9YkZYYfZYYfZi]gZi]gZi]gZi]gZi]g[9ahZIMhZIMhZIMhZYQiZYQiZYQi
ZiUjZiUj[9Uf[9Uf[9UfZiQeZiQeZiQeZiQeZiQe[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9YeYiYdZIUd
ZIUdZiUdZiUd[9Ud[9Ud[YQdZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZIMbZIMbZIMbZIMbZIMbZIMb
ZIMbZIMbZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaYiE`YiE`
YiE`YiE`YiE`YiE`YiE`YiE`Z9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaYiE`YiE`YiE`YiE`YiE`YiE`
YiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`YiI_YiI_YiI_YiI_YiI_YiI_YiI_YiI_Z9E_Z9E_
Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_YiA^YiA^Z9E_Z9E_Z9E_ZII`ZII`ZII`Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_
Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]YY=]YY=]
YY=]YY=]YY=]YY=]YY=]YY=]YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^Z9I]YiE/YiE/YiE/YiE/YiE/
YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YYA[YYA[YiE/YiE/YiE/Z9I]Z9I]Z9I]YiE/YiE/
YiE/YiE/YiE/YiE/YiE/YiE/ZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEX
ZYEXZYEXZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZ9=VZ9=V
Z9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=V
Z9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VYY5TYY5T
Yi9UZ9=VZ9=VYi9UYY5TYY5TYi=TYi=TYi=TZ9AUZ9AUZ9AUZIEVZIEVYi=TYi=TZ9AUZIEVZIEVZ9AU
Yi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYY9SYY9S
YY9SYY9SYi=TYi=TZ9AUZ9AUYi=TYY9SYI5RYI5RYI5RYi=TZ9AUZIEVZ9AUZ9AUZ9AUZ9AUZ9AUZ9AU
Z9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9=VZ9=V
Z9=VZIAWZIAWZIAWZYEXZYEXZiAVZiAVZiAVZiAVZiAVZiAVZiAVZiAVZIEVZIEVZIEVZIEVZIEVZIEV
ZIEVZIEV/9ERZY=QYY5TXY1[X99eX9EoWiR7X9^<WYfCWYjBWIfAW9b@W9b>VYf=Vij>Vij>WYbAWYbA
WYbAWYbAWI^@WI^@WI^@WI^@W9Z8WIf;X:6AWj2@WYf?/:RK]JJMVHIn?RH@EFE/?JBmBJZn>24UGa80
E1/2HR0E?S4YI[2bF:JgFDIEGAdBYIE`]kfT_YjS];:W];:W]K>X]K>X]K>X][BY][BY][BY];JZ/[BX
[k6U[JnS[:jR[JnS[k6U/;:V/K:X/[>Y]KJ/]kR^^;V_^;V_^;V_]kR^^kV_^kV_^kV__;Z`_;Z`_K^a
_K^a_K^a/kf]][ba^;Ve^kJg_[Vf`[ba^kNO/Jj?X9IdXYE_YYA[ZIEVZI=SZ95SYi9UZ9EZ[9EW[9EW
[9EW[9EW[9EW[9EW[9EW[9EW[YMY[YMY[YMY[YMY[YMY[IIX[9EWZiAV[iQZ[YMY[YMY[IIX[IIX[9EW
[9EW[9EW[9EW[9EW[9EW[9EW[IIX[IIX002dXHbdXHbdXHbdXHbdXHbdXHbdXHbdXHb_XXR_XXR_XHZ_
XHZ_XH^_XH^_X8f_X8f^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8ZbWhZbWhZbWhZbWhZbWhZbWhZbWhZb
WhZ/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR]WhV]WhV/WXR[
WHN[WHN/WXR]WhV]WhVZW8J[WHN/WXR]WhV^X8Z]WhV]WhV/WXR]WhV]WhV]WhV]WhV]WhV]WhV]WhV]
WhV/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR[WHN[WHN[WHN[
WHN[WHN[WHN[WHN[WHN[WXB[WXB[WXB[WXB[WXB[WXB[WXB[WXB_WX>_WX>_WX>_WX>_WX>_WX>_WX>_
WX>`WhF`WhF`WhF`WhF_WXB_WXB_WXB^WH>^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^
WH:^WH:^WH:^WH:^WH:]W86]W86^WH:^WH:^WH:_WX>_WX>_WX>^WH:^WH:^WH:^WH:^WH:^WH:^WH:^
WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]
W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86/W7n/W7n/W7n/W7n/W7n/W7n/W7n/
W7n^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f]Vgb]Vgb]Vgb]
Vgb]Vgb]Vgb]Vgb]Vgb/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/
VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^[VgN[VgN[VgN[
VgNZVWJZVWJZVWJZVWJXUWNYUgRYUgRYUgRZV7VZV7VZV7VZV7V[V7F[V7F/VGJ/VGJ/VGJ/VGJ]VWN]
VWN[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGBVVG>XV7>XV7>ZV7>ZV7>[V7>[V7>]Ug>YUg:YUg:YUg:Y
Ug:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:Y
Ug:XUW6XUW6XUW6XUW6XUW6XUW6XUW6XUW6WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2XUW6XUW6XUW6X
UW6XUW6XUW6XUW6XUW6WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2W
UG2WUVnWUVnWUVnWUVnWUVnWUVnWUVnWUVnWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jX
UFnXUFnYUW2YUW2YUW2XUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnX
UFnXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfVTffVTffVTffVTffVTffVTffVTffVTffWU6jWU6jWU6jW
U6jWU6jWU6jWU6jWU6jWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbW
UFbVU6^VU6^VU6^WUFbWUFbWUFbXUVfXUVfWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbZUFRZUFRZUFRZ
UFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRYU6NYU6NYU6NYU6NYU6NYU6NYU6NY
U6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJWTVFWTVFWTVFW
TVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFW
TVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFUT6>VTFBWTVFWTVFWTVFWTVFVTFBUT6>VTV>WTfBWTfBW
TfBXU6FXU6FXU6FXU6FVTV>WTfBXU6FXU6FXU6FXU6FWTfBVTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>V
TV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>UTF:UTF:VTV>VTV>WTfBWTfBWTfBWTfBVTV>VTV>UTF:U
TF:UTF:VTV>XU6FXU6FWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBW
TfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBXTfJXTfJXTfJXTfJYU6NYU6NYU6NZUFR[U6J[U6J[U6J[
U6J[U6J[U6J[U6J[U6JZUVNZUVNZUVNZUVNZUVNZUVNZUVNZUVNeV5nbUen]UF6ZTfFVTffVUGBVV7^W
VX2GVhnGVhnHW92JW92JW92KVhnJVXjIVHfMVi2MVi2LVXnLVXnKVHjJV8fJV8fJV8fGUH>LW8ZJVh^W
Z9RPWi6aZIc5]Zf:Mfm97P0n;bI7RHig^[e?:b=I3@1F8PAL70Y48a29Zj5YRHiA7BA_5`VIM5:m^J32
Z:Rd/ZNd/ZNd/ZNe/jRe/jRf]:Vf]:Vf]:Ve]j^c]JVa/jN^/:B][j>^/:B^/:B_/JFa/ZRb/jVd]J^f
]jfg^:jh^Jnh^Jng^:jk^Jnk^Jnk^Jnk^Jnl^[2l^[2m^k6m^k6c^Z^f^Znh^;:i]KBm^KC2_[?0_JRj
]i^YWh6SUgFRTFZWTVFUSV2OR5ZQS5nYUV^/UFN/UFN/UFN/UFN/UFN/UFN/UFN/UFN]UVR]UVR^UfV^
UfV^UfV]UVR/UFN[U6J^UfV^UfV]UVR]UVR]UVR/UFN/UFN/UFN^UfV]UVR]UVR]UVR]UVR]UVP00;>P
Rk>PRk>PRk>PRk>PRk>PRk>PRk>PRjnRR:nRR:nQRZnQRZnQRjnQRjnPSJnPSJjPRZjPRZjPRZjPRZjP
RZjPRZjPRZjPR[6NRK6NRK6NRK6NRK6NRK6NRK6NRK6NRJbNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bN
R:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:ZLQZ^MQjbNR:fORJfO
RJfORJbNR:bNR:fORJfORJfORJfORJfORJfORJfORJfORJ^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQjbN
R:bNR:bNR:bNR:bNR:bNR:bNR:bNR:^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQj^NQ:^NQ:^NQ:^NQ:^N
Q:^NQ:^NQ:^NQ:nNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNQ:nNQ:nNQ:nNQ:nNQ:nNQ:nNQ:nNQ:jM
PZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZfLPJfLPJfLPJjMPZjM
PZjMPZnNPjnNPjjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZfL
PJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfL
PJfLPJfLPJfLPJbLOjbLOjbLOjbLOjbLOjbLOjbLOjbLOjjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjL
OJjLOJjLOJjLOJjLOJjLOJjLOJjLOJbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNj^INZ^INZ^INZ^INZ^I
NZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^I
NZ^INZ^INZ^INZ^INZ^INZ^INZ^INZbLN:^KMj^KMjZJMZZJMZVIMJVIMJVIMJRFMjRFMjRFMjVGN:VG
N:ZHNJZHNJZHNJ^HMJ^HMJ^HMJbIMZfJMjfJMjjKN:jKN:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:JI
LjRHLjRHLjZHLjZHLj^HLj^HLjfGLjVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVG
LZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZRFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJNE
L:NEL:NEL:NEL:NEL:NEL:NEL:NEL:RFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJNEL:NEL:NEL:NEL:NE
L:NEL:NEL:NEL:RFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJNFKjNFKjNFKjNFKjNFKjNFKjNFKjNFKjND
KZNDKZNDKZNDKZNDKZNDKZNDKZNDKZJCKJNDKZNDKZNDKZREKjREKjREKjVFL:REKjREKjREKjREKjRE
KjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJJC
KJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJDJjJDJjJDJjJDJjNE
K:NEK:NEK:NEK:JDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjFCJZFCJZJDJjJDJjNEK:NEK:NEK:NEK:JD
JjJDJjJDJjJDJjJDJjJDJjJDJjJDJjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVD
IjVDIjVDIjVDIjRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRC
IZRCIZRCIZRCIZRCIZRCIZRCIZRCIZNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNB
IJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJF@
HjF@HjJAI:NBIJNBIJJAI:F@HjF@HjJBHjJBHjJBHjNCI:NCI:RDIJRDIJRDIJJBHjNCI:NCI:RDIJRD
IJNCI:NCI:JBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjFA
HZFAHZFAHZJBHjJBHjJBHjNCI:NCI:FAHZFAHZFAHZFAHZJBHjJBHjNCI:NCI:NCI:NCI:NCI:NCI:NC
I:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NB
IJNBIJRCIZRCIZRCIZVDIjVDIjVDIjZCIJZCIJZCIJZCIJZCIJZCIJZCIJZCIJVEIZVEIZVEIZVEIZVE
IZVEIZVEIZVEIZVAGJVBH:VCHjFBIj6@JIn>KIb?Kif?LXZBPHbDPi:GR9FISIZKTIfKTijKTijJUIjL
TIjLTIfKT9bJSibJSi^ISYZHSIZHSIbJR9^KRHn@P:f^WZVXV[J^XLFf[F=@B6`Y0T/F0DEGBWZCQG0h
9g0Q1U/W2EPC07A29Xn9MVYOEehD47PG2G909;2SSKZXXK>aY[BbYkBbYkBbYkFcZ;FcZ;FcZ;JdZKFg
ZkBfZ[:dZ;2bYZnaYJnaYJnaYJnaYK6bZ;:cZK>dZ[Ff[;Jg[KNh[[Nh[[Ri[kZh[[Zh[[^i[k^i[k^i
[kbj/;bj/;bj/;Jk[;Vk[kRi/;Re/;bi/L>o]<;0[[nmYKJ_U:JLOZ2@K:FAJ:N@Hj:;GZB?HZnIKj^D
IZ^DIZ^DIZ^DIZ^DIZ^DIZ^DIZ^DIZbEIjbEIjfFJ:fFJ:fFJ:fFJ:bEIj^DIZfFJ:fFJ:fFJ:bEIjbE
IjbEIjbEIjbEIjjGJJjGJJjGJJfFJ:bEIjbEI`00/j2;/j2;/j2;/j2;/j2;/j2;/j2;/j2;[j:8[j:8
[j6:[j6:[j6;[j6;[j2=[j2=[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:/In8/In8/In8/In8/In8/In8
/In8/In8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8Zif7Zif7
[9j8[9j8[9j8[9j8Zif7Zif7ZI^5ZYb6Zif7[9j8[In9[9j8[9j8[9j8[In9[In9[In9[In9[In9[In9
[In9[In9ZYb6ZYb6ZYb6ZYb6ZYb6ZYb6ZYb6ZYb6[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8ZYb6ZYb6
ZYb6ZYb6ZYb6ZYb6ZYb6ZYb6ZYf3ZYf3ZYf3ZYf3ZYf3ZYf3ZYf3ZYf3[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2
[Yf2[Yf2[Yf3[Yf3[Yf3[Yf3[Yf3[ij4[ij4[ij4[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1
[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[9^0[9^0[Ib1[Ib1[Ib1[Yf2[Yf2[Yf2[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1
[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0
[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0Zi]nZi]nZi]nZi]nZi]nZi]n
Zi]nZi]n[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[9Yk[9Yk
[9Yk[9Yk[9Yk[9Yk[9Yk[9YkZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUj
ZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZi]gZi]g
Zi]gZYYfZIUeZIUeZ9QdZ9QdYiEfZ9IgZ9IgZ9IgZIMhZIMhZIMhZYQiZYMdZYMdZiQeZiQe[9Uf[IYg
[IYg[IYgZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdYIQbYiMbYiMbZIMbZIMbZYMbZYMb[9IbZ9IaZ9Ia
Z9IaZ9IaZ9IaZ9IaZ9IaZ9IaZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZ9IaZ9IaZ9IaZ9IaZ9IaZ9Ia
Z9IaZ9IaYiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YiE`YiE`
YiE`YiE`YiE`YiE`YiE`YiE`YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YiE`YiE`YiE`YiE`YiE`YiE`
YiE`YiE`YYE^YYE^YYE^YYE^YYE^YYE^YYE^YYE^Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_YY=]YY=]
YY=]YiA^YiA^Z9E_Z9E_Z9E_YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^
YiA^YiA^YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]
YY=]YY=]YY=]YY=]YY=]YY=]Y99YYI=ZYI=ZYYA[YYA[YiE/YiE/YiE/YYA[YYA[YYA[YYA[YYA[YYA[
YYA[YYA[YI=ZYI=ZYI=ZYYA[YYA[YYA[YiE/YiE/YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[ZIAWZIAW
ZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZ9=VZ9=VZ9=VZ9=VZ9=VZ9=V
Z9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VYi9UYi9U
Yi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9U
Yi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UY8mRYI1SYY5TYY5TYY5TYY5TYI1SY8mRYI5RYY9S
YY9SYY9SYi=TYi=TYi=TZ9AUYY9SYY9SYi=TYi=TYi=TYi=TYY9SYY9SYI5RYI5RYI5RYI5RYI5RYI5R
YI5RYI5RYI5RYI5RYI5RYI5RYI5RYI5RYI5RYI5RY91QY91QYI5RYI5RYY9SYY9SYY9SYY9SY91QY91Q
YI5RYY9SYY9SYY9SYY9SYY9SYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=T
Yi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi9UYi9UYi9UYi9UZ9=VZ9=VZIAWZIAWZY=UZY=U
ZY=UZY=UZY=UZY=UZY=UZY=UYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TNfe3Og=;QWUCQg]GQ7UIP7IH
O7=HO7=HMG]RN7iWOX1/PhAdQhMkRXQnRhN2S8R3WifBWifBWYbAWYbAWI^@WI^@WI^@W9Z?X9j<W9b:
SXmoZJZJXJ2BZ:2C^JZQG4U1M2X6H180<1T3?S<MGQH4IQP1C1X0G1<0BQ<0@bD<?1X:E0`0KQ/<IcDQ
^JZG/j^N/k6V/k6V/k6V];:W];:W]K>X]K>X]K>X]KN[];JZ/kFY/[BX/K>W/;:V/;:V/;:V/[>Y/[>Y
/[>Y/kBZ]KJ/][N]]kR^^;V_^[R^^[R^^[R^^kV_^kV_^kV__;Z`_;Z`^[f^_Kfa^kZ`]kF]^[R^_kfb
`<2`_[bZ_kRT[:::WI1`XXmZZI=YZY=VZi=Y[YQ^ZiAVZiAVZiAVZiAVZiAVZiAVZiAVZiAVZiAVZiAV
[9EW[IIX[IIX[9EW[9EWZiAV[9EW[9EW[9EW[9EW[9EW[9EW[9EW[9EW[IIX[IIX[IIX[9EWZiAVZiAV
002bWhZbWhZbWhZbWhZbWhZbWhZbWhZbWhZ_XXR_XXR_XHZ_XHZ_XH^_XH^_X8f_X8f^X8Z^X8Z^X8Z^
X8Z^X8Z^X8Z^X8Z^X8Z`WXN`WXN`WXN`WXN`WXN`WXN`WXN`WXN[WHN[WHN[WHN[WHN[WHN[WHN[WHN[
WHN[WHN[WHN[WHN[WHN[WHN[WHN[WHN[WHNZW8J[WHN[WHN/WXR/WXR[WHN[WHNZW8JYVhFZW8J[WHN/
WXR/WXR/WXR/WXR[WHN/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXRYVhFYVhFYVhFYVhFYVhFYVhFYVhFY
VhF[WHN[WHN[WHN[WHN[WHN[WHN[WHN[WHNZW8JZW8JZW8JZW8JZW8JZW8JZW8JZW8JZWH>ZWH>ZWH>Z
WH>ZWH>ZWH>ZWH>ZWH>^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:]W8:]W8:]W8:^WH>^WH>^WH>_WXB_
WXB]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86/Vh2/Vh2/Vh2]
W86]W86]W86^WH:^WH:]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]
W86/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/
Vh2/Vh2/Vh2/Vh2/Vh2[Vgj[Vgj[Vgj[Vgj[Vgj[Vgj[Vgj[Vgj]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]
Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZZV7VZV7VZV7VZ
V7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZ
V7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZVWJZVWJZVWJYVGFYVGFYVGFYVGFYVGFWUGJWUGJWUGJX
UWNXUWNYUgRYUgRYUgRZUgBZUgBZUgBZUgB[V7F[V7F[V7F[V7FZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>Z
V7>UV7:WUg:WUg:YUg:YUg:ZUg:ZUg:/UW:XUW6XUW6XUW6XUW6XUW6XUW6XUW6XUW6YUg:YUg:YUg:Y
Ug:YUg:YUg:YUg:YUg:XUW6XUW6XUW6XUW6XUW6XUW6XUW6XUW6WUG2WUG2WUG2WUG2WUG2WUG2WUG2W
UG2VU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nWUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2VU6nVU6nVU6nV
U6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVUFjVUFjVUFjVUFjVUFjVUFjVUFjV
UFjXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnVTffVTffVTffVTffWU6jWU6jWU6jXUFnWU6jWU6jWU6jW
U6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWUFbWUFbWUFbWUFbWUFbWUFbWUFbW
UFbVTffVTffVTffVTffVTffVTffVTffVTffUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbSTFRTTVVTTVVU
TfZVU6^WUFbWUFbWUFbUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZTTVVUTfZUTfZUTfZVU6^VU6^VU6^V
U6^UTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJX
TfJXTfJXTfJXTfJXTfJWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFW
TVFXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBV
TFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBV
TFBTSf:UT6>UT6>VTFBVTFBUT6>UT6>TSf:UTF:UTF:UTF:VTV>VTV>WTfBWTfBWTfBUTF:VTV>VTV>W
TfBWTfBVTV>VTV>UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:U
TF:TT66TT66TT66UTF:UTF:VTV>VTV>VTV>SSf2TT66UTF:VTV>VTV>VTV>UTF:UTF:VTV>VTV>VTV>V
TV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>V
TV>VTFBVTFBWTVFWTVFWTVFXTfJXTfJXTfJYTVBYTVBYTVBYTVBYTVBYTVBYTVBYTVBVTV>VTV>VTV>V
TV>VTV>VTV>VTV>VTV>@R6>ITFbSVWRYX7jXWgjVW7jUVWjUVWjQWWnQWh6TXHFTXHbUXY>VXYNVXi^V
XYfLVXnLVXnMVi2MVi2MVi2MVi2MVi2MVi2ETh6HV8JEUXJTYIFFUHNSVhk1/ZVFPg]U;aQn<Qm=:A4m
9`i[9QMY:a]<:Q=`<1iL;aYE=AiWB3=iCCb<FTjGMFSDakNb/Z2c/JJc/JJc/JJc/JJd/ZNd/ZNd/ZNe
/jRc]JVc]JVc]JVc]JVc]JVb]:Rb]:Rb]:Rb/jVb/jVb/jVb/jVd]J^e]Zbg^:jh^Jni]jfi]jfj^:jj
^:jk^Jnk^Jnk^Jnk^Jnm_Jno_k>m_K6h^:bh]Z^m^k2n_;6k^Zbn^ZR`ZIFSUg^QSV^WTFR^UVb^UVb/
U6ZZTfFZTfFZTfFZTfFZTfFZTfFZTfFZTfFZTfFZTfF[U6J/UFN]UVR/UFN/UFN[U6JZTfF[U6J[U6J[
U6J/UFN/UFN/UFN/UFN[U6J[U6J[U6JZTfFZTfFZTfD00;:OR[:OR[:OR[:OR[:OR[:OR[:OR[:ORZnR
R:nRR:nQRZnQRZnQRjnQRjnPSJnPSJjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPR[2OQK2OQK2OQK2OQK2O
QK2OQK2OQK2OQJ^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQjVK
QJZLQZ^MQjbNR:bNR:^MQjZLQZVKQJVKQJVKQJ^MQj^MQjbNR:bNR:^MQj^MQjZLQZZLQZZLQZZLQZZL
QZZLQZZLQZZLQZVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJ^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQjZL
QZZLQZZLQZZLQZZLQZZLQZZLQZZLQZZMPjZMPjZMPjZMPjZMPjZMPjZMPjZMPjjMPZjMPZjMPZjMPZjM
PZjMPZjMPZjMPZbKPJbKPJfLPZfLPZjMPjjMPjnNQ:nNQ:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bK
P:bKP:bKP:bKP:bKP:bKP:bKP:bKP:^JOjbKP:bKP:bKP:fLPJfLPJfLPJjMPZbKP:bKP:bKP:bKP:bK
P:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^J
Oj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOjZJOJZJOJZJOJZJOJZJ
OJZJOJZJOJZJOJbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNj^I
NZ^INZ^INZ^INZ^INZ^INZ^INZ^INZZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZH
NJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJRH
M:RHM:RHM:VIMJVIMJVIMJVIMJVIMJNEMZNEMZNEMZRFMjRFMjRFMjVGN:VGN:ZGM:ZGM:ZGM:VFLjVF
LjVFLjVFLjVFLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjFHLZNGLZNGLZVGLZVGLZZGLZZGLZbFLZNE
L:NEL:NEL:NEL:NEL:NEL:NEL:NEL:VGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZNEL:NEL:NEL:NEL:NE
L:NEL:NEL:NEL:JDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZJD
KjJDKjJDKjJDKjJDKjJDKjJDKjJDKjFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFC
KZFCKZFCKZFCKZFDKJFDKJFDKJFDKJFDKJFDKJFDKJFDKJNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZFB
K:FBK:JCKJJCKJJCKJNDKZNDKZNDKZJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJC
KJJCKJJCKJJCKJJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJFB
K:FBK:FBK:FBK:FBK:FBK:FBK:FBK:>AJ:>AJ:BBJJFCJZJDJjJDJjNEK:RFKJFCJZFCJZFCJZFCJZFC
JZFCJZFCJZFCJZBBJJBBJJFCJZFCJZFCJZJDJjJDJjJDJjFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZRC
IZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZNBIJNBIJNBIJNBIJNB
IJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZJA
I:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JA
I:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:B?HZB?HZF@HjJAI:JAI:F@HjB?HZB?HZFA
HZFAHZFAHZJBHjJBHjJBHjNCI:NCI:FAHZFAHZJBHjNCI:NCI:JBHjFAHZFAHZFAHZFAHZFAHZFAHZFA
HZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZB@HJB@HJB@HJB@HJFAHZFAHZFAHZJBHj:>
Gj>?H:FAHZJBHjJBHjJBHjFAHZB@HJJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJB
HjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJAI:JAI:JAI:NBIJNBIJNBIJRCIZRCIZVB
I:VBI:VBI:VBI:VBI:VBI:VBI:VBI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI965FiV=Hj2DJZFGKJFE
Jj>CJJBDJZRFKJ2DK9jCKIbALIZAMYN@O9BAPY>AQY>ARIJDRINERYNERYRFRiVGS9ZHSIZHSI^ISY>A
Oi6AOiRIRIfNSYRGRJVQU<6bZKn/Y:^MTMVYWLRbVKF^UMV]X<V[X;6ZVM6YUlJZWlVaWlRjXkF`VkN^
Y;^]Yl>j/:^_W;:`YK:`YK>aY[>aY[>aY[BbYkBbYkBbYk:dZ;:dZ;>eZKBfZ[BfZ[BfZ[BfZ[BfZ[:c
ZK:cZK6bZ;6bZ;>dZ[Ff[;Nh[[Ri[kVg[KVg[KVg[KZh[[Zh[[^i[k^i[k^i[k^i[[nn/;jm[kVhZ[Ng
ZKZj[[bk/KZi[kZgZK^eX[:WS:BCLZ:=IjfDK:nGKJV@J:ZCIJZCIJZCIJZCIJZCIJZCIJZCIJZCIJVB
I:VBI:^DIZbEIjbEIjbEIjbEIjbEIjZCIJZCIJZCIJ^DIZ^DIZbEIjbEIjfFJ:RAHjRAHjRAHjRAHjVB
I:VBI000/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:[j:8[j:8[j6:[j6:[j6;[j6;[j2=[j2=[Z2:[Z2:
[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:/9n5/9n5/9n5/9n5/9n5/9n5/9n5/9n5Zif7Zif7Zif7Zif7Zif7Zif7
Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7ZI^5ZYb6Zif7[9j8[9j8Zif7ZYb6ZI^5ZI^5ZI^5
ZYb6Zif7[9j8[9j8Zif7Zif7ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4
Z9Z4Z9Z4Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZIb2ZIb2
ZIb2ZIb2ZIb2ZIb2ZIb2ZIb2[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[9^1[9^1[9^1[Ib2[Yf3[Yf3
[ij4[ij4[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0ZiYoZiYo
[9^0[9^0[9^0[Ib1[Ib1[Ib1[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0
[9^0[9^0ZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYo
ZiYoZiYoZiYoZiYoZiYoZiYoZYYmZYYmZYYmZYYmZYYmZYYmZYYmZYYm[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk
[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9YkZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZYQiZYQi
ZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQi
ZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiYiMcYiMcZ9QdZ9QdZIUeZYYfZYYfZYYfYYAeYiEf
YiEfYiEfZ9IgZ9IgZ9IgZIMhZYMdZYMdZIIcZIIcZ9EbYiAaYiAaYiAaZYQcZYQcZYQcZYQcZYQcZYQc
ZYQcZYQcY9MaYYIaYYIaZ9IaZ9IaZIIaZIIaZiEaYiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`ZIMbZIMb
ZIMbZIMbZIMbZIMbZIMbZIMbYiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`YYA_YYA_YYA_YYA_YYA_YYA_
YYA_YYA_YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YI=^YI=^
YI=^YI=^YI=^YI=^YI=^YI=^Y99]Y99]Y99]Y99]Y99]Y99]Y99]Y99]YIA]YIA]YIA]YIA]YIA]YIA]
YIA]YIA]YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YY=]YY=]YiA^YiA^YiA^YY=]YY=]
YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YYA[YYA[YYA[YYA[YYA[YYA[
YYA[YYA[YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/XY1WXi5X
Xi5XY99YYI=ZYYA[YiE/Z9I]YI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZY99YY99YY99YYI=ZYI=ZYI=Z
YYA[YYA[YI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=V
Z9=VZ9=VZ9=VZ9=VZ9=VZ9=VYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9U
Yi9UYi9UZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5T
YY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5T
YY5TYY5TXhiQY8mRYI1SYI1SYI1SYI1SY8mRXhiQY91QYI5RYI5RYI5RYY9SYY9SYY9SYi=TYI5RYI5R
YY9SYi=TYi=TYY9SYI5RYI5RY91QY91QY91QY91QY91QY91QY91QY91QY91QY91QY91QY91QY91QY91Q
Y91QY91QXhmPY91QY91QY91QYI5RYI5RYI5RYI5RXXiOXhmPYI5RYY9SYY9SYY9SYI5RY91QYY9SYY9S
YY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9S
YY9SYY9SYY5TYY5TYY5TYY5TYi9UYi9UZ9=VZ9=VZI9TZI9TZI9TZI9TZI9TZI9TZI9TZI9TZ9AUZ9AU
Z9AUZ9AUZ9AUZ9AUZ9AUZ9AUXi9OZIIS[9UVZiISYi5MYXiJZi1M[iAQZYEXYYA[Xi=^WI9dVY=jV9B2
UYF7UIJ<THn4THn4TY25U9:7UI>8UYB9UiF:UiF:XIn=TY:0UYN7UIJ6VYV;YinBYIJ=[IZBSj:O[iR@
Z:B<VjB:/ifBYj6JVjjO]j>B/j:O^j^N[ZfHV:fGZ[jb[JjZWYbB][fX/[2U/[2U/[2U/k6V/k6V];:W
];:W];:W/K>W/K>W/kFY];JZ]KN[]KN[]KN[]KN[/[>Y/[>Y/K:X/K:X/[>Y];F[]kR^^;V_^KN]^KN]
^KN]^[R^^[R^^[R^^kV_^kV_^kN/_Kb^_Kb^^KVY]kNY^[Z^_;^a^;V`]kFZa<2^`[JNZiUjX8YVZi9Z
/9M_ZY5YZY=UZY=UZY=UZY=UZY=UZY=UZY=UZY=UZ95SZI9TZY=U[9EW[9EW[9EW[9EW[9EWZI9TZI9T
ZY=UZiAVZiAV[9EW[9EW[IIXYXmQYXmQYXmQYi1RZ95SZ95S002aX8JaX8JaX8JaX8JaX8JaX8JaX8Ja
X8JbWhZbWhZbWhZbWhZbWhZbWhZbWhZbWhZ`WHRaWXVaWXVbWhZbWhZaWXVaWXV`WHR_W8N_W8N_W8N_
W8N_W8N_W8N_W8N_W8N^VhJ^VhJ^VhJ_W8N_W8N_W8N`WHR`WHRXVXBXVXBXVXBXVXBXVXBXVXBXVXBX
VXB]VXF]VXF]VXF]VXF^VhJ^VhJ^VhJ_W8NZW8JZW8JZW8JZW8JZW8JZW8JZW8JZW8JZW8JZW8JZW8JZ
W8JZW8JZW8JZW8JZW8JXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXB^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^
VhJ^WH>^WH>^WH>^WH>^WH>^WH>^WH>^WH>/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh2/Vh2/Vh2/
Vh2/Vh2/Vh2/Vh2/Vh2[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[
VWnZVGjZVGj[VWn[VWn/Vh2/Vh2/Vh2/Vh2ZVGj[VWn/Vh2/Vh2/Vh2/Vh2[VWnZVGjZVWfZVWf[Vgj[
Vgj/W7n/W7n/W7n/W7nYV7fZVGj[VWn[VWn[VWn[VWnZVGjYV7fZVWfZVWfZVWfZVWfZVWfZVWfZVWfZ
VWf/VWf/VWf/VWf/VWf/VWf/VWf/VWf/VWf]VWn]VWn/VGj[V7f[V7f/VGj]VWn]VWn[VGb[VGb[VGb[
VGb[VGb[VGb[VGb[VGb[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[
VGZZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7V/VW^[VGZ[VGZZV7VZV7VYUgRYUgRXUWNYUW>ZUgB/VGJ^
VgR^VgR]VWN/VGJ[V7F[VgJZVWFXV7>WUg>WUWFXUgJZV7V[VGZZV7VYUgRXUWNYUgR[VGZ[VGZYUgRV
U7FXV7BXV7BXV7BXV7BXV7BXV7BXV7BXV7BYUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>UUWFWUg>WUg>Y
Ug:YUg:ZUg6ZUg6/V6nYUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:WUG2WUG2WUG2WUG2WUG2WUG2WUG2W
UG2WUVnWUVnWUVnWUVnWUVnWUVnWUVnWUVnVU6nWUG2WUG2WUG2XUW6XUW6XUW6YUg:VU6nVU6nVU6nV
U6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVTffVTffVTffVTffVTffVTffVTffV
TffVUFjVUFjVUFjUU6fUU6fUU6fUU6fUU6fVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffV
TffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVU6^VU6^VU6^VU6^VU6^VU6^VU6^V
U6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^UTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZU
TfZUTfZUTfZUTfZUTfZUTfZUTfZVU6^VU6^VU6^UTfZTTVVSTFRUTfZUTfZUTfZUTfZUTfZUTfZUTfZU
TfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZRT6NSTFRSTFRTTVVTTVVUTfZUTfZVU6^UTfZUTfZUTfZU
TfZUTfZUTfZUTfZUTfZSTFRSTFRSTFRTTVVTTVVUTfZUTfZUTfZXTfJXTfJXTfJXTfJXTfJXTfJXTfJX
TfJXTVVWTFRVT6NVT6NVT6NVT6NWTFRXTVVYU6NXTfJXTfJWTVFWTVFVTFBUT6>UT6>VTFBVTFBWTVFX
TfJXTfJWTVFVTFBVTFBVTFBVTFBVTFBWTVFWTVFWTVFXTfJXTfJVTV>VTV>VTV>VTV>VTV>VTV>VTV>V
TV>UTF:UTF:UTF:UTF:TT66TT66TT66TT66UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:VTV>VTV>VTV>V
TV>VTV>VTV>VTV>VTV>SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2S
Sf2USenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenTSUjTSUjTSUjT
SUjTSUjTSUjTSUjTSUjUSenUSenUSenUSenUSenUSenUSenUSenRS5bSSEfTSUjUSenVT62VT62USenU
SenXTV:WTF6USenTSUjTSUjTSUjVT62WTF6WTUnWTUnWTUnWTUnWTUnWTUnWTUnWTUnWT6:WT6:WT6:X
TF>XTF>XTF>YTVBYTVBYTf>YTf>YTf>XTF>WT6>WT6>VSVBVSVBUSV2VSf6WT6:WT6:WT6:WT6:VSf6U
SV2WTF6WTF6WTF6WTF6WTF6WTF6WTF6WTF6UT5fWTUnYU66XTf2WTUnWTUnXTf2ZUF:VTEfVTEfVTEjV
TEjWTF6WT6:WT6:XTF>ST6>RTV>RU6BOUFJLU6bLTg6HTGJITGZ?TXV?THF>TH6=TWf>TWnAU8FFU8bH
U9>>VHV@VXVDVXNGWHJKWXFQWhNWXHZ[XXjWYiNUYIFSXi>SXi>TY9BXZ9R/[9b_[inZ[If[[Yj/[in]
/:6^/:B^/:B^[jF^[jF_/:N_/:N_/:N_/:N_/:N`/JR`/JR`/JRc/jfd]:jd]:jd]:jd]:jd]:jd]:jd
]:jg/jjf/Zfe/jVc/JJb/:Fc/JJf]:Zg]J^b^:Ne^:Ve]j^f]:bi/jjm];31^;C6_;Fh^Zjh^Zjh^j^h
^j^h^jbh^K2g][:g]KFj_k2i^ZZn^jJaZHbGSFFSUV:cYFZTV5J[TfV[U6N[U6NZTfFZTfFYTf>YTf>Y
U66XTV:XTV:YTf>ZU6BZU6BYTf>XTV:XTV:YTf>YTf>YTf>YTf>YTf>YTf>YTf>YTf>YU66ZU6BZU6B[
U6J/UFN/UFP00;6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[:OR[:OR[:OR[:OR[:OR[:OR[:OR[:OR[2M
R;2MR;6NRK:OR[:OR[6NRK2MR;2MR:nLQjnLQjnLQjnLQjnLQjnLQjnLQjnLQjfJQJjKQZjKQZjKQZnL
QjnLQjnLQk2MR:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:bIQ:fJQJfJQJfJQJjKQZjKQZjKQZjKQZVK
QJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJRJQ:RJQ:RJQ:RJQ:RJ
Q:RJQ:RJQ:RJQ:fJQJfJQJfJQJfJQJfJQJfJQJfJQJfJQJfLPZfLPZfLPZfLPZfLPZfLPZfLPZfLPZbK
PJbKPJbKPJbKPJbKPJbKPJbKPJbKPJbKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:^JOj^JOj^JOj^JOj^J
Oj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOjZIOZZIOZ^JOj^JOj^JOjbKP:bKP:bKP:ZI
OZ^JOjbKP:bKP:bKP:bKP:^JOjZIOZZJOJZJOJ^KOZ^KOZ^KOZbLOjbLOjbLOjVHOJZIOZZIOZ^JOj^J
OjZIOZZIOZVHOJZJOJZJOJZJOJZJOJZJOJZJOJZJOJZJOJbJOJbJOJbJOJbJOJbJOJbJOJbJOJbJOJfJ
OjbIOZbIOZ^HOJ^HOJbIOZbIOZfJOj^IO:^IO:^IO:^IO:^IO:^IO:^IO:^IO:^INZ^INZ^INZ^INZ^I
NZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZH
NJZHNJZHNJZHNJZHNJVGN:VGN:VGN:VFLjZGM:bIMZfJMjjKN:fJMjbIMZ^HMJZJMJVIM:RHLjNGLjNF
MJRGMZVGN:ZHNJRFMjNEMZNEMZRFMjZHNJZHNJRFMjNEMZRHM:RHM:RHM:RHM:RHM:RHM:RHM:RHM:RE
LZRELZRELZRELZRELZRELZRELZRELZBEM:JFLZJFLZRFLJRFLJVFL:VFL:^GKZRFLJRFLJRFLJRFLJRF
LJRFLJRFLJRFLJNEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:NFKjNFKjNFKjNFKjNFKjNFKjNFKjNFKjJD
KjJDKjNEL:NEL:NEL:RFLJRFLJRFLJJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJD
KjJDKjJDKjJDKjJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJFDKJFDKJFDKJFDKJFDKJFDKJFDKJFDKJJC
KJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJC
KJJCKJJCKJJCKJJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjFC
JZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZBBJJFCJZJDJjJDJjJD
JjFCJZBBJJBBJJFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZ>A
J:>AJ:>AJ:BBJJBBJJBBJJBBJJBBJJFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZ>AJ:>AJ:>AJ:BBJJBB
JJBBJJFCJZFCJZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRBJJNAJ:J@IjJ@IjJ@IjJ@IjNAJ:RBJJRC
IZRCIZNBIJNBIJJAI:JAI:F@HjF@HjJAI:JAI:NBIJRCIZRCIZNBIJJAI:JAI:JAI:JAI:JAI:JAI:NB
IJNBIJRCIZRCIZJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjFAHZFAHZFAHZB@HJB@HJB@HJB@HJB@HJB@
HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZ>?H:>?H:>?H:>?H:>?
H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:F?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?
GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZF?GjF?GjF?GjF?GjF?
GjF?GjF?GjF?Gj>=GJ>=GJB>GZF?GjF?GjF?GjB>GZB>GZJ@H:J@H:B>GZB>GZB>GZF?GjJ@H:NAHJNB
GjNBGjNBGjNBGjJAGZJAGZJAGZJAGZF>H:F>H:J?HJJ?HJJ?HJN@HZN@HZN@HZRCH:RBHZRBHZRAHjN@
HjN@HjN?IJN?IJJ?HJN@HZN@HZRAHjRAHjN@HZN@HZJ?HJJ@H:J@H:J@H:J@H:J@H:J@H:J@H:J@H:B?
G:JAGZNBGjNBGjF@GJF@GJNBGjRCH:F@G:JAGJJAGZJAGZNAHJN@HZN@HZN@HZF@HjBBHj:BHj:CIInC
JIbBL9bAMIb@N96CP96CP92API2@PY:BQYBDR9JERiRGSI^OU9ZLT9JIRYNFR9VFQifGRZ2HRj6IS9nO
SijNSYfMSIfMSInOSj6QTJBTU:JVUZJYVJNZVZR[W:Z]WZ^]XJ^/XZ^/XZ^/X[2bY[2bY[2bY[2bY[2b
Y[6cYk6cYk6cYk:cZ[:cZ[:cZ[:cZ[:cZ[>dZk>dZk>dZkbi/KZh[[RfZkRfZkVhZ[Zh[K^i[[Zh[KZo
/;Zm[[Rj[[Zi[k^i[kfh[kff[K^eZ[Vk[kVl[KRkZkNkZ;NjZ[Nh[[Rh/[Rf]KJg[KFeZKfhZKfbWZZL
Oj:AJZBCHZFCGZ^CJJ^DIjZCIZZCIJZCIJVCHjVCHjVDHJVCHjVCHjVCHjZDI:ZDI:VCHjVCHjVCHjVC
HjVCHjVCHjVCHjVCHjVCHjVCHjVCHjVDHJVCHjZDI:ZCIJZCIJZCIP00/9n5/9n5/9n5/9n5/9n5/9n5
/9n5/9n5/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:[ib7/9f8/Ij9/Ij9/Ij9/Ij9/9f8[ib7[Y^6[Y^6
[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[IZ5[IZ5[Y^6[Y^6[Y^6[ib7[ib7[ib7Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4
Z9Z4Z9Z4[9V4[9V4[9V4[IZ5[IZ5[Y^6[Y^6[Y^6ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5
ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5
[IZ5[IZ5ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9^0[9^0
[9^0[9^0[9^0[9^0[9^0[9^0ZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYo
ZiYoZiYoZYUnZYUnZYUnZiYoZiYoZiYo[9^0[9^0ZYUnZYUnZiYo[9^0[9^0ZiYoZYUnZYUnZYYmZYYm
ZYYmZi]nZi]nZi]n[9ao[9aoZIQmZIQmZYUnZiYoZiYoZYUnZIQmZIQmZYYmZYYmZYYmZYYmZYYmZYYm
ZYYmZYYm[9Ym[9Ym[9Ym[9Ym[9Ym[9Ym[9Ym[9Ym[IYo[9UnZiQmZiQmZiQmZiQm[9Un[IYoZiUlZiUl
ZiUlZiUlZiUlZiUlZiUlZiUlZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUj
ZiUjZiUjZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZYQiZYQiZYQiZYQiZIIcZYMd
ZiQe[9Uf[IYg[9Uf[9UfZiQeZIUdZIUdZ9QcYiMcYiIeZ9MfZIMhZIMhYYAeYI=dY99cYI=dZ9IgZIMh
Z9IgYiEfYiMcYiMcYiMcYiMcYiMcYiMcYiMcYiMcZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbY9EdYYIb
YYIbZ9IaZ9IaZII`ZII`ZiM^Z9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaYiE`YiE`YiE`YiE`YiE`YiE`
YiE`YiE`YiI_YiI_YiI_YiI_YiI_YiI_YiI_YiI_YYA_YYA_YYA_YiE`YiE`Z9IaZ9IaZ9IaYYA_YYA_
YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YY=]YY=]YY=]YY=]YY=]YY=]
YY=]YY=]YIA]YIA]YIA]YIA]YIA]YIA]YIA]YIA]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]
YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YYA[YYA[YYA[YYA[YYA[YYA[
YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=Z
YI=ZYI=ZYI=ZYI=ZYI=ZYI=ZXi5XY99YYI=ZYYA[YYA[YI=ZY99YY99YYI=ZYI=ZYI=ZYI=ZYI=ZYI=Z
YI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZY99YY99YY99YY99YXi5XXi5XXi5XXi5XYI=ZYI=Z
YI=ZYI=ZYI=ZYI=ZYI=ZYI=ZXY1WXi5XXi5XXi5XY99YY99YY99YY99YYi9UYi9UYi9UYi9UYi9UYi9U
Yi9UYi9UYi5WYi5WYY1VYHmUYHmUYY1VYi5WYi5WYi9UYi9UYi9UYi9UYY5TYY5TYY5TYI1SYI1SYY5T
Yi9UYi9UYi9UYi9UYY5TYI1SYI1SYI1SYY5TYY5TYi9UYi9UYi9UYi9UYI5RYI5RYI5RYI5RYI5RYI5R
YI5RYI5RY91QY91QY91QY91QY91QY91QY91QY91QY91QY91QY91QY91QY91QY91QY91QY91QYI5RYI5R
YI5RYI5RYI5RYI5RYI5RYI5RXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmP
XhmPXhmPYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOY8iNY8iN
Y8iNY8iNY8iNY8iNY8iNY8iNYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOXheMY8iNYHmOYHmOYHmOY8iN
XheMXXaLY8iNY8iNY8iNY8iNY8iNYHmOYi5QZ99RZ9=PYi9OYi9OYY5NYY5NYI1MYI1MY8mLY8eOY8eO
Y8eOY8eOYHiPYHiPYXmQYXmQYY5NYY5NYY1PYi5QYi1RYi1SYi1SYi1SYi1RYi1RZ95SZI9TZI9TZ95S
Yi1RYi1RYY1PYY1PYY1PYY1PYY1PYY1PYY1PYY1PXXeJY8mLYY5NYI1MY8mLY8mLYI1MYi9OYI1LYI1L
YI1MYY5NYY1PYi1RYi1RYi1RZ91RYi1RYY9RYI=TXi9WXI5/X91cX8meU9EcU9=iTi21UHn8UI6<UI>;
UiN9UYZ7YZ:GX9bAVYF<Ui:9VI><W9J?W9J?WIF>XJ2BXJ2BXJ2BXZ6CXj:DY:>EYJBFYZFGZjjN[:nP
[K2Q[k6U/;:V/K:X/K:Y/K:Y[[6R[[6R[[6R[k:S[k:S/;>T/;>T/;>T/[BX/[BX/kFY/kFY/kFY];JZ
];JZ];JZ]KFW/[:T/;2R/K6U];BX]KFY/k>U/;2R/K:X/;6W/;:V]KFW^kZ/^k^[^[NX][>T^kfa^[f^
^KfZ^;bY^;bY^Kb]^[^b^k^e_Kbb_kfc`kbca[Z^_JjKYY5fW8IR[IE[ZY9XZY=VZY=VZY=UZI9TZI=S
ZI=SZ9=PZI=SZYATZYATZYATZYATZYATZYATZI=SZ99RZ99RZ99RZ99RZ99RZ99RZ99RZ99RYi9OYi5Q
Z99RZI9TZY=UZiAW002`WhF`WhF`WhF`WhF`WhF`WhF`WhF`WhFaWXVaWXVaWXVaWXVaWXVaWXVaWXVa
WXV_W8N`WHR`WHRaWXVaWXV`WHR`WHR_W8N^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ]VXF]VXF]VXF^
VhJ^VhJ^VhJ_W8N_W8NXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXB/VHB/VHB/VHB/VHB]VXF]VXF^VhJ^
VhJYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFXVXBXVXBXVXBX
VXBXVXBXVXBXVXBXVXB]VXF]VXF]VXF]VXF]VXF]VXF]VXF]VXFZVGnZVGnZVGnZVGnZVGnZVGnZVGnZ
VGn/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2ZVGjZVGjZVGjZ
VGjZVGjZVGjZVGjZVGjZVGjZVGjZVGjZVGjZVGjZVGjZVGjZVGjYV7fYV7fZVGjZVGj[VWn[VWn[VWn[
VWnYV7fZVGj[VWn[VWn[VWn[VWnZVGjYV7fYVGbYVGbZVWfZVWf[Vgj[Vgj[Vgj[VgjXUgbYV7fZVGjZ
VGjZVGjZVGjYV7fXUgbYVGbYVGbYVGbYVGbYVGbYVGbYVGbYVGb[VGb[VGb[VGb[VGb[VGb[VGb[VGb[
VGb/VGj/VGj[V7fZUgbZUgb[V7f/VGj/VGjZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7VZV7VZV7VZ
V7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VYUgRYUgRYUgRYUgRYUgRYUgRYUgRY
UgRWUGJXUWNXUWNYUgRYUgRZV7VZV7V[VGZZUgBZUgB[V7F[V7F/VGJ/VGJ/VGJ/VGJXV7>XV7>XV7>X
V7BXUgJXUgJXUWNXUWNUTgBSTG:RT76STG:VU7FXUWNXUWNWUGJWUg>WUg>WUg>WUg>WUg>WUg>WUg>W
Ug>XUG:XUG:XUG:XUG:XUG:XUG:XUG:XUG:TUGBVUW:VUW:XUW6XUW6YUW2YUW2[UfjXUW6XUW6XUW6X
UW6XUW6XUW6XUW6XUW6WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUVnWUVnWUVnWUVnWUVnWUVnWUVnW
UVnUTfjVU6nVU6nVU6nWUG2WUG2WUG2XUW6UTfjUTfjUTfjUTfjUTfjUTfjUTfjUTfjUTfjUTfjUTfjU
TfjUTfjUTfjUTfjUTfjUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbTTfbTTfbTTfbTTfbTTfbUU6fUU6fU
U6fUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbU
TVbUTVbUTVbUTVbUTVbUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZU
TfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVRT6NSTFRTTVVU
TfZUTfZUTfZTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVT
TVVUTfZTTVVTTVVSTFRSTFRRT6NRT6NQSfJTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVRT6NRT6NRT6NS
TFRSTFRTTVVTTVVTTVVWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTFNVT6JUSfFUSfFUSfFUSfFVT6JW
TFNVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBUT6>UT6>VTFBWTVFWTVFVTFBUT6>UT6>UT6>UT6>UT6>V
TFBVTFBVTFBWTVFWTVFUTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:SSf2SSf2SSf2SSf2TT66TT66TT66T
T66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66SSf2SSf2SSf2S
Sf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2USenUSenUSenUSenUSenUSenUSenU
SenUSenUSenUSenUSenUSenUSenUSenUSenSSEfSSEfSSEfSSEfSSEfSSEfSSEfSSEfUSenUSenUSenU
SenUSenUSenUSenUSenTSUjTSUjUSenUSenTSUjSSEfRS5bQRe^RS5bRS5bSSEfTSUjUSenVT62WTF6X
TV:XTf2WTUnWTUnVTEjUT5fUT5fTSebTSebTSUjTSUjTSUjUSenUSenUSenVT62VT62TSe^TSebUT5fV
T62VT62WT6:WT6>WT6>WTF6XTV:XTV:YTf>YTf>XTV:XTV:WTF6VT62VT62VT62VT62VT62VT62VT62V
T62RSEZTSebVTEjVTEjTSebTSebUT5fWTUnUT5bUT5bUT5fUT5fVT62VSf6WT6:WT6:XT6:XTF6WTF6X
TV:VTV>UTFRSSfbSSVnHUVJITg2JT7jIShRGShnGU8bGV8REVh:VXHbRW8VKUXNLUX^NVI2OWI>NW96K
VHjIV8ZJVH^LVhfNWHnOWY2NWHnNWHnMW8jSYYNTYiRVZ9bXZYjZZj6[[:>/[JB/[JB^/J6_/Z:_/Z:`
/j>a]:Ba]:Bb]JFb]JFc]JVc]JVc]JVd]ZZe]j^e]j^f^:bf^:bk_JZg^:Re]JNf]J^j^Jnl^k6i^Jfe
]JNd]:jf]jjh^Zjj_Jfn`:fo`Jk0`K70`;:h^Jng^Jfe^:Rd^:Fe^JJf^JZh^Jnj^k:d]Z>o_k6j^:fj
]:W1]:B^WH>RS6VcVg6ZTVRZTfJZTfJYTVBYTVBXTV:XTV:XTf2ZU6BZU6BYTf>YTf>YTf>YTf>ZU6BZ
U6BXTV:XTV:XTV:XTV:XTV:XTV:XTV:XTV:UT5fUSenWTF6YTVB/UFN^UfX00;2OQK2OQK2OQK2OQK2O
QK2OQK2OQK2OQK6NRK6NRK6NRK6NRK6NRK6NRK6NRK6NRJnLQjnLQk2MR;2MR;2MR;2MR:nLQjnLQjfJ
QJfJQJfJQJfJQJfJQJfJQJfJQJfJQJbIQ:bIQ:fJQJfJQJfJQJjKQZjKQZjKQZRJQ:RJQ:RJQ:RJQ:RJ
Q:RJQ:RJQ:RJQ:^HPj^HPjbIQ:bIQ:bIQ:fJQJfJQJfJQJRJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJ
Q:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:bIQ:bIQ:bIQ:bIQ:bI
Q:bIQ:bIQ:bIQ:ZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOj^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:^J
Oj^JOj^JOj^JOj^JOj^JOj^JOj^JOjZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZZI
OZZIOZZIOZZIOZVHOJVHOJVHOJZIOZZIOZZIOZ^JOj^JOjVHOJVHOJZIOZ^JOj^JOjZIOZVHOJVHOJVI
O:VIO:VIO:ZJOJZJOJZJOJ^KOZ^KOZRGO:RGO:VHOJZIOZZIOZVHOJRGO:RGO:VIO:VIO:VIO:VIO:VI
O:VIO:VIO:VIO:^IO:^IO:^IO:^IO:^IO:^IO:^IO:^IO:bIOZ^HOJZGO:ZGO:ZGO:ZGO:^HOJbIOZZH
NjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZH
NJZHNJZHNJZHNJVGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:NEMZNEMZRFMjRFMjVGN:VGN:ZHNJZHNJZG
M:ZGM:ZGM:ZGM:ZGM:^HMJbIMZbIMZNGLZNGLZRHLjRHM:RGMZRGMZNEMZNEMZFCM:>ALZ6?L::@LJFC
M:NEMZRFMjRFMjJFLZJFLZJFLZJFLZJFLZJFLZJFLZJFLZNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJ>D
LjFELJFELJNEL:NEL:REKjREKjZFKJNEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:JDKjJDKjJDKjJDKjJD
KjJDKjJDKjJDKjJEKZJEKZJEKZJEKZJEKZJEKZJEKZJEKZFCKZFCKZFCKZJDKjJDKjNEL:NEL:NEL:FC
KZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFBK:FBK:FBK:FBK:FB
K:FBK:FBK:FBK::AJZ>BJj>BJj>BJjBCK:FDKJFDKJFDKJFBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FB
K:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FCJZFCJZFCJZFCJZFC
JZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZBB
JJBBJJBBJJBBJJBBJJBBJJBBJJBBJJ6?IZ:@Ij>AJ:BBJJFCJZFCJZBBJJBBJJBBJJBBJJBBJJBBJJBB
JJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJ>AJ:>AJ::@Ij:@Ij6?IZ6?IZBB
JJBBJJBBJJBBJJBBJJBBJJBBJJBBJJ6?IZ:@Ij:@Ij:@Ij>AJ:>AJ:>AJ:BBJJNBIJNBIJNBIJNBIJNB
IJNBIJNBIJNBIJJAI:JAI:F@HjB?HZB?HZF@HjJAI:JAI:F@HjF@HjF@HjF@HjF@HjJAI:JAI:JAI:B?
HZF@HjJAI:JAI:JAI:JAI:F@HjB?HZB?HZB?HZF@HjF@HjJAI:JAI:JAI:JAI:B@HJB@HJB@HJB@HJB@
HJB@HJB@HJB@HJ:>Gj:>Gj:>Gj>?H:>?H:B@HJB@HJFAHZ>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?
H:>?H:>?H:>?H:>?H:>?H:>?H:>?H::>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>
Gj:>Gj:>Gj:>GjB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZ>=
GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZ>=GJB>GZB>GZB>GZB>
GZ:<G:6;Fj2:FZ6;Fj:<G:>=GJB>GZF?GjJ@H:J@H:J@H:JAGZJAGZJAGZF@GJF@GJB?G:B?G:B?G:F@
GJF@GJF@GJJAGZJAGZJAGZNBGjNBGj>>FZB?FjB?FjF@GJF?GjJ@H:J?HJN@HZNBGjNBGjRCH:VDHJVD
HJRCH:NBGjNBGjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjB?G:F@GJNBGjNBGjF@GJF@GJJAGZRCH:B?
FjB?FjF@GJF@GJF?GjJ?HJJ?HJJ?HJN?HJRAHJRAGjNBGjNAHJJAI:J?JJJ=JijCGijBJ9b?MIf@PYZ@
RIRCRYJGQiFKQ9bNPIZJPYZHQY^JS9jLTIjOSiVNRIJLPi^ISYbJSinMTZ:PUJ>QUZ:PUJ6OU:2NTj:T
V:BVVZJXW:VZX:^/Xjf^YJj^Z:j^Z:jaXZjaXZnbXk2cY;6dYK:eY[:eY[>fYk2bY[2bY[6cYk:dZ;>e
ZKBfZ[BfZ[FgZkFkY;:fXjn`Y[2`Z[>b[[Bd[[>dZ[2bY[>a/;Jf/;Rj[[JiZK:fXk6dYK>g[;Ni/kVh
];Ri/;Ni[KNjZ[NjZ[Vl[KZk/K^l/jVaV[g3/;Nk[k6cYl>o[L2eVZ^LMJZFIjZBJ:VBIJVBIJVBI:RA
HjRBHZRBHZNBGjZDI:VCHjRBHZNAHJNAHJRBHZVCHjZDI:NAHJNAHJNAHJNAHJNAHJNAHJNAHJNAHJJA
GZJ@H:J@H:N@HZRAHjRAI000[ij4[ij4[ij4[ij4[ij4[ij4[ij4[ij4/9f8/9f8/9f8/9f8/9f8/9f8
/9f8/9f8[Y^6[ib7[ib7/9f8/9f8[ib7[ib7[Y^6[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[9V4[9V4
[9V4[IZ5[IZ5[IZ5[Y^6[Y^6Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4ZiR3ZiR3ZiR3ZiR3[9V4[9V4
[IZ5[IZ5Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4
Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4[9V4[9V4[9V4[9V4[9V4[9V4[9V4[9V4ZYUoZYUoZYUoZYUoZYUoZYUo
ZYUoZYUoZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZIQmZIQm
ZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZ9MlZIQmZIQmZIQmZYUnZYUn
ZYUnZYUnZ9MlZIQmZYUnZYUnZYUnZYUnZIQmZ9MlZ9QkZIUlZIUlZIUlZYYmZYYmZYYmZYYmYiIkZ9Ml
ZIQmZIQmZIQmZIQmZ9MlYiIkZ9QkZ9QkZ9QkZ9QkZ9QkZ9QkZ9QkZ9QkZYQkZYQkZYQkZYQkZYQkZYQk
ZYQkZYQkZiQmZiQmZYMlZIIkZIIkZYMlZiQmZiQmZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMhZIMh
ZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZ9IgZ9IgZ9IgZ9IgZ9IgZ9Ig
Z9IgZ9IgYiEfZ9IgZ9IgZ9IgZ9IgZ9IgZIMhZIMhZYMdZYMdZIIcZIIcZIIcZYMdZiQe[9UfYYIaYiMb
YiMbZ9QdZ9MfYiIeYiEfYYAeYiEfY99cXY1aXY1aYI=dYiEfZ9IgZ9IgYYIbYYIbYYIbYYIbYYIbYYIb
YYIbYYIbYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaXiAcYIEaYIEaYiE`YiE`Z9E_Z9E_ZYI]YiE`YiE`
YiE`YiE`YiE`YiE`YiE`YiE`YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYE^YYE^YYE^YYE^YYE^YYE^
YYE^YYE^YI=^YI=^YI=^YI=^YYA_YYA_YYA_YiE`Y99]Y99]Y99]Y99]Y99]Y99]Y99]Y99]Y99]Y99]
Y99]Y99]Y99]Y99]Y99]Y99]Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[XI1YXY5ZXY5ZXi9[Y9=/Y9=/
YIA]YIA]Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[
Y95[Y95[Y95[Y95[Y95[Y95[Y99YY99YY99YY99YY99YY99YY99YY99YY99YY99YY99YY99YY99YY99Y
Y99YY99YYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XX8iUXHmV
XY1WY99YYI=ZYI=ZY99YY99YXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5X
Xi5XXi5XXi5XXi5XXY1WXY1WXY1WXY1WXY1WXHmVXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXHmVXHmV
XHmVXY1WXY1WXi5XXi5XXi5XYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY9SYI5RYI5RY91QY91QYI5R
YI5RYY9SY8mRY8mRY8mRYI1SYI1SYI1SYY5TYY5TY8mRYI1SYI1SYY5TYY5TYI1SYI1SY8mRY8mRY8mR
Y8mRYI1SYI1SYY5TYY5TYY5TY91QY91QY91QY91QY91QY91QY91QY91QXHeNXHeNXXiOXXiOXhmPY91Q
Y91QYI5RXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiO
XXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOY8iNY8iNY8iNY8iNY8iNY8iN
Y8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNXXaLXXaLXXaLXXaLXXaLXXaLXXaLXXaLY8iNY8iN
Y8iNY8iNY8iNY8iNY8iNY8iNXXaLXheMXheMY8iNXheMXXaLXH]KXH]KXH]KXXaLXheMY8iNYHmOYHmO
YHmOY8iNY8mLY8mLYI1MYI1MYI1MYI1MYI1MYI1MYI1MYI1MYI1MYY5NYY5NYi9OYi9OYi9OXhmHXhmH
Y8mKY8mKY8mLY8iNYHmOYHiPYI1MYY5NYi9OYi9OYi9OYi9OYY5NYI1MYHmOYHmOYHmOYHmOYHmOYHmO
YHmOYHmOY8mLYI1MYi9OYi9OYI1MYI1MYi9OZ9=PY8mKY8mKY8mLY8mLYHmOYHiPYXmQYXmQY91QY91P
Y99MY99MY99MY91PY8iTY8iUXhmPX8mTWhmZW91dVY5mUY>4UYJ:UIJ<TYR5TiR9UIR?UYNCUYRBUIV=
UY^6UIb1VIN=ViV?WI^AX9jDXZ2FXZ2FXZ2FXZ2FX::FXZBHYJJLZ:VPZjbS[JfW[ZjX[ZfYZjbR[:fS
[JjT[ZnU[k2V/;6W/K:X/[>Y/kB[/kB[];F/]KJ]][N^^;V`^;V`^KZa][fX]KZ[];J`/[6c/[6e/k:d
]KJb]kZa]k:c^kRc_Knc_/6b_<6b^kni_/31`/;8b<G7bLO7bLW3b/_1blc2c<g3c<c6c<_7bM76c]SB
a]7?`l_;e=K@e]:o^Jn=WHeRZI5WZI9UZI9UZ95SZ95SYi5QYi5QYi9OZI=SZ99RYY1PYHmOYHmOYY1P
Z99RZI=SYi5QYi5QYi5QYi5QYi5QYi5QYi5QYi5QZIAQZ99RYY1PY8eOXX]MX8UL002_WXB_WXB_WXB_
WXB_WXB_WXB_WXB_WXB`WHR`WHR`WHR`WHR`WHR`WHR`WHR`WHR^VhJ^VhJ_W8N`WHR`WHR_W8N^VhJ^
VhJ/VHB/VHB/VHB/VHB/VHB/VHB/VHB/VHB[V8>/VHB/VHB/VHB]VXF]VXF]VXF^VhJXVXBXVXBXVXBX
VXBXVXBXVXBXVXBXVXBZUh:ZUh:[V8>[V8>/VHB/VHB/VHB/VHBWVH>WVH>WVH>WVH>WVH>WVH>WVH>W
VH>WVH>WVH>WVH>WVH>WVH>WVH>WVH>WVH>XVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXB[V8>[V8>[V8>[
V8>[V8>[V8>[V8>[V8>[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2ZVGnZVGnZVGnZVGnZVGnZVGnZVGnZ
VGnZVGjZVGjZVGjZVGjZVGjZVGjZVGjZVGjYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fY
V7fYV7fYV7fYV7fYV7fXUgbXUgbYV7fYV7fYV7fZVGjZVGjZVGjXUgbYV7fYV7fZVGjZVGjYV7fYV7fX
UgbXV7^XV7^YVGbYVGbYVGbZVWfZVWfZVWfWUW^XUgbXUgbYV7fYV7fXUgbXUgbWUW^XV7^XV7^XV7^X
V7^XV7^XV7^XV7^XV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^[V7fZUgbZUgbYUW^YUW^ZUgbZUgb[
V7fYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRY
UgRYUgRYUgRYUgRYUgRXUWNXUWNXUWNXUWNXUWNXUWNXUWNXUWNXUWNXUWNXUWNXUWNXUWNWUGJWUGJW
UGJZUgBYUW>XUG:XUG:XUG:ZUgB[V7F/VGJUUG2VUW6WUg:XV7BXUgJWUWFVU7FUTgBYUgRVU7FSTG:S
TG:TTW>WUGJXUWNXUWNUUG6UUG6UUG6UUG6UUG6UUG6UUG6UUG6VTg2VTg2VTg2VTg2VTg2VTg2VTg2V
Tg2RTg:TU72TU72VU6nVU6nWU6jWU6jYUFbVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nUTfjUTfjUTfjU
TfjUTfjUTfjUTfjUTfjUU6fUU6fUU6fUU6fUU6fUU6fUU6fUU6fTTVfTTVfUTfjUTfjUTfjVU6nVU6nV
U6nTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTF^TTF^TTF^T
TF^TTF^TTF^TTF^TTF^PSfRQT6VRTFZRTFZSTV^TTfbUU6fUU6fTTF^TTF^TTF^TTF^TTF^TTF^TTF^T
TF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTVVTTVVTTVVT
TVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVUTfZUTfZUTfZUTfZUTfZUTfZUTfZU
TfZSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFROSFBPSVFRT6NSTFRTTVVUTfZUTfZTTVVSTFRSTFRSTFRS
TFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRQSfJQSfJQSfJRT6NRT6NRT6NRT6NR
T6NSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRQSfJQSfJQSfJRT6NRT6NRT6NSTFRSTFRVTFBVTFBVTFBV
TFBVTFBVTFBVTFBVTFBVTV>UTF:TT66TT66TT66TT66UTF:VTV>SSV6SSV6TSf:TSf:UT6>UT6>VTFBV
TFBTSf:TSf:UT6>VTFBVTFBUT6>TSf:TSf:TSf:TSf:TSf:TSf:UT6>UT6>UT6>VTFBSSf2SSf2SSf2S
Sf2SSf2SSf2SSf2SSf2PS5fPS5fQSEjRSUnSSf2TT66TT66UTF:RSUnRSUnRSUnRSUnRSUnRSUnRSUnR
SUnQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjQ
SEjQSEjQSEjQSEjQSEjSSEfSSEfSSEfSSEfSSEfSSEfSSEfSSEfSSEfSSEfSSEfSSEfSSEfSSEfSSEfS
SEfRS5bRS5bRS5bRS5bRS5bRS5bRS5bRS5bSSEfSSEfSSEfSSEfSSEfSSEfSSEfSSEfPRUZQRe^RS5bS
SEfSSEfSSEfRS5bRS5bQRe^RS5bTSUjUSenUSenTSUjSSEfRS5bRSEZSSU^SSU^TSebUT5fVTEjVTEjV
TEjTSe^TSe^TSe^TSe^UT5bUT5bVTEfVTEfTT5VTT5VTT5VSSUZSSU^SSU^SSEfSSEfTSe^UT5bUT5bV
TEfVTEfUT5bUT5bTSe^TSUjTSUjTSUjTSUjTSUjTSUjTSUjTSUjRSEZTSebVTEjUT5fTSebTSebUT5fW
TUnSSUZSSUZTSebTSebUSenUSV2USV2USV2PT66PTUjPTUfRTe^QTUZQT5fQSf2QSV>VRF:TS6:OSf2L
TV>ITfjFTgjETXfFTYN7TYJ<TYf@Tj:ATJ>?SifBTiNJWIBPYYFIUhfKVHnMVi6PWYBRX9JTXYRUXiVV
Y9ZSY9ZUYYbXZIn/[JB_[jVa/J^c/Zjc/Zjk^kFl_;Jm_KNn_[Ro_kW1`K_2`[c2`[c5`l;5`l;6a<?7
aLC9alK:b<O;bLS<b/WDf/OEfLgDe=C@cMK<b=C=bMCCd]KJfmWHdmCGe=3Gf<kKgm?PiMcNh^?GenG?
cN?Fd=_He=[Kf=[Mg=SNg]SMg=SLf]WKfMWKh>o0am^b_=Bma^7Df>[Pg]k=`k:YVgjYTFNYTVFXTFBX
TF>XTF>WTF6WTF6WTUnXTV:VT62TSUjRS5bRS5bTSUjVT62XTV:WTF6WTF6WTF6WTF6WTF6WTF6WTF6W
TF6YU66XTV:WTF6TSEnRRefOR5/00:nNQ:nNQ:nNQ:nNQ:nNQ:nNQ:nNQ:nNQ;2MR;2MR;2MR;2MR;2M
R;2MR;2MR;2MR:jKQZjKQZnLQk2MR;2MR:nLQjjKQZjKQZbIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bIQ:^H
Pj^HPjbIQ:bIQ:bIQ:fJQJfJQJfJQJRJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:ZGPZZGPZ^HPj^HPj^H
PjbIQ:bIQ:bIQ:NIPjNIPjNIPjNIPjNIPjNIPjNIPjNIPjNIPjNIPjNIPjNIPjNIPjNIPjNIPjNIPjRJ
Q:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:^HPj^HPj^HPj^HPj^HPj^HPj^HPj^HPj^JP:^JP:^JP:^JP:^J
P:^JP:^JP:^JP:ZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZVH
OJVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJRGO:RGO:RGO:VHOJVH
OJVHOJZIOZZIOZRGO:VHOJVHOJZIOZZIOZVHOJVHOJRGO:RHNjRHNjRHNjVIO:VIO:VIO:ZJOJZJOJNF
NjNFNjRGO:VHOJVHOJRGO:NFNjNFNjRHNjRHNjRHNjRHNjRHNjRHNjRHNjRHNjZHNjZHNjZHNjZHNjZH
NjZHNjZHNjZHNj^HOJZGO:VFNjVFNjVFNjVFNjZGO:^HOJVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVG
N:VGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:RFMjRFMjRFMjRFMjRF
MjRFMjRFMjRFMjVGN:VGN:RFMjRFMjNEMZNEMZJDMJJDMJZGM:VFLjRELZRELZRELZVFLj^HMJbIMZFE
L:JFLJNGLZRHM:RGMZNFMJJDMJFCM:^INZRFMjBBLj>ALZFCM:NEMZRFMjNEMZFELJFELJFELJFELJFE
LJFELJFELJFELJJCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL::CLZBDL:BDL:JDKjJDKjNDKZNDKZVEK:JD
KjJDKjJDKjJDKjJDKjJDKjJDKjJDKjFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFDKJFDKJFDKJFDKJFD
KJFDKJFDKJFDKJBBKJBBKJBBKJFCKZFCKZJDKjJDKjJDKjBBKJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBB
KJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJj2?J:2?J:6@JJ:AJZ>B
JjBCK:FDKJJEKZBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBA
JjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBB
JJBBJJBBJJBBJJFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZ>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ9n=
I:2>IJ:@Ij>AJ:BBJJFCJZFCJZBBJJ>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>A
J:>AJ:>AJ:>AJ:2>IJ2>IJ6?IZ6?IZ:@Ij:@Ij>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:2>
IJ6?IZ6?IZ6?IZ:@Ij:@Ij:@Ij>AJ:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:FAHZFAHZB@HJ>?H:>?
H:B@HJFAHZFAHZ>>HJ>>HJ>>HJB?HZF@HjF@HjJAI:JAI:>>HJB?HZF@HjF@HjF@HjF@HjB?HZ>>HJ>>
HJB?HZB?HZB?HZF@HjF@HjF@HjF@Hj>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H9n;G:2<GJ6=GZ:>Gj>?
H:B@HJB@HJFAHZ:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=
GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ>=GJ>=GJ>=GJ>=GJ>=
GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ:<G::<G::<G::<G::<G::<G::<G::<G:>=
GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GIn9FJ2:FZ6;Fj>=GJ>=GJ>=GJ>=GJ>=GJ:<G:>=GJB>GZF?GjF?
Gj>=GJ:<G:6;Fj6<FJ6<FJ:=FZB?G:F@GJJAGZNBGjNBGj:=FJ:=FJ:=FJ>>FZ>>FZB?FjB?FjB?FjFB
FJB@FJB@FJ>>FZ>>FZ:=FZ:<G:6;Fj>>FZB?FjB?FjF@G:F@G:B?FjB?Fj>>FZB>GZB>GZB>GZB>GZB>
GZB>GZB>GZB>GZ6<FJ:=FZB?G:B?G::=FZ:=FZB?G:F@GJ>>FZ>>FZB?G:B?G:B>GZF>H:F>H:F>H9nA
HInBGYnCGIjCFInBFYnAG:6@Gj6>HJR7IZF9H:6?FYbCFYJDI9FDN9FAT9B?WX2;YXJ>[8b=/h^:/Hn:
ZYFCYjJTZ[Bc[l2n]<6o]L?1]lG3^LS6_<_9_lg;`Lk<`/g>a<o@a];Cb]GFcMWIdm_Je]gLf=kMfMOE
e=SFeMWGe][HemcJfMgKf]kLfmoMg=WGem[Hf=_IfMcJf]kLg=oMgN3Ng^7OgmOMc=[Me=[IgMC?g/g7
f/k9f=ODgN7Ph^SSi>3MfMSIcm_Oe=kRgMCFg[fkdJZUaMG>gMSBgMcHg]oMgN3NgMoMg=gKfm_Hf[jo
iHJ9]GQn[INOc[^ni=OEj=[Ac/>cYZVAIjRAI:RAI:RAHjN@HZNAHJNAHJJAGZNAHJF?Gj>=GJ6;Fj6;
Fj>=GJF?GjNAHJJ@H:J@H:J@H:J@H:J@H:J@H:J@H:J@H:NBGjNAHJNAHJN@HZJ?HJJ?HP00/If4/If4
/If4/If4/If4/If4/If4/If4[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[9^1[9^1[9^1[9^1[9^1[9^1
[9^1[9^1[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[9V4[9V4[9V4[9V4[9V4[9V4[9V4[9V4[9^1[9^1
[9^1[9^1[9^1[9^1[9^1[9^1ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3[9^1ZiZ0ZYUoZIQnZYUoZiZ0
[Ib2[Yf3ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZYUoZYUo
ZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUnZYUnZYUnZYUnZYUnZYUn
ZYUnZYUnZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZiQmZiQmZiQmZiQmZiQmZiQmZiQmZiQm[9Ym[9Ym
[9Ym[9Ym[9Ym[9Ym[9Ym[9YmZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQk
ZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQkZIMjZIMjZIMjZYQkZYQkZiUlZiUlZiUlZYQkZYQk
ZYQkZYQkZYQkZYQkZYQkZYQkZ9IiZIMjZIMjZYQkZYQkZiUlZiUl[9YmZIMhZIMhZIMhZIMhZIMhZIMh
ZIMhZIMhYIMjYIMjYiMjYiMjZIMjZiIjZiIjZiIjZiMhZiMhZiMhZiMhZiMhZiMhZiMhZiMhZYMdZYMd
ZYMdZYMdZYMdZYMdZYMdZYMdZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZYMdZYMdZYMdZYMdZYMdZYMd
ZYMdZYMdYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcYY=`YiAa
YiAaYiAaZ9EbZ9EbZ9EbZIIcYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAa
YiAaYiAaXYE_Y9A_Y9A_YYA_YYA_YiA_YiA_ZI=_YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^YY=]YY=]
YY=]YY=]YY=]YY=]YY=]YY=]YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI9/YI9/YI9/YI9/YI9/YI9/
YI9/YI9/YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/Y95[Y95[
Y95[Y95[Y95[Y95[Y95[Y95[Xi1ZXi1ZXi1ZY95[Y95[YI9/YI9/YI9/Y95[Y95[Y95[Y95[Y95[Y95[
Y95[Y95[Xi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi5XY99YY99YYI=ZYI=ZY99YY99YXi5XYI=ZY99Y
XY1WXHmVXHmVXY1WY99YYI=ZXY1WXY1WXY1WXi5XXi5XXi5XY99YY99YYI=ZXY1WX8iUXHmVY99YYI=Z
Xi5XXHmVXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5X
Xi5XXi5XXi5XXi5XXi5XXi5XX91RX91RXI5SXI5SXY9TXi=UXi=UXi=UXi=UXY9TX91RXI5SXi=UXi=U
XY9TXI5SYi9UZ9=VZ9=VZ9=VZ9=VYY5TYI1SY8mRYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TY91QY91Q
Y91QY91QYI5RYI5RYI5RYY9SYI5RYI5RYI5RYI5RYI5RYI5RYI5RYI5RYHiPYHiPYHiPYHiPYHiPYHiP
YHiPYHiPY8eOYHiPYXmQYXmQYXmQYXmQYHiPY8eOY8iNYHmOYHmOYHmOYY1PYY1PYY1PYi5QY8eOY8eO
Y8eOY8eOY8eOY8eOY8eOY8eOXHeMXHeMXHeMXHeMXHeMXHeMXHeMXHeMXXaLXXaLXXaLXXaLXXaLXXaL
XXaLXXaLXheMXheMXheMXheMXheMXheMXheMXheMXXaLXXaLXheMXheMXheMY8iNY8iNY8iNXXaLXXaL
XXaLXXaLXXaLXXaLXXaLXXaLXXaLXXaLXHaIXHaIXHaHXXeIXhmHXhmHY8mLXhiKXXeJX8]HX8]HX8]H
X8]HX8]HXXaLXXaLXH]KXH]KXH]KXXaLXheMY8iNXXeJXXeJXXeJXXeJXXeJXXeJXXeJXXeJY8mLXhiK
XHaIX8]HX8]HXHaIXhiKY8mLXHaIXHaIXXeJXXeJXXeJXhiKXhiKXhiKYHmOY8iNXheMXXaLXXaLXheM
Y8iNYHmOXXiGXXiGXXeIXXeIXXeJXXeJXXaLXXaLYHiLYHiLYHiLYHiLYHiLYHiLYHiLYHiLXhaJXhaJ
XhaJXhaJXhaJXhaJXhaJXhaJYi1NYi1NYi1NYi1NYi1NYi1NYi1NYi1NXhaJY8eKYHiLYHiLYHiLYHiL
Y8eKXhaJYXmMYXmMYXmMYXmMYHiLYHiLYHiLYHiLXhmHXhmHY8mKY8mKYI1MYI1MYHmOYHmOVh]MWX]H
XhmFZY9LZYA[W8akRGn5NW>88UR?:DnW94B]<ERk7d6b:cbaUigHh>WDg=6eiMk?f]WMa/cOa<_Tbm?T
d=WMf=kIjLoVkmkRj^?Dfmc<emcMc]c^/<OQRZO2`/GTd]?Wg=gQg]cDh^3Fj^GThmgXe<oT^KoLR8fj
OXK1Yk?YaMOfcmkWf^3Ohn;Nk][?h=SO^L7YM8GD?e6fDEbhTYWBaLWRi]gPgMGFg=GJgMg[a/odRj7R
AVW364B_A6JjN97?]L?Of]kOiN?RfMWY^;kYVJ?S@Fk5>6Bo<5Rh>efgIG_2VjO?aLO?emC6XIAnVXa_
WHUPZ8mM[i=M[HmNZHiRZHiYZY=SZI9RYi1PYHiNY8eMYHiNYXmOYi1PZ95QZ95QZ95QZ95QZ95QZ95Q
Z95QZ95QYi1PYi1PZ95QZI9RZI9RZ95Q002aWHBaWHBaWHBaWHBaWHBaWHBaWHBaWHB^VhJ^VhJ^VhJ^
VhJ^VhJ^VhJ^VhJ^VhJ/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6]VXF]VXF]VXF]VXF]VXF]VXF]VXF]
VXF/VHB/VHB/VHB/VHB/VHB/VHB/VHB/VHB/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6[V8>[V8>[V8>[
V8>[V8>[V8>[V8>[V8>/Vh6[VX2ZVGnYV7jZVGn[VX2]W8:^WH>[VX2[VX2[VX2[VX2[VX2[VX2[VX2[
VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2ZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZ
VGnZVGnZVGnZVGnZVGnZVGjZVGjZVGjZVGjZVGjZVGjZVGjZVGjYV7fYV7fYV7fYV7fYV7fYV7fYV7fY
V7f[V7f[V7f[V7f[V7f[V7f[V7f[V7f[V7f[VGb[VGb[VGb[VGb[VGb[VGb[VGb[VGbZV7^ZV7^ZV7^Z
V7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^Z
V7^YUgZYUgZYUgZZV7^ZV7^ZV7^[VGb[VGbZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^YUgZYUgZYUgZZ
V7^ZV7^ZV7^ZV7^ZV7^YUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRUUgZUUgZWUgZWUgZYUgZ[UWZ[UWZ[
UWZ[UgR[UgR[UgR[UgR[UgR[UgR[UgR[UgRZUgBZUgBZUgBZUgBZUgBZUgBZUgBZUgBYUW>YUW>YUW>Y
UW>YUW>YUW>YUW>YUW>ZUgBZUgBZUgBZUgBZUgBZUgBZUgBZUgBWU76WU76WU76WU76WU76WU76WU76W
U76XUG:XUG:XUG:XUG:XUG:XUG:XUG:XUG:VTg2VTg2WU76WU76WU76XUG:XUG:XUG:WU76WU76WU76W
U76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76RUFnTU6nTU6nVU6nVU6nWU6nWU6nY
TfnWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jVTffVTffVTffVTffVTffVTffVTffVTffUTfjUTfjUTfjU
TfjUTfjUTfjUTfjUTfjUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbVTffVTffVTffVTffVTffVTffVTffV
TffUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbTTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^ST6ZST6ZST6ZT
TF^TTF^TTF^UTVbUTVbRSfVRSfVRSfVRSfVRSfVRSfVRSfVRSfVST6ZST6ZST6ZST6ZST6ZST6ZST6ZS
T6ZSTFRSTFRTTVVUTfZUTfZTTVVSTFRSTFRSTFRSTFRRT6NQSfJQSfJRT6NTTVVUTfZRT6NRT6NRT6NR
T6NSTFRSTFRTTVVTTVVUTfZRT6NPSVFQSfJTTVVUTfZSTFRQSfJSTFRSTFRSTFRSTFRSTFRSTFRSTFRS
TFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRQTF>QTF>QTF>Q
TF>RTVBRTVBRTVBRTVBRTVBQTF>OSf6PT6:RTVBRTVBQTF>PT6:UT6>UT6>VTFBVTFBVTFBUT6>TSf:T
Sf:UT6>UT6>UT6>UT6>UT6>UT6>UT6>UT6>SSf2TT66TT66TT66UTF:UTF:UTF:UTF:TT66TT66TT66T
T66TT66TT66TT66TT66USV2USV2USV2USV2USV2USV2USV2USV2TSEnUSV2VSf6VSf6VSf6VSf6USV2T
SEnTSUjTSUjUSenUSenUSenVT62VT62VT62TSEnTSEnTSEnTSEnTSEnTSEnTSEnTSEnQSEfQSEfQSEfQ
SEfQSEfQSEfQSEfQSEfTSUjTSUjTSUjTSUjTSUjTSUjTSUjTSUjSSEfSSEfSSEfSSEfSSEfSSEfSSEfS
SEfRS5bRS5bRS5bSSEfSSEfTSUjTSUjTSUjRS5bRS5bRS5bRS5bRS5bRS5bRS5bRS5bSSEfRS5bRSEZQ
S5VQS5RQS5RRSUNRSUNSSU^RSEZQS5VPReRPReRPReRPReRPReRRS5bQRe^QRe^QRe^QRe^RS5bSSEfT
SUjRSEZRSEZRSEZRSEZRSEZRSEZRSEZRSEZSSU^SSU^QS5VPReRPReRQS5VSSU^SSU^QS5VQS5VQS5VR
SEZRSEZRSEZSSU^SSU^TSUjTSUjRS5bQRe^QRe^RS5bTSUjTSUjRSUNRSUNRSEVRSEVRSEZRSEZRS5bR
S5bUSUbUSUbUSUbUSUbUSUbUSUbUSUbUSUbSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZUSUbUSUbUSUbU
SUbUSUbUSUbUSUbUSUbSS5ZTSE^TSE^USUbUSUbTSE^TSE^SS5ZUSUbUSUbUSUbUSUbUSUbUSUbUSUbU
SUbSSeRSSeRTSe^TSe^TSebUT5fUSenUSenPT6:QSU^RSUFWSeVXTFBQSGBBPh26NhE7Hj0dAJHD9iXC
=JH:;ZXO=K>7T=??f/[^jngEfNb__>Q^Q<DnEieQM[>W]n;6co3UfnOGdm;Bf<gCgn6ianAmTL]9Hjlb
Dj=XNkRCX]32cN?MhNKRi>CIfnFoa]nX/MI4HjhbCZD]AZA1EjUaQ[Via=[ShNOQe]SSh^be_]UPN;8W
BJLVAk`^BKM6FZQ_P;6b/;cFe>3Ng^b^]<]]OJM7HZDfG;X/F/HeC;U<G[5eOJbYZKOEd]CEe^2QYlAV
LIdeEJhlFkQ0GKm3F[IAH:UeNjRZZKWDcLZ`YI6UUg^QT6VXTV:/U5jWSe^VSen[TfV/UFFZTf>WT62U
SUjUSUjVSenXTF6YTV:WT62WT62WT62WT62WT62WT62WT62WT62USUjVSenVSenWT62WT62VSel00;2L
Pk2LPk2LPk2LPk2LPk2LPk2LPk2LPjjKQZjKQZjKQZjKQZjKQZjKQZjKQZjKQZbKPJbKPJbKPJbKPJbK
PJbKPJbKPJbKPJfJQJfJQJfJQJfJQJfJQJfJQJfJQJfJQJbIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bK
PJbKPJbKPJbKPJbKPJbKPJbKPJbKPJ^HPj^HPj^HPj^HPj^HPj^HPj^HPj^HPj^JP:ZIOjZIOjZIOjZI
Oj^JP:bKPJfLPZ^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:ZI
OjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOZZIOZZIOZZIOZZI
OZZIOZZIOZZIOZVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJ^HOJ^HOJ^HOJ^HOJ^HOJ^HOJ^HOJ^HOJZH
NjZHNjZHNjZHNjZHNjZHNjZHNjZHNjVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVG
NZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZRFNJVGNZVGNZVGNZZHNjZHNjZHNjZHNjVG
NZVGNZVGNZVGNZVGNZVGNZVGNZVGNZZHNjZHNjZHNjZHNjVGNZVGNZVGNZVGNZRFMjRFMjRFMjRFMjRF
MjRFMjRFMjRFMjBFNJBFNJJFNJJFNJRFNJZENJZENJZENJZGMZZGMZZGMZZGMZZGMZZGMZZGMZZGMZVF
LjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjVF
LjVFLjVFLjVFLjNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJRELZRELZRELZRELZRELZRELZRELZRELZJC
L:JCL:JCL:NDLJNDLJRELZRELZRELZNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJND
LJNDLJNDLJNDLJ:EKjBDKjBDKjJDKjJDKjNDKjNDKjVCKjNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZJC
KJJCKJJCKJJCKJJCKJJCKJJCKJJCKJFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFBK:FBK:FBK:FBK:FB
K:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:>@
JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ:?JJ>@JZ>@JZ>@JZBAJjBAJjBAJjBAJj6>J:6>J:6>J:6>J:6>
J:6>J:6>J:6>J::?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:@Ij>AJ:BBJJBBJJBBJJBBJJ>AJ::@Ij:@
Ij6?IZ6?IZ6?IZ:@Ij>AJ:BBJJFCJZ6?IZ6?IZ:@Ij:@Ij>AJ:>AJ:>AJ:>AJ:BBJJ:@Ij6?IZ6?IZ>A
J:BBJJ>AJ:6?IZ:@Ij:@Ij:@Ij:@Ij:@Ij:@Ij:@Ij:@Ij:AIZ:AIZ:AIZ:AIZ:AIZ:AIZ:AIZ:AIZ:@
Ij:@Ij:@Ij:@Ij:@Ij:@Ij:@Ij:@Ij:BI::BI::BI:6AHj6AHj6AHj6AHj6AHj6AHin?HIj>H9n?HJ2@
HZ6AHj2@HYj>H::=H:>>HJB?HZF@HjF@HjF@HjB?HZ>>HJF@HjF@HjF@HjF@HjF@HjF@HjF@HjF@Hj>?
H:>?H:>?H:B@HJB@HJFAHZFAHZFAHZB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJF>H:F>H:F>H:F>H:F>
H:F>H:F>H:F>H:B=GjF>H:F>H:J?HJJ?HJF>H:F>H:B=GjB>GZB>GZB>GZF?GjF?GjJ@H:J@H:J@H:B=
GjB=GjB=GjB=GjB=GjB=GjB=GjB=Gj6=GJ6=GJ6=GJ6=GJ6=GJ6=GJ6=GJ6=GJB>GZB>GZB>GZB>GZB>
GZB>GZB>GZB>GZ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ:<G::<G::<G::<G:>=GJ>=GJB>GZB>GZ:<
G::<G::<G::<G::<G::<G::<G::<G:>=GJ>=GJ>>Fj:=FZ6<F:6<F:2<EJ2<EJ:=FZ:=FZ6<FJ2;F9n:
Ein:Ej2;F:2;F::=FZ6<FJ6<FJ2;F:6<FJ:=FZ>>FjB?G::=FZ:=FZ:=FZ:=FZ:=FZ:=FZ:=FZ:=FZ>>
Fj:=FZ6<FJ6<FJ6<FJ6<FJ:=FZ>>Fj6<FJ6<FJ6<FJ6<FJ:=FZ:=FZ:=FZ>>Fj>>Fj>>Fj:=FZ6<FJ6<
FJ:=FZ>>Fj>>Fj:>Ej:>Ej:=FJ:=FJ:=FZ:=FZ:<G::<G:B=FjB=FjB=FjB=FjB=FjB=FjB=FjB=Fj><
FZ><FZ><FZ><FZ><FZ><FZ><FZ><FZ>=FJ>=FJ>=FJ>=FJ>=FJ>=FJ>=FJ>=FJ><FZ><FZB=FjF>G:F>
G:B=Fj><FZ><FZB=FjB=FjB=FjB=FjB=FjB=FjB=FjB=Fj>?F:>?F:>>FZB?FjB?G:B?G:F?GjF?Gj>D
IZ6@GJ:=EZJ=EJR>GjJ=Jin:MIR6NgehYEeDZRP/W0h/W@0QYA0W/WB1d<SEdk>hei:ReceK/P4ZWPPb
[ALkYcQ?YG=oaKRl_M3Je=CRh:JicV=h]Rm8[QHf]@`b^10fU3iKYH2B^k[1d]GKh/7;g86E^4IQT`0g
ZQA4`BE=bbI6[ceDV8VB/mC=f^oMi:fkeeegWc=HW2QD^ADn_254_3eL^CaIWZN[_/W=h=;HjjB_bfYj
Z4=OX2eAZAm9[RXh[TaF]7n1^k>`a]WFf=oNh<34cibS]eES]D9AYc]9XDmK[G5i_9JG`kVeb=;;c/:h
YZfRQib>JYV9FYJ4Chij@hmjAYF1DJfFIZ^DI:N@H:F>GZB=GJJ?GjVBHZ^DI:N@H:N@H:N@H:N@H:N@
H:N@H:N@H:N@H:B=GJF>GZF>GZJ?GjJ?GjF>GP00/9b3/9b3/9b3/9b3/9b3/9b3/9b3/9b3[Y^6[Y^6
[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9^1[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5
[IZ5[IZ5[9V4[9V4[9V4[9V4[9V4[9V4[9V4[9V4[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9^1ZYN2ZYN2
ZYN2ZYN2ZYN2ZYN2ZYN2ZYN2ZYUoZYUoZYUoZYUoZYUoZiZ0ZiZ0[9^1ZYUoZYUoZYUoZYUoZYUoZYUo
ZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQn
ZIQnZIQnZIQnZIQnZIQnZIQnZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZ9MlZ9MlZ9MlZ9MlZ9MlZ9Ml
Z9MlZ9MlZYMlZYMlZYMlZYMlZYMlZYMlZYMlZYMlZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMj
ZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMj
ZIMjZIMjZ9IiZ9IiZ9IiZIMjZIMjZYQkZYQkZYQkZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZiUlZYQk
ZYQkZIMjZIMjZ9IiZ9IiYiEhZ9IgZ9IgZ9IgZ9IgZ9IgZ9IgZ9IgZ9IgY9IiY9IiYYIiYYIiZ9IiZYEi
ZYEiZYEiZYMfZYMfZYMfZYMfZYMfZYMfZYMfZYMfZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIc
ZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcYiAaYiAaYiAaYiAaYiAaYiAa
YiAaYiAaZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbYI9_YY=`YY=`YY=`YiAaYiAaYiAaZ9EbYiAaYiAa
YiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaXIA^Xi=^Xi=^YI=^YI=^YY=^
YY=^Z99^YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/Y99]Y99]
Y99]Y99]Y99]Y99]Y99]Y99]Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[
Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Xi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXXmYXXmY
XXmYXi1ZXi1ZY95[Y95[Y95[XHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXXmYXXmYXXmYXXmYXXmYXXmY
XXmYXXmYXY1WXi5XXi5XY99YY99YXi5XXi5XXY1WX8iUX8iUXHmVXHmVXY1WXi5XY99YY99YXHmVXHmV
XHmVXY1WXY1WXY1WXi5XXi5XXY1WXY1WXHmVXY1WXY1WXY1WXY1WXHmVXY1WXY1WXY1WXY1WXY1WXY1W
XY1WXY1WXY5VXY5VXY5VXY5VXY5VXY5VXY5VXY5VXY1WXY1WXY1WXY1WXY1WXY1WXY1WXY1WXY9TXY9T
XY9TXI5SX91RX91RWhmQWhmQX91RWXiPWHeOWHeOWhmQX91RWhmQWHeOXHaOXXePXhiQYI1SYI1SYI1S
YI1SYI1SY8mRY8mRY8mRY8mRY8mRY8mRY8mRY8mRXhmPXhmPXhmPXhmPY91QY91QYI5RYI5RY91QY91Q
Y91QY91QY91QY91QY91QY91QYHiPYHiPYHiPYHiPYHiPYHiPYHiPYHiPY8eOY8eOYHiPYHiPYHiPYHiP
Y8eOY8eOXheMY8iNY8iNY8iNYHmOYHmOYHmOYY1PXhaNXhaNXhaNXhaNXhaNXhaNXhaNXhaNX8aLX8aL
X8aLX8aLX8aLX8aLX8aLX8aLXH]KXH]KXH]KXH]KXH]KXH]KXH]KXH]KXXaLXXaLXXaLXXaLXXaLXXaL
XXaLXXaLXH]KXH]KXXaLXXaLXXaLXheMXheMXheMXH]KXH]KXH]KXH]KXH]KXH]KXH]KXH]KXheMXheM
XhiKXXeJXHaHX8]GWh]DWXYCXHaIXHaIX8]HWhYGWhYGWhYGX8]HXHaIXHaIXHaIX8]HX8]HX8]HXHaI
XXeJXhiKXHaIXHaIXHaIXHaIXHaIXHaIXHaIXHaIXHaIXHaIXHaIXHaIXHaIXHaIXHaIXHaIX8]HX8]H
XHaIXHaIXHaIXXeJXXeJXXeJXXeJXHaIXHaIXHaIXHaIXHaIXHaIXXeJXHeFXHeFXHaHXHaHXHaIXHaI
XH]KXH]KXhaJXhaJXhaJXhaJXhaJXhaJXhaJXhaJXX]IXX]IXX]IXX]IXX]IXX]IXX]IXX]IXheIXheI
XheIXheIXheIXheIXheIXheIXX]IXhaJY8eKY8eKY8eKY8eKXhaJXX]IXhaJXhaJXhaJXhaJY8eKY8eK
Y8eKY8eKXXiGXXiGXhiJXhiJY8mLY8mLY8iNY8iNXYATXY5PXheIYheG[8mLZY1RZ8iYYXe]WXR2SGJL
HEfT<DZP1RZP2B2[J77;cmOX/KWGB5bE4CNG2Sbj02Zb2C6X=df/AU6KYjN]bm7@b]KJRYZg@UBK7CBQ
4C6c2Bjh4CfR?ej]PY:m`/GDhN;VbmCQRZ71Cg2N7UBi0S6M1bjK>eRcN8k8/kkIfMSRiMSP_/gP//ST
KXo0=e^Y<52d;DJ/CfFcWK7[cLgKb/[Fc<oMcM?V]<7QQIW9EW2b?5^VHG74SY[J`/S]g]oYi>CNhn3K
gMoPf=[T[K;YPHFoJ6jYQhc3^kkZemSbg=WRfMKBdl^j^;2IX9MfV8mTV8eKVH]FX91KZYUV[9EUZI9R
YXmOXhaLXhaLYHiNZI9RZiATYi1PYi1PYi1PYi1PYi1PYi1PYi1PYi1PYHiNYHiNYXmOYi1PYi1PYXmO
002_Vh:_Vh:_Vh:_Vh:_Vh:_Vh:_Vh:_Vh:^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ/Vh6/Vh6/Vh6/
Vh6/Vh6/Vh6/Vh6/Vh6/VHB/VHB/VHB/VHB/VHB/VHB/VHB/VHB[V8>[V8>[V8>[V8>[V8>[V8>[V8>[
V8>[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2ZUh:ZUh:ZUh:ZUh:ZUh:ZUh:ZUh:ZUh:XUgfYV7jYV7jZ
VGnZVGn[VX2[VX2[VX2ZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZ
VGnYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7fYV7fYV7fY
V7fYV7fYV7fYV7fYV7fXUgbXUgbXUgbXUgbXUgbXUgbXUgbXUgbZUgbZUgbZUgbZUgbZUgbZUgbZUgbZ
UgbXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZY
UgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZWUGRXUWVXUWVXUWVYUgZYUgZYUgZZ
V7^YUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZZV7^ZV7^YUgZYUgZXUWVXUWVWUGRWUGRWUGJWUGJWUGJW
UGJWUGJWUGJWUGJWUGJSUGRSUGRUUGRUUGRWUGRYU7RYU7RYU7RYUW>YUW>YUW>YUW>YUW>YUW>YUW>Y
UW>XUG:XUG:XUG:XUG:XUG:XUG:XUG:XUG:YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>XUG:XUG:XUG:X
UG:XUG:XUG:XUG:XUG:WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76W
U76UTVnUTVnUTVnVTg2VTg2WU76WU76WU76VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2V
Tg2VTg2VTg2VTg2VTg2QU6jSTfjSTfjUTfjUTfjVTfjVTfjXTVjVTffVTffVTffVTffVTffVTffVTffV
TffUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTF^TTF^TTF^T
TF^TTF^TTF^TTF^TTF^ST6ZST6ZST6ZST6ZST6ZST6ZST6ZST6ZTTF^TTF^TTF^TTF^TTF^TTF^TTF^T
TF^ST6ZST6ZST6ZST6ZST6ZST6ZST6ZST6ZQSVRRSfVRSfVRSfVST6ZST6ZST6ZTTF^RSfVRSfVRSfVR
SfVRSfVRSfVRSfVRSfVQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRRT6NRT6NSTFRSTFRSTFRSTFRRT6NR
T6NPSVFPSVFQSfJQSfJRT6NRT6NRT6NRT6NPSVFPSVFQSfJQSfJRT6NRT6NRT6NRT6NQSfJQSfJRT6NR
T6NQSfJQSfJQSfJRT6NQSfJQSfJQSfJQSfJQSfJQSfJQSfJQSfJQTF>QTF>QTF>QTF>QTF>QTF>QTF>Q
TF>QSfJQSfJQSfJQSfJQSfJQSfJQSfJQSfJRTVBRTVBQTF>QTF>PT6:OSf6OSf6OSf6OSf6NSV2LS5jM
SEnOSf6OSf6NSV2LS5jRSF2SSV6UT6>VTFBVTFBVTFBVTFBVTFBSSV6SSV6SSV6SSV6SSV6SSV6SSV6S
SV6RSUnRSUnSSf2SSf2SSf2TT66TT66TT66SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2TSEnTSEnTSEnT
SEnTSEnTSEnTSEnTSEnSS5jTSEnTSEnUSV2USV2TSEnTSEnSS5jSSEfSSEfSSEfTSUjTSUjUSenUSenU
SenSS5jSS5jSS5jSS5jSS5jSS5jSS5jSS5jPS5bPS5bPS5bPS5bPS5bPS5bPS5bPS5bQRe^QRe^QRe^Q
Re^QRe^QRe^QRe^QRe^RS5bRS5bRS5bRS5bRS5bRS5bRS5bRS5bQRe^QRe^QRe^RS5bRS5bRS5bSSEfS
SEfQRe^QRe^QRe^QRe^QRe^QRe^QRe^QRe^RS5bRS5bSSU^RSEZQS5RPReNNRU>MRE:PReRPReRORUNN
REJORUNORUNPReRQS5VQS5RPReNPReNORUJPReNQS5RRSEVSSUZQS5VQS5VQS5VQS5VQS5VQS5VQS5VQ
S5VPReRPReRQS5VQS5VQS5VQS5VPReRPReRPReRPReRPReRPReRQS5VQS5VRSEZRSEZPReNPReNQS5RQ
S5RQS5RQS5RPReNPReNQSEJQSEJQS5RQS5RQS5VQS5VQRe^QRe^SS5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZS
S5ZRReVRReVRReVRReVRReVRReVRReVRReVSSUNSSUNSSUNSSUNSSUNSSUNSSUNSSUNRReVRReVSS5ZT
SE^TSE^SS5ZRReVRReVQRURQRURRReVRReVSS5ZSS5ZTSE^TSE^RSUNRSUNRSEVSSUZSSU^SSU^TSUjT
SUjNSejRSebUSe^XT5b/TEj/TEnYT5jXSUnST4bRS7><Q8iLLI0^C9TS=:UWJ<;>cnW2b<fS/m1=KJlC
?IdI@ZTU@iaEI:>/[mcZg_3MeMoDe=[;cnNY/NI_Ol]1F[0]CZAALKf6V]C7bnS[i>O/i=gJf][4dMng
c^QoW<Q@JZ1BIJ:<WLjod>_Fi^gOi^WLgn?ZjnWCfm_>fnVU/mMSK:EbM[2f^>3?d^OWh^7RgM[ThMgZ
j^[RiNg5c>2W/]:GXl^_a=Vmcm[9emG<eLS9c;c3`kNh][Fb[[>^//FBUZV3QiZAUJNQYZnRY:BNX9BO
XHk5`Jn/Yi:>RVf2OU^8PUNDRU^KSEfLS5fYTV:WT62TSEfRRe^RRe^TSEfWT62YTV:VSenVSenVSenV
SenVSenVSenVSenVSenVSenWT62XTF6XTF6XTF6XTF400:nKPZnKPZnKPZnKPZnKPZnKPZnKPZnKPZjK
QZjKQZjKQZjKQZjKQZjKQZjKQZjKQZbKPJbKPJbKPJbKPJbKPJbKPJbKPJbKPJbIQ:bIQ:bIQ:bIQ:bI
Q:bIQ:bIQ:bIQ:^HPj^HPj^HPj^HPj^HPj^HPj^HPj^HPj^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:VF
PJVFPJVFPJVFPJVFPJVFPJVFPJVFPJNFO:RGOJVHOZZIOj^JP:ZIOjZIOjVHOZVHOZVHOZVHOZVHOZVH
OZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRG
OJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGO:RGO:RGO:RGO:RGO:RGO:RGO:RGO:NFNjNFNjNFNjNFNjNF
NjNFNjNFNjNFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZRF
NJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRF
NJRFNJRFNJRFNJNEN:NEN:NEN:RFNJRFNJVGNZVGNZVGNZRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJVG
NZVGNZRFNJRFNJRFNJRFNJRFNJNEN:NEMZNEMZNEMZNEMZNEMZNEMZNEMZNEMZ>EN:>EN:FEN:FEN:NE
N:VDN:VDN:VDN:VGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZRELZRELZRELZRELZRELZRELZRELZRELZVF
LjVFLjVFLjVFLjVFLjVFLjVFLjVFLjRELZRELZRELZRELZRELZRELZRELZRELZNDLJNDLJNDLJNDLJND
LJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJFBKjFBKjFBKjFBKjJCL:JCL:JCL:NDLJJC
L:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:2CKJ:BKJ:BKJBBKJBB
KJFBKJFBKJNAKJFBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:BAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJj>A
K:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@
JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ6>
J:6>J:6>J::?JJ:?JJ>@JZ>@JZ>@JZ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ6>J:6>J:6>J:6>J:6>
J:6>J:6>J:6>J:6?IZ:@Ij:@Ij>AJ:>AJ::@Ij:@Ij6?IZ2>IJ6?IZ:@Ij:@Ij:@Ij6?IZ2>IJ2>IJ2>
IJ2>IJ2>IJ6?IZ6?IZ:@Ij:@Ij:@Ij2>IJ6?IZ:@Ij:@Ij2>IIn=I:6?IZ:@Ij6?IZ6?IZ6?IZ6?IZ6?
IZ6?IZ6?IZ6?IZ6AHZ6AHZ6AHZ6AHZ6AHZ6AHZ6AHZ6AHZ6?IZ6?IZ6?IZ6?IZ6?IZ6?IZ6?IZ6?IZ2@
HZ2@HZ2@HZ2@HZ2@HYn?HIn?HIn?HIn?HIj>H9f=Gif=Gin?HJ2@HYj>H9f=GjB?HZB?HZF@HjJAI:JA
I:JAI:F@HjF@Hj:=H::=H::=H::=H::=H::=H::=H::=H::>Gj:>Gj:>Gj:>Gj>?H:>?H:B@HJB@HJ>?
H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:B=GjB=GjB=GjB=GjB=GjB=GjB=GjB=Gj><GZ><GZB=GjF>H:F>
H:B=Gj><GZ><GZ>=GJ>=GJ>=GJ>=GJB>GZB>GZB>GZF?Gj:;GJ:;GJ:;GJ:;GJ:;GJ:;GJ:;GJ:;GIn;
Fin;Fin;Fin;Fin;Fin;Fin;Fin;Fj>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ6;Fj6;Fj6;Fj6;Fj6;
Fj6;Fj6;Fj6;Fj2:FZ2:FZ6;Fj6;Fj:<G::<G::<G::<G:2:FZ2:FZ2:FZ2:FZ2:FZ2:FZ2:FZ2:FZ2:
FZ6;Fj:=FZ>>Fj:=FJ2;Eij:Dib8DIn:Ein:Eij9EYj9EYj9EYn:Ej2;F:6<FJ2;Ej2;Ein:EYn:EYn:
EZ2;Ej6<F::=FJ2;F:2;F:2;F:2;F:2;F:2;F:2;F:2;F9n:Ej2;F:6<FJ6<FJ6<FJ6<FJ2;F9n:Ein:
Ein:Ej2;F:2;F:2;F:6<FJ6<FJ6<FIj9EIn:EZ2;Ej6<F:6<F:2;Ein:EYj9EJ2<EJ2<EJ2;Ej2;Ej2;
F:2;F:2:FZ2:FZ:;FJ:;FJ:;FJ:;FJ:;FJ:;FJ:;FJ:;FJ6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:F:>?
EZ>?EZ>?EZ>?EZ>?EZ>?EZ>?EZ>?EZ6:F::;FJ><FZ><FZ><FZ><FZ:;FJ6:F:29Ej29Ej29Ej6:F::;
FJ><FZ><FZB=Fj6=EZ:>Ej:=FJ:=FJ>>Fj>>Fj>=GJ>=GIj<Ej2=FZF?GjRAHJRAHJNAGJF@FJ>?EZ6G
>J:@EI^@JWj8LFakUF1Q/GYc]/o;enGUdm7IfKW:iGnEaE1UW7f=^<[?j=[Ihmo@iMkCgMgGf=oKhMOE
jk[1hYFTaGN>Z;6mhL[?j>CQj^kTgNKMd=gHcm[OgMkYkMKNelgAe];Di]OJj<cFe/WGc<gJd/cGeM;:
^O?_g>OXf=;Bd]_FiMC:flRm`=S@`kfeZ<K0/lO2/kZjZ[bk/K^l^:BUZH:3SGb=N7^;LgJ5JW9nHVif
Gf]^GfMWHFIRHEINE4aDBTaBAeAKCUQMCUAHAEAG@EUL@c/i9cDd82h^5STk7VAR@i>=JZJHM9f=JJF>
GZB=GJ><G::;Fj><G:B=GJJ?GjN@H:J?GjJ?GjJ?GjJ?GjJ?GjJ?GjJ?GjJ?GjN@H:N@H:RAHJVBHZVB
HZRAH@00[YZ1[YZ1[YZ1[YZ1[YZ1[YZ1[YZ1[YZ1[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[9^1[9^1
[9^1[9^1[9^1[9^1[9^1[9^1ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZYN2ZYN2ZYN2ZYN2ZYN2ZYN2
ZYN2ZYN2ZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZIJ1ZIJ1ZIJ1ZIJ1ZIJ1ZIJ1ZIJ1ZIJ1YiIlZ9Mm
ZIQnZYUoZiZ0ZYUoZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQn
ZIQnZIQnZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MlZ9Ml
Z9MlZ9MlZ9MlZ9MlZ9MlZ9MlYiIkYiIkYiIkYiIkYiIkYiIkYiIkYiIkZIIkZIIkZIIkZIIkZIIkZIIk
ZIIkZIIkZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9Ii
Z9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiYiEhYiEhYiEhZ9IiZ9IiZ9Ii
ZIMjZIMjZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiYiEhYiEhYiEhZ9IiZ9IiZ9IiZ9IiZ9IiYiEfYiEf
YiEfYiEfYiEfYiEfYiEfYiEfXiEhXiEhYIEhYIEhYiEhZIAhZIAhZIAhZIMbZIMbZIMbZIMbZIMbZIMb
ZIMbZIMbYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcYiAaYiAa
YiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYY=`YY=`YY=`YY=`YY=`YY=`
YY=`YY=`Y95^Y95^YI9_YI9_YI9_YY=`YY=`YY=`YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_
YI9_YI9_YI9_YI9_YI9_YI9_X9=]XY9]XY9]Y99]Y99]YI9]YI9]Yi5]YI9/YI9/YI9/YI9/YI9/YI9/
YI9/YI9/Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/Xi1ZXi1Z
Xi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXi1ZXi1ZXi1ZXi1ZXi1ZXi1Z
Xi1ZXi1ZXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXHiXXHiXXHiXXXmYXXmYXXmYXi1ZXi1ZXHiXXHiX
XHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHmVXHmVXY1WXi5XXi5XXY1W
XHmVXHmVXHmVXY1WXY1WXi5XXY1WX8iUWXaSWH]RX8iUX8iUX8iUX8iUXHmVXHmVXHmVXY1WWheTXHmV
Xi5XXY1WWheTWXaSX8iUXi5XXHmVXHmVXHmVXHmVXHmVXHmVXHmVXHmVXI5RXI5RXI5RXI5RXI5RXI5R
XI5RXI5RXHmVXHmVXHmVXHmVXHmVXHmVXHmVXHmVWhmQWhmQWhmQWhmQX91RX91RX91RX91RX91RWhmQ
WHeOWXiPX91RX91RWhmQWXiPXhiQY8mRYI1SYI1SYI1SY8mRXhiQXXePXHaOXHaOXHaOXHaOXHaOXHaO
XHaOXHaOXHeNXHeNXXiOXXiOXhmPXhmPXhmPXhmPXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXhaNXhaN
XhaNXhaNXhaNXhaNXhaNXhaNXX]MXhaNY8eOY8eOY8eOY8eOXhaNXX]MXXaLXXaLXheMXheMXheMY8iN
Y8iNY8iNXX]MXX]MXX]MXX]MXX]MXX]MXX]MXX]MWh]KWh]KWh]KWh]KWh]KWh]KWh]KWh]KXXaLXXaL
XXaLXXaLXXaLXXaLXXaLXXaLXH]KXH]KXH]KXH]KXH]KXH]KXH]KXH]KX8YJX8YJX8YJXH]KXH]KXXaL
XXaLXXaLX8YJX8YJX8YJX8YJX8YJX8YJX8YJX8YJWXQHWhUIXHaIXXeJXXeIXHaHWXYCWHUBWXUFWXUF
WXUFWHQEWXUFWhYGX8]HXHaIX8aEWh]DWh]DWh]DWh]DX8aEXHeFXXiGX8]HX8]HX8]HX8]HX8]HX8]H
X8]HX8]HWXUFWhYGX8]HXHaIXHaIX8]HWhYGWXUFWhYGWhYGWhYGX8]HX8]HX8]HXHaIXHaIWHUBWXYC
Wh]DX8aEX8aEWh]DWXYCWHUBX8aEX8aEX8]GX8]GX8]HX8]HX8YJX8YJXHYHXHYHXHYHXHYHXHYHXHYH
XHYHXHYHXHYHXHYHXHYHXHYHXHYHXHYHXHYHXHYHXHeDXHeDXHeDXHeDXHeDXHeDXHeDXHeDXHYHXX]I
XX]IXhaJXhaJXX]IXX]IXHYHWXMEWhQFX8UGX8UGXHYHXX]IXhaJXhaJXHeFXHeFXXeIXXeIXXeJXhiK
XheMXheMWhaCXHaHXXiOXhiQXHiQX8mNX8mGX91EVYE@WXYJYI1MVI1GVIF3S82TSh2Of=70e=>oknkT
gn3T`l?Cb/cNf=STfmWIhMoGbl[DiNKTk^kRfMS>e=7Ci>?/iN[[dMkFgmgLf=GAdLg8d<c7dm38d]38
c<g3b<Vod]G6`/2o_;Rn_;Rm_L2gaLbm_LFjYJZX]kF[Vib<UiV5U9J:Qh>2RXB5TH]nOgiTQXIhSXj0
RhinPhUfRHmnSI65MWM]DU9<BD/eCU4kDUQ1D5M2BU<nC58oE5Y9Gf9CEf1<Dea7EUa5HFA>Kg5KNWUT
NWUUN7ITTiB0UIN3RXmjQhagZZVEd<Vea[RRX8igXhaLY8eMY8eMYHiNYXmOYXmOYXmOYXmOYHiNYHiN
YHiNYHiNYHiNYHiNYHiNYHiNYXmOYXmOYi1PZ95QZ95QYi1P002^VX6^VX6^VX6^VX6^VX6^VX6^VX6^
VX6^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6[V8>[V8>[V8>[
V8>[V8>[V8>[V8>[V8>ZUh:ZUh:ZUh:ZUh:ZUh:ZUh:ZUh:ZUh:ZVGnZVGnZVGnZVGnZVGnZVGnZVGnZ
VGnYUX6YUX6YUX6YUX6YUX6YUX6YUX6YUX6VUG^WUWbYV7jZVGn[VX2ZVGnYV7jXUgfYV7jYV7jYV7jY
V7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jXUgfXUgfXUgfXUgfXUgfXUgfXUgfX
UgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgbXUgbXUgbXUgbXUgbXUgbXUgbXUgbWUW^WUW^WUW^W
UW^WUW^WUW^WUW^WUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^Z
V7^XUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVX
UWVXUWVXUWVXUWVXUWVVU7NWUGRWUGRWUGRXUWVXUWVXUWVYUgZXUWVXUWVXUWVXUWVXUWVXUWVXUWVX
UWVVU7NVU7NWUGRWUGRXUWVXUWVYUgZYUgZVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FRU7NRU7NTU7NT
U7NVU7NXTgNXTgNXTgNXUW6XUW6XUW6XUW6XUW6XUW6XUW6XUW6WU76WU76WU76WU76WU76WU76WU76W
U76YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76W
U76WU76WU76WU76WU76VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2TTFjTTFjTTFjUTVnUTVnVTg2VTg2V
Tg2UTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnPTffRTVfRTVfT
TVfTTVfUTVfUTVfWTFfUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbTTF^TTF^TTF^TTF^TTF^TTF^TTF^T
TF^STFbSTFbSTFbSTFbSTFbSTFbSTFbSTFbST6ZST6ZST6ZST6ZST6ZST6ZST6ZST6ZQSVRQSVRQSVRQ
SVRQSVRQSVRQSVRQSVRST6ZST6ZST6ZST6ZST6ZST6ZST6ZST6ZRSfVRSfVRSfVRSfVRSfVRSfVRSfVR
SfVPSFNQSVRQSVRQSVRRSfVRSfVRSfVST6ZOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JPSFNPSFNPSFNP
SFNPSFNPSFNPSFNPSFNQSfJQSfJRT6NSTFRSTFRRT6NQSfJQSfJRT6NRT6NSTFRSTFRRT6NOSFBMRf:K
RF2OSFBPSVFPSVFPSVFQSfJQSfJQSfJQSfJNS6>QSfJSTFRRT6NOSFBNS6>PSVFSTFRPSVFPSVFPSVFP
SVFPSVFPSVFPSVFPSVFPT66PT66PT66PT66PT66PT66PT66PT66PSVFPSVFPSVFPSVFPSVFPSVFPSVFP
SVFNSV2NSV2NSV2OSf6PT6:PT6:QTF>QTF>QTF>OSf6NSV2OSf6PT6:QTF>PT6:NSV2SSV6SSV6SSV6S
SV6SSV6RSF2PRejPRejQS5nQS5nQS5nQS5nQS5nQS5nQS5nQS5nQSEjQSEjRSUnRSUnRSUnSSf2SSf2S
Sf2RSUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnSS5jSS5jSS5jSS5jSS5jSS5jSS5jSS5jRRefSS5jSS5jT
SEnTSEnSS5jSS5jRRefRS5bRS5bRS5bSSEfSSEfTSUjTSUjTSUjRRefRRefRRefRRefRRefRRefRRefR
RefORe^ORe^ORe^ORe^ORe^ORe^ORe^ORe^PRUZPRUZPRUZPRUZPRUZPRUZPRUZPRUZQRe^QRe^QRe^Q
Re^QRe^QRe^QRe^QRe^PRUZPRUZPRUZQRe^QRe^QRe^RS5bRS5bPRUZPRUZPRUZPRUZPRUZPRUZPRUZP
RUZLQUJNR5RPReRRSEZSSUZQS5ROReBMRE:NREJNREJMR5FMR5FNREJORUNPReRQS5VPS5FOReBOReBN
RU>OReBPS5FQSEJRSUNPReRPReRPReRPReRPReRPReRPReRPReRNREJORUNPReRQS5VQS5VPReRORUNN
REJORUNORUNORUNORUNPReRPReRQS5VQS5VMRE:NRU>OReBPS5FPS5FOReBNRU>MRE:PS5FPS5FPReNP
ReNPReRPReRPRUZPRUZQRURQRURQRURQRURQRURQRURQRURQRURQRURQRURQRURQRURQRURQRURQRURQ
RURORe:ORe:ORe:ORe:ORe:ORe:ORe:ORe:QRURQRURRReVSS5ZSS5ZRReVQRURQRURNQeFNQeFOR5JP
RENQRURRReVSS5ZSS5ZQSEJQSEJQS5RRSEVRSEZRSEZSSEfSSEfPS5:QS5RPS5fMRf:KRf6JS5bKT5NM
TUJ@RVNJPfV]SV6TSDVTTVVEP8R@P87OfJk9b;Zl]jk1^;G<`L?5^[fh/;2h]Jfm_;:_^k^T/ZJP[9JY
[9b/ZJBYY:FVYZ2W[9fbZY>`ZIR[ZZ2Y[:ZVZjZUZ:JYZZ2][InRZZVNX:ZYY[JaZkJTXIbMWXjTY9RV
XijHXJFAWIN?W8jJY9ROY:>AUYFBVHbX/INIXYRGXIFIYYRNZi^IYYJAVhjCVi2NY9VSU96NU8fJUhnN
WiFOYYNNYi>LYXnLYHZJYI6RZiJW[IJUZ8nVYI2_ZiVf/:Fg[jRPXXjZ[iZTZYVPYIK3`kGYhMCA`KBI
PgNSS5bTSEfVSenXTF6XTF6XTF6WT62VSenUSUjUSUjUSUjUSUjUSUjUSUjUSUjUSUjTSEfUSUjVSenV
SenVSenVSel00:jKP:jKP:fJOjbHOjbGPJfHPZjIQ:jIQ:bKPJbKPJbKPJbKPJbKPJbKPJbKPJbKPJ^J
P:^JP:^JP:^JP:^JP:^JP:^JP:^JP:bKPJbKPJbKPJbKPJ^JP:^JP:ZIOjZIOjZIOjZIOjZIOjZIOjZI
OjZIOjZIOjZIOjVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZNF
O:RGOJRGOJVHOZVHOZZIOj^JP:^JP:VHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVH
OZVHOZVHOZVHOZJENZNFNjNFNjRGO:RGO:VHOJVHOJZIOZNFNjNFNjNFNjNFNjNFNjNFNjNFNjNFNjVF
NjVFNjVFNjVFNjVFNjVFNjVFNjVFNjVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZNEN:NEN:NEN:RFNJRF
NJRFNJVGNZVGNZRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJJD
MjJDMjNEN:NEN:NEN:NEN:JDMjJDMjRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJNEMZNEMZNEMZNEMZNE
MZNEMZNEMZNEMZNEMZNEMZNEMZNEMZNEMZNEMZNEMZNEMZRFMjNEMZJDMJJDMJJDMJJDMJNEMZRFMjJD
MJJDMJJDMJJDMJNEMZNEMZNEMZRFMjNEMZNEMZNEMZNEMZNEMZNEMZNEMZNEMZVFLjVFLjVFLjVFLjVF
LjVFLjVFLjVFLjJCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:NDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJND
LJNDLJNDLJNDLJNDLJNDLJNDLJNDLJJCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JC
L:JCL:JCL:JCL:FBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjBA
KZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAK:BAK:BAK:BAK:BAK:BAK:BAK:BAK::AIZ:AIZ6?IZ2>IJ2=
Ij6>JJ:?JZ:?JZBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJj:AJZ:AJZ:AJZ>@JZF@JZF@JZN@JZN@JZ:?
JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ>@JZ>@JZ>@JZ:?JJ6>
J:6>J:2=Ij2=Ij6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J::?JJ:?JJ:?JJ6>J:2=Ij2=Iin<IYn<IZ:?
JJ6>J:2=Iin<IYn<IZ2=Ij6>J::?JIn=I9n=I9n=I9n=I9n=I9n=I9n=I9n=I:6?IZ6?IZ6?IZ6?IZ6?
IZ6?IZ6?IZ6?IZB>IJB>IJF?IZJ@IjJ@IjF?IZB>IJB>IJ:=H:>>HJ>>HJ>>HJB?HZB?HZB?HZF@Hj6?
IZ6?IZ6?IZ6?IZ6?IZ6?IZ6?IZ6?IZF@HjF@HjF@HjF@HjF@HjF@HjF@HjF@Hj:>Gj>?H:B@HJB?HZB>
I:B>I:>=I::<Hj:<HZ:<HZ:<HZ:<HZ:<HZ:<HZ:<HZ:<HZF@HjB?HZ>>HJ:=H::=H:>>HJB?HZF@Hj>>
HJ>>HJ>>HJ>>HJ:=H::=H:6<Gj6<GjB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJ6=GZ6=GZ6=GZ6=GZ6=
GZ6=GZ6=GZ6=GZ:;GJB=GjF>H:B=Gj:;GJ:;GJ><GZF>H:B>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZ:;
GJ:;GJ:;GJ:;GJ:;GJ:;GJ:;GJ:;GJ><GZ><GZ><GZ><GZ><GZ><GZ><GZ><GZ:=FZ>>Fj>>Fj>>FjB?
G:B?G:B?G:B?G:>=GJ:<G::<G:6;Fj6;Fj:<G::<G:>=GIn:Ein:Ej2;F:6<FJ6<FJ2;F9n:Ein:Eij8
F9n9FJ6;Fj:<G::<G:6;Fin9FIj8F:2;F:2;F:2;F:2;F:2;F:2;F:2;F:2;F9j9EYn:Ej2;F9n:Eij9
EYn:Ej6<FJB?G9n:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ej6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EIn:
Din:Din:Din:Din:Din:Din:Din:Dj2;E:2;E9n:Dij9DYf8DIj9DYj9DYn:Din:Din:Din:Din:Din:
Din:Din:Din:Dj6<EJ2;E:2;E:2;E:2;E:6<EJ:=EZ>>Ein:Din:Din:Dj2;E:2;E:2;E:6<EJ6<EIn:
Dj2;E::=EZ:=EZ2;E:2;E::=EZ>>Ej:=EZ6<EJ2;E:2;E:2;E:2;E:6<EJ:=EZ2;E:2;E:2;E:2;E:2;
E:2;E:2;E:2;E:2;E:2;E:2;E:2;E9n:Din:Din:Din:Dj2<Dj2<Dj2<Dj6=E:6=E:6=E::>EJ:>EJ:=
EZ:=EZ:=EZ:=EZ:=EZ:=EZ:=EZ:=EZ2;E:2;E:2;E:2;E:2;E:2;E:2;E:2;E:>>Ej:=EZ:=EZ6<EJ6<
EJ2;E9n:Din:Dj6=E:6=E:6=E::=EZ:<F:>=FJ><FZ><FZRADjJ@EZ>>Ej6;Fj2:H:2:IYn:JZ6<KJ>I
Mj6KOYjMR9^OTiRPUYZNV9ZMU9ZKTJ>NUJBOUZJQV:FPUjBOUZ>NUJFPUjJQV:^XVZVVV:NTUZNTUZRU
UjVVV:RUUjNTUZVUVZZVVjZVVjVVV:NTUZBQTZ>PTJ:OT9^LTYnMTjROUJbPU:RLT:6HSYZHSYZKTIfO
S:2RSj>UTZBVTj:TTJ2RSinQSYnQSZNRTjJQTZJQTZRSU:^VUjbWV:ZUUZVTUJbWV:fXVJnZVk6/WK>^
WkF`XKNbXkRcY;FZY[>cXjR`VJ>/V;jn/]_?aLnkXZbEKj6>Fj>>Fj>>FjB=FjB=FjJ=FjJ=FjR=FjF>
G:F>G:F>G:F>G:F>G:F>G:F>G:F>G:B=FjB=FjF>G:F>G:J?GJJ?G@00[Y^0[Y^0[IYo[9Qo[9N1[IR2
[YV4[YV4[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9^1ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0[9^1[9^1
[9^1ZiZ0ZiZ0ZiZ0ZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZIQnZIQnZIQnZIQnZIQnZIQn
ZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnYiIlZ9MmZ9MmZIQnZIQnZYUoZYUoZYUoZIQnZIQn
ZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnYiIkYiIkYiIkZ9MlZ9MlZ9Ml
Z9MlZ9MlYiIkYiIkYiIkYiIkYiIkYiIkYiIkYiIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIMjZIMj
ZIMjZIMjZIMjZIMjZIMjZIMjYYAgYiEhYiEhYiEhZ9IiZ9IiZ9IiZIMjZ9IiZ9IiZ9IiZ9IiZ9IiZ9Ii
Z9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiYYAgYYAgYiEhYiEhYiEhYiEhYYAgYYAgZ9IiZ9Ii
Z9IiZ9IiZ9IiZ9IiZ9IiZ9IiYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAe
YYAeYYAeYiEfYiEfYYAeYI=dYI=dYYAeYiEfYiEfYI=dYYAeYYAeYYAeYiEfYiEfYiEfYiEfYYAeYYAe
YYAeYYAeYYAeYYAeYYAeYYAeZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbYY=`YY=`YY=`YY=`YY=`YY=`
YY=`YY=`YiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYY=`YY=`
YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YI9_YI9_YI9_YI9_YI9_YI9_
YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95/Y95/
Y95/Y95/Y95/Y95/Y95/Y95/Xi9WXi9WXY1WXHmVXHiXXXmZXi1[Xi1[Y95[Y95[Y95[Y95[Y95[Y95[
Y95[Y95[XY5ZXY5ZXY5ZXi1ZYI1ZYI1ZYi1ZYi1ZXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmY
XXmYXXmYXXmYXXmYXXmYXXmYXi1ZXi1ZXXmYXXmYXHiXXHiXX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eW
X8eWX8eWXXmYXXmYXHiXXHiXX8eWX8eWWhaVWhaVXXmYXHiXX8eWWhaVWhaVX8eWXHiXXXmYWheTWheT
WheTWheTWheTWheTWheTWheTX8iUX8iUX8iUX8iUX8iUX8iUX8iUX8iUXheTY8iUYHmVYHmVYHmVYHmV
Y8iUXheTXXePXXePXhiQXhiQXhiQY8mRY8mRY8mRX8iUX8iUX8iUX8iUX8iUX8iUX8iUX8iUY8mRY8mR
Y8mRY8mRY8mRY8mRY8mRY8mRXXiOXhmPY91QY8mRY8iTY8iTXheTXXaSXXePXXePXXePXXePXXePXXeP
XXePXXePYI1SY8mRXhiQXXePXXePXhiQY8mRYI1SXhiQXhiQXhiQXXePXXePXXePXHaOXHaOXhmPXhmP
XhmPXhmPXhmPXhmPXhmPXhmPXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNXX]MXhaNYHiPY8eOXX]MXHYL
XhaNY8eOY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNXX]MXX]MXX]MXX]MXX]MXX]MXX]MXX]MXhaNXhaN
XhaNXhaNXhaNXhaNXhaNXhaNXHaIXXeJXXeJXXeJXhiKXhiKXhiKXhiKXheMXXaLXXaLXH]KXH]KXXaL
XXaLXheMWhYGWhYGX8]HXHaIXHaIX8]HWhYGWhYGWhUIWhUIX8YJX8YJX8YJX8YJWhUIWhUIX8]HX8]H
X8]HX8]HX8]HX8]HX8]HX8]HWhYGX8]HX8]HWhYGWXUFWXUFX8]HXhiKWhYGWhYGWhYGWhYGWhYGWhYG
WhYGWhYGXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaEWXUBWXUBWXUBWXUBWXUBWXUBWXUBWXUBX8]DWhYC
WXUBWXUBWHQAWXUBWXUBWhYCWXUBWXUBWXUBWXUBWXUBWXUBWXUBWXUBXHaEX8]DX8]DWhYCX8]DXHaE
XXeFXhiGWXUBWhYCWhYCWhYCX8]DX8]DX8]DXHaEWXUBX8]DXXeFXHaEX8]DX8]DXHaEXhiGXXeFXHaE
X8]DX8]DX8]DX8]DXHaEXXeFX8]DX8]DX8]DX8]DX8]DX8]DX8]DX8]DXHaEX8]DX8]DX8]DX8]DX8]D
X8]DX8]DX8aCX8aCX8aCX8aCXHeDXHeDXXiEXXiEWhYCWhYCWhYCWhYCWhYCWhYCWhYCWhYCX8]DX8]D
X8]DX8]DX8]DX8]DX8]DX8]DXXeFXXeFXHaEXHaEX8]DX8]DWhYCWhYCXHeDXHeDXHeDXXeFXXaHXXaH
XhaJXhaJYXmGYHiFXXaHXH]KX8]NWh]RXH]WX8aYXYI^WiIdW9QoVI^8Ui^@UY^BV9^BVY^AWYn?X:6A
XZ>CXJ:BX:6AX:6AXZ>CY:FEY:BHY:BHY:BHYJFIYZJJYjNKYZJJYJFIYZFKYjJLZ:NMZZZNZZZNZ:RL
Y:BHXJ6EX:BIXZ:FY:2EZJ6DZJ6DY:2EX:2DW:2EVYf>W9n@WJ2AWJ2AVij?VYf>W9n@WJ2AXYnAXYnA
XYnAY:6CYZ>EYjBFYZ>EY:6CYjBFYjBFZJJHZjRJ[JZL[jbN/JjP/ZnQ]Zn/^;RZZ[>NY:jM`L:ih=O>
dL2[ZIEbXHiKXhiKXhiKY8eKY8eKYXeKYXeKZ8eKYHiLYHiLYHiLYHiLYHiLYHiLYHiLYHiLY8eKY8eK
YHiLYHiLYHiLYXmM002^Vh2]VWn/VGj/V7n/Uh6/Uh6]V8>^VHB/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/
Vh6[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2/Vh6/Vh6[VX2[VX2[VX2ZVGnZVGnZVGnZVGnZVGnZVGnZ
VGnZVGnZVGnZVGnZVGnYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jY
V7jXUgfXUgfXUgfXUgfYV7jYV7jYV7jZVGnYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jY
V7jYV7jYV7jYV7jYV7jXUgbXUgbXUgbXUgbWUW^WUW^WUW^WUW^WUW^WUW^WUW^WUW^WUW^WUW^WUW^W
UW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^XUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVVU7NVU7NWUGRW
UGRWUGRXUWVXUWVXUWVWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRW
UGRVU7NVU7NWUGRWUGRWUGRWUGRVU7NVU7NWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRVU7FVU7FVU7FV
U7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FWUGJVU7FVU7FUTgBUTgBVU7FVU7FW
UGJUTgBUTgBUTgBVU7FVU7FWUGJWUGJWUGJVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FXUG:XUG:XUG:X
UG:XUG:XUG:XUG:XUG:VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2WU76WU76WU76WU76WU76WU76WU76W
U76WU76WU76WU76WU76WU76WU76WU76WU76VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2V
Tg2VTg2VTg2VTg2VTg2UTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnU
TVnTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjST6^ST6^ST6^ST6^ST6^ST6^ST6^ST6^TTfRTTfRSTFRR
T6NRSfVST6^TTFbTTFbST6ZST6ZST6ZST6ZST6ZST6ZST6ZST6ZQT6VQT6VQT6VRSfVTSfVTSfVVSfVV
SfVQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRRSfVRSfVRSfVQ
SVRQSVRQSVRPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNQSVRQSVRQSVRPSFNPSFNPSFNOS6JO
S6JQSVRPSFNPSFNOS6JOS6JPSFNPSFNQSVROSFBOSFBOSFBOSFBOSFBOSFBOSFBOSFBPSVFPSVFPSVFP
SVFPSVFPSVFPSVFPSVFSSFBTSVFTSVFUSfJUSfJTSVFTSVFSSFBRSF2RSF2RSF2SSV6SSV6TSf:TSf:T
Sf:PSVFPSVFPSVFPSVFPSVFPSVFPSVFPSVFTSf:TSf:TSf:TSf:TSf:TSf:TSf:TSf:RSUnSSf2SSf2T
Sf:TSVBSSF>SSFBRS6>RSF2RSF2RSF2RSF2RSF2RSF2RSF2RSF2TSf:SSV6SSV6RSF2RSF2SSV6SSV6T
Sf:SSV6SSV6RSF2RSF2RSF2QS5nQS5nQS5nSSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2QSEjQSEjQSEjQ
SEjQSEjQSEjQSEjQSEjQRUbSS5jTSEnTSEnRRefQRUbRRefTSEnSSEfSSEfSSEfSSEfSSEfSSEfSSEfS
SEfRRefRRefRRefRRefRRefRRefRRefRRefSS5jSS5jSS5jSS5jSS5jSS5jSS5jSS5jPReRPReRPReRQ
S5VQS5VRSEZRSEZRSEZSSEfRS5bQRe^QRe^QRe^QRe^RS5bSSEfNREJORUNPReRPReRPReRPReRORUNN
REJPRUZPRUZOREVOREVOREVOREVPRUZPRUZORUNORUNORUNORUNORUNORUNORUNORUNPReRQS5VQS5VO
RUNMR5FMR5FORUNQS5VNREJNREJNREJNREJNREJNREJNREJNREJPReBPReBPReBPReBPReBPReBPReBP
ReBNRE:NRE:NRE:NRE:NRE:NRE:NRE:NRE:ORU>NRE:NRE:MR56MR56NRE:ORU>ORU>NRE:NRE:NRE:N
RE:NRE:NRE:NRE:NRE:PReBORU>ORU>ORU>ORU>PReBQS5FRSEJNRE:NRE:ORU>ORU>ORU>PReBPReBP
ReBNRE:ORU>QS5FQS5FORU>ORU>PReBRSEJQS5FQS5FPReBORU>ORU>PReBQS5FQS5FPReBPReBPReBP
ReBPReBPReBPReBPReBQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FORe:ORe:PS5>PS5>QSEBQSEBQSEBQ
SEBORU>ORU>ORU>ORU>ORU>ORU>ORU>ORU>QS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQ
S5FPReBPReBPReBORU>PS5>QSEBQSEBQS5FRS5RRS5RRReVRReVSS5ZSS5ZRRe^QRe^ORebPRejOS5nP
SF:PT66NT6JJTFnGTgZEUH>FV8bFVXnHW96FWHRHWhZJXHbKXXfJXHbJXHbLXhjNYI2MX9NNXIROXYVP
XiZOXYVMX9NLWiJJWIBJWY>IWI:JWIBNXIRPXiZOXYVIW9>CUXfNXiBLWi2JV8fKUhbMVHjMVi2HVhbC
V8VPXINQXYRRXiVQXYRPXINQXYRTYI^VYifVYYZUYIVUYIVWYi^ZZYj[ZinYZIfWYi^[Zin/[:2][J6_
[j>a/JFc/jNd]:Re]JV_[:Ra]JVS[YZLYYJj_;KKeM39_J^IS6bQSU^SSU^SSU^TSE^TSE^VSE^VSE^X
SE^TSE^TSE^TSE^TSE^TSE^TSE^TSE^TSE^TSE^TSE^TSE^USUbUSUbUSU`00:fJOjfJOjbIOZ^GOZ^F
P:bGPJfHPjfHPjbKPJbKPJbKPJbKPJbKPJbKPJbKPJbKPJZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOj^J
P:^JP:^JP:^JP:ZIOjZIOjVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZRGOJRGOJRGOJRGOJRG
OJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRG
OJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJVHOJRGO:RGO:NFNjNF
NjJENZJENZFDNJNFNjNFNjNFNjNFNjNFNjNFNjNFNjNFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjRF
NJRFNJRFNJRFNJRFNJRFNJRFNJRFNJJDMjJDMjJDMjNEN:NEN:NEN:RFNJRFNJNEN:NEN:NEN:NEN:NE
N:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:JDMjJDMjNEN:NEN:NEN:NEN:JDMjJDMjNE
N:NEN:NEN:NEN:NEN:NEN:NEN:NEN:JDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJJD
MJJDMJJDMJJDMJNEMZJDMJFCM:FCM:FCM:FCM:JDMJNEMZFCM:FCM:FCM:FCM:JDMJJDMJNEMZNEMZJD
MJJDMJJDMJJDMJJDMJJDMJJDMJJDMJRELZRELZRELZRELZRELZRELZRELZRELZJCL:JCL:JCL:JCL:JC
L:JCL:JCL:JCL:NDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJFB
KjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjBAKZBAKZBAKZBAKZBA
KZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@
Jj>@Jj>@Jj>@Jj>@Jj>@Jj>@Jj>@JjFDJJBCJ:BBJJ>AJ:>@JZBAK:BAK:FBKJ>@JZ>@JZ>@JZ>@JZ>@
JZ>@JZ>@JZ>@JZ6@JJ6@JJ6@JJ:?JJB?JJB?JJJ?JJJ?JJ6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>
J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=
Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Iin<IYn<IYn<IZ2=Ij2=Iin<IYn<IYn<IYn<IZ2=Ij2=Iin=
I9n=I9n=I9n=I9n=I9n=I9n=I9n=I:2>IJ2>IJ2>IJ2>IJ2>IJ2>IJ2>IJ2>IJ>=I:>=I:B>IJF?IZF?
IZB>IJ>=I:>=I:6<Gj:=H::=H::=H:>>HJ>>HJ>>HJB?HZ2>IJ2>IJ2>IJ2>IJ2>IJ2>IJ2>IJ2>IJB?
HZB?HZB?HZB?HZB?HZB?HZB?HZB?HZ:>Gj:>Gj>?H:>>HJ>=Hj>=Hj:<Hj:<Hj6=GZ6=GZ6=GZ6=GZ6=
GZ6=GZ6=GZ6=GZ>>HJ>>HJ:=H::=H::=H::=H:>>HJ>>HJ:=H::=H::=H::=H:6<Gj6<Gj2;GZ2;GZ:>
Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj2<GJ2<GJ2<GJ2<GJ2<GJ2<GJ2<GJ2<GJ6;Fj>=GJB>GZ>=GJ6;
Fj6;Fj:<G:B>GZ:<G::<G::<G::<G::<G::<G::<G::<G:6;Fj6;Fj6;Fj6;Fj6;Fj6;Fj6;Fj6;Fj:<
G::<G::<G::<G::<G::<G::<G::<G9n:Ein:Ein:Ej2;F:2;F:2;F:6<FJ6<FJ:<G::<G:6;Fj2:FZ2:
FZ6;Fj:<G::<G9j9EYj9EYn:Ej2;F:2;F9n:Eij9EYj9EZ6;Fj2:FYj8F9f7Eif7Eij8F:2:FZ6;Fin:
Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ej2;F:6<FJ6<FIn:Eif8EIb7E9j9EZ2;F9j9EYj9EYj9EYj9EYj9
EYj9EYj9EYj9EYn:Din:Din:Din:Din:Din:Din:Din:Dij9DYj9DYj9DYj9DYj9DYj9DYj9DYj9DYj9
DYf8DIf8DIf8DIf8DIj9DYn:Din:Dij9DYj9DYj9DYj9DYj9DYj9DYj9DYj9DYn:Dij9DYj9DYj9DYj9
DYn:Dj2;E:6<EIj9DYj9DYj9DYn:Din:Din:Dj2;E:2;E9f8DIj9DZ2;E:2;E9j9DYj9DZ2;E:6<EJ6<
EJ2;E9n:Din:Din:Din:Dj2;E:6<EJ2;E:2;E:2;E:2;E:2;E:2;E:2;E:2;E:2;E:6<EJ6<EJ6<EJ6<
EJ:=EZ:=EZ:=EYn;DYn;DYn;DZ2<Dj2<Dj2<Dj6=E:6=E:6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<
EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ2;E:2;E:2;E:2;E:2;E:2;E:2;E:2;E:2<Dj2<Dj2<Dj6<EJ6;
Ej:<F::;FJ:;FJ6:G:6:G:6:G:6;Fj6;Fin<FJ2=FZ2=FZ6<F9n;Fi^>HYR>K9JBMYNFPYRIRIVKSi>I
R9FKRYRNSIRNSIRNSIVOSY^QT9fSTYfQUYnSV:>WW:BXWJ>WW:6UVYnSV9nSV9jUV9ZQU9ROTY^QUYnU
VZ6VWIjSVYVNUJ2VTj>VUZ2RUYnOTinOTj2RUYnRTYVOS9VGSI^ISijLTYnMTijLTYjLTYnMTj6OUIjN
TYfMTIjNTZ2PU::RUZ>SUj:RUZ2PU:BTV:FUVJJVVZRXW:ZZWZ^[Wjf]XJf]XK2]Z;BgZ:J_VYfTUK^k
]M_Ed<Jn[IN=Kj2=FZ:=FZ:=FZ><FZ><FZF<FZF<FZN<FZ><FZ><FZ><FZ><FZ><FZ><FZ><FZ><FZ><
FZ><FZB=FjB=FjF>G:F>G000[IYo[9UnZiQmZiMnZiJ0ZiJ0[9N2[IR3ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0
ZiZ0ZiZ0ZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZiZ0ZiZ0ZYUoZYUoZYUoZIQnZIQnZIQnZIQnZIQn
ZIQnZIQnZIQnZIQnZIQnZIQnZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9Mm
Z9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmYiIlYiIlYiIlZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9Mm
Z9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MlZ9MlYiIkYiIkYYEjYYEjYIAiYIAiYiIkYiIkYiIkYiIkYiIkYiIk
YiIkYiIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkYiEhYiEhYiEhYiEhYiEhYiEhYiEhYiEhYI=fYI=f
YYAgYYAgYYAgYiEhYiEhYiEhYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAg
YYAgYYAgYYAgYYAgYiEhYiEhYiEhYiEhYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYI=dYI=d
YI=dYI=dYI=dYI=dYI=dYI=dYI=dYI=dYI=dYI=dYI=dYI=dYI=dYI=dYYAeYYAeYI=dY99cY99cYI=d
YYAeYYAeY99cY99cYI=dYI=dYI=dYYAeYYAeYYAeYI=dYI=dYI=dYI=dYI=dYI=dYI=dYI=dYiAaYiAa
YiAaYiAaYiAaYiAaYiAaYiAaYY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`
YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_
YI9_YI9_YI9_YI9_YI9_YI9_Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^
Y95^Y95^Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1[Xi1[Xi1[Xi1[Xi1[Xi1[Xi1[Xi1[YIAYY9=X
Y99YXi5XXi1ZY95/Y95/YI9]Xi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZX8mXX8mXX8mXXHiXXhiXXhiX
YHiXYHiXX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eW
X8eWX8eWX8eWX8eWXHiXXHiXWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaV
WhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWXaSWXaSWXaSWXaSWXaSWXaSWXaSWXaSWheTWheT
WheTWheTWheTWheTWheTWheTXXaSXheTY8iUY8iUY8iUY8iUXheTXXaSXHaOXHaOXHaOXXePXXePXhiQ
XhiQXhiQWheTWheTWheTWheTWheTWheTWheTWheTXhiQXhiQXhiQXhiQXhiQXhiQXhiQXhiQXHeNXXiO
XXiOXhiQXheSXXaRXXaSXH]RXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNXXePXXePXXePXXePXXePXXeP
XXePXXePXXePXXePXHaOXHaOXHaOX8]NX8]NX8]NXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNX8aMX8aM
X8aMX8aMX8aMX8aMX8aMX8aMX8]HXXeJXhiKXhiKXHaIX8]HXHaIXhiKXXaLXXaLXXaLXXaLXXaLXXaL
XXaLXXaLXHaIXHaIXHaIXHaIXHaIXHaIXHaIXHaIXXeJXXeJXXeJXXeJXXeJXXeJXXeJXXeJWXUFWXUF
WhYGWhYGX8]HX8]HX8]HX8]HXXaLXH]KX8YJX8YJX8YJX8YJXH]KXXaLWHQEWXUFWhYGWhYGWhYGWhYG
WXUFWHQEX8YJWhUIWXQHW8IFW8IFWXQHWhUIX8YJWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFX8]HX8]H
X8]HWhYGW8MDW8MDWHQEWhYGWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWXUBWXUBWXUBWXUBWXUBWXUB
WXUBWXUBWHQAWHQAWHQAWHQAWHQAWHQAWHQAWHQAWHQAW8M@W8M@W8M@W8M@WXUBWhYCWhYCWHQAWHQA
WHQAWHQAWHQAWHQAWHQAWHQAWXUBWXUBWHQAWHQAWHQAWXUBWhYCX8]DWHQAWHQAWXUBWXUBWXUBWhYC
WhYCWhYCW8M@WHQAWhYCWhYCWHQAWHQAWhYCX8]DX8]DX8]DWhYCWXUBWXUBWhYCX8]DX8]DX8]DX8]D
X8]DX8]DX8]DX8]DX8]DX8]DWhYCX8]DX8]DX8]DXHaEXHaEXXeFXXeFWXYAWXYAWh]BWh]BX8aCX8aC
X8aCX8aCXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaEWhYCWhYC
WhYCWhYCWhYCX8]DX8]DX8]DWh]BX8aCX8aCX8]DXH]GXH]GXHYHXX]IWXULWh]LWh]LXH]KXHaIX8]G
X8aEX8aEX8aCWh]DWX]HW8aQVi1ZW9AfW9R0ViZ6V9J<VYR>WI^AWI^AWI^AWYbBX9jDXZ2FXZ:BY:BD
YjNGYJFEX:2@Vi^;VIV9V9R8TYR1SY=nRi1kS91mTiJ6VYf>Wj6EX::FSi5kUiV6WIf?VY^AVibBXJ6C
XJ>@WZ2:X9^<Y9n@Z:>DZjJGZZFFZ:>DZ:>DZ:>DYjJBYZFAYZFAZ:NCZjZF[:^GZZVEZ:NCZZVEZZVE
ZjZF[JbH[ZfI/:nK/K2L/K2L^;FV_KfU/kNJZjfG`kfbgM?9bl2ZXIQfX8eJXXeJXXeJXhaJXhaJYHaJ
YHaJYhaJXhaJXhaJXhaJXhaJXhaJXhaJXhaJXhaJXhaJXhaJXhaJY8eKY8eKY8eK002/VGj/VGj[V7fZ
UWfZUGn[UX2/Uh:/Uh:[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2YV7jYV7jYV7jYV7jYV7jYV7jYV7jY
V7jZVGnZVGnZVGnZVGnYV7jYV7jYV7jXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfWUWbWUWbWUWbW
UWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbXUgfXUgfXUgfWUWbWUWbWUWbVUG^V
UG^WUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUW^WUW^VUGZV
UGZVUGZVUGZVUGZUU7VWUW^WUW^WUW^WUW^WUW^WUW^WUW^WUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^Y
UW^WUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRUTgJUTgJUTgJVU7NVU7NVU7NWUGRWUGRVU7NVU7NVU7NV
U7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NWUGRWUGRWUGRWUGRVU7NV
U7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBU
TgBUTgBUTgBUTgBUTgBVU7FUTgBTTW>TTW>TTW>TTW>UTgBVU7FTTW>TTW>TTW>TTW>UTgBUTgBVU7FV
U7FUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBWU76WU76WU76WU76WU76WU76WU76WU76VTg2VTg2VTg2V
Tg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2V
Tg2TTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjST6fST6fST6fS
T6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fRSfbRSfbRSfbRSfbRSfbRSfbRSfbR
SfbRSfZRSfZRSfZRSfZRSfZRSfZRSfZRSfZTTfRTTfRSTFRRT6NRSfVST6^TTFbTTFbRSfVRSfVRSfVR
SfVRSfVRSfVRSfVRSfVPSfRPSfRPSfRQSVRSSVRSSVRUSVRUSVRPSFNPSFNPSFNPSFNPSFNPSFNPSFNP
SFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNOS6JOS6JOS6JPSFNPSFNPSFNQSVRQSVROS6JOS6JOS6JO
S6JOS6JOS6JOS6JOS6JNRfFNRfFNRfFNRfFOS6JOS6JOS6JPSFNNRfFNRfFOS6JPSFNPSFNOS6JNRfFN
RfFNS6>NS6>NS6>NS6>NS6>NS6>NS6>NS6>OSFBOSFBOSFBOSFBOSFBOSFBOSFBOSFBRS6>RS6>SSFBT
SVFTSVFSSFBRS6>RS6>QS5nQS5nQS5nQS5nRSF2RSF2RSF2SSV6OSFBOSFBOSFBOSFBOSFBOSFBOSFBO
SFBSSV6SSV6SSV6SSV6SSV6SSV6SSV6SSV6QSEjQSEjRSUnSSV6SSF>RS6:QRf:QRf:PS5bPS5bPS5bP
S5bPS5bPS5bPS5bPS5bQS5nQS5nRSF2SSV6SSV6RSF2QS5nQS5nQS5nQS5nQS5nQS5nPRejPRejPRejO
RUfPS5fPS5fPS5fPS5fPS5fPS5fPS5fPS5fORebORebORebORebORebORebORebORebPReRRSEZSSU^R
SEZPReRPReRQS5VSSU^QRe^QRe^QRe^QRe^QRe^QRe^QRe^QRe^PReRPReRPReRPReRPReRPReRPReRP
ReRQS5VQS5VQS5VQS5VQS5VQS5VQS5VQS5VORUNORUNORUNORUNPReRPReRQS5VQS5VQRe^QRe^PRUZO
REVOREVPRUZQRe^QRe^MR5FNREJNREJORUNORUNNREJNREJMR5FOREVNR5RNR5RMQeNMQeNNR5RNR5RO
REVNREJNREJNREJNREJNREJNREJNREJNREJNREJORUNORUNNREJLQeBLQeBMR5FPReRMR5FMR5FMR5FM
R5FMR5FMR5FMR5FMR5FMR56MR56MR56MR56MR56MR56MR56MR56MR56MR56MR56MR56MR56MR56MR56M
R56LQe2KQTnKQTnKQTnLQe2MR56ORU>PReBMR56MR56MR56MR56MR56MR56MR56MR56MR56MR56LQe2L
Qe2LQe2MR56NRE:ORU>MR56MR56MR56NRE:NRE:NRE:ORU>ORU>KQTnMR56NRE:NRE:LQe2LQe2NRE:O
RU>PReBORU>ORU>NRE:NRE:ORU>ORU>PReBPReBPReBPReBPReBPReBPReBPReBPReBMR56NRE:NRE:O
RU>PReBQS5FQS5FQS5FNRU6NRU6NRU6ORe:ORe:PS5>PS5>PS5>NRE:NRE:NRE:NRE:NRE:NRE:NRE:N
RE:ORU>ORU>ORU>ORU>ORU>ORU>ORU>ORU>NRE:NRE:NRE:ORU>ORU>ORU>PReBPReBORe:ORe:ORe:P
ReBPRUJQReNQRURQRURKRUVLReZNRUZOS5VPReRPRUJOREFORU>OReBPS5>QS5FQS5RQSf2PTVRNU7:M
UGNOU8JQUXRSV8ZSV8ZSV8ZSV8ZUVXbWW8jUWX>TWH:PVGjESW>5OV=hLEI`JDi^Ida7Ab=5A293@B94
@RA:Ab]EDCUPFdIXHdj2OVF?RgRGUXRLVY:TXYZ[ZYbZYY>QWHBYWhN/XXZ`YXjbZ92`YXj_YHf^Y8b_
YHfbZ8ZaYhVaYhVcZH^f[8jg[HneZhfcZH^_YHN`YXRaYhVbZ8ZcZH^dZXbeZhff[8j_YhZaZhJ^Z7nY
X7neYi74/j2gZXZPUFVOS5VQS5VQS5VRReVRReVTReVTReVVReVRReVRReVRReVRReVRReVRReVRReVR
ReVRReVSS5ZSS5ZSS5ZTSE^TSE/00:bIOZ^HOJ^HOJZFOJZEOj^FP:^FPJbGPZZIOjZIOjZIOjZIOjZI
OjZIOjZIOjZIOjVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZZIOjZIOjZIOjVHOZVHOZVHOZRGOJRGOJRG
OJRGOJRGOJRGOJRGOJRGOJRGOJRGOJNFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NF
O:NFO:NFO:NFO:RGOJRGOJRGOJNFO:NFO:JENjJENjFDNZNFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NF
O:NFO:NFO:NFO:NFO:NFO:NFO:NFO:FDNJFDNJFDNJJENZJENZJENZJENZJENZNFNjNFNjNFNjNFNjNF
NjNFNjNFNjNFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjNEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:BB
MJFCMZFCMZFCMZJDMjJDMjJDMjNEN:FCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFC
MZFCMZFCMZFCMZJDMjJDMjNEN:NEN:NEN:NEN:JDMjJDMjFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZBB
LjBBLjBBLjBBLjBBLjBBLjBBLjBBLjBBLjBBLjBBLjBBLjBBLjBBLjBBLjBBLjFCM:FCM:BBLj>ALZ>A
LZBBLjFCM:FCM:>ALZ>ALZBBLjBBLjFCM:FCM:FCM:FCM:BBLjBBLjBBLjBBLjBBLjBBLjBBLjBBLjJC
L:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:FBKjFBKjFBKjFBKjFB
KjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBA
KZBAKZBAKZBAKZBAKZBAKZBAKZBAKZ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@
KJ>@KJ>@KJ>@KJ:?K::?K::?K::?K::?K::?K::?K::?K::?JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZ>B
Ij>BIj:@Ij6?IZ6>J::?JZ>@Jj>@Jj:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ2?J:2?J:2?J:6>J:>>
J:>>J:F>J:F>J9n<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYj;
IIj;IIn<IYn<IZ2=Ij2=Ij6>J:6>J9j;IIj;IIj;IIj;IIj;IIj;IIj;IIj;IIf:I9f:I9j;IIj;IIn<
IYn<IZ2=Ij2=Iif:I9j;IIn<IZ2=Ij2=Iin<IYj;IIf:I9f;HYf;HYf;HYf;HYf;HYf;HYf;HYf;HYj<
Hij<Hij<Hij<Hij<Hij<Hij<Hij<Hj6;HZ:<Hj>=I:>=I:>=I:>=I::<Hj6;HZ2;GZ2;GZ6<Gj6<Gj6<
Gj:=H::=H::=H9j<Hij<Hij<Hij<Hij<Hij<Hij<Hij<Hj:=H::=H::=H::=H::=H::=H::=H::=H:2<
GJ6=GZ:>Gj:=H::<HZ:<HZ6;HZ2:HJ2<G:2<G:2<G:2<G:2<G:2<G:2<G:2<G:2;GZ6<Gj:=H:>>HJ>>
HJ:=H:6<Gj2;GZ6<Gj6<Gj6<Gj2;GZ2;GZ2;GYn:GIn:GIn;G9n;G9n;G9n;G9n;G9n;G9n;G9n;G9n;
G9n;G9n;G9n;G9n;G9n;G9n;G9n;G:2;Ej6<F:>>FZ:=FJ2;Ein:EZ6<F::=FJ2:FZ2:FZ2:FZ2:FZ2:
FZ2:FZ2:FZ2:FZ2;Ej2;Ej2;Ej2;Ej2;Ej2;Ej2;Ej2;Ej6<F:6<F:6<F:6<F:6<F:6<F:6<F:6<F9n:
Ein:Ej2;F:2;F:6<FJ6<FJ6<FJ6<FJ6;Fj2:FYn9FIn9FIn9FIn9FJ2:FZ6;Fif8EIf8EIj9EYn:Ein:
Eij9EYf8EIf8EIf7Eif7Eij8F9j8F9j8F9j8F9f7Eif7Eij9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYf8
EIj9EYj9EYf8EIb7E9b7E9j9EZ6<FIb7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7D9b7D9b7D9b7D9b7
D9b7D9b7D9b7D9b7D9b7D9b7D9b7D9b7D9b7D9b7D9b7D9^6Ci^6Ci^6Ci^6Cib7D9f8DIn:Dj2;E9b7
D9b7D9b7D9b7D9b7D9b7D9b7D9b7D9b7D9b7D9^6Ci^6Cib7D9f8DIj9DYj9DYb7D9f8DIf8DIf8DIj9
DYj9DYj9DYn:DiZ5CYb7D9f8DIf8DIb7D9^6Cif8DIn:Dj2;E9n:Dij9DYj9DYj9DYj9DYn:Dj2;E:2;
E:2;E:2;E:2;E:2;E:2;E:2;E:2;E9b7D9b7D9f8DIj9DYn:Din:Dj2;E:6<EIj:DIj:DIj:DIj:DIn;
DYn;DYn;DZ2<Dif8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIj9DYj9DYj9DYj9DYj9DYj9DYj9DYj9DYf8
DIf8DIj9DYj9DYn:Din:Dj2;E:2;E9n;DYn;DYn;DZ2;E:2:EZ2:EZ6:F:6:F9V;EY^;EYb<Ein=F:2;
Ej29Ej27EIn6E9Z:EIn;E::<DZF=DjF>EZ>>Fin?HIf?IJ2?KZ:AL:BCLZ>BLJ:AL::AL:BCLZJEM::B
KJ:BKIf=J920Fh1`Bg=S?VeM>6eM>6iY>6mY>VmY?6iV?ViU?gE[BH5fEX^0HYV@MJ:KQjbVVK>`Z<:o
]lc6^KjgXjVPQIZ<J9Z<J9Z<J9V;IiN9IIN9IIZ<J9f?Jin?IIj>I9n?IJ6AIj>CJJBDJZ>CJJ6AIi^;
HIb<HYf=Hij>I9n?IJ2@IZ2@IZ6AIj6AIj2BHJ2BGZ6>HJ><K:B<KZ2<Hi^<E9n<FJ6<FJ6<FJ:;FJ:;
FJB;FJB;FJJ;FJ6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:F::;FJ:;FJ><FZ><FZ><FZB=F`00[9UnZiQm
ZiQmZYImZYEoZiJ0ZiJ1[9N2ZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZIQnZIQnZIQnZIQnZIQnZIQn
ZIQnZIQnZYUoZYUoZIQnZIQnZIQnZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmYiIlYiIl
YiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlZ9MmZ9MmZ9MmYiIlYYEkYYEk
YIAjYIAjYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlY9=hY9=h
YIAiYIAiYYEjYYEjYiIkYiIkYiIkYiIkYiIkYiIkYiIkYiIkYiIkYiIkZIIkZIIkZIIkZIIkZIIkZIIk
ZIIkZIIkYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgY99eY99eYI=fYI=fYI=fYYAgYYAgYYAgYI=fYI=f
YI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYYAgYYAgYiEhYiEhYiEhYiEh
YYAgYYAgYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fY99cY99cY99cY99cY99cY99cY99cY99cY99cY99c
Y99cY99cY99cY99cY99cY99cYI=dYI=dY99cXi5bXi5bY99cYI=dYI=dXi5bXi5bY99cY99cY99cYI=d
YI=dYI=dY99cY99cY99cY99cY99cY99cY99cY99cYY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`
YY=`YY=`YY=`YY=`YY=`YY=`YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_
YI9_YI9_Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Xi1]Xi1]
Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]XXm/XXm/XXm/XXm/XXm/XXm/
XXm/XXm/XXmZXXmZXXmZXXmZXXmZXXmZXXmZXXmZXY5VXY5VXHmVX8iUX8eWXHiYXXmZXXmZXXmYXXmY
XXmYXXmYXXmYXXmYXXmYXXmYWhiWWhiWWhiWX8eWXXeWXXeWY8eWY8eWWhaVWhaVWhaVWhaVWhaVWhaV
WhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWX]UWX]UWX]UWhaVX8eWX8eWXHiXXHiXWX]UWX]U
WX]UWX]UWX]UWX]UWX]UWX]UW8USWHYTWHYTWX]UWX]UWhaVX8eWX8eWW8USWHYTWhaVX8eWX8eWWhaV
WHYTW8USWH]RWH]RWH]RWH]RWH]RWH]RWH]RWH]RWXaSWXaSWXaSWXaSWXaSWXaSWXaSWXaSXH]RXXaS
XheTXheTXheTXheTXXaSXH]RX8]NX8]NX8]NXHaOXHaOXXePXXePXXePWXaSWXaSWXaSWXaSWXaSWXaS
WXaSWXaSXXePXXePXXePXXePXXePXXePXXePXXePX8aMXHeNXHeNXXePXXaRXH]QXH]RX8YQX8eJX8eJ
X8eJX8eJX8eJX8eJX8eJX8eJWhYMX8]NXXePXhiQXhiQXXePX8]NWhYMXHaOXHaOX8]NX8]NX8]NWhYM
WhYMWhYMWh]LWh]LWh]LWh]LWh]LWh]LWh]LWh]LWh]LWh]LWh]LWh]LWh]LWh]LWh]LWh]LWhYFXHaH
XXeIXXeIX8]GWhYFX8]GXXeIX8YJX8YJX8YJX8YJX8YJX8YJX8YJX8YJX8]GX8]GX8]GX8]GX8]GX8]G
X8]GX8]GXHaHXHaHXHaHXHaHXHaHXHaHXHaHXHaHX8]HX8]HX8]HXHaIXHaIXXeJXXeJXXeJXH]KX8YJ
WhUIWhUIWhUIWhUIX8YJXH]KW8MDWHQEWXUFWXUFWXUFWXUFWHQEW8MDVhEEWHMGWXQHWhUIWhUIWXQH
WHMGVhEEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEVhICWHQEWXUFWHQEW8MDW8MDWhYGXHaIW8MDW8MD
W8MDW8MDW8MDW8MDW8MDW8MDW8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@
W8M@W8M@VXE>VXE>VXE>VhI?W8M@WHQAWhYCX8]DW8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@
VhI?VhI?VhI?W8M@WHQAWXUBW8M@W8M@WHQAWHQAWHQAWXUBWXUBWXUBVXE>VhI?WHQAWHQAVhI?VhI?
WHQAWXUBWhYCWhYCWXUBWHQAWHQAWXUBWhYCWhYCX8]DX8]DX8]DX8]DX8]DX8]DX8]DX8]DVXE>VhI?
W8M@WHQAWXUBWhYCWhYCX8]DWHU@WXYAWXYAWXYAWh]BWh]BWh]BWh]BX8]DX8]DX8]DX8]DX8]DX8]D
X8]DX8]DWHQAWHQAWHQAWHQAWHQAWHQAWHQAWHQAWHQAWHQAWHQAWXUBWhYCWhYCX8]DX8]DWXYAWh]B
Wh]BWhYCX8YFX8YFX8UGXHYHV8aBVHeCW8eEWheHX8]GWhQFWhEFX8AEUhUHW8YEXXaBYXe?Z8a@YHaD
X8]HWXYKW8UFWX]HWhaIWhaIWHYGWHYGWX]HX8eJW8MJX8]NXhiQXHaOWHQKW8MJX8]NYI1SVi1GWi=M
X9=OVheMUHIHUHEKWhiWZ9IaX9AhYIZ4ZJ6D/jfVal6jc/Ji]Z^EThM[WXiSW8aQV8QMTh=HTH5FU8AI
VXYOWhmTXH]KX8YJXH]KXheMYHmOYY1PYHmOXheMX8YJX8YJXH]KXXaLXheMY8iNYHmOYHmOXheMXHiE
Xi1CYhmKXhIOW7mJW8EEXi1CWhaIXHaIXHaIXX]IXX]IY8]IY8]IYX]IXHYHXHYHXHYHXHYHXHYHXHYH
XHYHXHYHXX]IXX]IXX]IXhaJXhaJXhaJ002[Ugj[Ugj[Ugj[Ugj[Ugj[Ugj[Ugj[UgjYV7jYV7jZVGnZ
VGnZVGn[VX2[VX2[VX2YV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jXUgfXUgfXUgfXUgfXUgfXUgfXUgfX
UgfZVGnYV7jYV7jXUgfXUgfWUWbWUWbVUG^WUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUW^WUW^WUW^W
UW^WUW^WUW^WUW^WUW^WUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbW
UWbVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZV
UGZVUGZVUGZVUGZVUGZWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRW
UGRUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJTTWFUTgJUTgJU
TgJVU7NVU7NVU7NWUGRSTGBTTWFUTgJUTgJUTgJUTgJTTWFSTGBVU7FVU7FUTgBTTW>TTW>UTgBVU7FV
U7FSTG:STG:TTW>TTW>UTgBUTgBUTgBUTgBTTWFTTWFTTWFTTWFTTWFTTWFTTWFTTWFTTW>TTW>TTW>T
TW>TTW>TTW>TTW>TTW>STG:STG:TTW>TTW>UTgBUTgBUTgBUTgBTTW>TTW>TTW>TTW>TTW>TTW>TTW>T
TW>VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2UTVnUTVnUTVnU
TVnUTVnUTVnUTVnUTVnTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjT
TFjSTFbSTFbSTFbSTFbSTFbSTFbSTFbSTFbSTFbSTFbSTFbSTFbSTFbSTFbSTFbSTFbTTFjST6fST6fR
SfbRSfbQSV^PSFZPSFZST6fST6fST6fST6fST6fST6fST6fST6fRSfZRSfZRSfZRSfZRSfZRSfZRSfZR
SfZQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVROS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JNRfFOS6JOS6JO
S6JPSFNPSFNPSFNQSVRPSfRPSfROSVNPSFNQS6JQS6JRRfFRRfFNRfFNRfFNRfFNRfFNRfFNRfFNRfFN
RfFMRVBMRVBMRVBMRVBMRVBMRVBMRVBMRVBNRfFNRfFNRfFNRfFNRfFNRfFNRfFNRfFSSFBSSFBSSFBS
SFBSSFBSSFBSSFBSSFBPSVFPSVFOSFBOSFBNS6>MRf:MRf:MRf:QRf:QRf:QRf:QRf:QRf:QRf:QRf:Q
Rf:PRV6PRV6PRV6QRf:RS6>RS6>SSFBSSFBRSUnRSUnRSUnQS5nQRf6QRf6QRf:QRf:NRU^ORebORebP
S5fPS5fQSEjQSEjRSUnQS5nQS5nPRejPRejPRejPRejORUfORUfQRf6QRf6QRf6QRf6QRf6QRf6QRf6Q
Rf6RSF2RSF2QS5nPRejPRejORUfORUfNREbNRU^NRU^NRU^ORebORebPS5fPS5fPS5fPS5fORebORebN
RU^NRU^ORebORebPS5fORebORebORebORebORebORebORebORebLR5VLR5VMREZNRU^NRU^ORebORebO
RebQRe^PRUZNR5ROREVQRe^QRe^PRUZOREVQRURQRURQRURQRURQRURQRURQRURQRURORUNORUNORUNO
RUNORUNORUNORUNORUNORUNORUNORUNORUNORUNORUNORUNORUNORUNORUNORUNORUNORUNORUNORUNO
RUNPReRPReRPReRPReRPReRPReRPReRPReRNREJORUNORUNPReRPReRQS5VQS5VRSEZORUNORUNORUNN
REJMR5FMR5FLQeBLQeBNREJNREJNREJNREJNREJNREJNREJNREJLQeBLQeBLQeBLQeBLQeBLQeBLQeBL
QeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQE>LQE>LQE>LQE>LQE>LQE>LQE>LQE>JRE6LR56MRE:N
RE:MR56NQU2MQDnNQ4jNRE:NRE:MR56MR56LQe2KQTnKQTnKQTnORU>LQe2JQDjKQTnNRE:ORU>MR56J
QDjKQTnKQTnLQe2LQe2MR56MR56MR56MR56PS5>ORe:MRE2KQdjJQTfKQdjLR4nLR4nLQe2LQe2LQe2L
Qe2LQe2LQe2LQe2LQe2MR56MR56MR56MR56MR56MR56MR56MR56LQE>LQE>LQE>LQE>LQE>LQE>LQE>L
QE>KQTnKQTnKQTnLQe2MR56MR56NRE:NRE:ORe:ORe:NRU6NRU6MRE2MRE2LR4nLR4nMRE2MRE2MRE2M
RE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2LR4nMRE2MRE2MRE2NRU6NRU6NRU6O
Re:NRE:MR56LQe2KQTnLQe2MR56ORU>PReBLQe2LQe2MR56MR56NRE:NRE:ORU>ORU>MRE2MRE2MRE2M
RE2MRE2MRE2MRE2MRE2PReBORU>NRE:NRE:NRE:NRE:ORU>PReBQRURQRURQRURQRURQRURQRURQRURQ
RURSSUNRSEJRSEJQS5FQS5FPReBPReBORU>SS5ZQRUROR5JNQeFNQeFPRENSS5ZUSUbOTFfRU72/WWZj
[8S3]I6l[XZWVGFEQf>KREBQSU^OS5VHQ5BOReb]VFZ`VfjWTVFQRURQRURQRURRReVRReVSS5ZSS5ZS
S5ZRReVRReVSS5ZSS5ZSS5ZTSE^TSE^TSE^QRURPRENPRENPRENPRENQRURRReVSS5ZORU>ORU>PReBQ
S5FQS5FRSEJRSEJRSEJSSUNRSEJRSEJQS5FQS5FPReBORU>ORU>SReFSReFSReFSReFSReFSReD00:^G
OZ^GOZ^GOZ^GOZ^GOZ^GOZ^GOZ^GOZVHOZVHOZVHOZZIOjZIOj^JP:^JP:^JP:VHOZVHOZVHOZVHOZVH
OZVHOZVHOZVHOZRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJVHOZVHOZVHOZRGOJNFO:NFO:NFO:JENjNF
O:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFNjNFNjNFNjNFNjNFNjNFNjNFNjNFNjNFO:NFO:NFO:NFO:NF
O:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:JENZJENZJENZJENZJENZJENZJENZJENZJE
NZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJDMjJDMjJDMjJDMjJD
MjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFC
MZFCMZFCMZFCMZFCMZFCMZFCMZFCMZBBMJBBMJFCMZFCMZFCMZJDMjJDMjJDMj>AM:BBMJFCMZFCMZFC
MZFCMZBBMJ>AM:JDMJJDMJFCM:BBLjBBLjFCM:JDMJJDMJ>ALZ>ALZBBLjBBLjBBLjFCM:FCM:FCM:BB
MJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBLjBBLjBBLjBBLjBBLjBBLjBBLjBBLj>ALZ>ALZBBLjBBLjBB
LjFCM:FCM:FCM:BBLjBBLjBBLjBBLjBBLjBBLjBBLjBBLjJCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JC
L:JCL:JCL:JCL:JCL:JCL:JCL:JCL:FBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjBAKZBAKZBAKZBAKZBA
KZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZ>AK:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>A
K:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>@KJ>@KJ:?K::?K:6>Jj6>Jj2=JZ2=JZ:?K::?K::?K::?K::?
K::?K::?K::?K::?JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZ2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Iin<
IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYj;IIj;IIn<IYn<IYn<IZ2=Ij2=Ij2=Ij2?J9n>Iin>Ij2=Ij6<
IZ2;IJ:;IJ:;IIj;IIj;IIj;IIj;IIj;IIj;IIj;IIj;IIf:I9f:I9f:I9f:I9f:I9f:I9f:I9f:I9j;
IIj;IIj;IIj;IIj;IIj;IIj;IIj;IJ:<Hj:<Hj:<Hj:<Hj:<Hj:<Hj:<Hj:<Hin=I9n=I9n=I9j<Hij<
Hif;HYf;HYf;HZ6;HZ6;HZ6;HZ6;HZ6;HZ6;HZ6;HZ6;HZ2:HJ2:HJ2:HJ6;HZ6;HZ:<Hj:<Hj:<Hj6=
GZ6=GZ6=GZ6<Gj6;HJ6;HJ6;HZ6;HYn;G9n;G:2<GJ2<GJ2<GJ2<GJ2<GJ6=GZ:=H::=H::=H:6<Gj6<
Gj6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj2;GZ2;GYn:GIn:GIj9G9j:
Fij:Fij:Fin;G9n;G9n;G:2<GJ2<GJ2<GIn;G9j:Fij:Fij:Fij:Fin;G:2<GIn;G9n;G9n;G9n;G9n;
G9n;G9n;G9n;G9f9FYf9FYf9FYj:Fij:Fij:Fij:Fij:Fj6;Fin9FIj8F9n9FJ6;Fj6;Fj2:FYj8F:6:
F:6:F:6:F:6:F:6:F:6:F:6:F:6:F9n:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:
Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ej2;F:2;F:2;F:2;F:2;F:2;F:2;F:2;F9j9
EYj9EYn:Ein:Ej2;F:2;F:6<FJ6<FIn:Ein:Eij9EYj9EYf8EIf8EIb7E9b7E9f8EIf8EIf8EIf8EIf8
EIf8EIf8EIf8EIb7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b5
Dib5Dib5Dib5Dib5Dib5Dib5Dib5DiZ9DIb8DIb8DIf8DIf8DIj6D9f5Cij4CYf8DIf8DIf8DIb7D9b7
D9b7D9b7D9b7D9j9DYb7D9Z5CY^6Cif8DIj9DYf8DIZ5CY^6Ci^6Cib7D9b7D9b7D9f8DIf8DIf8DIn;
DYj:DIb8Ci^7CYZ6CI^7CYb8Cib8Cib7D9b7D9b7D9b7D9b7D9b7D9b7D9b7D9f8DIf8DIf8DIf8DIf8
DIf8DIf8DIf8DIb5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib7D9b7D9b7D9b7D9b7D9f8DIf8DIf8DIn;
DYj:DIj:DIj:DIf9D9b8Cib8Cib8Cif9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9
D9f9D9f9D9f9D9b8Cib8Cif9D9f9D9f9D9j:DIj:DIj:DIj9DYf8DIb7D9b7D9b7D9f8DIn:Dj2;E9b7
D9b7D9b7D9f8DIj9DYj9DYj9DYn:Dif9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9n:Din:Dij9DYf8DIf8
DIj9DYn:Din:Dj6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:F::=EZ:=EZ6<EJ6<EJ2;E:2;E9n:Din:Dj:;
FJ6:F9n8EYj7EIj7EJ29Ej:;FJB=Fif<II^:Hi^:Hj6@JJNFKjJEKYj=IYJ5GZ2;EjB?Fj:=FY^5EIn9
FJ^DIZbEIjB=H:6:F:6:F:6:F:6:F::;FJ:;FJ><FZ><FZ:;FJ:;FJ:;FJ><FZ><FZ><FZB=FjB=Fj6:
F:29Ej29Ein8EZ29Ej6:F::;FJ><FZ2;E:2;E:2;E:6<EJ6<EJ6<EJ6<EJ6<EJ:=EZ:=EZ6<EJ6<EJ2;
E:2;E9n:Din:Dj>;EJ>;EJ>;EJ>;EJ>;EJ>;E@00ZiMnZiMnZiMnZiMnZiMnZiMnZiMnZiMnZIQnZIQn
ZIQnZIQnZYUoZYUoZiZ0ZiZ0ZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnYiIlYiIlYiIlYiIlYiIlYiIl
YiIlYiIlZ9MmZ9MmZ9MmZ9MmYiIlYiIlYiIlYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEjYYEj
YYEjYYEjYYEjYYEjYYEjYYEjYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEk
YYEkYYEkYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAi
YIAiYIAiYIAiYIAiYIAiYIAiYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAg
YYAgYYAgYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fY99eY99e
Y99eYI=fYI=fYYAgYYAgYYAgXi5dXi5dY99eYI=fYI=fY99eXi5dXi5dYYAeYI=dYI=dY99cY99cYI=d
YI=dYYAeXi5bXi5bXi5bY99cY99cY99cYI=dYI=dY99eY99eY99eY99eY99eY99eY99eY99eY99cY99c
Y99cY99cY99cY99cY99cY99cXi5bXi5bXi5bY99cY99cY99cYI=dYI=dY99cY99cY99cY99cY99cY99c
Y99cY99cYY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_
YI9_YI9_YI9_YI9_YI9_YI9_Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^
Y95^Y95^XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XXm/XXm/
XXm/XXm/XHi[XHi[XHi[X8eZXHi[XHi[XHi[XHi[XHi[XHi[XHi[XHi[XHiYXHiYXHiYXHiYXHiYXHiY
XHiYXHiYX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWX]UWX]U
WX]UWhaVWhaVX8eWX8eWX8eWWhiWWhiWWXeVWhaVXHaVX8]UXX]UXX]UWX]UWX]UWX]UWX]UWX]UWX]U
WX]UWX]UWHYTWHYTWHYTWHYTWHYTWHYTWHYTWHYTWX]UWX]UWX]UWX]UWX]UWX]UWX]UWX]UX8YQX8YQ
X8YQX8YQX8YQX8YQX8YQX8YQWXaSWXaSWXaSWXaSWH]RWH]RWH]RW8YQXH]RXH]RXH]RXH]RXH]RXH]R
XH]RXH]RX8YPX8YPX8YPX8YPXH]QXH]QXH]QXXaRX8aMX8aMX8aMX8]NX8YPX8YPX8YQX8YQX8aMX8aM
X8aMX8aMWh]LWh]LWh]LWh]LXXePXXePXXePXXePXXePXXePXXePXXePX8]NX8]NX8]NX8]NX8]NX8]N
X8]NX8]NXHaOX8]NX8]NX8]NWhYMWhYMWhYMWhYMWHUJWXYKWXYKWXYKWh]LWh]LWh]LWh]LWh]LWh]L
WXYKWHUJWHUJWXYKWh]LWh]LWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXYKWHUJWHUJWHUJ
WHUJWHUJXH]KWhUIWXQHWXQHX8YJXH]KX8YJWXQHX8UGX8UGX8UGX8UGX8UGX8UGX8UGX8UGWXUFWXUF
WXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUF
WXUFWXUFWhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGWXUFWXUFWXUFWhYGWhYGWhYGX8]HX8]HWXUFWXUF
WXUFWHQEWHQEWHQEW8MDW8MDWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEW8MDW8MDW8MDW8MDW8MDW8MD
W8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8ECW8ECW8ECW8ECW8ECW8ECW8ECW8ECVHQ@VhM@
W8QAWHQAWHQAWXI@WHE?WXA>VhI?VhI?VhI?W8M@W8M@W8M@W8M@W8M@WHQAW8M@VXE>VhI?WHQAWHQA
W8M@VhI?VhI?VhI?VhI?W8M@W8M@W8M@WHQAWHQAWXYAWHU@W8Q?VhM>VhM>VhM>VhM>W8Q?W8M@W8M@
W8M@W8M@W8M@W8M@W8M@W8M@WHQAWHQAWHQAWHQAWHQAWHQAWHQAWHQAW8IBW8IBW8IBW8IBW8IBW8IB
W8IBW8IBW8M@W8M@W8M@W8M@W8M@VhI?VhI?VhI?WXYAWXYAWHU@WHU@WHU@W8Q?W8Q?W8Q?WHU@WHU@
WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@W8Q?W8Q?W8Q?WHU@WHU@WXYA
WXYAWXYAWHQAW8M@W8M@W8M@W8M@WHQAWXUBWhYCW8M@W8M@W8M@WHQAWHQAWHQAWXUBWXUBWHU@WHU@
WHU@WHU@WHU@WHU@WHU@WHU@WhYCWXUBWXUBWHQAWHQAWXUBWXUBWhYCX8YFX8YFX8YFX8YFX8YFX8YF
X8YFX8YFXHaEXHaEX8]DX8]DX8]DWhYCWhYCWhYCXHYHX8UGWXMEWXMEWXMEX8UGXX]IXhaJWhYMW8MJ
VHAGVHAGW8MJWXULWhYMWXULXHaHYI1LXXeIVhICWHMGYHmOYXmQWhQJX8UGX8UGX8UGXHYHXHYHXX]I
XX]IXX]IXHYHXHYHXX]IXX]IXX]IXhaJXhaJXhaJX8UGX8UGWhQFWhQFX8UGX8UGXX]IXX]IXHaEXHaE
XHaEX8]DX8]DX8]DX8]DX8]DXHaEXHaEXHaEXHaEX8]DX8]DX8]DWhYCXXYDXXYDXXYDXXYDXXYDXXYD
002ZUWfZUWfZUWfZUWfZUWfZUWfZUWfZUWfXUgfXUgfYV7jYV7jYV7jZVGnZVGnZVGnXUgfXUgfXUgfX
UgfXUgfXUgfXUgfXUgfWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbW
UWbVUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUGZVUGZVUGZVUGZVUGZVUGZVUGZVUGZVUG^VUG^VUG^V
UG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^UU7VUU7VUU7VUU7VUU7VUU7VUU7VU
U7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VVU7NVU7NVU7NV
U7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NUTgJUTgJUTgJUTgJUTgJUTgJUTgJU
TgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJSTGBTTWFTTWFTTWFUTgJUTgJUTgJVU7NRT7>STGBTTWFT
TWFTTWFTTWFSTGBRT7>UTgBUTgBTTW>TTW>TTW>TTW>UTgBUTgBRT76RT76STG:STG:TTW>TTW>TTW>T
TW>STGBSTGBSTGBSTGBSTGBSTGBSTGBSTGBSTG:STG:STG:STG:STG:STG:STG:STG:RT76RT76STG:S
TG:TTW>TTW>TTW>TTW>STG:STG:STG:STG:STG:STG:STG:STG:UTVnUTVnUTVnUTVnUTVnUTVnUTVnU
TVnTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjST6fST6fST6fS
T6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fRT6^RT6^RT6^RT6^RT6^RT6^RT6^R
T6^RT6^RT6^RT6^RT6^RT6^RT6^RT6^RT6^QSV^QSV^QSV^QSV^QSV^QSV^QSV^QSV^PSFZPSFZPSFZP
SFZPSFZPSFZPSFZPSFZQSVVQSVVQSVVQSVVQSVVQSVVQSVVQSVVPSFNPSFNPSFNPSFNPSFNPSFNPSFNP
SFNOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JMRVBNRfFNRfFNRfFOS6JOS6JOS6JPSFNNSFJNSFJNSFJO
S6JPRfFPRfFRRfFRRfFMRVBMRVBMRVBMRVBMRVBMRVBMRVBMRVBLRF>LRF>LRF>LRF>LRF>LRF>LRF>L
RF>MRVBMRVBMRVBMRVBMRVBMRVBMRVBMRVBORF2ORF2ORF2ORF2ORF2ORF2ORF2ORF2MRf:MRf:MRf:M
Rf:LRV6LRV6LRV6LRV6PRV6PRV6PRV6PRV6PRV6PRV6PRV6PRV6PRV2PRV2PRV2PRV2PRV2PRV2QRf6Q
Rf6ORebORebORebORUfOREnPRV2PRV6PRV6QSEjPS5fPS5fORebORebNRU^NRU^NRU^PRejPRejQS5nQ
S5nQS5nQS5nRSF2RSF2ORebORebORebORebORebORebORebORebORUfORUfORUfORUfORUfORUfORUfO
RUfMREZMREZMREZNRU^NRU^ORebORebORebORebNRU^NRU^MREZMREZNRU^NRU^ORebNRU^NRU^NRU^N
RU^NRU^NRU^NRU^NRU^NRU^NRU^NRU^MREZMREZLR5VLR5VKQeRPRUZOREVMQeNNR5RPRUZPRUZOREVN
R5RPRENPRENPRENPRENPRENPRENPRENPRENNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJN
REJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJORUNORUNORUNORUNORUNORUNORUNO
RUNNREJNREJNREJNREJNREJNREJNREJNREJMR5FMR5FMR5FMR5FMR5FLQeBLQeBLQeBMR5FMR5FMR5FM
R5FMR5FMR5FMR5FMR5FLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBL
QeBKQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:HQdnJQTnKQe2LQe2LQe2NQU2MQDnNQ4jJQDjJQDjJQDjK
QTnLQe2LQe2MR56MR56LQe2KQTnKQTnKQTnLQe2LQe2KQTnKQTnJQDjJQDjKQTnKQTnLQe2LQe2LQe2L
Qe2LR4nLR4nKQdjKQdjKQdjKQdjKQdjKQdjKQTnKQTnKQTnKQTnKQTnKQTnKQTnKQTnMR56MR56MR56M
R56MR56MR56MR56MR56KQE6KQE6KQE6KQE6KQE6KQE6KQE6KQE6MR56MR56LQe2LQe2KQTnJQDjJQDjJ
QDjMRE2MRE2MRE2MRE2LR4nLR4nLR4nLR4nMRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2M
RE2MRE2MRE2MRE2MRE2KQdjLR4nLR4nLR4nMRE2MRE2MRE2NRU6LQe2LQe2LQe2LQe2LQe2MR56NRE:N
RE:LQe2LQe2LQe2LQe2MR56MR56MR56MR56MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2ORU>NRE:MR56M
R56MR56MR56NRE:ORU>OREFOREFOREFOREFOREFOREFOREFOREFORU>ORU>ORU>ORU>ORU>ORU>ORU>O
RU>OR5JOR5JNQeFMQUBNQeFOR5JPRENQRURNQeFPRENSS5ZTSE^SS5ZRReVQRURQRURQS5FTSeRRS5RL
QU:MQUBRRe^RRe^NQUROR5JOR5JPRENPRENPRENQRURQRURQRURPRENPRENQRURQRURQRURRReVRReVR
ReVPRENOR5JOR5JOR5JOR5JPRENQRURRReVQS5FQS5FQS5FPReBPReBORU>ORU>NRE:PReBPReBPReBP
ReBPReBPReBPReBPReBRRUBRRUBRRUBRRUBRRUBRRU@00:ZFOJZFOJZFOJZFOJZFOJZFOJZFOJZFOJRG
OJRGOJRGOJVHOZVHOZVHOZZIOjZIOjRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJNFO:NFO:NFO:NFO:NF
O:NFO:NFO:NFO:JENjJENjJENjJENjNFO:NFO:NFO:NFO:FDNZFDNZFDNZFDNZFDNZFDNZFDNZFDNZFD
NJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNZFDNZFDNZFDNZFDNZFDNZFDNZFDNZFDNZFDNZFDNZFDNZFD
NZFDNZFDNZFDNZBCN:BCN:BCN:BCN:BCN:BCN:BCN:BCN:BCN:BCN:BCN:BCN:BCN:BCN:BCN:BCN:BC
N:BCN:BCN:BCN:BCN:BCN:BCN:BCN:FCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFC
MZFCMZFCMZFCMZBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJ>A
M:>AM:>AM:BBMJBBMJFCMZFCMZFCMZ:@Lj:@Lj>AM:BBMJBBMJ>AM::@Lj:@LjFCM:BBLjBBLj>ALZ>A
LZBBLjBBLjFCM::@LJ:@LJ:@LJ>ALZ>ALZ>ALZBBLjBBLj>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>A
LZ>ALZ>ALZ>ALZ>ALZ>ALZ>ALZ>ALZ:@LJ:@LJ:@LJ>ALZ>ALZ>ALZBBLjBBLj>ALZ>ALZ>ALZ>ALZ>A
LZ>ALZ>ALZ>ALZFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBA
KZBAKZBAKZBAKZBAKZBAKZBAKZBAKZ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@
KJ>@KJ>@KJ>@KJ:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj2=
JZ2=JZ2=JZ2=JZ2=JZ6>Jj6>Jj6>Jin<JIn<JIn<JIn<JIn<JIn<JIn<JIn<JJ2=J:2=J:2=J:2=J:2=
J:2=J:2=J:2=J9n<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYj;IIj;IIj;IIj;IIj;IIj;IIj;IIj;IIf:
I9f:I9f:I9j;IIj;IIn<IYn<IYn<IYf<IIf<IIf<IIj;IJ2;IJ2;IJ:;IJ:;IIf:I9f:I9f:I9f:I9f:
I9f:I9f:I9f:I9b9Hib9Hib9Hib9Hib9Hib9Hib9Hib9Hif:I9f:I9f:I9f:I9f:I9f:I9f:I9f:I9j8
Gij8Gij8Gij8Gij8Gij8Gij8Gij8Gi^9H9^9H9^9H9^9H9b:HIb:HIb:HIb:HJ2:HJ2:HJ2:HJ2:HJ2:
HJ2:HJ2:HJ2:HJ2;GZ2;GZ2;GZ2;GZ2;GZ2;GYn:GIn:GIf9FYf9FYj:Fij9G9n9Gin9Gj2:HJ2:HJ2<
GJ2<GJ2<GIn;G9j:Fij:Fif9FYf9FYj9G9j9G9j9G9n:GIn:GJ2;GZ2;GZ2;GYj:Fij:Fij:Fij:Fij:
Fij:Fij:Fij:Fij9G9j9G9j9G9n:GIn:GIn:GIn:GIn:GIb8FIf9FYf9FYf9FYj:Fij:Fij:Fin;G9j:
Fij:Fif9FYf9FYf9FYf9FYj:Fij:Fij:Fij:Fij:Fij:Fij:Fij:Fij:Fij:Fij:Fij:Fif9FYf9FYb8
FI^7F9^7F9^7F:2:FYj8F9f7Eif7Ein9FJ2:FYn9FIf7Ein8EYn8EYn8EYn8EYn8EYn8EYn8EYn8EYf8
EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8
EIf8EIf8EIf8EIj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYf8EIf8EIf8EIf8EIf8EIf8EIf8EIf8EIb7
E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9^6Di^6Di^6Di^6Di^6
Di^6Di^6Di^6Di^6Di^6Di^6Di^6Di^6Di^6Di^6Di^6Di^4DY^4DY^4DY^4DY^4DY^4DY^4DY^4DYN6
CYV5CYZ6Cib7D9b7D9f5Cif5Cij4CYV4CIZ5CYZ5CY^6Ci^6Cib7D9b7D9b7D9Z5CY^6Ci^6Ci^6Ci^6
CiZ5CY^6Ci^6CiZ5CYZ5CYZ5CY^6Ci^6Ci^6Cib7D9b7D9Z6CIZ6CI^7CY^7CY^7CY^7CY^7CY^7CY^6
Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6Cib7D9b7D9b7D9b7D9b7D9b7D9b7D9b7D9^6Ci^6Ci^6Ci^6Ci^6
Ci^6Ci^6Ci^6Cib7D9b7D9b7D9^6Ci^6CiZ5CYZ5CYV4CIb8Cib8Cib8Cib8Cib8Cib8Cib8Cib8Cib8
Cib8Cib8Cib8Cib8Cib8Cib8Cib8Cib8Cib8Cib8Cib8Cib8Cib8Cib8Cib8Ci^7CY^7CY^7CYb8Cib8
Cif9D9f9D9f9D9^6Ci^6Cib7D9b7D9f8DIf8DIf8DIf8DIb7D9b7D9b7D9b7D9b7D9b7D9b7D9b7D9b8
Cib8Cib8Cib8Cib8Cib8Cib8Cib8Cij9DYj9DYf8DIb7D9b7D9f8DIj9DYj9DYj9DYj9DYj9DYj9DYj9
DYj9DYj9DYj9DYj9DYj9DYj9DYj9DYj9DYj9DYj9DYj9DYj7EIf6E9f6E9f6E9j7EIj7EIn8EZ29Eif2
Cj66DjJ;F:N<FJF:Ej>8EJ:7E::7E9j:DJ2;E:2;E9f7Dif6E9n8EZ29FIn8F9j7EIj7EIn8EYn8EYn8
EZ29Ej29Ej29Ein8EYn8EZ29Ej29Ej29Ej6:F:6:F:6:F9n8EYn8EYj7EIj7EIn8EZ29Ej6:F:6:F:6<
EJ6<EJ2;E:2;E9n:Dij9DYj9DYj9DYn:Din:Din:Din:Din:Dj2;E:2;E:2;E:69Dj69Dj69Dj69Dj69
Dj69D`00ZIElZIElZIElZIElZIElZIElZIElZIElYiIlYiIlZ9MmZ9MmZIQnZIQnZIQnZIQnYiIlYiIl
YiIlYiIlYiIlYiIlYiIlYiIlYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEkYIAjYIAjYYEkYYEkYYEkYiIl
YiIlYiIlYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAjYIAj
YIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjY9=hY9=hY9=hY9=hY9=hY9=h
Y9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hYI=fYI=f
YI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fY99eY99eY99eY99eY99eY99e
Y99eY99eY99eY99eY99eY99eY99eY99eY99eY99eXi5dXi5dXi5dXi5dY99eY99eY99eYI=fXHmbXY1c
Xi5dXi5dXi5dXi5dXY1cXHmbYI=dY99cXi5bXi5bXi5bXi5bY99cYI=dXHm`XY1aXY1aXY1aXi5bXi5b
Xi5bXi5bXY1cXY1cXY1cXY1cXY1cXY1cXY1cXY1cXY1aXY1aXY1aXY1aXY1aXY1aXY1aXY1aXHm`XY1a
XY1aXY1aXi5bXi5bXi5bXi5bXY1aXY1aXY1aXY1aXY1aXY1aXY1aXY1aY95^Y95^Y95^Y95^Y95^Y95^
Y95^Y95^Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]XXm/XXm/
XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XHmZXHmZXHmZXHmZXHmZXHmZ
XHmZXHmZXHmZXHmZXHmZXHmZXHmZXHmZXHmZXHmZWhaYWhaYWhaYX8eZX8eZX8eZXHi[XHi[WhaYWhaY
WhaYWhaYWhaYWhaYWhaYWhaYX8eXX8eXX8eXX8eXX8eXX8eXX8eXX8eXWhaVWhaVWhaVWhaVWhaVWhaV
WhaVWhaVWX]UWX]UWX]UWX]UWX]UWX]UWX]UWX]UWHYTWHYTWHYTWHYTWX]UWX]UWX]UWhaVW8]TW8]T
W8]TWHYTX8]UX8]UXX]UXhaVW8USW8USW8USW8USW8USW8USW8USW8USVhQRVhQRVhQRVhQRVhQRVhQR
VhQRVhQRW8USW8USW8USW8USW8USW8USW8USW8USWhUPWhUPWhUPWhUPWhUPWhUPWhUPWhUPVXQOVXQO
VXQOVXQOVhUPVhUPVhUPW8YQWhUPWhUPWhUPWhUPWhUPWhUPWhUPWhUPX8aMX8aMX8aMX8aMWh]LWh]L
Wh]LWXYKW8QIW8QIW8QIWHQKWXQNWhUOWhUPWhUPWh]LWh]LWh]LWXYKWXYKWXYKWXYKWXYKW8MJW8MJ
WHQKWXULWXULWhYMX8]NX8]NWXYJWXYJWXYJWXYJWXYJWXYJWXYJWXYJWHQKWHQKWXULWXULWXULWhYM
WhYMWhYMW8QIW8QIW8QIWHUJWHUJWXYKWXYKWXYKWXYKWHUJWHUJW8QIW8QIWHUJWHUJWXYKWHUJWHUJ
WHUJWHUJWHUJWHUJWHUJWHUJWHUJW8QIW8QIW8QIW8QIW8QIVhMHVhMHWhUIWXQHW8IFWHMGWhUIWhUI
WXQHWHMGWhQFWhQFWhQFWhQFWhQFWhQFWhQFWhQFWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQE
WHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWXUFWXUFWXUFWXUFWXUFWXUF
WXUFWXUFWHQEWHQEWHQEW8MDW8MDW8MDVhICVhICVhICVhICVhICVhICW8MDW8MDW8MDWHQEW8MDW8MD
W8MDW8MDW8MDW8MDW8MDW8MDVhICVhICVhICVhICVhICVhICVhICVhICVhICVhICVhICVhICVhICVhIC
VhICVhICVX=AVX=AVX=AVX=AVX=AVX=AVX=AVX=AUXE=V8A=VHE>VhI?W8M@WHE?WHE?WXA>VXE>VXE>
VXE>VXE>VhI?VhI?VhI?VhI?VHA=VhI?W8M@VhI?VXE>VHA=VXE>W8M@VHA=VXE>VXE>VXE>VhI?VhI?
VhI?VhI?V8A;VHE<VXI=VhM>W8Q?VhM>VhM>VXI=VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>W8M@W8M@
W8M@W8M@W8M@W8M@W8M@W8M@VXI=VXI=VXI=VXI=VXI=VXI=VXI=VXI=VhI?VhI?VhI?VhI?VXE>VXE>
VXE>VXE>VhM>VhM>VhM>VhM>W8Q?W8Q?W8Q?WHU@W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?
W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?VhM>VhM>VhM>VhM>W8Q?W8Q?W8Q?WHU@VXE>VXE>VhI?W8M@WHQAWHQA
W8M@W8M@WHQAW8M@W8M@W8M@VhI?VhI?VhI?VhI?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?WXUBWHQA
W8M@W8M@W8M@W8M@WHQAWXUBWHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@W8M@W8M@WHQAWHQAWHQAWXUB
WXUBWXUBW8ECW8ECWHIDWHIDWHIDWXMEWXMEWXMEXHICXXMDXHICWhAAWX=@X8EBXhQEYX]HWXM?X8UA
XHUCXHUCWhMCWhIDXHQFXXUGWHIDWHIDWXMEWXMEWXMEWhQFWhQFWhQFWXMEWXMEWhQFWhQFX8UGX8UG
X8UGX8UGWhQFWXMEWXMEWXMEWXMEWhQFX8UGXHYHX8]DWhYCWhYCWhYCWhYCWhYCWXUBWXUBWXUBWXUB
WXUBWhYCWhYCWhYCX8]DX8]DXHUCXHUCXHUCXHUCXHUCXHUC002YUGbYUGbYUGbYUGbYUGbYUGbYUGbY
UGbWUWbWUWbWUWbXUgfXUgfYV7jYV7jYV7jWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbVUG^VUG^VUG^V
UG^VUG^VUG^VUG^VUG^TTgVUU7ZUU7ZUU7ZVUG^WUWbWUWbWUWbUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZU
U7ZUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZU
U7ZUU7ZUU7ZUU7ZUU7ZSTWNSTWNSTWNSTWNSTWNSTWNSTWNSTWNSTWNSTWNSTWNSTWNSTWNSTWNSTWNS
TWNSTWNSTWNSTWNSTWNSTWNSTWNSTWNSTWNTTWFTTWFTTWFTTWFTTWFTTWFTTWFTTWFTTWFTTWFTTWFT
TWFTTWFTTWFTTWFTTWFSTGBSTGBSTGBSTGBSTGBSTGBSTGBSTGBSTGBSTGBSTGBSTGBSTGBSTGBSTGBS
TGBRT7>RT7>STGBSTGBSTGBTTWFTTWFTTWFQSg:RT7>RT7>STGBSTGBRT7>RT7>QSg:TTW>TTW>STG:R
T76RT76STG:TTW>TTW>QSg2QSg2RT76RT76RT76STG:STG:STG:RT7>RT7>RT7>RT7>RT7>RT7>RT7>R
T7>RT76RT76RT76RT76RT76RT76RT76RT76QSg2QSg2RT76RT76RT76STG:STG:STG:RT76RT76RT76R
T76RT76RT76RT76RT76TTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjRSfbRSfbRSfbRSfbRSfbRSfbRSfbR
SfbST6fST6fST6fST6fST6fST6fST6fST6fRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbR
SfbRSfbRSfbRSfbRSfbQSfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZQ
SfZNRfRNRfROS6VOS6VPSFZPSFZQSV^QSV^PSFZPSFZPSFZPSFZPSFZPSFZPSFZPSFZOS6NOS6NOS6NO
S6NOS6NOS6NOS6NOS6NNRfFNRfFNRfFNRfFNRfFNRfFNRfFNRfFMRVBMRVBMRVBMRVBMRVBMRVBMRVBM
RVBLRF>LRF>MRVBMRVBMRVBNRfFNRfFNRfFKRV>KRV>KRV>MRVBPRfFPRfFRRfFSS6JLRF>LRF>LRF>L
RF>LRF>LRF>LRF>LRF>KR6:KR6:KR6:KR6:KR6:KR6:KR6:KR6:LRF>LRF>LRF>LRF>LRF>LRF>LRF>L
RF>PRV6PRV6PRV6PRV6PRV6PRV6PRV6PRV6IQejIQejIQejJR5nJR5nKRF2KRF2KRF2ORF2ORF2ORF2O
RF2ORF2ORF2ORF2ORF2PS5fPS5fPS5fORebORebNRU^NRU^NRU^JQUNKQeRKQeRLQeZMQefNR5jORF2O
RF2MREZMREZMREZNRU^NRU^NRU^NRU^NRU^LQeZMR5^MR5^NREbORUfPRejQS5nQS5nMREVMREVMREVM
REVMREVMREVMREVMREVLQeZMR5^MR5^NREbNREbORUfORUfORUfLR5VLR5VLR5VMREZMREZMREZNRU^N
RU^NRU^MREZLR5VLR5VLR5VLR5VMREZNRU^MREZMREZMREZMREZMREZMREZMREZMREZKQeRKQeRKQeRK
QeRLR5VLR5VLR5VLR5VOREVMQeNLQUJMQeNNR5ROREVNR5RLQUJOR5JOR5JOR5JOR5JOR5JOR5JOR5JO
R5JLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBL
QeBLQeBLQeBLQeBLQeBNREJNREJNREJNREJNREJNREJNREJNREJMR5FMR5FLQeBLQeBKQU>KQU>JQE:J
QE:JQE:JQE:KQU>KQU>LQeBLQeBMR5FMR5FKQU>KQU>KQU>KQU>KQU>KQU>KQU>KQU>JQE:JQE:JQE:J
QE:JQE:JQE:JQE:JQE:JQE:JQE:JQE:JQE:JQE:JQE:JQE:JQE:JPe6JPe6JPe6JPe6JPe6JPe6JPe6J
Pe6EQ4bGPdbIQDjKQTnKQTnMQDnMQDnOQDnKQTnKQTnJQDjJQDjJQDjJQDjJQDjIQ4fHPdbKQTnLQe2K
QTnIQ4fHPdbJQDjLQe2IQ4fIQ4fJQDjJQDjJQDjKQTnKQTnKQTnGPdZHQ4^JQTfKQdjLR4nLR4nKQdjJ
QTfJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjKQTnKQTnKQTnKQTnKQTnKQTnKQTnKQTnJQTfJQTfJQTfJ
QTfJQTfJQTfJQTfJQTfIQ4fJQDjJQDjJQDjJQDjJQDjKQTnKQTnJQTfJQTfJQTfKQdjLR4nLR4nLR4nM
RE2KQdjKQdjKQdjKQdjKQdjKQdjKQdjKQdjKQdjKQdjKQdjKQdjKQdjKQdjKQdjKQdjJQTfJQTfKQdjK
QdjKQdjLR4nLR4nLR4nIQ4fJQDjKQTnMR56MR56LQe2KQTnKQTnMR56LQe2LQe2LQe2KQTnJQDjJQDjJ
QDjKQdjKQdjKQdjKQdjKQdjKQdjKQdjKQdjMR56MR56LQe2KQTnKQTnLQe2MR56MR56LR4nLR4nLR4nL
R4nLR4nLR4nLR4nLR4nKQTnKQTnLQe2LQe2MR56MR56NRE:NRE:KQ5:KQ5:LQE>MQUBMQUBMQUBMQUBM
QUBSRURQR5JNQE>MQ5:NQE>QR5JSRURTReVORDnQRU:SS5BSReFPR5:MQE6NQE>QR5JMQUBMQUBMQUBM
QUBNQeFNQeFNQeFOR5JNQeFNQeFNQeFNQeFOR5JOR5JPRENPRENOR5JNQeFNQeFMQUBNQeFOR5JPRENQ
RURNRE:NRE:NRE:NRE:ORU>ORU>ORU>ORU>MR56MR56NRE:NRE:ORU>ORU>PReBPReBQRE>QRE>QRE>Q
RE>QRE>QRE<00:VEO:VEO:VEO:VEO:VEO:VEO:VEO:VEO:NFO:NFO:NFO:RGOJRGOJRGOJVHOZVHOZNF
O:NFO:NFO:NFO:NFO:NFO:NFO:NFO:JENjJENjJENjJENjJENjJENjJENjJENjBCNJBCNJFDNZFDNZJE
NjJENjNFO:NFO:BCNJBCNJBCNJBCNJBCNJBCNJBCNJBCNJBCN:BCN:BCN:BCN:BCN:BCN:BCN:BCN:BC
NJBCNJBCNJBCNJBCNJBCNJBCNJBCNJBCNJBCNJBCNJBCNJBCNJBCNJBCNJBCNJ>BMj>BMj>BMj>BMj>B
Mj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMjBB
MJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJ>AM:>AM:>AM:>AM:>A
M:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM::@Lj:@Lj:@Lj>AM:>AM:BBMJBBMJBBMJ6?
LZ:@Lj:@Lj>AM:>AM::@Lj:@Lj6?LZBBLj>ALZ>ALZ:@LJ:@LJ>ALZ>ALZBBLj6?L:6?L:6?L::@LJ:@
LJ:@LJ>ALZ>ALZ:@Lj:@Lj:@Lj:@Lj:@Lj:@Lj:@Lj:@Lj:@LJ:@LJ:@LJ:@LJ:@LJ:@LJ:@LJ:@LJ6?
L:6?L:6?L::@LJ:@LJ:@LJ>ALZ>ALZ:@LJ:@LJ:@LJ:@LJ:@LJ:@LJ:@LJ:@LJBAKZBAKZBAKZBAKZBA
KZBAKZBAKZBAKZ:?K::?K::?K::?K::?K::?K::?K::?K:>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ:?
K::?K::?K::?K::?K::?K::?K::?K::?K::?K::?K::?K::?K::?K::?K::?K:6?JZ6?JZ6?JZ6?JZ6?
JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JYj;J9j;J9j;J9n<JJ2=JZ2=JZ6>Jj6>Jj6>
Jj6>Jj6>Jj6>Jj6>Jj6>Jj6>Jj6>Jin<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Iij;IIj;IIj;IIj;IIj;
IIj;IIj;IIj;IIf:I9f:I9f:I9f:I9f:I9f:I9f:I9f:I9b9Hib9Hib9Hif:I9f:I9j;IIj;IIj;IIZ9
HY^:Hi^:Hif:I9n:I:2;IJ:;IJ><IYb9Hib9Hib9Hib9Hib9Hib9Hib9Hib9Hi^8HY^8HY^8HY^8HY^8
HY^8HY^8HY^8HYb9Hib9Hib9Hib9Hib9Hib9Hib9Hib9Hj2:HJ2:HJ2:HJ2:HJ2:HJ2:HJ2:HJ2:HIR6
GIR6GIV7GYV7GYZ8Gi^9H9^9H9^9H9n9H9n9H9n9H9n9H9n9H9n9H9n9H9n9H:2<GJ2<GJ2<GIn;G9j:
Fij:Fif9FYf9FYZ6EiZ6Ei^7F9b7FYf7GIj8GYn9H9n9H9b8FIb8FIf9FYf9FYj:Fin;G9n;G9n;G9f8
Fij9G9j9G9n:GJ6<Gj:=H::=H:>>HIb9EYb9EYb9EYb9EYb9EYb9EYb9EYb9EYb7FYb7FYf8Fif8Fij9
G9n:GIn:GIn:GI^7F9b8FIb8FIb8FIf9FYf9FYf9FYj:Fij:Fif9FYb8FIb8FIb8FIb8FIf9FYj:Fif9
FYf9FYf9FYf9FYf9FYf9FYf9FYf9FYZ6EiZ6EiZ6Ei^7F9b8FIb8FIf9FYf9FYn9FIf7Eib6EYf7Eij8
F9n9FIj8F9b6EYj7EIj7EIj7EIj7EIj7EIj7EIj7EIj7EIb7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7
E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9f8EIf8EIf8EIf8EIf8
EIf8EIf8EIf8EIf8EIb7E9b7E9^6Di^6DiZ5DYZ5DYV4DIV4DIZ5DYZ5DY^6Di^6Dib7E9f8EIf8EI^6
Di^6Di^6Di^6Di^6Di^6Di^6Di^6DiZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5
DYZ5DYZ5DYZ5DYZ3DIZ3DIZ3DIZ3DIZ3DIZ3DIZ3DIZ3DIB3BiN3C9R4CI^6Ci^6Cif5Cif5Cin5Cib7
D9^6Ci^6CiZ5CYZ5CYV4CIV4CIR3C9R3C9Z5CYf8DI^6CiR3C9N2BiV4CIb7D9V4CIV4CIV4CIZ5CYZ5
CYZ5CY^6Ci^6CiJ2BIR4BiZ6CI^7CYb8Cib8Ci^7CYZ6CIZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CY^6
Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6CiZ6CIZ6CIZ6CIZ6CIZ6CIZ6CIZ6CIZ6CIR3C9V4CIV4CIZ5CYZ5
CY^6Ci^6Cib7D9V5C9Z6CIZ6CI^7CY^7CYb8Cib8Cif9D9^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7
CY^7CY^7CY^7CY^7CY^7CY^7CY^7CYZ6CIZ6CIZ6CI^7CY^7CYb8Cib8Cib8CiR3C9V4CI^6Cif8DIf8
DIb7D9^6CiZ5CYf8DIb7D9b7D9^6Ci^6CiZ5CYZ5CYV4CI^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CYf8
DIf8DIb7D9^6Ci^6Cib7D9f8DIf8DIb8Cib8Cib8Cib8Cib8Cib8Cib8Cib8CiZ5CY^6Ci^6Cib7D9b7
D9f8DIf8DIj9DYZ3DI^4DYb5Dif6E9f6E9f6E9f6E9b5Dib5EI^4E9b5EIj7Ej6:FZ6:FYj7EiZ3Dj>;
DJB<DZJ=EJJ=EJ:8DYj3D9j3D::7EIb5Dib5Dif6E9f6E9f6E9j7EIj7EIj7EIf6E9f6E9j7EIj7EIn8
EYn8EYn8EYn8EYj7EIj7EIf6E9f6E9j7EIn8EZ29Ej29Eif8DIf8DIf8DIj9DYn:Din:Dj2;E:2;E9f8
DIf8DIf8DIj9DYn:Din:Dj2;E:2;E:28DZ28DZ28DZ28DZ28DZ28DP00ZIIkZIIkZIIkZIIkZIIkZIIk
ZIIkZIIkYiAiYiAiYiAiYiAiZ9EjZ9EjZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkZ9EjZ9Ej
Z9EjZ9EjZ9EjZ9EjZ9EjZ9EjZYImZ9AkYi=jYY9iYY9iYi=jZ9AkZYImYiAiYiAiYiAiYiAiYiAiYiAi
YiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gYY=hYY=h
YI9gY95fY95fYI9gYY=hYY=hYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gY95fY95fY95fY95fY95fY95f
Y95fY95fYY=hYI9gY95fXi1eXi1eY95fYI9gYY=hYI=fYI=fY99eY99eXi5dXY1cXY1cXY1cYY9cYY9c
YY9cYY9cYY9cYY9cYY9cYY9cYI1dYI1dYI1dYI1dYI1dYI1dYI1dYI1dYI5bYI5bYI5bYI5bYI5bYI5b
YI5bYI5bYY9cYY9cYI5bY91aY91aXhm`Xhm`XXi_XY1cXY1cXY1cXY1cXY1cXY1cXY1cXY1cYI5bY91a
Y91aXhm`Xhm`Y91aY91aYI5bYI5bYI5bYI5bY91aY91aY91aXhm`Xhm`X95aX95aX95aX95aX95aX95a
X95aX95aY91aY91aXhm`Xhm`Xhm`Xhm`XXi_XXi_Y91aXhm`Xhm`XXi_XXi_Xhm`Xhm`Y91aYY9cYI5b
Y91aXXi_XXi_XXi_XXi_XXi_Y95/Y95/Y95/Y95/Y95/Y95/Y95/Y95/Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]
Xi1]Xi1]Xhm/Xhm/Xhm/Xhm/Xhm/Xhm/Xhm/Xhm/YI9]Y95/Y95/Xi1[Xi1[XXmZXHiYXHiYXXi[XXi[
XXi[XXi[XXi[XXi[XXi[XXi[XXmZXXmZXXmZXXmZXXmZXXmZXXmZXXmZXHeZXHeZXHeZXHeZXHeZXHeZ
XHeZXHeZXHiYXHiYXHiYXHiYXHiYXHiYXHiYXHiYWXaSWhaVX8eWX8eXX8eXX8aYWh]XWXUYWX]VWhaW
WhaWX8eWWheTWXaSWHaQW8]PXHYTXHYTXHYTXHYTXHYTXHYTXHYTXHYTWX]VWX]VWX]VWX]VWX]VWX]V
WX]VWX]VX8YQX8YQXH]RXH]RXXaSXXaSXXaSXXaSWXQOWhUPWhUPX8YQX8YQWhUPWhUPWXQOX8YQWhUP
WhUPWXQOWXQOWhUPWhUPX8YQWXMQWXMQWXMQWXMQWXMQWXMQWXMQWXMQWXQOWXQOWXQOWXQOWXQOWXQO
WXQOWXQOWXULWXULWXULWXULWXULWXULWXULWXULX8]NWhYMWhYMWXULWXULWHQKW8MJW8MJWhUPWXQO
WHMNW8IMW8IMWXQOWhUPXH]RXHUOXHUOXHUOX8QNX8QNWhMMWXILWXILX8UKX8UKX8UKX8UKX8UKX8UK
X8UKX8UKWHUJWHUJWHUJWHUJWHUJWHUJWHUJWHUJWHUJWHUJWHUJWHUJWHUJWHUJWHUJWHUJWhQJWhQJ
WhQJWhQJWhQJWhQJWhQJWhQJWHIHWHIHWXMIWXMIWhQJX8UKX8UKX8UKVhUJVhUJVhUJW8YKW8YKW8YK
WH]LWH]LWXMIWXMIWXMIWXMIWXMIWXMIWXMIWXMIWhQJWhQJWhQJWhQJWhQJWhQJWhQJWhQJWXQHWXQH
WXQHWXQHWXQHWXQHWXQHWXQHWHMGWHMGWHMGWHMGWXQHWXQHWXQHWhUIWhQFWhQFWhQFWhQFWhQFWhQF
WhQFWhQFWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWhQFWhQF
WhQFX8UGX8UGX8UGXHYHXHYHW8ECWHIDWHIDWHIDWXMEWXMEWXMEWhQFWhYCWhYCWhUEWXQDWHIDWHID
W8EEW8EEVhABVhABVhABVhABVhABVhABVhABVhABVXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VhI?VhI?
VhI?VhI?VhI?VhI?VhI?VhI?W8M@VhI?VhI?VXE>VXE>VHA=VHA=V8=<W8M@W8M@VhI?VXE>VXE>VHA=
VHA=V8=<W8M@W8M@VhI?VXE>VXE>VHA=VHA=V8=<W8E=W8E=W8E=VhA<VhA<VX=;VX=;VX=;V8A;VHE<
VHE<VXI=VXI=VHE<VHE<V8A;W8M:W8I<VhE;VhA<VhA<Vh==VX9<VX9>VHE<VHE<VHE<VHE<VHE<VHE<
VHE<VHE<VXI=VXI=VXI=VXI=VXI=VXI=VXI=VXI=VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<
W8E=W8E=W8E=WHI>WHI>WHI>VX=;VX=;VX=;VhA<VhA<W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=
W8E=W8E=WHI>WXM?WhQ@WhQ@WhQ@WhQ@WXM?WHI>W8E=W8E=WHI>WHI>WHI>WXM?WXM?WXM?WXM?WXM?
WHI>W8E=W8E=WHI>WXM?WXM?W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=
W8E=W8E=WHEAWHEAWHEAWHEAWHEAWHEAWHEAWHEAW8E=W8E=WHI>WHI>WHI>WXM?WXM?WXM?W8=AW8=A
WHABWHABWHABWXECWXECWXECWXUBWXUBWXUBWXUBWHQAWHQAWHQAWHQAWHI>WHI>WHI>WHI>WHI>WHI>
WHI>WHI>WHE?WHE?WXI@WXI@WhMAWhMAWhMAWhMAWXI@WXI@WXI@WXI@WXI@WXI@WXI@WXI@W8E=W8E=
W8E=WHI>WHI>WXM?WXM?WXM?XHQFXHQFXXUGXhYHXhYHXXUGXHQFXHQFWhMAWhMAWhMAWhMAWhMAWhMA
WhMAWhMAX8QBX8QBWhMAWXI@WXI@WhMAX8QBX8QBXHUCXHUCXHUCXHUCXHUCXHUCXHUCXHUCXHUCXHUC
XHUCXHUCXHUCXHUC002YUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^WU7VWU7VWU7VWU7VXUGZXUGZYUW^Y
UW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^XUGZXUGZXUGZXUGZXUGZXUGZXUGZXUGZYUGbXU7^WTgZV
TWVVTWVWTgZXU7^YUGbVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRV
TgRUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNVTgRVTgRUTWNTTGJTTGJUTWNVTgRVTgRUTWNUTWNUTWNU
TWNUTWNUTWNUTWNUTWNTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJVTgRUTWNTTGJST7FST7FTTGJUTWNV
TgRTTWFTTWFTTWFSTGBSTGBRT7>RT7>RT7>VTW>VTW>VTW>VTW>VTW>VTW>VTW>VTW>UT7BUT7BUT7BU
T7BUT7BUT7BUT7BUT7BUTG:UTG:UTG:UTG:UTG:UTG:UTG:UTG:UTG:UTG:UTG:TT76TT76SSg2SSg2R
SVnRT7>RT7>RT7>RT7>RT7>RT7>RT7>RT7>UTG:TT76TT76SSg2SSg2TT76TT76UTG:UTG:UTG:TT76T
T76TT76SSg2SSg2SSg2RT76RT76RT76RT76RT76RT76RT76RT76SSg2SSg2SSg2SSg2SSg2SSg2RSVnR
SVnTT76SSg2RSVnRSVnRSVnRSVnSSg2TT76UTG:TT76SSg2RSVnRSVnRSVnRSVnRSVnTTFbTTFbTTFbT
TFbTTFbTTFbTTFbTTFbST6fST6fST6fST6fST6fST6fST6fST6fSSfbSSfbSSfbSSfbSSfbSSfbSSfbS
SfbTTFbTTFbST6^ST6^RSfZRSfZQSVVQSVVRSV^RSV^RSV^RSV^RSV^RSV^RSV^RSV^PSFRPSFRPSFRP
SFRPSFRPSFRPSFRPSFRPS6VPS6VPS6VPS6VPS6VPS6VPS6VPS6VPSFRPSFRPSFRPSFRPSFRPSFRPSFRP
SFRNS6>OS6JPSFNPSFRPSFRPS6VORfRNRFVNRfJOS6NOS6NOS6JOSFBNS6>MS66LRf2QRVBQRVBQRVBQ
RVBQRVBQRVBQRVBQRVBNRfJNRfJNRfJNRfJNRfJNRfJNRfJNRfJPRV6PRV6PRV6QRf:QRf:RS6>RS6>R
S6>NR5nNR5nORF2PRV6PRV6ORF2NR5nNR5nPRV6ORF2NR5nNR5nNR5nNR5nORF2PRV6NQf6NQf6NQf6N
Qf6NQf6NQf6NQf6NQf6NR5nNR5nNR5nNR5nNR5nNR5nNR5nNR5nNREbNREbNREbNREbNREbNREbNREbN
REbORUfORUfNREbNREbMR5^MR5^LQeZLQeZORF2NR5nMQejLQUfLQUfMQejORF2ORF2PREbPREbPREbP
REbPREbOR5^OR5^OR5^PRE^PRE^PRE^PRE^PRE^PRE^PRE^PRE^MREZMREZMREZMREZMREZMREZMREZM
REZMREZMREZMREZMREZMREZMREZMREZMREZOR5ZOR5ZOR5ZOR5ZOR5ZOR5ZOR5ZOR5ZNQeVNQeVNQeVN
QeVOR5ZOR5ZOR5ZOR5ZIQeRIQeRJR5VJR5VJR5VKREZKREZKREZMQURMQURMQURMQURMQURMQURMQURM
QUROR5ZOR5ZOR5ZOR5ZOR5ZOR5ZOR5ZOR5ZMQeNMQeNMQeNMQeNMQeNMQeNMQeNMQeNLQUJMQeNMQeNM
QeNNR5RNR5RNR5RNR5RNQeFNQeFNQeFNQeFNQeFNQeFNQeFNQeFMQUBMQUBMQUBMQUBMQUBMQUBMQUBM
QUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBNQeFNQeFOR5JOR5JOR5JLQE>LQE>MQUBM
QUBMQUBNQeFNQeFNQeFMR56MR56MQe>MQe>MQUBLQE>LQEFLQEFKQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:K
Q5:JQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjKQTnKQTnKQTnKQTnKQTnKQTnKQTnKQTnKQTnJQDjJQDjJ
QDjJQDjJQDjIQ4fIQ4fKQTnKQTnKQTnJQDjJQDjIQ4fIQ4fHPdbKQTnKQTnKQTnJQDjJQDjIQ4fIQ4fH
PdbLQDfLQDfKQ4bKQ4bKQ4bJPd^JPd^JPd^HQ4^HQ4^IQDbJQTfJQTfIQDbHQ4^HQ4^KQTVKQD^KQD^K
Q4bKQ4bKPdfJPTbJPTjIQDbIQDbIQDbIQDbIQDbIQDbIQDbIQDbJQTfJQTfJQTfJQTfJQTfJQTfJQTfJ
QTfKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bLQDfLQDfLQDfMQTjMQTjJPd^JPd^JPd^K
Q4bKQ4bKQ4bLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfMQTjNQdnNQdnOR52OR52NQdnNQdnM
QTjKQ4bKQ4bKQ4bKQ4bLQDfLQDfMQTjMQTjNQdnMQTjMQTjLQDfLQDfMQTjMQTjNQdnLQDfLQDfLQDfL
QDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfMQDnMQDnMQDnMQDnMQDnMQDnMQDnM
QDnLQDfLQDfLQDfMQTjMQTjNQdnNQdnNQdnLPe6LPe6LPe6MQ5:MQ5:NQE>NQE>NQE>LQe2LQe2LQe2L
Qe2LQe2LQe2LQe2KQTnMQTjMQTjMQTjMQTjMQTjMQTjMQTjMQTjMQDnMQDnNQU2NQU2NQU2OQe6OQe6O
Qe6NQU2NQU2NQU2NQU2NQU2NQU2NQU2NQU2MQTjMQTjMQTjMQTjNQdnNQdnOR52OR52PQeFQR5JRRENR
RENRRENRRENQR5JPQeFOQe6OQe6OQe6OQe6OQe6OQe6OQe6OQe6PR5:PR5:OQe6NQU2NQU2OQe6PR5:P
R5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5800:RENZRENZRENZRENZRE
NZRENZRENZRENZNDNJNDNJNDNJNDNJRENZRENZVFNjVFNjRENZRENZRENZRENZRENZRENZRENZRENZND
NJNDNJNDNJNDNJNDNJNDNJNDNJNDNJRDNjRDNjNCNZJBNJJBNJNCNZRDNjRDNjJCN:JCN:JCN:JCN:JC
N:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:FBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjJC
N:FBMjFBMjBAMZBAMZFBMjFBMjJCN:FBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjBAMZBAMZBAMZBAMZBA
MZBAMZBAMZBAMZFBMjBAMZ>@MJ>@MJ>@MJ>@MJBAMZFBMjBBMJ>AM:>AM:>AM::@Lj:@Lj:@Lj:@LjJB
LjJBLjJBLjJBLjJBLjJBLjJBLjJBLjF@M:F@M:F@M:F@M:F@M:F@M:F@M:F@M:FALZFALZFALZFALZFA
LZFALZFALZFALZFALZB@LJB@LJB@LJ>?L:>?L:>?L:>?L::@Lj:@Lj:@Lj:@Lj:@Lj:@Lj:@Lj:@LjFA
LZB@LJ>?L:>?L:>?L:>?L:B@LJFALZFALZB@LJB@LJB@LJ>?L:>?L:>?L:>?L::@LJ:@LJ:@LJ:@LJ:@
LJ:@LJ:@LJ:@LJ:>Kj:>Kj:>Kj:>Kj:>Kj:>Kj>?L:>?L:>?L:>?L::>Kj6=KZ6=KZ:>Kj>?L:>?L:B@
LJB@LJ>?L::>Kj6=KZ6=KZ:>Kj:>Kj>@Jj>@Jj>@Jj>@Jj>@Jj>@Jj>@Jj>@Jj:?K::?K::?K::?K::?
K::?K::?K::?K::>Jj:>Jj:>Jj:>Jj:>Jj:>Jj:>Jj:>Jj>@Jj>@Jj>@Jj>@Jj:?JZ:?JZ:?JZ6>JJ6=
JZ6=JZ6=JZ6=JZ6=JZ6=JZ6=JZ6=JYn<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Ij2<JJ2<JJ2<JJ2<JJ2<
JJ2<JJ2<JJ2<JJ2=J:2=J:2=J:2=J:2=J:2=J:2=J:2=J9j<Hin<IYn<IZ2=J:2=J9n;J9n;J9j9JIj;
IYj;IYn<Iin<IYn=I9j<Hif<HIb;H:6:I:6:I:6:I:6:I:6:I:6:I:6:I:6:I9f:IIf:IIf:IIf:IIf:
IIf:IIf:IIf:IIn9H9n9H:2:HJ2:HJ2:HJ6;HZ6;HZ6;HYf7GYj8Gin9H9n9H9n9H9n9H9j8Gif7GYn9
H9n9H9j8Gif7GYf7GYj8Gin9H9n9H9f7GYf7GYf7GYf7GYf7GYf7GYf7GYf7GYf7GYf7GYf7GYf7GYf7
GYf7GYf7GYf7GYf8Fif8Fif8Fif8Fif8Fif8Fif8Fif8Fij9G9j9G9j9G9j9G9f8Fif8Fif8Fib7FYn9
Gij8GYf7GIb6G9b6G9f7GIf7GIj8GYn8Fin8Fin8Fin8Fin8Fj29G:29G:29G9n8FYn8FYn8FYn8FYn8
FYn8FYn8FYn8FYb8FIb8FIb8FIb8FIb8FIb8FIb8FIb8FIj:Fij:Fij:Fij:Fij:Fij:Fij:Fij:Fij7
FIj7FIj7FIj7FIj7FIj7FIj7FIj7FIn8FYn8FYn8FYj7FIj7FIj7FIj7FIj7FIZ6EiZ6EiZ6Ei^7F9^7
F9^7F9b8FIb8FIf6F9f6F9f6F9f6F9f6F9f6F9f6F9f6F9j7FIj7FIj7FIj7FIj7FIj7FIj7FIj7FIf7
Eif7Eif7Eif7Eif7Eif7Eif7Eif7Eib6EYb6EYb6EYf7Eif7Eij8F9j8F9j8F9j7EIj7EIj7EIj7EIj7
EIj7EIj7EIj7EIf6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9^4
DY^4DYb5Dib5Dib5Dif6E9f6E9f6E9b5Dib5Dib5Dif6E9f6E9j7EIj7EIj7EI^6Ci^6Ci^5DI^5DI^4
DYb5Dib5EIb5EI^4DY^4DY^4DY^4DY^4DY^4DY^4DY^4DYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CY^6
Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6CiV4CIV4CIV4CIV4CIZ5CYZ5CYZ5CYZ5CY^6CiZ5CYZ5CYZ5CYV4
CIV4CIV4CIV4CI^6CiZ5CYZ5CYZ5CYV4CIV4CIV4CIV4CI^4C9^4C9^4C9^4C9Z3BiZ3BiZ3BiV2BYN3
BYR4BiV5C9V5C9V5C9V5C9R4BiN3BYZ5B9Z4BYZ4BYZ3BiZ3BiZ2C9^3CI^3CiR4BiR4BiR4BiR4BiR4
BiR4BiR4BiR4BiZ6CIZ6CIZ6CIZ6CIZ6CIZ6CIZ6CIZ6CIZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3Bi^4
C9^4C9^4C9^4C9b5CIb5CIb5CIf6CYV2BYZ3BiZ3BiZ3Bi^4C9^4C9^4C9^4C9b5CIb5CIb5CIb5CIb5
CIb5CIb5CIb5CIb5CIf6CYj7Cij7Cij7Cij7Cif6CYb5CIV2BYV2BYZ3BiZ3BiZ3Bi^4C9^4C9^4C9j7
Cif6CYb5CIb5CIb5CIb5CIf6CYj7Cib5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5
CIb5CIb5CIb5CIf5Cif5Cif5Cif5Cif5Cif5Cif5Cif5Cib5CIb5CIb5CIb5CIf6CYf6CYj7Cij7Cib4
D9b4D9b4D9b4D9f5DIf5DIj6DYj6DYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CY^6Ci^6Cif6CYf6CYf6CYf6CYf6
CYf6CYf6CYf6CYf5Cif5Cif5Cij6D9j6D9j6D9n7DIn7DIj6D9j6D9j6D9j6D9j6D9j6D9j6D9j6D9f6
CYf6CYj7Cij7Cin8D9n8D9n8D9n8D:28E:28E:69EJ::EZ::EZ69EJ28E:28E9n7DIn7DIn7DIn7DIn7
DIn7DIn7DIn7DJ28DYn7DIn7DIj6D9j6D9n7DIn7DJ28DZ28DZ28DZ28DZ28DZ28DZ28DZ28DZ28DZ28
DZ28DZ28DZ28DZ28DZ28DP00Z9EjZ9EjZ9EjZ9EjZ9EjZ9EjZ9EjZ9EjYiAiYiAiYiAiYiAiZ9EjZ9Ej
ZIIkZIIkZ9EjZ9EjZ9EjZ9EjZ9EjZ9EjZ9EjZ9EjYiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiYi=jYi=j
Yi=jYY9iYY9iYi=jYi=jYi=jYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=h
YY=hYY=hYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gY95fY95fY95fY95fYI9gYI9gYI9gYI9g
YI9gYI9gYI9gYI9gYI9gYI9gXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eY95fY95fXi1eXi1eXi1eXi1e
Y95fY95fXi5dXi5dXY1cXY1cXY1cXY1cXY1cXY1cYI5bYI5bYI5bYI5bYI5bYI5bYI5bYI5bY8mcY8mc
Y8mcY8mcY8mcY8mcY8mcY8mcY91aY91aY91aY91aY91aY91aY91aY91aXhm`Xhm`Xhm`Xhm`Xhm`Xhm`
Xhm`Xhm`XHmbXHmbXHmbXHmbXHmbXHmbXHmbXHmbY91aY91aXhm`XXi_XXi_Xhm`Y91aY91aY91aY91a
Y91aXhm`Xhm`Xhm`XXi_XXi_Xhm`Xhm`Xhm`Xhm`Xhm`Xhm`Xhm`Xhm`XHe^XHe^XXi_XXi_XXi_XXi_
Xhm`Xhm`Xhm`XXi_XXi_XHe^XHe^XXi_XXi_Xhm`Xhm`Xhm`XXi_XHe^XHe^XHe^XXi_Xhm`Xi1[Xi1[
Xi1[Xi1[Xi1[Xi1[Xi1[Xi1[XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXi[XXi[XXi[XXi[XXi[XXi[
XXi[XXi[XXmZXXmZXXmZXXmZXXmZXXmZXXmZXXmZXHeZXHeZXHeZXHeZXHeZXHeZXHeZXHeZX8eXX8eX
X8eXX8eXX8eXX8eXX8eXX8eXX8aYX8aYX8aYX8aYX8aYX8aYX8aYX8aYX8eXX8eXX8eXX8eXX8eXX8eX
X8eXX8eXWXaSWX]UWhaVWhaWWhaWWh]XWXYWWXUYWHYUWX]VWX]VWhaVWXaSWH]RW8]PVhYOX8USX8US
X8USX8USX8USX8USX8USX8USW8USW8USW8USW8USW8USW8USW8USW8USWXQOWXQOWhUPWhUPX8YQX8YQ
X8YQX8YQWHMNWXQOWXQOWhUPWhUPWXQOWXQOWHMNWhUPWXQOWXQOWHMNWHMNWXQOWXQOWhUPWHMNWHMN
WHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHQKWHQKWHQKWHQKWHQKWHQK
WHQKWHQKWHQKWHQKWHQKWHQKWHQKWHQKWHQKWHQKWXQNWXQNWHMMWHMMW8ILW8ILW8ILW8ILWHIHWXMI
WXMIWhQJWhQJX8UKX8UKX8UKWhQJWhQJWhQJWhQJWhQJWhQJWhQJWhQJW8QIW8QIW8QIW8QIW8QIW8QI
W8QIW8QIWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXMIWXMIWXMIWXMIWXMIWXMIWXMIWXMIWhQJWhQJ
WhQJWXMIWHIHWHIHW8EGW8EGVXIGVXIGVXIGVhMHVhMHW8QIW8QIW8QIWHIHWHIHWHIHWHIHWHIHWHIH
WHIHWHIHWXMIWXMIWXMIWXMIWXMIWXMIWXMIWXMIWHMGWHMGWHMGWHMGWHMGWHMGWHMGWHMGW8IFW8IF
W8IFW8IFWHMGWHMGWXQHWXQHWXMEWXMEWXMEWXMEWXMEWXMEWXMEWXMEWHIDWHIDWHIDWHIDWHIDWHID
WHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDVhABVhABVhABW8ECW8ECWHIDWHIDWHIDVhABW8EC
W8ECW8ECWHIDWHIDWHIDWXMEV8=<VHA=VH=?VXA@VX=AVhABVhADW8EEVX=AVX=AVX=AVX=AVX=AVX=A
VX=AVX=AVHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>V8=<V8=<
V8=<VHA=VHA=VXE>VXE>VhI?VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=
VHA=VHA=VhA<VhA<VhA<VX=;VX=;VH9:VH9:VH9:Uh=:V8A;V8A;VHE<VHE<V8A;V8A;Uh=:VHA7VH=9
VXA:VX=;VX=;VX9<Vh==Vh=?V8A;V8A;V8A;V8A;V8A;V8A;V8A;V8A;VHE<VHE<VHE<VHE<VHE<VHE<
VHE<VHE<VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VhA<VhA<VhA<W8E=W8E=W8E=VH9:VH9:
VH9:VX=;VX=;VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<W8E=WHI>WHI>WHI>WHI>
W8E=VhA<VH9:VH9:VX=;VX=;VhA<VhA<VhA<VhA<WHI>WHI>W8E=VhA<VhA<W8E=WHI>WHI>VhA<VhA<
VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<W8E=W8E=W8E=W8E=W8E=W8E=
W8E=W8E=VhA<VhA<W8E=W8E=W8E=WHI>WHI>WHI>Vh=?Vh=?W8A@W8A@W8A@WHEAWHEAWHEAVXE>VXE>
VXE>VXE>VhI?VhI?VhI?VhI?W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8A>W8A>WHE?WHE?WXI@WXI@
WXI@WXI@WHE?WHE?WHE?WHE?WHE?WHE?WHE?WHE?WXM?WXM?WXM?WXM?WhQ@WhQ@X8UAX8UAWhMCWhMC
X8QDXHUEXHUEX8QDWhMCWhMCWhMAWhMAWhMAWhMAWhMAWhMAWhMAWhMAWhMAWhMAWXI@WXI@WXI@WXI@
WhMAWhMAX8QBX8QBX8QBX8QBX8QBX8QBX8QBX8QBX8QBX8QBX8QBX8QBX8QBX8QB002WU7VWU7VWU7VW
U7VWU7VWU7VWU7VWU7VWU7VWU7VWU7VWU7VXUGZXUGZYUW^YUW^WU7VWU7VWU7VWU7VWU7VWU7VWU7VW
U7VVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTWVVTWVVTWVWTgZWTgZVTWVVTWVVTWVUTWNUTWNUTWNU
TWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNTTGJTTGJTTGJTTGJTTGJTTGJTTGJT
TGJUTWNTTGJTTGJST7FST7FTTGJTTGJUTWNTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJST7FST7FST7FS
T7FST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FQSg:QSg:RT7>RT7>RT7>RT7>RT7>R
T7>UTG:UTG:UTG:UTG:UTG:UTG:UTG:UTG:TSg>TSg>TSg>TSg>TSg>TSg>TSg>TSg>TT76TT76TT76T
T76TT76TT76TT76TT76RSVnRSVnRSVnSSg2SSg2SSg2SSg2SSg2QSg:QSg:QSg:QSg:QSg:QSg:QSg:Q
Sg:TT76SSg2RSVnRSVnRSVnRSVnSSg2TT76TT76TT76SSg2SSg2RSVnRSVnRSVnRSVnSSg2SSg2SSg2S
Sg2SSg2SSg2SSg2SSg2PS6fPS6fQSFjQSFjRSVnRSVnSSg2SSg2RSVnRSVnQSFjQSFjQSFjQSFjRSVnR
SVnRSVnRSVnQSFjPS6fQSFjQSFjRSVnSSg2ST6^ST6^ST6^ST6^ST6^ST6^ST6^ST6^RSfbRSfbRSfbR
SfbRSfbRSfbRSfbRSfbQSFZQSFZQSFZQSFZQSFZQSFZQSFZQSFZQSVVQSVVQSVVQSVVQSVVRSfZRSfZR
SfZPS6VPS6VPS6VPS6VPS6VPS6VPS6VPS6VQSVVQSVVQSVVQSVVQSVVQSVVQSVVQSVVORfRORfRORfRO
RfRORfRORfRORfRORfROS6NOS6NOS6NOS6NOS6NOS6NOS6NOS6NMRf:NRfFNRfFOS6NOS6NNRVNNRVNM
R6RMRVFMRVFNRfJNRfFNS6>MRf:LRf2KRUnPRF>PRF>PRF>PRF>PRF>PRF>PRF>PRF>LRV6LRV6LRV6L
RV6LRV6LRV6LRV6LRV6MQejNR5nNR5nNR5nORF2ORF2ORF2ORF2MQejMQejNR5nNR5nNR5nNR5nMQejM
QejNR5nNR5nMQejMQejMQejMQejNR5nNR5nLQUbLQUbLQUbLQUbLQUbLQUbLQUbLQUbLQUfLQUfLQUfL
QUfLQUfLQUfLQUfLQUfLQeZLQeZLQeZLQeZLQeZLQeZLQeZLQeZLQeZLQeZLQeZLQeZLQeZMR5^MR5^M
R5^LQeZLQeZMR5^MR5^MR5^LQeZLQeZLQeZMQURMQURMQURNQeVOR5ZOR5ZPRE^PRE^NQeVNQeVNQeVN
QeVNQeVNQeVNQeVNQeVKQeRKQeRKQeRKQeRKQeRKQeRKQeRKQeRNRU^NRU^NRU^NRU^NRU^NRU^NRU^N
RU^MQURMQURMQURMQURMQURMQURMQURMQUROR5ZOR5ZNQeVNQeVMQURLQENLQENLQENMQURMQURMQURN
QeVNQeVOR5ZOR5ZOR5ZLQENLQENLQENLQENLQENLQENLQENLQENMQURMQURMQURMQURMQURMQURMQURM
QURLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJKQEFKQEFLQUJLQUJLQUJMQeNMQeNMQeNMQUBMQUBMQUBM
QUBMQUBMQUBMQUBMQUBLQE>LQE>LQE>LQE>LQE>LQE>LQE>LQE>LQE>LQE>LQE>LQE>LQE>LQE>LQE>L
QE>LQE>LQE>LQE>LQE>MQUBMQUBMQUBNQeFKQ5:KQ5:KQ5:LQE>LQE>MQUBMQUBMQUBHPdbHPdbIPdnI
PdnJPe6JPe6KQ5BKQ5BJPe6JPe6JPe6JPe6JPe6JPe6JPe6JPe6IQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fI
Q4fJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjGPT^GPT^HPdbHPdbIQ4fJQDjJQDjJQDjHPdbHPdbHPdbI
Q4fIQ4fIQ4fIQ4fIQ4fHPdbHPdbHPdbIQ4fIQ4fIQ4fIQ4fIQ4fKQ4bJPd^JPd^JPd^IPTZIPTZIPTZH
PDVGPdZGPdZHQ4^HQ4^HQ4^HQ4^GPdZGPdZHPdJHPTRIPdVIPTZJPd^JPTbKPdfKPdnHQ4^HQ4^HQ4^H
Q4^HQ4^HQ4^HQ4^HQ4^IQDbIQDbIQDbIQDbIQDbIQDbIQDbIQDbJPd^JPd^JPd^JPd^JPd^JPd^JPd^J
Pd^JPd^JPd^JPd^JPd^KQ4bKQ4bLQDfLQDfHPDVIPTZIPTZIPTZJPd^JPd^JPd^KQ4bKQ4bKQ4bKQ4bK
Q4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bLQDfMQTjMQTjLQDfKQ4bKQ4bJPd^KQ4bKQ4bKQ4bLQDfLQDfLQDfL
QDfMQTjLQDfKQ4bKQ4bKQ4bKQ4bLQDfMQTjKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bK
Q4bKQ4bKQ4bKQ4bKQ4bLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfKQ4bKQ4bKQ4bLQDfLQDfLQDfMQTjM
QTjKPdfKPdfKPdfLQ4jLQ4jLQ4jMQDnMQDnJQDjJQDjKQTnKQTnLQe2LQe2MR56MR56LQDfLQDfLQDfL
QDfLQDfLQDfLQDfLQDfLQ4jLQ4jLQ4jMQDnMQDnMQDnNQU2NQU2MQDnMQDnMQDnMQDnMQDnMQDnMQDnM
QDnMQTjMQTjNQdnNQdnNQdnOR52OR52OR52NQU2OQe6OQe6PR5:PR5:OQe6OQe6NQU2NQU2NQU2NQU2N
QU2NQU2NQU2NQU2NQU2OQe6NQU2NQU2MQDnMQDnNQU2NQU2OQe6OQe6OQe6OQe6OQe6OQe6OQe6OQe6O
Qe6OQe6OQe6OQe6OQe6OQe6OQe400:NDNJNDNJNDNJNDNJNDNJNDNJNDNJNDNJNDNJNDNJNDNJNDNJRE
NZRENZVFNjVFNjNDNJNDNJNDNJNDNJNDNJNDNJNDNJNDNJJCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:FA
N:FAN:JBNJNCNZNCNZJBNJFAN:FAN:FBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjFB
MjFBMjFBMjFBMjBAMZBAMZBAMZBAMZBAMZBAMZBAMZBAMZFBMjBAMZ>@MJ>@MJ>@MJ>@MJBAMZFBMjBA
MZBAMZBAMZBAMZBAMZBAMZBAMZBAMZ:?M::?M::?M::?M::?M::?M::?M::?M:6>Lj:?M:>@MJ>@MJ>@
MJ>@MJ:?M:6>Lj2>LJ6?LZ6?LZ6?LZ:@Lj:@Lj:@Lj:@LjB@LJB@LJB@LJB@LJB@LJB@LJB@LJB@LJ>>
LZ>>LZ>>LZ>>LZ>>LZ>>LZ>>LZ>>LZ>?L:>?L:>?L:>?L:>?L:>?L:>?L:>?L:6=KZ6=KZ:>Kj:>Kj:>
Kj>?L:>?L:>?L:2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ>?L:>?L::>Kj6=KZ6=KZ:>Kj>?L:>?L:>?
L:>?L:>?L::>Kj:>Kj:>Kj6=KZ6=KZ>>Kj>>Kj>>Kj>>Kj>>Kj>>Kj>>Kj>>Kin;K9n;K:2<KJ6=KZ6=
KZ:>Kj>?L:>?L::>Kj6=KZ6=KZ2<KJ2<KJ6=KZ6=KZ:>Kj6=KZ6=KZ2<KJ2<KJ2<KJ6=KZ:>Kj>?L::?
JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZ6>Jj6>Jj6>Jj6>Jj6>Jj6>Jj6>Jj6>Jj6=JZ6=JZ6=JZ6=JZ6=
JZ6=JZ6=JZ6=JZ2=J:2=J:2=J:6>JJ6>JJ6>JJ:?JZ:?JZ2<JJ2<JJ2<JJ2<JJ2<JJ2<JJ2<JJ2<JJ:?
JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JYn;J9n;J9n;J9n;J9n;J9n;J9n;J9n;J9n<Iin<Iin<Iin<Iin<
Iin<Iin<Iin<Iif;HYf:I9j;IIn<Iin<Iij:Iif9IYf8J9b9I9f:IIf:IIj;IIf;HYb:HI^:GiZ9GYn8
HYn8HYn8HYn8HYn8HYn8HYn8HYn8HY^9H9^9H9^9H9^9H9^9H9^9H9^9H9^9H9b6GIf7GYf7GYf7GYj8
Gij8Gij8Gin9H9b6GIf7GYf7GYj8Gij8Gif7GYf7GYb6GIj8Gif7GYf7GYb6GIb6GIf7GYf7GYj8Gib6
G9b6G9b6G9b6G9b6G9b6G9b6G9b6G9b6GIb6GIb6GIb6GIb6GIb6GIb6GIb6GIb7FYb7FYb7FYb7FYb7
FYb7FYb7FYb7FY^6FI^6FI^6FIb7FYb7FYb7FYf8Fif8FiZ6EiZ6Eib8FIf9FYf9FYf9FYf9FYb8FIf7
Eif7Eij8F9j8F9j8F9j8F9j8F9n9FIj7FIj7FIj7FIj7FIj7FIj7FIj7FIj7FI^7F9^7F9^7F9^7F9^7
F9^7F9^7F9^7F9b8FIb8FIb8FIb8FIb8FIb8FIb8FIb8FIf6F9f6F9f6F9f6F9f6F9f6F9f6F9f6F9f6
F9f6F9f6F9f6F9f6F9b5Eib5Eib5Eij6F9j6F9n7FIn7FIn7FJ28FZ28FZ28FYb5Eib5Eib5Eib5Eib5
Eib5Eib5Eib5Eif6F9f6F9f6F9f6F9f6F9f6F9f6F9f6F9b6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EY^5
EI^5EI^5EI^5EIb6EYb6EYf7Eif7Eif6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9b5Dib5Dib5Dib5Dib5
Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Di^4DY^4DYb5Dib5Dib5Dif6E9f6E9f6E9^4
DY^4DY^4DY^4DYb5Dib5Dib5Dif6E9V4CIV4CIZ4D9Z4D9Z3DIZ3DIZ3Di^4E9V2D9V2D9V2D9V2D9V2
D9V2D9V2D9V2D9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9V4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIR3
C9R3C9R3C9R3C9R3C9V4CIV4CIV4CIN2BiN2BiR3C9R3C9R3C9V4CIV4CIV4CIN2BiN2BiR3C9R3C9R3
C9V4CIV4CIV4CIZ3BiZ3BiZ3BiV2BYV2BYR1BIR1BIR1BIJ2BIN3BYN3BYR4BiR4BiN3BYN3BYJ2BIN2
AIN1AiR2B9V2BYV2BYZ2C9^3CI^3CiN3BYN3BYN3BYN3BYN3BYN3BYN3BYN3BYR4BiR4BiR4BiR4BiR4
BiR4BiR4BiR4BiV2BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYZ3BiZ3BiZ3Bi^4C9^4C9^4C9R1
BIR1BIR1BIV2BYV2BYZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3Bi^4C9b5CIb5
CI^4C9Z3BiZ3Bi^4C9^4C9^4C9^4C9b5CIb5CIb5CIf6CYb5CIb5CI^4C9Z3BiZ3Bi^4C9b5CIb5CIZ3
BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3Bi^5Bi^5Bi^5Bi^5Bi^5
Bi^5Bi^5Bi^5BiZ3BiZ3Bi^4C9^4C9b5CIb5CIb5CIb5CIZ3BiZ3Bi^4C9^4C9b5CIb5CIb5CIb5CIZ5
CYZ5CY^6Ci^6Cib7D9f8DIj9DYj9DY^4C9^4C9^4C9^4C9^4C9^4C9^4C9^4C9^3CIb4CYb4CYb4CYf5
Cif5Cif5Cif5Cib4CYb4CYb4CYb4CYb4CYb4CYb4CYb4CYb5CIb5CIb5CIf6CYf6CYj7Cij7Cij7Cif6
CYj7Cij7Cin8D9n8D9j7Cij7Cif6CYj6D9j6D9j6D9j6D9j6D9j6D9j6D9j6D9n7DIj6D9f5Cif5Cif5
Cif5Cij6D9n7DIn7DIn7DIn7DIn7DIn7DIn7DIn7DIn7DIn7DIn7DIn7DIn7DIn7DIn7D@00YiAiYiAi
YiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiZ9EjZ9EjZIIkZIIkYiAiYiAiYiAiYiAiYiAiYiAi
YiAiYiAiYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gY91gYI5hYY9iYi=jYi=jYY9iYI5hY91gY95fY95f
Y95fY95fY95fY95fY95fY95fY95fY95fY95fY95fY95fY95fY95fY95fXi1eXi1eXi1eXi1eXi1eXi1e
Xi1eXi1eY95fY95fXi1eXXmdXXmdXi1eY95fY95fXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXXmdXXmd
XXmdXXmdXXmdXXmdXXmdXXmdXHicXHicXi1eY95fY95fXi1eXHicXHicX8iaX8iaX8iaXHmbXHmbXY1c
XY1cXY1cY91aY91aY91aY91aY91aY91aY91aY91aXhibXhibXhibXhibXhibXhibXhibXhibXhm`Xhm`
Xhm`Xhm`Xhm`Xhm`Xhm`Xhm`X8a]XHe^XHe^XXi_XXi_Xhm`Xhm`Xhm`X8iaX8iaX8iaX8iaX8iaX8ia
X8iaX8iaXhm`XXi_XHe^XHe^XHe^XHe^XXi_Xhm`Xhm`Xhm`XXi_XXi_XXi_XHe^XHe^XHe^Xhi_Xhi_
Xhi_Xhi_Xhi_Xhi_Xhi_Xhi_WXY[Wh]/Wh]/X8a]XHe^XXi_Xhm`Xhm`XXi_XHe^X8a]X8a]X8a]X8a]
XHe^XXi_X8a]X8a]X8a]Wh]/X8a]XHe^XXi_Xhm`XXmZXXmZXXmZXXmZXXmZXXmZXXmZXXmZXHi[XHi[
XHi[XHi[XHi[XHi[XHi[XHi[XHeZXHeZXHeZXHeZXHeZXHeZXHeZXHeZWhaWWhaWX8eXX8eXXHiYXHiY
XXmZXXmZWh]XWh]XWh]XWh]XWh]XWh]XWh]XWh]XXHiYXHiYXHiYXHiYXHiYXHiYXHiYXHiYWXYWWXYW
WXYWWXYWWXYWWXYWWXYWWXYWWX]VWX]VWX]VWX]VWX]VWX]VWX]VWX]VW8YQWHYTWX]UWX]VWX]VWXYW
WHUVW8MWW8UTWHYUWHYUWHYTWH]RW8YQVhYOVXUNWhQRWhQRWhQRWhQRWhQRWhQRWhQRWhQRVXUNVXUN
VXUNVXUNVXUNVXUNVXUNVXUNW8IMW8IMW8IMWHMNWHMNWHMNWXQOWXQOW8IMW8IMWHMNWXQOWXQOWHMN
W8IMW8IMWXQOWHMNW8IMW8IMW8IMW8IMWHMNWXQOW8MJW8MJW8MJW8MJW8MJW8MJW8MJW8MJW8IMW8IM
W8IMW8IMW8IMW8IMW8IMW8IMW8MJW8MJW8MJW8MJW8MJW8MJW8MJW8MJVXEHVXEHVhIIVhIIW8MJW8MJ
WHQKWHQKUh=DV8AEVXIGWHUJWXYKWXYKWXYKWHUJWXQHWXQHWXQHWXQHWHMGWHMGWHMGWHMGWXMIWXMI
WXMIWXMIWXMIWXMIWXMIWXMIVXIGVXIGVXIGVXIGVXIGVXIGVXIGVXIGVhMHVhMHVhMHVhMHVhMHVhMH
VhMHVhMHW8EGW8EGW8EGW8EGW8EGW8EGW8EGW8EGW8EGW8EGW8EGW8EGWHIHWHIHWHIHWHIHWHEGWHEG
WHEGWXIHWXIHWXIHWhMIWhMIVhAFVhAFVhAFVhAFVhAFVhAFVhAFVhAFW8EGW8EGW8EGW8EGW8EGW8EG
W8EGW8EGVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVXADVXADVhEEVhEEW8IFW8IFW8IFW8IFW8ECW8EC
W8ECW8ECW8ECW8ECW8ECW8ECVhABVhABVhABVhABVhABVhABVhABVhABVhABVhABVhABVhABVhABVhAB
VhABVhABVH9@VX=AVX=AVX=AVhABVhABVhABW8ECVX=AVX=AVhABVhABVhABW8ECW8ECW8ECVhI?VhI?
VhEAVhEAVX=AVX=AVX=CVX=CVH9@VH9@VH9@VH9@VH9@VH9@VH9@VH9@V8=<V8=<V8=<V8=<V8=<V8=<
V8=<V8=<VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=V8=<V8=<V8=<V8=<V8=<Uh9;Uh9;Uh9;UX5:Uh9;
Uh9;V8=<V8=<VHA=VHA=VHA=UX5:Uh9;Uh9;V8=<V8=<VHA=VHA=VHA=VX=;VX=;VH9:VH9:VH9:V859
V859V859UX99UX99Uh=:V8A;V8A;Uh=:UX99UX99UX54Uh57Uh57V859VH9:VX9<Vh==Vh=?Uh=:Uh=:
Uh=:Uh=:Uh=:Uh=:Uh=:Uh=:V8A;V8A;V8A;V8A;V8A;V8A;V8A;V8A;VH9:VH9:VH9:VH9:VH9:VH9:
VH9:VH9:VH9:VH9:VH9:VX=;VX=;VX=;VhA<VhA<V859V859V859VH9:VH9:VH9:VX=;VX=;VX=;VX=;
VX=;VX=;VX=;VX=;VX=;VX=;VH9:VX=;VX=;VhA<VhA<VX=;VX=;VH9:VH9:VH9:VX=;VX=;VX=;VhA<
VhA<VhA<W8E=VhA<VhA<VX=;VX=;VhA<VhA<W8E=VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;
VX=;VX=;VX=;VX=;VX=;VX=;VhE;VhE;VhE;VhE;VhE;VhE;VhE;VhE;VX=;VX=;VX=;VhA<VhA<W8E=
W8E=W8E=VX=;VX=;VX=;VhA<VhA<W8E=W8E=W8E=V8=<V8=<VHA=VXE>VhI?W8M@W8M@WHQAVhA<VhA<
VhA<VhA<VhA<VhA<VhA<VhA<Vh==Vh==W8A>W8A>W8A>WHE?WHE?WHE?W8A>W8A>W8A>W8A>W8A>W8A>
W8A>W8A>VhA<VhA<VhA<VhA<W8E=W8E=W8E=WHI>W8E=WHI>WXM?WXM?WXM?WXM?WHI>W8E=WHE?WHE?
WHE?WHE?WHE?WHE?WHE?WHE?WXI@WXI@WHE?W8A>W8A>WHE?WXI@WXI@WXI@WXI@WXI@WXI@WXI@WXI@
WXI@WXI@WXI@WXI@WXI@WXI@WXI@WXI@002VTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRWU7VWU7VWU7VW
U7VXUGZXUGZYUW^YUW^VTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRUTWNUTWNUTWNUTWNUTWNUTWNUTWNU
TWNSSgJUTGRVTWVWTgZWTgZVTWVUTGRSSgJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJT
TGJTTGJTTGJTTGJTTGJST7FST7FST7FST7FST7FST7FST7FST7FTTGJST7FST7FRSgBRSgBST7FST7FT
TGJST7FST7FST7FST7FST7FST7FST7FST7FRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBPSG:QSW>ST7FT
TGJTTGJST7FQSW>PSG:OSG2OSG2PSW6PSW6QSg:RT7>RT7>RT7>TT76TT76TT76TT76TT76TT76TT76T
T76SSW:SSW:SSW:SSW:SSW:SSW:SSW:SSW:SSg2SSg2SSg2SSg2SSg2SSg2SSg2SSg2PS6fPS6fQSFjQ
SFjRSVnSSg2SSg2SSg2PSW6PSW6PSW6PSW6PSW6PSW6PSW6PSW6SSg2RSVnQSFjQSFjQSFjQSFjRSVnS
Sg2SSg2SSg2RSVnRSVnQSFjQSFjQSFjQSFjUSFnUSFnUSFnUSFnUSFnUSFnUSFnUSFnNRV^NRV^ORfbP
S6fQSFjRSVnSSg2SSg2RSVnQSFjPS6fPS6fPS6fPS6fQSFjRSVnPS6fPS6fORfbORfbPS6fQSFjRSVnS
Sg2RSfZRSfZRSfZRSfZRSfZRSfZRSfZRSfZQSV^QSV^QSV^QSV^QSV^QSV^QSV^QSV^PS6VPS6VPS6VP
S6VPS6VPS6VPS6VPS6VOS6NOS6NOS6NPSFRQSVVQSVVRSfZRSfZORfRORfRORfRORfRORfRORfRORfRO
RfROS6NOS6NOS6NOS6NOS6NOS6NOS6NOS6NNRVNNRVNNRVNNRVNNRVNNRVNNRVNNRVNNRfJNRfJNRfJN
RfJNRfJNRfJNRfJNRfJLRV6MRVBMRVBNRfJNRfJMRFJMRFJLQfNLRFBLRFBMRVFMRVBMRf:LRV6KRUnJ
REjOR6:OR6:OR6:OR6:OR6:OR6:OR6:OR6:JREjJREjJREjJREjJREjJREjJREjJREjKQEbLQUfLQUfL
QUfMQejMQejMQejMQejLQUfLQUfMQejNR5nNR5nMQejLQUfLQUfNR5nMQejLQUfLQUfLQUfLQUfMQejN
R5nKQUVKQUVKQUVKQUVKQUVKQUVKQUVKQUVKQEbKQEbKQEbKQEbKQEbKQEbKQEbKQEbKQUVKQUVKQUVK
QUVKQUVKQUVKQUVKQUVJQERJQERJQERKQUVLQeZLQeZMR5^MR5^EPE:GPeBJQUNLR5VNRU^ORebNRU^N
RU^ORUNORUNNREJNREJMR5FLQeBLQeBLQeBMQURMQURMQURMQURMQURMQURMQURMQURJQUNJQUNJQUNJ
QUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNLQENLQENLQENLQENLQENLQENLQENL
QENKQ5JKQ5JKQ5JLQENMQURMQURNQeVNQeVKPeFKPeFLQ5JLQ5JLQ5JMQENMQENMQENKQ5JKQ5JKQ5JK
Q5JKQ5JKQ5JKQ5JKQ5JLQENLQENLQENLQENLQENLQENLQENLQENKQEFKQEFKQEFKQEFKQEFKQEFKQEFK
QEFJQ5BJQ5BKQEFKQEFKQEFLQUJLQUJLQUJLQE>LQE>LQE>LQE>LQE>LQE>LQE>LQE>KQ5:KQ5:KQ5:K
Q5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:HPDnHPDnHPDnHPDnIPU2IPU2JPe6J
Pe6JPe6JPe6JPe6KQ5:KQ5:LQE>LQE>LQE>MR56MR56LQU:LQU:KQ5:JPe6JPe>JPe>IPU2IPU2IPU2I
PU2IPU2IPU2IPU2IPU2HPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fI
Q4fIQ4fIQ4fIQ4fHPdbGPT^GPT^FPDZFPDZFPDZFPDZGPT^GPT^HPdbIQ4fIQ4fIQ4fFPDZFPDZGPT^G
PT^HPdbIQ4fIQ4fIQ4fJPd^IPTZIPTZIPTZHPDVHPDVHPDVGP4RFPTVFPTVGPdZHQ4^HQ4^GPdZFPTVF
PTVFPDBFP4JGPDNHPDVIPTZJPTbKPdfKPdnGPdZGPdZGPdZGPdZGPdZGPdZGPdZGPdZHQ4^HQ4^HQ4^H
Q4^HQ4^HQ4^HQ4^HQ4^IPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZJPd^JPd^KQ4bK
Q4bGP4RHPDVHPDVHPDVIPTZIPTZIPTZJPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^IPTZIPTZJPd^K
Q4bKQ4bJPd^IPTZIPTZGP4RHPDVHPDVHPDVIPTZIPTZIPTZJPd^LQDfKQ4bJPd^JPd^JPd^JPd^KQ4bL
QDfJPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^KQTVKQTVKQTVK
QTVKQTVKQTVKQTVKQTVJPd^JPd^JPd^KQ4bKQ4bKQ4bLQDfLQDfJPd^JPd^JPd^KQ4bKQ4bKQ4bLQDfL
QDfFPDZFPDZGPT^HPdbIQ4fJQDjKQTnKQTnKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKPdfKPdfKPdfL
Q4jLQ4jLQ4jMQDnMQDnLQ4jLQ4jLQ4jLQ4jLQ4jLQ4jLQ4jLQ4jJPd^JPd^JPd^JPd^KQ4bKQ4bKQ4bL
QDfLQDfMQTjMQTjNQdnNQdnMQTjMQTjLQDfMQDnMQDnMQDnMQDnMQDnMQDnMQDnMQDnNQU2MQDnMQDnL
Q4jLQ4jMQDnMQDnNQU2NQU2NQU2NQU2NQU2NQU2NQU2NQU2NQU2NQU2NQU2NQU2NQU2NQU2NQU000:NE
N:NEN:NEN:NEN:NEN:NEN:NEN:NEN:JCN:JCN:JCN:JCN:NDNJNDNJNDNJRENZNDNJNDNJNDNJNDNJND
NJNDNJNDNJNDNJFBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjBAMZBAMZBAMZBAMZBAMZBAMZBAMZBAMZBA
MZBAMZBAMZBAMZBAMZBAMZBAMZBAMZ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJBAMZBAMZBAMZFB
MjFBMjFBMjFBMj>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ6>
Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj:?M::?M::?M::?M::?M::?M::?M::?M:6?L:6?L:6?L:6?L:6?
L:6?L:6?L:6?L:>AM::@Lj:@Lj6?LZ6?LZ2>LJ2>LIn=L::=LJ:=LJ:=LJ:=LJ:=LJ:=LJ:=LJ:=LJ:>
Kj:>Kj:>Kj:>Kj:>Kj:>Kj:>Kj:>Kj6=KZ6=KZ6=KZ:>Kj:>Kj:>Kj>?L:>?L::>Kj:>Kj:>Kj:>Kj:>
Kj:>Kj:>Kj:>Kj6=KZ6=KZ6=KZ:>Kj:>Kj:>Kj>?L:>?L:6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ6=
KZ6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ2<KJ2<KJ2<KJ6=KZ6=KZ6=KZ:>Kj:>Kj6=KZ6=KZ6=KZ6=KZ6=
KZ6=KZ6=KZ6=KZ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ6>JJ6>JJ6>JJ6>JJ6>JJ6>JJ6>JJ6>JJ:?
JZ6>JJ2=J:2=J:2=J:2=J:6>JJ:?JZ6>JJ6>JJ6>JJ6>JJ6>JJ6>JJ6>JJ6>JJ:?JZ6>JJ6>JJ6>JJ2=
J:2=J:2=J:2=J9n<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Iij;IYj;IYj;IYj;IYj;IYj;IYj;IYj;IYf:
IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIZ8GiZ7HIZ7HI^8Hi^8
Hi^7I9b8IIb7Iib8IIb8IIj8I9f7Hin8HYj8Gj27Gj28GYj8Gij8Gij8Gin9H9n9H:2:HJ2:HJ2:HJ2:
HIj8Gif7GI^5Fi^6FI^7F9f9FYf9FYb7FYb7FYf8Fij9G9j9G9f8Fib7FYb7FYb7FYb7FYb7FYb7FYb7
FYb7FYb7FYb7FYf8Fib7FY^6FIZ5F9Z5F9^6FIb7FYf8Fif8Fif8Fif8Fib7FY^6FI^6FIZ5F9Z5F9b7
FYb7FYb7FYb7FYb7FYb7FYb7FYb7FYb8FIb8FIb8FIb8FIb8FIb8FIb8FIb8FI^4EY^4EY^4EY^4EY^4
EY^4EY^4EY^4EY^4EYb5Eib5Eib5Eif6F9f6F9f6F9j7FIb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYj8
F9j8F9j8F9j8F9j8F9j8F9j8F9j8F9b6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb5Eib5Eib5Eib5Eib5
Eib5Eib5Eib5Eib6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYZ4E9^5EIb6EYb6EYb6EYb6EY^5EIZ4E9^5
EI^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EIZ4E9Z4E9^5EI^5EIb6
EYb6EYb6EYb6EYV3Di^5EIf7Eif7Ei^5EIZ4E9^5EIb6EYZ3DIZ3DI^4DY^4DY^4DYb5Dib5Dib5Di^6
Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6CiV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CI^6Ci^6Ci^6Ci^6Ci^6
Ci^6Ci^6Ci^6Cib7D9b7D9^6CiZ5CYZ5CYV4CIV4CIR3C9R3C9V4CIV4CIZ5CYZ5CY^6Ci^6Cib7D9Z5
CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4
CIV4CIV4CIV4CIZ6CIV5C9V5C9R4BiR4BiN3BYJ2BIJ2BIN3BYN3BYN3BYN3BYN3BYN3BYN3BYN3BYN2
BiN2BiN2BiN2BiN2BiN2BiN2BiN2Bi>1C9F0C9J1CIR2CYR2CY^3Ci^3Cif2CiR1BIV2BY^4C9b5CIb5
CI^4C9V2BYR1BIEoAIJ0AYR2B9V3BIZ4BYV3BIR2B9N1AiV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIJ0
AYN1AiV3BIZ4BY^5BiZ4BYV3BIR2B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9V2BYV2BYV2BYV2BYV2
BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYR1BIR1BIR1BIJ0AYJ0AYN1AiR2B9V3BIZ4BY^5Bi^5BiZ4
BYZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIV4AYV4AYV4AiZ5B9Z4
BYZ3Bi^4C9^4C9^5Bi^5Bib6C9b6C9b6C9f7CIf7CIf7CIZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYZ4
BYZ4BYZ4BYZ4BYZ4BYV3BIV3BIV3BIR2B9R2B9R2B9V3BIV3BIV3BIZ4BYZ4BYR1BIR1BIV2BYZ3BiZ3
Bi^4C9^4C9^4C9V2BYV2BYZ3Bi^4C9^4C9Z3BiV2BYV2BYf6CYb5CIb5CI^4C9^4C9Z3BiZ3BiV2BYZ3
BiZ3BiZ3Bi^4C9^4C9b5CIb5CIb5CIZ3Bi^4C9^4C9b5CIb5CI^4C9^4C9Z3Bi^3Ci^3Ci^3Ci^3Ci^3
Ci^3Ci^3Ci^3CiZ3BiZ3BiZ3Bi^4C9^4C9b5CIb5CIb5CI^4C9^4C9b5CIf6CYj7Cin8D:29DJ29DIZ6
CIZ6CIV5C9^4C9f4C9j5CJ66CZ:7Cij6DYj6DYj6DYf5DIf5DIf5DIf5DIf5DIb4D9b4D9b4D9b4D9b4
D9b4D9b4D9b4D9j7Cij7Cij7Cif6CYf6CYf6CP00YYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYI9gYY=h
YY=hYY=hYiAiYiAiYiAiYiAiYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYI9gYI9gYI9gYI9gYI9gYI9g
YI9gYI9gY95fY95fY95fY95fY95fY95fY95fY95fY95fY95fY95fY95fY95fY95fY95fY95fXi1eXi1e
Xi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eY95fY95fYI9gYI9gYI9gXi1eXi1eXi1eXi1eXi1eXi1e
Xi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXHicXHicXHicXHicXHicXHicXHicXHicXXmdXXmd
XXmdXXmdXXmdXXmdXXmdXXmdXHm`XHm`XHm`XHm`XHm`XHm`XHm`XHm`XHmbXHmbXHmbXHmbXHmbX8ia
X8iaX8iaXXeaXXeaXXeaXXeaXXeaXXeaXXeaXXeaXXi_XXi_XXi_XXi_XXi_XXi_XXi_XXi_XHe^XHe^
XHe^XHe^XXi_XXi_Xhm`Xhm`XXi_XXi_XXi_XXi_XXi_XXi_XXi_XXi_XHe^XHe^XHe^XHe^XXi_XXi_
Xhm`Xhm`XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^Wh]/X8a]
X8a]X8a]XHe^XHe^XHe^XXi_XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/
Wh]/Wh]/X8eXX8eXX8eXX8eXX8eXX8eXX8eXX8eXXHiYXHiYX8eXWhaWWhaWX8eXXHiYXHiYX8eXX8eX
X8eXX8eXX8eXX8eXX8eXX8eXXHiYXHiYXHiYXHiYX8eXX8eXX8eXWhaWWhaWWhaWWhaWWhaWWhaWWhaW
WhaWWhaWWX]VWX]VWX]VWX]VWX]VWX]VWX]VWX]VWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYU
WHYUWHYUWHYUWHYUWHYUWHYUVXQOVXMQVhQRVhQSW8UTW8QUW8QUW8MWW8QUW8UTWHMSWHQRWhQRWXQO
X8QNX8QNWXQOWXQOWXQOWXQOWhUPWhUPX8YQX8YQWhUPWXQOW8ILVhEKVhIIVhMHW8QIWHUJW8MJW8MJ
WHQKWXULWXULWHQKW8MJW8MJVhIIVhIIVhIIVhIIVhIIVhIIVhIIVhIIWHQKW8MJVhIIVXEHVXEHVhII
W8MJWHQKWHQKWHQKW8MJW8MJVhIIVhIIVXEHVXEHVhIIVhIIVhIIVhIIVhIIVhIIVhIIVhIIVXIGVXIG
VXIGVXIGVXIGVXIGVXIGVXIGVhAFVhAFVhAFVhAFVhAFVhAFVhAFVhAFVhAFVhAFW8EGW8EGW8EGWHIH
WHIHWHIHW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IF
W8IFW8IFW8IFW8IFW8IFW8IFW8EGW8EGW8EGW8EGW8EGW8EGW8EGW8EGW8IFW8IFW8IFW8IFW8IFW8IF
W8IFW8IFVXADVhEEW8IFW8IFW8IFW8IFVhEEVXADVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEE
VhEEVhEEVhEEVhEEVhEEVhEEVXADVXADVhEEVhEEVhEEW8IFW8IFW8IFVH=CVhEEWHMGWHMGVhEEVXAD
VXADVhEEVX=AVX=AVX=AVhABVhABW8ECW8ECW8ECVhI?VhI?VhI?VhI?VhI?VhI?VhI?VhI?VHA=VHA=
VHA=VHA=VHA=VHA=VHA=VHA=VhI?VhI?VhI?VhI?VhI?VhI?VhI?VhI?VhI?VhI?VhI?VXE>VXE>VHA=
VHA=V8=<VHA=VHA=VXE>VXE>VXE>VXE>VXE>VhI?VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=
VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHE<VHE<V8A;V8A;Uh=:Uh=:
UX99UX99Uh=:Uh=:Uh=:Uh=:Uh=:Uh=:Uh=:Uh=:Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;U8=;UX9;
UX9;V8=<V8=<VX9<VX9<W89<V859VH9:VX=;VhA<VhA<VX=;VH9:V859UGm5UX16Uh57VH=9VH=9VH=9
V898Uh57VH=9VH=9VH=9VH=9VH=9VH=9VH=9VH=9UX16Uh57V898VXA:VXA:VXA:VH=9V898Uh57Uh57
Uh57Uh57Uh57Uh57Uh57Uh57VH9:VH9:VH9:VH9:VH9:VH9:VH9:VH9:VH9:VH9:VH9:VH9:V859V859
V859V859Uh57Uh57V898V898VH=9VH=9VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:VH=9VH=9
VH=9VH=9VH=9VH=9VH=9VH=9VHA6VHA6VHA7VHA7VXA:VX=;VhA<VhA<VH=9VXA:VXA:VXA:VhE;VhE;
VhE;VhE;VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:VH=9VH=9VH=9Uh57V898
V898V898VH=9VH=9VH=9VXA:VH9:VH9:VH9:VX=;VX=;VX=;VX=;VX=;VH9:VH9:VX=;VhA<VhA<VX=;
VH9:VH9:VhA<VhA<VhA<VhA<VhA<VX=;VX=;VX=;VX=;VX=;VX=;VhA<VhA<VhA<W8E=W8E=VX=;VX=;
VhA<W8E=W8E=VhA<VX=;VX=;Vh==Vh==Vh==Vh==Vh==Vh==Vh==Vh==VX=;VX=;VX=;VhA<VhA<VhA<
W8E=W8E=VH9:VX=;VX=;VhA<W8E=WHI>WXM?WXM?VXI=VHE<VHE<VhA<WHA<WXE=XHI>XXM?WHE?WHE?
WHE?WHE?WHE?WHE?WHE?WHE?W8A>W8A>W8A>W8A>W8A>W8A>W8A>W8A>WHI>WHI>WHI>WHI>WHI>WHI>
002VU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NUTWNUTWNUTWNVTgRVTgRWU7VWU7VWU7VVTgRVTgRVTgRV
TgRVTgRVTgRVTgRVTgRUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNTTGJTTGJTTGJTTGJTTGJTTGJTTGJT
TGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJST7FST7FST7FST7FST7FST7FST7FST7FRSgBRSgBST7FS
T7FTTGJTTGJTTGJTTGJST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FS
T7FRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBPSVnPSVnPSVnP
SVnPSVnPSVnPSVnPSVnPSW6PSW6PSW6PSW6QSg:QSg:QSg:QSg:QS72QS72QS72QS72QS72QS72QS72Q
S72QSFjQSFjQSFjQSFjQSFjQSFjQSFjQSFjPS6fPS6fQSFjQSFjRSVnRSVnRSVnRSVnQSFjQSFjQSFjQ
SFjQSFjQSFjQSFjQSFjPS6fPS6fQSFjQSFjRSVnRSVnRSVnRSVnPS6fPS6fPS6fPS6fPS6fPS6fPS6fP
S6fPS6fPS6fPS6fPS6fPS6fPS6fPS6fPS6fORfbORfbPS6fPS6fPS6fQSFjQSFjQSFjPS6fPS6fPS6fP
S6fPS6fPS6fPS6fPS6fORfbORfbORfbORfbORfbORfbORfbORfbPSFRPSFRPSFRPSFRPSFRPSFRPSFRP
SFRQSVVPSFRPSFROS6NOS6NPSFRPSFRQSVVPSFRPSFRPSFRPSFRPSFRPSFRPSFRPSFRQSVVQSVVQSVVP
SFRPSFROS6NOS6NOS6NOS6NOS6NOS6NOS6NOS6NOS6NOS6NOS6NNRfJNRfJNRfJNRfJNRfJNRfJNRfJN
RfJMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFKRF2KR6:LRF>L
RFBLRFBMRFJMRFJMR6RKR6>KR6>MR6:MR6:NR5nNR5jPR5jOQefMQefMQefMQefNR5jNR5jOREnOREnO
REnNR5nMQejLQUbKQE^KQUVKQeRLR5VLR5VKQUVLQeZMR5^MR5^MR5^MR5^LQeZKQUVKQUVKQUVKQUVK
QUVKQUVKQUVKQUVKQUVLQeZKQUVKQUVJQERJQERKQUVKQUVLQeZLQeZLQeZLQeZKQUVKQUVKQUVJQERJ
QERKQUVKQUVKQUVKQUVKQUVKQUVKQUVKQUVIQEJIQEJIQEJIQEJIQEJIQEJIQEJIQEJKQ5JKQ5JKQ5JK
Q5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JLQENLQENMQURMQURMQURLQUJLQUJLQUJLQUJLQUJLQUJLQUJL
QUJKQEFKQEFKQEFKQEFKQEFKQEFKQEFKQEFLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQENLQENLQENL
QENLQENLQENLQENLQENLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJJQ5BJQ5BKQEFLQUJLQUJKQEFJQ5BJ
Q5BKQEFKQEFKQEFKQEFKQEFKQEFKQEFKQEFKQU>KQU>KQU>KQU>KQU>KQU>KQU>KQU>JQ5BJQ5BJQ5BK
QEFKQEFKQEFLQUJLQUJIPe>KQEFMQeNMQeNKQEFJQ5BJQ5BKQEFJPe6JPe6JPe6JPe6KQ5:KQ5:LQE>L
QE>KQTnKQTnKQTnKQTnKQTnKQTnKQTnKQTnJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjKQTnKQTnKQTnK
QTnKQTnKQTnKQTnKQTnKQTnJQDjJQDjJQDjIQ4fIQ4fIQ4fIQ4fJQDjJQDjJQDjJQDjIQ4fIQ4fIQ4fI
Q4fGPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^HPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbH
PdbHPdbHPdbHPdbHPdbHQ4^HQ4^HQ4^HQ4^GPdZGPdZGPdZFPTVFPTVFPTVFPTVFPTVFPTVFPTVFPTVF
PTVFPDZFPDZFPDZFPDZFPDZFPDZFPDZFPDZEQ4bGPdbGPdbGPT^GPT^IPD^IPD^KPD^HPDVHPDVIPTZJ
Pd^JPd^IPTZHPDVHPDVEOdFFP4JGPDNHPTRHPTRHPTRHPTRGPDNHPTRHPTRHPTRHPTRHPTRHPTRHPTRH
PTRFP4JFP4JHPTRIPdVIPdVIPdVHPTRHPTRGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNHPDVHPDVHPDVH
PDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVHPTRHPTRHPTRHPTRHPTRHPTRIPdVI
PdVIPdVIPdVIPdVIPdVIPdVIPdVIPdVIPdVHPTRHPTRHPTRHPTRHPTRHPTRHPTRHPTRHPdFHPdFIQ4NI
Q4NJQ4ZJPd^JPd^JPd^HPTRHPTRHPTRHPTRIPdVIPdVJQ4ZJQ4ZIPdVIPdVIPdVIPdVIPdVIPdVIPdVI
PdVIPdVIPdVIPdVIPdVIPdVIPdVIPdVIPdVGPDNGPDNHPTRHPTRHPTRIPdVIPdVIPdVJPd^JPd^JPd^I
PTZIPTZIPTZIPTZIPTZHPDVIPTZJPd^JPd^JPd^JPd^IPTZHPDVJPd^JPd^JPd^JPd^KQ4bKQ4bKQ4bK
Q4bIPTZJPd^JPd^JPd^KQ4bKQ4bKQ4bKQ4bIPTZJPd^KQ4bKQ4bKQ4bKQ4bJPd^IPTZJPTbJPTbJPTbJ
PTbJPTbJPTbJPTbJPTbIPTZJPd^JPd^JPd^KQ4bKQ4bKQ4bKQ4bHPDVHPDVIPTZJPd^KQ4bKQ4bLQDfL
QDfJQTfIQDbIQDbJPd^MQ4bNQDfQQTjRQdnMQDnMQDnMQDnMQDnMQDnMQDnMQDnMQDnLQ4jLQ4jLQ4jL
Q4jLQ4jLQ4jLQ4jLQ4jMQTjMQTjMQTjMQTjMQTjMQTh00:JDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjFB
MjFBMjFBMjFBMjJCN:JCN:NDNJNDNJJCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:FBMjFBMjFBMjFBMjFB
MjFBMjFBMjFBMj>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ:?
M::?M::?M::?M::?M::?M::?M::?M:6>Lj:?M::?M::?M:>@MJ>@MJ>@MJBAMZ:?M::?M::?M::?M::?
M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M:6>
Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj2>Kj2>Kj2>Kj2>Kj2>Kj2>Kj2>Kj2>Kij<Kin=L9n=L:2>LJ2>
LJ6?LZ6?LZ:@Lj6<L:6<L:6<L:6<L:6<L:6<L:6<L:6<L:6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ2<
KJ2<KJ2<KJ6=KZ6=KZ6=KZ:>Kj:>Kj6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ2<KJ2<KJ2<KJ6=KZ6=
KZ6=KZ:>Kj:>Kj2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KIn;
K9n;K9n;K:2<KJ2<KJ2<KJ6=KZ6=KZ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KIn;K9n;K9n;K9n;K9n;
K9n;K9n;K9n;K:2=J:2=J:2=J:2=J:2=J:2=J:2=J:2=J:6>JJ2=J9n<Iin<Iin<Iin<Ij2=J:6>JJ2=
J:2=J:2=J:2=J:2=J:2=J:2=J:2=J:6>JJ6>JJ2=J:2=J9n<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Iin<
Iin<Iin<Iin<Iif:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIb9I9b9I9b9I9b9I9b9I9b9I9b9I9b9I9b9
I9b9I9b9I9b9I9b9I9b9I9b9I9b9I9^9H9b9Hib9Hib9I9f:IIf9IYf9IYf8J9^8Hi^8HYf8HYb8Gij8
GYf7GIn8Fin8Fib6G9b6G9f7GIf7GIf7GIj8GYj8GYj8GYf7GYf7GYb6G9b6G9^6FI^7F9^7F9^7F9^6
FI^6FIb7FYf8Fif8Fib7FY^6FI^6FI^6FI^6FI^6FI^6FI^6FI^6FI^6FI^6FI^6FI^6FIZ5F9Z5F9Z5
F9Z5F9^6FI^6FI^6FI^6FI^6FI^6FI^6FIZ5F9Z5F9Z5F9^6FI^6FI^6FI^6FI^6FI^6FI^6FI^6FIV5
EYV5EYV5EYV5EYV5EYV5EYV5EYV5EY^4EY^4EY^4EY^4EY^4EY^4EY^4EY^4EYZ3EI^4EY^4EY^4EYb5
Eib5Eib5Eif6F9b6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EY^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EIb6
EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6
EYb6EYb6EYb6EYV3DiZ4E9^5EI^5EI^5EI^5EIZ4E9V3DiZ4E9Z4E9Z4E9Z4E9Z4E9Z4E9Z4E9Z4E9Z5
DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYV3DiV3DiZ4E9Z4E9^5EI^5EI^5EI^5EIR2DYZ4E9b6EYb6EYZ4
E9V3DiZ4E9^5EIV2D9V2D9Z3DIZ3DIZ3DI^4DY^4DY^4DYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5
CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYV4CIV4CIV4CIV4CIV4
CIV4CIV4CIV4CI^6CiZ5CYZ5CYV4CIV4CIR3C9R3C9R3C9N2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiR3
C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9N3BYN3BYN3BYN3BYN3
BYN3BYN3BYN3BYJ2BIJ2BIJ2BIJ2BIJ2BIJ2BIJ2BIJ2BIJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYF4
BiN4BiN4BiN3BYN3BYR1BIR1BIV0B9R1BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIEoAIJ0AYJ0AYN1AiN1
AiN1AiN1AiN1AiR2B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9EoAIJ0AYJ0AYN1AiN1AiR2B9R2B9R2B9N1
AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiR1BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIN0B9N0B9N0B9R1BIR1
BIR1BIR1BIR1BIR2B9R2B9R2B9R2B9R2B9N1AiN1AiN1AiV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIR2
B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9R3AIR3AIR3AYV4AiV3BIV2BYZ3BiZ3BiN1AiN1AiR2B9R2B9V3
BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIR2B9R2B9R2B9V3BIV3BIV3BIV3BIZ4BYN1
AiN1AiN1AiR2B9R2B9R2B9V3BIV3BIZ3BiZ3BiZ3BiV2BYV2BYR1BIR1BIN0B9R1BIR1BIV2BYZ3BiZ3
BiV2BYR1BIR1BIR1BIV2BYV2BYZ3BiZ3Bi^4C9^4C9b5CIV2BYV2BYV2BYZ3BiZ3Bi^4C9^4C9^4C9V2
BYZ3BiZ3Bi^4C9^4C9Z3BiZ3BiV2BYZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiV2BYV2BYV2BYZ3BiZ3
Bi^4C9^4C9^4C9V2BYV2BYZ3BiZ3Bi^4C9^4C9b5CIb5CIV5C9V5C9R4BiZ3Bib3Bif4C:25CJ66CYb5
CIb5CIb5CIb5CIb5CIf6CYf6CYf6CY^4C9^4C9^4C9^4C9^4C9^4C9^4C9^4C9b5CIb5CIb5CIb5CIb5
CIf6CP00YI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fY95fY95fYI9gYI9gYI9gYY=hYY=hYY=hYI9gYI9g
YI9gYI9gYI9gYI9gYI9gYI9gY95fY95fY95fY95fY95fY95fY95fY95fXi1eXi1eXi1eXi1eXi1eXi1e
Xi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdX8ebXHic
XHicXHicXXmdXXmdXXmdXi1eXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmd
XXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXHicXHicXHicXHicXHicXHicXHicXHicX8i_X8i_
X8i_X8i_X8i_X8i_X8i_X8i_WXa_WXa_Whe`Whe`X8iaX8iaXHmbXHmbX8]_X8]_X8]_X8]_X8]_X8]_
X8]_X8]_X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]Wh]/Wh]/X8a]X8a]XHe^XHe^XHe^XHe^X8a]X8a]
X8a]X8a]X8a]X8a]X8a]X8a]Wh]/Wh]/X8a]X8a]XHe^XHe^XHe^XHe^Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/
Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/WXY[WXY[Wh]/Wh]/Wh]/X8a]X8a]X8a]Wh]/Wh]/
Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WhaWWhaWWhaWWhaWWhaWWhaW
WhaWWhaWX8eXX8eXWhaWWX]VWX]VWhaWX8eXX8eXWhaWWhaWWhaWWhaWWhaWWhaWWhaWWhaWX8eXX8eX
X8eXWhaWWhaWWhaWWX]VWX]VWX]VWX]VWX]VWX]VWX]VWX]VWX]VWX]VWHYUWHYUWHYUWHYUWHYUWHYU
WHYUWHYUW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTVhUPVhQR
VhQRW8UTW8UTWHUVWHUVWHQXVhQRVXMQW8QOW8QOWHMMWHQKWhQKWXMIVhIIVhIIW8MJW8MJW8MJWHQK
WHQKWHQKW8IMW8IMW8ILW8ILVhIIVhMHVXIGVXIGVXEHVhIIW8MJW8MJW8MJW8MJVhIIVXEHVXEHVXEH
VXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEH
VXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXEHVXIGVXIGVXIGVXIGVXIGVXIGVXIGVXIGVhAFVhAF
VhAFVhAFVhAFVhAFVhAFVhAFVX=EVX=EVX=EVhAFVhAFW8EGW8EGW8EGVhEEVhEEVhEEVhEEVhEEVhEE
VhEEVhEEW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhICVhIC
VhICVhICVhICVhICVhICVhICVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVH=CVH=CVXADVhEEVhEEVXAD
VH=CVH=CVXADVXADVXADVXADVXADVXADVXADVXADVXEAVXEAVXEAVXEAVXEAVXEAVXEAVXEAVH=CVH=C
VH=CVXADVXADVXADVhEEVhEEV89BVXADW8IFW8IFVXADVH=CVH=CVXADVH9@VH9@VH9@VX=AVX=AVX=A
VhABVhABVXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>
VXE>VXE>VXE>VXE>VXE>VXE>V8=<V8=<V8=<VHA=VHA=VHA=VHA=VHA=VXE>VXE>VXE>VHA=V8=<V8=<
Uh9;Uh9;V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<
V8=<V8=<V8=<V8=<V8=<V8=<UX99UX99UX99UX99UX99Uh=:Uh=:Uh=:UH58UH58UH58UH58UH58UH58
UH58UH58UH19UH19UH19UH19UH19UH19UH19UH19UHA;UhA;UX=:Uh=:UX99Uh18Uh18VH18Uh18Uh18
Uh18Uh18Uh18Uh18Uh18Uh18UGm5UGm5UGm5UX16UX16Uh57Uh57V898Uh57Uh57Uh57Uh57Uh57Uh57
Uh57Uh57UGm5UGm5UGm5UGm5UX16UX16Uh57Uh57UX16UX16UX16UX16UX16UX16UX16UX16Uh18Uh18
Uh18Uh18Uh18Uh18Uh18Uh18UWm7UWm7UWm7Uh18V859V859V859VH9:V898V898V898Uh57Uh57Uh57
Uh57Uh57V898V898V898V898V898V898V898V898Uh57Uh57Uh57Uh57Uh57Uh57Uh57Uh57Uh94Uh94
V8=6V8=6VH=9VH9:VH9:VH9:V898V898V898VH=9VH=9VXA:VXA:VXA:V898V898V898V898V898V898
V898V898Uh57Uh57V898V898VH=9VH=9VXA:VXA:UX16UX16Uh57Uh57Uh57V898V898V898VX=;VX=;
VH9:VH9:V859Uh18Uh18Uh18Uh18V859VH9:VH9:VH9:VH9:V859Uh18V859V859VH9:VH9:VX=;VX=;
VhA<VhA<V859VH9:VH9:VH9:VX=;VX=;VX=;VhA<VH9:VH9:VX=;VX=;VX=;VX=;VH9:VH9:VX=;VX=;
VX=;VX=;VX=;VX=;VX=;VX=;V859VH9:VH9:VH9:VX=;VX=;VX=;VhA<VhA<VhA<VhA<VhA<W8E=W8E=
W8E=W8E=VHE<V8A;V8A;VH9:W8=;WHA<X8E=XHI>VX=;VhA<VhA<VhA<W8E=WHI>WHI>WHI>VhA<VhA<
VhA<VhA<VhA<VhA<VhA<VhA<VX=;VhA<VhA<VhA<W8E=WHI>002UTgJUTgJUTgJUTgJUTgJUTgJUTgJU
TgJTTGJTTGJTTGJTTGJUTWNUTWNVTgRVTgRUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNTTGJTTGJTTGJT
TGJTTGJTTGJTTGJTTGJRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBR
SgBQSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>PSG:PSG:PSG:PSG:QSW>QSW>RSgBRSgBQSW>QSW>QSW>Q
SW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>Q
SW>PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:OSFjOSFjOSFjOSFjOSFjOSFjOSFjOSFjNS6nOSG2OSG2O
SG2OSG2OSG2PSW6PSW6PRfnPRfnPRfnPRfnPRfnPRfnPRfnPRfnPS6fPS6fPS6fPS6fPS6fPS6fPS6fP
S6fORfbORfbORfbPS6fPS6fQSFjQSFjQSFjPS6fPS6fPS6fPS6fPS6fPS6fPS6fPS6fORfbORfbORfbP
S6fPS6fQSFjQSFjQSFjORfbORfbORfbORfbORfbORfbORfbORfbORfbORfbORfbORfbORfbORfbORfbO
RfbNRV^NRV^NRV^ORfbORfbORfbPS6fPS6fORfbORfbORfbORfbORfbORfbORfbORfbNRV^NRV^NRV^N
RV^NRV^NRV^NRV^NRV^OS6NOS6NOS6NOS6NOS6NOS6NOS6NOS6NPSFROS6NNRfJNRfJNRfJNRfJOS6NP
SFROS6NOS6NOS6NOS6NOS6NOS6NOS6NOS6NPSFRPSFROS6NOS6NNRfJNRfJNRfJNRfJNRfJNRfJNRfJN
RfJNRfJNRfJNRfJNRfJLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBKR6>KR6>KR6>KR6>KR6>KR6>KR6>K
R6>KR6>KR6>KR6>KR6>KR6>KR6>KR6>KR6>JR5nJQf6JQf6KR6>KR6>KQfBLR6FLQfNJR5nJR5nLR5nK
R5fMR5^LQeZNQeVNQeVJQUNJQUNKQeRKQeRKQeRLR5VLR5VLR5VKQEbKQEbLQUbLQUbLQeZKQeRJQUNI
QEJJQERJQERKQUVLQeZLQeZKQUVJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERIQ5NIQ5NJQERK
QUVKQUVJQERIQ5NIQ5NIQ5NIQ5NIQ5NIQ5NJQERJQERJQERKQUVJQERJQERJQERJQERJQERJQERJQERJ
QERJQUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JJPeFJPeFJPeFJ
PeFKQ5JKQ5JKQ5JLQENKQEFKQEFKQEFKQEFKQEFKQEFKQEFKQEFLQUJLQUJLQUJLQUJLQUJLQUJLQUJL
QUJKQEFKQEFKQEFKQEFKQEFKQEFKQEFKQEFKQU>KQU>KQU>KQU>KQU>KQU>KQU>KQU>KQEFKQEFKQEFK
QEFKQEFKQEFKQEFKQEFHPU:IPe>JQ5BJQ5BJQ5BJQ5BIPe>HPU:IPe>IPe>IPe>IPe>IPe>IPe>IPe>I
Pe>IQ52IQ52IQ52IQ52IQ52IQ52IQ52IQ52HPU:IPe>IPe>IPe>JQ5BJQ5BJQ5BJQ5BGPE6IPe>KQEFK
QEFJQ5BHPU:IPe>JQ5BHPDnHPDnIPU2IPU2JPe6JPe6JPe6JPe6IQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fI
Q4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fGPT^GPT^HPdbH
PdbHPdbIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbH
PdbGPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^EPDREPDREPDRF
PTVFPTVFPTVGPdZGPdZEPDREPDREPDREPDREPDREPDREPDREPDREP4VEP4VEP4VEP4VEP4VEP4VEP4VE
P4VDQ4VEPdREPdRFPTRFPTRHPTRGPDNIPDNGP4RGP4RFOdNEOTJEOTJFOdNGP4RGP4RFP4JEOdFEOdFD
OTBEOdFFP4JGPDNHPTRGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNEOdFEOdFDOTBDOTBDOTBEOdFFP4JG
PDNFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4REOTJEOTJFOdNF
OdNGP4RHPDVIPTZIPTZFP4JFP4JGPDNGPDNGPDNGPDNGPDNGPDNHPTRHPTRHPTRHPTRHPTRHPTRHPTRH
PTRGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPTBGPTBGPTFHPdJHPTRIPTZIPTZIPTZHPTRHPTRHPTRH
PTRIPdVIPdVJQ4ZJQ4ZHPTRHPTRHPTRHPTRHPTRHPTRHPTRHPTRFP4JFP4JGPDNHPTRHPTRIPdVJQ4ZJ
Q4ZFP4JFP4JFP4JGPDNGPDNGPDNHPTRHPTRIPTZHPDVHPDVHPDVHPDVHPDVGP4RGP4RGP4RHPDVHPDVI
PTZIPTZHPDVHPDVGP4RHPDVIPTZIPTZIPTZIPTZIPTZJPd^JPd^HPDVHPDVHPDVIPTZIPTZJPd^JPd^J
Pd^HPDVIPTZIPTZJPd^JPd^IPTZIPTZHPDVIPdVIPdVIPdVIPdVIPdVIPdVIPdVIPdVHPDVHPDVHPDVI
PTZIPTZJPd^JPd^JPd^KQ4bKQ4bLQDfLQDfLQDfLQDfLQDfLQDfHQ4^HQ4^GPdZIPTZKPTZLPd^OQ4bP
QDfIPdVJQ4ZJQ4ZKQD^LQTbLQTbMQdfMQdfJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZIPTZJPd^JPd^K
Q4bLQDfLQDd00:BBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJ>@MJ>@MJBAMZBAMZFBMjFBMjFBMjFBMjBA
MZBAMZBAMZBAMZBAMZBAMZBAMZBAMZ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ:?M::?M::?M::?M::?
M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M:6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lin<
LIn<LIn<LJ2=LZ2=LZ6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>
Lj6>Lj6>Lj6>Lin<LIn<LIn<LIn<LIn<LIn<LIn<LIn<LJ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LYn=
KYn=KYn=KYn=KYn=KYn=KYn=KYn=KYn=L9n=L9n=L9n=L9n=L9j<Kij<Kij<Kj2;Kj2;Kj2;Kj2;Kj2;
Kj2;Kj2;Kj2;Kj2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KIn;K9n;K9n;K9n;K:2<KJ2<KJ2<KJ6=KZ2<
KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KIn;K9n;K9n;K9n;K:2<KJ2<KJ2<KJ6=KYj:Jij:Jij:Jij:Jij:
Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jif9JYj:Jij:Jij:Jin;K9n;K9n;K:2<KIj:
Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jif9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYj;IYj;IYj;IYj;IYj;
IYj;IYj;IYj;IYn<Iin<Iij;IYf:IIf:IIj;IYn<Iin<Iij;IYj;IYj;IYj;IYj;IYj;IYj;IYj;IYn<
Iin<Iin<Iin<Iij;IYj;IYf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIb9I9b9I9b9I9b9I9b9
I9b9I9b9I9b9I9^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8HiR6
GIR5GiV6H9V6HIZ7HYZ6HiZ6HiZ5IIZ8GiZ8Gi^8GI^8Fif8Fib8FIj7FIj8F9Z6EiZ6EiZ6EiZ6Ei^7
F9^7F9^7F9b8FIZ4Fi^5G9b6G9b6G9b7FY^7F9V5EYR4EIV4EiZ5F9^6FI^6FI^6FI^6FIZ5F9V4EiV4
EiV4EiV4EiV4EiV4EiV4EiV4EiV4EiR3EYV4EiZ5F9^6FI^6FIZ5F9V4EiR3EYR3EYR3EYV4EiV4EiZ5
F9Z5F9^6FI^6FIV4EiV4EiV4EiV4EiV4EiV4EiV4EiV4EiV5EYV5EYV5EYV5EYV5EYV5EYV5EYV5EY^4
EY^4EY^4EY^4EY^4EY^4EY^4EY^4EYV2E9V2E9Z3EIZ3EIZ3EI^4EY^4EY^4EYZ4E9Z4E9Z4E9Z4E9Z4
E9Z4E9Z4E9Z4E9^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EIZ4E9Z4E9Z4E9Z4E9Z4E9Z4E9Z4E9Z4E9Z5
DIZ5DIZ5DIZ5DIZ5DIZ5DIZ5DIZ5DIZ4E9Z4E9Z4E9Z4E9Z4E9Z4E9Z4E9Z4E9R2DYV3DiV3DiZ4E9Z4
E9V3DiV3DiR2DYV3DiV3DiV3DiV3DiV3DiV3DiV3DiV3DiV5CYV5CYV5CYV5CYV5CYV5CYV5CYV5CYR2
DYR2DYV3DiV3DiV3DiZ4E9Z4E9Z4E9N1DIV3Di^5EI^5EIV3DiR2DYR2DYV3DiR1CiR1CiR1CiV2D9V2
D9Z3DIZ3DIZ3DIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiV4
CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIJ1BYN2BiN2BiR3C9R3C9V4CIV4CIV4CIN2BiN2BiN2BiR3C9R3
C9R3C9R3C9R3C9N2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2
BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiB0AiB0AiF1B9F1B9J2BIJ2BIN3BYN3BYB0AiB0AiB0AiB0AiB0
AiB0AiB0AiB0AiAoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9:2AiB2AiB2AiF1AiJ2B9R2B9R2B9Z2B9N0
B9IoAiEnAYAmAIAmAIEnAYIoAiN0B9J0AYEoAIAnA9AnA9AnA9EoAIN1AiR2B9J0AYJ0AYJ0AYJ0AYJ0
AYJ0AYJ0AYJ0AYEoAIAnA9=m@i=m@i=m@iAnA9J0AYN1AiEoAIEoAIEoAIEoAIEoAIEoAIEoAIEoAIIo
AiIoAiIoAiIoAiIoAiIoAiIoAiIoAiAmAIAmAIEnAYIoAiN0B9R1BIV2BYV2BYEoAIEoAIJ0AYJ0AYN1
AiN1AiR2B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9J0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYN2
A9N2A9N2AIN2AIR2B9R1BIR1BIV2BYJ0AYJ0AYJ0AYN1AiN1AiN1AiR2B9R2B9R2B9R2B9R2B9R2B9R2
B9R2B9R2B9R2B9EoAIEoAIJ0AYN1AiR2B9V3BIZ4BYZ4BYEoAIJ0AYJ0AYJ0AYN1AiN1AiN1AiR2B9N0
B9N0B9N0B9N0B9R1BIR1BIR1BIR1BIN0B9N0B9R1BIV2BYV2BYR1BIN0B9N0B9V2BYV2BYV2BYV2BYV2
BYR1BIR1BIR1BIR1BIR1BIR1BIV2BYV2BYV2BYZ3BiZ3BiR1BIR1BIV2BYZ3BiZ3BiV2BYR1BIR1BIV3
BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIR1BIR1BIR1BIV2BYV2BYV2BYZ3BiZ3Bi^4C9Z3BiZ3BiZ3BiZ3
BiZ3BiZ3BiZ3BiR4BiN3BYN3BYV2BY^2BYb3Bin4C:25CIR2B9V3BIZ4BYZ4BY^5Bib6C9f7CIf7CIZ4
BYZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYR1BIV2BYZ3BiZ3Bi^4C9b5C@00Y99eY99eY99eY99eY99eY99e
Y99eY99eXi1eXi1eY95fY95fY95fYI9gYI9gYI9gY95fY95fY95fY95fY95fY95fY95fY95fXi1eXi1e
Xi1eXi1eXi1eXi1eXi1eXi1eXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmd
XXmdXXmdXHicXHicXHicXHicXHicXHicXHicXHicWhaaWhaaWhaaWhaaX8ebX8ebX8ebXHicXHicXHic
XHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicWX]`WX]`WX]`WX]`WX]`WX]`
WX]`WX]`X8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebWhe^Whe^Whe^Whe^Whe^Whe^Whe^Whe^X8iaX8ia
Whe`Whe`WXa_WXa_WH]^WH]^WhY^WhY^WhY^WhY^WhY^WhY^WhY^WhY^Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/
Wh]/Wh]/WXY[Wh]/Wh]/Wh]/X8a]X8a]X8a]X8a]Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/WXY[Wh]/
Wh]/Wh]/X8a]X8a]X8a]X8a]WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[
WXY[WXY[WHUZWHUZWXY[WXY[WXY[Wh]/Wh]/Wh]/WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WHUZWHUZ
WHUZWHUZWHUZWHUZWHUZWHUZWX]VWX]VWX]VWX]VWX]VWX]VWX]VWX]VWhaWWhaWWX]VWHYUWHYUWX]V
WhaWWhaWWX]VWX]VWX]VWX]VWX]VWX]VWX]VWX]VWhaWWhaWWhaWWX]VWX]VWX]VWHYUWHYUWHYUWHYU
WHYUWHYUWHYUWHYUWHYUWHYUW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTVhQSVhQSVhQSVhQSVhQSVhQS
VhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSUhELUhANV8EOV8EPVHIQVHERVHERVHATVXQOVHQM
VhQMVhQKW8QIW8QIWXQHWHMGVHEFVHEFVXIGVXIGVXIGVhMHVhMHVhMHVXAKVXAKW8ILW8ILW8MJVXIG
VHEFUh=DVHAGVXEHVhIIVhIIVhIIVhIIVXEHVHAGVHAGVHAGVHAGVHAGVHAGVHAGVHAGVHAGUh9EV8=F
VXEHVhIIVhIIVXEHV8=FUh9EUh9EV8=FV8=FVHAGVHAGVXEHVhIIVhIIVHAGVHAGVHAGVHAGVHAGVHAG
VHAGVHAGUh=DUh=DUh=DUh=DUh=DUh=DUh=DUh=DVhAFVhAFVhAFVhAFVhAFVhAFVhAFVhAFVH9DVH9D
VH9DVX=EVX=EVhAFVhAFVhAFVXADVXADVXADVXADVXADVXADVXADVXADVH=CVH=CVH=CVH=CVH=CVH=C
VH=CVH=CVXADVXADVXADVXADVXADVXADVXADVXADVXEAVXEAVXEAVXEAVXEAVXEAVXEAVXEAVXADVXAD
VXADVXADVXADVXADVXADVXADV89BVH=CVH=CVXADVXADVH=CVH=CV89BVH=CVH=CVH=CVH=CVH=CVH=C
VH=CVH=CVHE>VHE>VHE>VHE>VHE>VHE>VHE>VHE>V89BV89BV89BVH=CVH=CVH=CVXADVXADUh5AVH=C
VhEEVhEEVH=CV89BV89BVH=CV85?V85?V85?VH9@VH9@VH9@VX=AVX=AVHA=VHA=VHA=VHA=VHA=VHA=
VHA=VHA=UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=UX5:UX5:
Uh9;Uh9;V8=<VHA=VHA=VHA=UX5:UX5:Uh9;Uh9;V8=<VHA=VHA=VHA=UH19UH19UH19UH19UH19UH19
UH19UH19Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;U817U817
U817UH58UX99UX99Uh=:Uh=:U817U817U817U817U817U817U817U817U7m8U7m8U7m8U7m8U7m8U7m8
U7m8U7m8TH94Th54Th54UH95UX=6V8=6VHA7Vh=7Uh18UWm7U7e5Tga4Tga4U7e5UWm7Uh18UX16UGm5
U7i4Tge3U7i4UGm5Uh57V898UX16UX16UX16UX16UX16UX16UX16UX16UGm5U7i4Tge3TWa2TWa2U7i4
UX16Uh57UGm5UGm5UGm5UGm5UGm5UGm5UGm5UGm5UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7U7e5U7e5
UGi6UWm7Uh18V859VH9:VH9:U7i4U7i4UGm5UX16Uh57V898VH=9VH=9Uh57Uh57Uh57Uh57Uh57Uh57
Uh57Uh57UX16UX16UX16UX16UX16UX16UX16UX16UX53Uh94Uh95Uh95V898V859V859V859U7i4U7i4
U7i4UGm5UGm5UX16UX16UX16Uh57Uh57Uh57Uh57Uh57Uh57Uh57Uh57UGm5UGm5UX16Uh57V898VH=9
VXA:VXA:UGm5UGm5UX16UX16UX16Uh57Uh57Uh57UWm7UWm7UWm7Uh18V859V859VH9:VH9:UWm7Uh18
V859V859V859V859Uh18UWm7VX=;VX=;VH9:VH9:V859V859Uh18Uh18Uh18V859V859V859VH9:VH9:
VH9:VX=;V859V859VH9:VX=;VX=;VH9:V859V859VHA7VHA7VHA7VHA7VHA7VHA7VHA7VHA7Uh18V859
V859V859VH9:VH9:VH9:VX=;VH9:VH9:VH9:VH9:V859V859V859V859V8A;Uh=:Uh=:V859Vh9:W8=;
WhA<X8E=V8=6V8=6VHA7VXE8VhI9W8M:WHQ;WXU<VXE8VXE8VXE8VXE8VXE8VXE8VXE8VXE8V859V859
VH9:VX=;VhA<W8E=002VTGFVTGFUT7BUT7BVTGFWTWJXTgNXTgNST7FST7FST7FST7FST7FST7FST7FS
T7FST7FST7FST7FST7FST7FST7FST7FST7FRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBR
SgBRSgBRSgBRSgBRSgBQSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>PSG:PSG:PSG:PSG:PSG:PSG:PSG:P
SG:PSW6PSW6PSW6PSW6PSW6PSW6PSW6PSW6PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:QSW>QSW>QSW>Q
SW>QSW>QSW>QSW>QSW>OS76OS76OS76PSG:PSG:PSG:QSW>QSW>MRfjMRfjNS6nNS6nOSG2PSW6PSW6P
SW6QSFjQSFjPS6fPS6fORfbORfbNRV^NRV^RSVnRSVnRSVnQSFjPS6fPS6fORfbORfbPS6fPS6fPS6fP
S6fPS6fPS6fPS6fPS6fPS6fPS6fORfbORfbNRV^NRV^MRFZMRFZPS6fPS6fPS6fPS6fPS6fPS6fPS6fP
S6fORfbORfbORfbORfbPS6fPS6fPS6fQSFjNRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^N
RV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^N
RV^MRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZNRV^NRV^MRFZLR6VLR6VMRFZNRV^NRV^MRVFMRVFMRVFM
RVFMRVFMRVFMRVFMRVFNRfJNRfJNRfJNRfJNRfJNRfJNRfJNRfJOS6NOS6NNRfJNRfJMRVFLRFBLRFBL
RFBNRfJMRVFMRVFLRFBLRFBKR6>KR6>JQf:LRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBJQf:KR6>KR6>L
RFBLRFBKR6>KR6>JQf:KR6>KR6>KR6>KR6>KR6>KR6>KR6>KR6>KR6:KR6:JQf6JQf6JQf6IQV2IQV2I
QV2LRF>LRF>KR6:KR6:KR6:KR6:KR6:JQf6IQV2HQEnJQUfJQUfKQE^KQE^MQUVMQUVJQUNJQUNJQUNJ
QUNJQUNJQUNJQUNJQUNHQ5FHQ5FHQ5FIQEJJQUNJQUNKQeRKQeRNQeVMQURLQENKQ5JJPeFJPeFJPeFK
Q5JHQ5FHQ5FHQ5FIQEJJQUNJQUNKQeRKQeRDP56EPE:FPU>HQ5FHQ5FHQ5FHQ5FHQ5FJQUNHQ5FGPeBG
PeBIQEJJQUNIQEJGPeBJPeFJPeFJPeFJPeFJPeFJPeFJPeFJPeFJQ5BJQ5BJQ5BJQ5BJQ5BJQ5BJQ5BJ
Q5BKQ5JKQ5JJPeFIPUBIPUBJPeFKQ5JKQ5JLQUJLQUJKQEFKQEFJQ5BIPe>IPe>IPe>KQEFKQEFKQEFJ
Q5BJQ5BJQ5BJQ5BJQ5BIQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56I
Q56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56I
Q56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56I
Q56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56HPDnHPDnHPDnIPU2IPU2JPe6JPe6JPe6JQDjJQDjJQDjI
Q4fIQ4fHPdbHPdbHPdbIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fHQ4^HQ4^HQ4^HQ4^HQ4^HQ4^HQ4^H
Q4^LQDfIPTZGP4RHPDVKQ4bLQDfJPd^HPDVJQTfIQDbIQDbHQ4^HQ4^GPdZFPTVFPTVGPdZGPdZHQ4^I
QDbIQDbHQ4^GPdZGPdZIPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZHPDVHPDVHPDVHPDVHPDVHPDVHPDVH
PDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVIPTZFOdNDODFEOTJHPDVIPTZGP4RDODFFOdNFOdNFOdNF
OdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNEOdFEOdFEOdFEOdFEOdFEOdFEOdFE
OdFGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNDOd6DOd6EP4>E
P4>FP4JFOdNFOdNFOdNCOD>COD>COD>COD>COD>COD>COD>COD>DOTBDOTBEOdFEOdFFP4JFP4JFP4JF
P4JBOTBDP4JFPTRHPTRIPDNGOdFJOdJKP4NFOTZFOTRFOdNFP4JFPDBFPD>FPT6FPT6EOdFEOdFEOdFE
OdFEOdFEOdFEOdFEOdFFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JGO4>HODBJOdJKP4NKP4NJOdJHODBG
O4>EOdFFP4JFP4JFP4JGPDNGPDNGPDNHPTRFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JGPDNG
PDNHPTRIPdVIPdVIPdVKP4NKP4NJOdJIOTFIOTFJOdJKP4NKP4NFP4JFP4JFP4JFP4JFP4JFP4JFP4JF
P4JHPTRHPTRHPTRHPTRHPTRHPTRHPTRHPTREOdFFP4JFP4JFP4JGPDNGPDNGPDNHPTRIPTZHPDVGP4RG
P4RGP4RGP4RHPDVIPTZHPDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVJQ4ZIPdVGPDNGPDNGPDNIPdVJQ4ZL
QTbIPdVJQ4ZJQ4ZJQ4ZIPdVHPTRGPDNFP4JFPD>HPdFJQDRIQ4NHPTRHPDVIPTZKQ4bIPTZIPTZHPDVH
PDVGP4RFOdNFOdNFOdNJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZMR4^LQTbKQD^JPd^KQ4bLQ4jNQU2O
Qe>NPd^NPd^NPd^NPd^NPd^NPd^NPd^NPd^NPd^NPd^NPd^NPd^NPd^NPd/00:JAMJJAMJF@M:F@M:F@
M:JAMJNBMZRCMj>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ:?
M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M:6>Lj6>Lj6>Lj6>Lj6>
Lj6>Lj6>Lj6>Lj2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ2=
LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lin<LIn<LIn<LIn<LJ2=
LZ2=LZ6>Lj6>Lij<Kij<Kij<Kij<Kin=L9n=L9n=L9n=L:6=KZ6=KZ2<KJ2<KIn;K9n;K9j:Jij:Jj:>
Kj:>Kj6=KZ6=KZ2<KJ2<KIn;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K:2<KIn;K9n;K9n;K9j:
Jif9JYf9JYf9JYn;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9j:Jin;K9n;K9n;K:2<KJ2<KJ2<KJ2<KIj:
Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:
Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jif9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYj:
Jij:Jif9JYb8JIb8JIf9JYj:Jij:Jif:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIj;IYj;IYj;IYj;IYj;
IYj;IYj;IYj;IYj;IYj;IYj;IYf:IIf:IIb9I9b9I9b9I:2=J9n<Iin<Iin<Iij;IYf:IIf:IIf:IIb9
I9b9I9b9I9b9I9b9I9b9I9b9I9b9I9Z7HYZ7HY^8Hib9I9b9I9^8HiZ7HYZ7HY^8Hi^8Hi^8Hi^8Hi^8
Hi^8Hi^8Hi^8Hi^8HY^8HYZ7HIZ7HIV6H9V6H9V6H9V6H9^8HY^8HY^8HY^8HY^8HYZ7HIZ7HIZ7HIR5
GiR5GiZ6GIZ6GI^5Fi^5Fif6FIb5F9Z6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6EiV5EYV5EYV5EYV5EYV5
EYZ6EiZ6EiZ6Eif6F9b5Ei^4EYZ3EIZ3EIZ3EI^4EY^4EYV5EYV5EYV5EYV5EYV5EYZ6EiZ6EiZ6EiF1
DYJ2DiN3E9R4EIV5EYV5EYR4EIR4EIV5EYR4EIJ2DiN3E9V5EYZ6EiR4EIN3E9Z3EIZ3EIZ3EIZ3EIZ3
EIZ3EIZ3EIZ3EIR2DYR2DYR2DYR2DYR2DYR2DYR2DYR2DY^4EYZ3EIZ3EIV2E9V2E9Z3EIZ3EI^4EY^5
EI^5EI^5EIZ4E9Z4E9V3DiV3DiV3DiZ4E9Z4E9Z4E9Z4E9Z4E9Z4E9Z4E9Z4E9V4DIV4DIV4DIV4DIV4
DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4
DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4
DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIZ5DYZ5DYV4DIV4DIV4DIR3D9R3D9R3D9R1
CiR1CiR1CiV2D9V2D9V2D9Z3DIZ3DIZ5CYZ5CYV4CIV4CIV4CIR3C9R3C9R3C9V4CIV4CIV4CIV4CIV4
CIV4CIV4CIV4CIR4BiR4BiR4BiR4BiR4BiR4BiR4BiR4Bib5CIV2BYN0B9R1BI^4C9b5CIZ3BiR1BIV5
C9V5C9R4BiR4BiN3BYN3BYJ2BIJ2BIN3BYN3BYR4BiV5C9V5C9R4BiN3BYN3BYV2BYV2BYV2BYV2BYV2
BYV2BYV2BYV2BYN0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9R1
BIIoAiAmAIEnAYR1BIV2BYN0B9AmAIIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIo
AiIoAiIoAiIoAiEoAIEoAIEoAIEoAIEoAIEoAIEoAIEoAIJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYEo
AIEoAIEoAIEoAIEoAIEoAIEoAIEoAIAo@IAo@IF0@iF0@iEoAIIoAiIoAiIoAiAnA9AnA9AnA9AnA9An
A9AnA9AnA9AnA9AnA9AnA9EoAIEoAIEoAIJ0AYJ0AYJ0AY9nA9B0AYJ2B9R2B9R0AYMoAIYoAY^0AiIn
B9InB9IoAiJ0AYJ1A9J1@iJ1@iJ2@IEoAIEoAIEoAIEoAIEoAIEoAIEoAIEoAIJ0AYJ0AYJ0AYJ0AYJ0
AYJ0AYJ0AYJ0AYQmA9UnAIYoAY^0Ai^0AiYoAYUnAIQmA9EoAIEoAIJ0AYJ0AYJ0AYN1AiN1AiN1AiJ0
AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYN1AiN1AiN1AiN1AiR2B9R2B9R2B9R2B9^0Ai^0AiYoAYUnAIUn
AIYoAY^0Ai^0AiJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYN1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiEo
AIEoAIJ0AYJ0AYJ0AYN1AiN1AiN1AiR1BIR1BIN0B9IoAiIoAiN0B9R1BIR1BIN0B9N0B9N0B9N0B9N0
B9N0B9N0B9N0B9R2B9R2B9R2B9R2B9R2B9V3BIZ4BYZ4BYV3BIV3BIZ4BYZ4BYV3BIR2B9N1AiJ0AYJ1
@iR3AIZ5B9V4AiR2B9R1BIV2BY^4C9V2BYV2BYV2BYR1BIR1BIN0B9N0B9N0B9Z4BYZ4BYZ4BYZ4BYZ4
BYZ4BYZ4BYZ4BY^6BIZ4BYV3BIV2BYV2BYZ2C9b4CYf5DIj3Bij3Bij3Bij3Bij3Bij3Bij3Bij3Bij3
Bij3Bij3Bij3Bij3Bij3B`00YY5eYI1dYI1dYI1dYI1dYY5eYi9fZ9=gXi1eXi1eXi1eXi1eXi1eXi1e
Xi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmd
XXmdXXmdXXmdXXmdXXmdXXmdXHicXHicXHicXHicXHicXHicXHicXHicX8ebX8ebX8ebX8ebX8ebX8eb
X8ebX8ebWhe`Whe`Whe`Whe`Whe`Whe`Whe`Whe`WhaaWhaaWhaaWhaaWhaaWhaaWhaaWhaaX8ebX8eb
X8ebX8ebX8ebX8ebX8ebX8ebWX]`WX]`WhaaWhaaX8ebX8ebX8ebX8ebWhe`Whe`Whe`WXa_WXa_WXa_
WXa_WXa_X8a]X8a]X8a]X8a]Wh]/Wh]/Wh]/Wh]/XHe^XHe^XHe^X8a]X8a]X8a]Wh]/Wh]/Wh]/Wh]/
Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/WXY[WXY[WXY[WHUZWHUZWHUZWh]/Wh]/Wh]/Wh]/Wh]/Wh]/
Wh]/Wh]/WXY[WXY[WXY[Wh]/Wh]/X8a]X8a]X8a]WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[
WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[
WXY[WXY[WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWXY[WHUZW8QYW8QYW8QYW8QYWHUZWXY[WHYUWHYU
WHYUWHYUWHYUWHYUWHYUWHYUWX]VWX]VWX]VWX]VWX]VWX]VWX]VWX]VWX]VWHYUWHYUWHYUW8UTW8UT
W8UTW8UTWhaWWhaWWX]VWX]VWX]VWHYUWHYUWHYUW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTVHIQVXMR
VhQSVhQSVhQSVhQSVXMRVHIQVXMRVXMRVXMRVXMRVXMRVXMRVXMRVXMRVXMQVXMQVXMQVXMQVHIPVHIP
V8EOV8EOVXMQVXMQVXMQVXMQVXMQVXMQVXMQVXMQV8EOV8EOVXIMVHELVhEKVXAJW8EHW8EHVXIGVXIG
VXIGVXIGVXIGVXIGVXIGVXIGVXIGVXIGVXIGVHEFVHEFVHEFVHEFVHEFVhAFVhAFVX=EVX=EVX=EVhAF
W8EGW8EGVHEFVHEFVHEFVHEFVHEFV8AEV8AEV8AEUX9CUh=DV8AEVHEFVHEFVHEFVHEFV8AEVHEFUh=D
UX9CUh=DVHEFVHEFV8AEUX9CVX=EVX=EVX=EVX=EVX=EVX=EVX=EVX=EUh5AUh5AUh5AUh5AUh5AUh5A
Uh5AUh5AVhAFVX=EVH9DVH9DVH9DVH9DVX=EVhAFVhEEVXADVXADVXADVH=CVH=CVH=CVH=CVXADVXAD
VXADVXADVXADVXADVXADVXADVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAA
VHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAA
VHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAA
VHAAVHAAVXEBVXEBVHAAVHAAV8=@V8=@Uh9?Uh9?Uh1>V85?V85?V85?VH9@VH9@VH9@VH9@VHA=VHA=
VHA=VHA=V8=<V8=<V8=<Uh9;V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<Uh=:Uh=:Uh=:Uh=:Uh=:Uh=:
Uh=:Uh=:VhA<VH9:V859V859VX=;VhA<VX=;V859V8A;V8A;V8A;V8A;Uh=:Uh=:Uh=:UX99UX99Uh=:
V8A;V8A;V8A;V8A;Uh=:UX99V859V859V859V859V859V859V859V859Uh18Uh18Uh18Uh18Uh18Uh18
Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18UWm7U7e5UGi6Uh18Uh18UWm7UGi6UWm7UWm7
UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UGm5UGm5UGm5UGm5UGm5UGm5
UGm5UGm5UX16UX16UX16UX16UX16UX16UX16UX16Tge3Tge3Tge3Tge3Tge3Tge3Tge3Tge3U7m1U7m1
U7m2UH13UGm5UGi6UWm7UWm7U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4UGm5UGm5UGm5
UX16UX16TWi4U816UX98V898V816Ugm5VGi5VWm6UWm7UWm7UWm7UX16UX54UX54UX53UX53UGm5UGm5
UGm5UGm5UGm5UGm5UGm5UGm5UX16UX16UX16UX16UX16UX16UX16UX16VGi5VWm6Vh17Vh17Vh17Vh17
VWm6VGi5UH13UH13UH13UX54UX54Uh95Uh95Uh95UX16UX16UX16UX16UX16UX16UX16UX16V898V898
Uh57Uh57Uh57Uh57Uh57UX16Vh17VWm6VWm6VGi5VGi5VWm6VWm6Vh17UX16UX16UX16UX16UX16UX16
UX16UX16Uh57Uh57Uh57Uh57Uh57Uh57Uh57Uh57UGm5UGm5UGm5UX16UX16Uh57Uh57Uh57V859Uh18
Uh18UWm7UWm7Uh18Uh18V859Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18UX16Uh57V898VH=9VH=9VH=9
VH=9V898V898VH=9VH=9VH=9VH=9V898Uh57UX16UX53V8=5VHA7VHA7V898Uh18VH9:VhA<VX=;VX=;
VH9:VH9:VH9:V859V859V859VH=9VH=9VH=9VH=9VH=9VH=9VH=9VH=9VHA7VH=9V898V859V859VH5;
VX9<Vh=?WH9:WH9:WH9:WH9:WH9:WH9:WH9:WH9:WH9:WH9:WH9:WH9:WH9:WH9:002UT7BUT7BTSg>T
Sg>UT7BVTGFWTWJWTWJST7FST7FST7FST7FST7FST7FST7FST7FRSgBRSgBRSgBRSgBRSgBRSgBRSgBR
SgBQSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>Q
SW>QSW>QSW>QSW>QSW>PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:OSG2OSG2OSG2OSG2OSG2OSG2OSG2O
SG2OS76OS76OS76OS76OS76OS76OS76OS76PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:NRg2NRg2NRg2O
S76OS76OS76PSG:PSG:OSG2OSG2OSG2NS6nMRfjMRfjLRVfLRVfPS6fPS6fPS6fPS6fORfbORfbORfbO
RfbPS6fPS6fPS6fPS6fPS6fPS6fORfbORfbORfbORfbORfbORfbORfbORfbORfbORfbNRV^NRV^NRV^N
RV^MRFZMRFZMRFZMRFZORfbORfbORfbORfbORfbORfbORfbORfbNRV^NRV^NRV^NRV^ORfbORfbPS6fP
S6fNRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^N
RV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^LR6VLR6VLR6VLR6VLR6VLR6VLR6VL
R6VMRFZMRFZLR6VKQfRKQfRLR6VMRFZMRFZMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFM
RVFMRVFMRVFMRVFMRVFMRVFMRVFLRFBLRFBLRFBLRFBLRFBLRFBKR6>KR6>KR6>KR6>KR6>KR6>KR6>K
R6>KR6>KR6>KR6>KR6>KR6>KR6>KR6>KR6>IQV6JQf:JQf:KR6>KR6>JQf:JQf:IQV6JQf:JQf:JQf:J
Qf:JQf:JQf:JQf:JQf:JQf6JQf6IQV2IQV2IQV2HQEnHQEnHQEnHQEnIQV2IQV2IQV2IQV2IQV2JQf6J
Qf6HQEnHQEnIQEbIQEbJQ5ZJQ5ZLQERLQERJQUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNKQeRKQeRJQUNJ
QUNIQEJHQ5FHQ5FHQ5FJPeFIPUBIPUBIPUBJPeFKQ5JLQENMQURJQUNJQUNIQEJIQEJHQ5FGPeBGPeBG
PeBGPeBHQ5FIQEJIQEJJQUNIQEJHQ5FHQ5FIQEJGPeBFPU>FPU>HQ5FIQEJHQ5FFPU>IPUBIPUBIPUBI
PUBIPUBIPUBIPUBIPUBIPe>IPe>IPe>IPe>IPe>IPe>IPe>IPe>JPeFJPeFIPUBHPE>HPE>IPUBJPeFJ
PeFJQ5BJQ5BIPe>IPe>IPe>IPe>IPe>IPe>IPe>IPe>IPe>IPe>IPe>JQ5BJQ5BJQ5BHPe2HPe2HPe2H
Pe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2H
Pe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2H
Pe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2HPe2JQE:JQE:IQ56IQ56HPe2GPTnGPTnF
PDjGP4jGP4jGP4jHPDnHPDnIPU2IPU2IPU2IQ4fIQ4fIQ4fHPdbHPdbGPT^GPT^GPT^HPdbHPdbHPdbH
PdbHPdbHPdbHPdbHPdbGPdZGPdZGPdZGPdZGPdZGPdZGPdZGPdZIPTZIPTZHPDVIPTZIPTZIPTZIPTZH
PDVGPdZGPdZGPdZGPdZGPdZGPdZGPdZGPdZFPTVFPTVGPdZHQ4^HQ4^GPdZFPTVFPTVHPDVHPDVHPDVH
PDVHPDVHPDVHPDVHPDVGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RG
P4RFOdNEOTJEOTJEOTJFOdNFOdNFOdNEOTJFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNF
OdNFOdNFOdNFOdNFOdNDOTBDOTBDOTBDOTBDOTBDOTBDOTBDOTBEOdFEOdFEOdFEOdFEOdFEOdFEOdFE
OdFDOTBDOTBDOTBDOTBDOTBDOTBDOTBDOTBCOT2COT2DOd:DOd:EOdFEOTJEOTJEOTJEOdFEOdFEOdFE
OdFEOdFEOdFEOdFEOdFCOD>COD>DOTBDOTBEOdFEOdFEOdFEOdFAOD>COdFEPDNGPDNHP4JFOTBIOTFJ
OdJFP4JFP4JFP4JFP4JFP4JFPDBFPDBFPDBDOTBDOTBDOTBDOTBDOTBDOTBDOTBDOTBFP4JFP4JFP4JF
P4JFP4JFP4JFP4JFP4JJOdJKP4NKP4NKP4NKP4NKP4NKP4NJOdJDOd:EP4>EP4>EP4>FPDBFPDBFPDBG
PTFFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JHPTRHPTRHPTRGPDNFP4JFP4JEOdFEOdFJOdJJOdJIOTFI
OTFIOTFIOTFJOdJJOdJFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JGPDNGPDNGPDNGPDNGPDNGPDNGPDNG
PDNDOTBEOdFEOdFEOdFFP4JFP4JFP4JGPDNHPDVGP4RFOdNFOdNFOdNFOdNGP4RHPDVGP4RGP4RGP4RG
P4RGP4RGP4RGP4RGP4REOdFFP4JHPTRIPdVJQ4ZIPdVHPTRGPDNGPDNHPTRHPTRIPdVIPdVHPTRGPDNF
P4JEP4:GPTBIQ4NHPdJGPDNGP4RHPDVJPd^IPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZIPdVIPdVIPdVI
PdVIPdVIPdVIPdVIPdVIQ4NHPTRHPTRIPTZIPTZJPTbJPTbKPdnMPTZMPTZMPTZMPTZMPTZMPTZMPTZM
PTZMPTZMPTZMPTZMPTZMPTZMPTX00:F@M:B?LjB?LjB?LjB?LjF@M:JAMJNBMZ>@MJ>@MJ>@MJ>@MJ>@
MJ>@MJ>@MJ>@MJ:?M::?M::?M::?M::?M::?M::?M::?M:6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>
Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj2=LZ2=LZ2=LZ2=LZ2=
LZ2=LZ2=LZ2=LYj<Kij<Kij<Kij<Kij<Kij<Kij<Kij<Kij;L9j;L9j;L9j;L9j;L9j;L9j;L9j;L:2=
LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LYf:Kif:Kij;L9j;L9n<LIn<LIn<LIn<LIn=L9n=L9j<Kij<Kif;
KYb:KIb:KIb:KIn;K9n;K9n;K9n;K:2<KJ2<KJ2<KJ2<KIn;K9n;K9n;K9n;K9n;K9n;K:2<KJ2<KIj:
Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jif9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYj:Jij:Jij:Jij:Jij:
Jij:Jij:Jij:Jif9JYf9JYj:Jij:Jij:Jin;K9n;K9n;K9f9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9
JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9
JYf9JYf9JYf9JYb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIf9JYb8JI^7J9^7J9^7J9^7J9b8JIf9JYf:
IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:II^8Hi^8Hib9I9b9I9b9
I9b9I9b9I9b9I9Z7HYZ7HYZ7HYZ7HY^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8HiV6
HIV6HIZ7HYZ7HYZ7HYZ7HYV6HIV6HIZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYV6H9V6H9V6H9V6H9R5
GiR5GiN4GYN4GYN4GYN4GYN4GYR5GiR5GiV6H9V6H9Z7HIN4GYN4GYV5G9R4FiZ4FYZ4FY^4Ei^4EiV5
EYV5EYV5EYV5EYV5EYV5EYV5EYV5EY^7F9^7F9Z6EiZ6EiV5EYR4EIR4EIR4EIV2E9V2E9V2E9V2E9V2
E9Z3EIb5Eib5EiV5EYV5EYV5EYR4EIR4EIN3E9N3E9J2DiN3E9R4EIV5EYV5EYV5EYR4EIN3E9N3E9R4
EIJ2DiF1DYJ2DiR4EIR4EIN3E9F1DYV2E9V2E9V2E9V2E9V2E9V2E9V2E9V2E9V3DiV3DiV3DiV3DiV3
DiV3DiV3DiV3DiZ3EIV2E9R1DiR1DiR1DiR1DiV2E9Z3EIR2DYR2DYV3DiV3DiV3DiV3DiV3DiV3DiN1
DIR2DYR2DYR2DYV3DiZ4E9Z4E9Z4E9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3
D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3
D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3
D9R3D9R3D9R3D9V4DIV4DIR3D9R3D9N2CiN2CiN2CiJ1CYIoCIN0CYN0CYN0CYR1CiR1CiR1CiV2D9V4
CIR3C9R3C9R3C9N2BiN2BiN2BiJ1BYR3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9J2BIJ2BIJ2BIJ2BIJ2
BIJ2BIJ2BIJ2BIR1BIR1BIV2BYV2BYR1BIR1BIR1BIV2BYJ2BIJ2BIJ2BIJ2BIJ2BIN3BYN3BYN3BYF1
B9J2BIN3BYN3BYN3BYN3BYJ2BIF1B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9IoAiIoAiIoAiIoAiIo
AiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiEnAYEnAYIoAiEnAYEnAYAmAIEnAYEnAYEn
AYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYAnA9AnA9AnA9AnA9An
A9AnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9EoAIEoAIEoAIEoAIEoAIEoAIEoAIEoAI=n
@9=n@9=n@IAo@YAnA9AmAIEnAYEnAYAnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9=m@i=m@i=m@iAnA9An
A9AnA9EoAIEoAI5m@i=oAIF1AiN1AiMoAIInA9QmA9UnAIF0@iF0@iF0@iEoAIEoAIEoAIEoAIEoAIAn
A9AnA9AnA9AnA9AnA9AnA9AnA9AnA9EoAIEoAIEoAIEoAIEoAIEoAIEoAIEoAI^0AiYoAYYoAYYoAYYo
AYYoAYYoAY^0AiAo@IAo@IAo@IF0@YF0@YJ1@iJ1@iJ1@iEoAIEoAIEoAIEoAIEoAIEoAIEoAIEoAIR2
B9N1AiN1AiJ0AYJ0AYEoAIEoAIEoAIYoAYUnAIUnAIQmA9QmA9UnAIUnAIYoAYEoAIEoAIEoAIEoAIEo
AIEoAIEoAIEoAIJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYAnA9AnA9AnA9EoAIEoAIJ0AYJ0AYJ0AYN0
B9N0B9IoAiEnAYEnAYIoAiN0B9N0B9IoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiAnA9J0AYN1AiV3BIV3
BIV3BIN1AiJ0AYJ0AYN1AiN1AiR2B9R2B9R2B9N1AiN1AiF0@YN2A9R3AYR3AYN1AiIoAiR1BIZ3BiR1
BIR1BIR1BIR1BIV2BYV2BYV2BYV2BYR2B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9V4AiV3BIZ4BYZ3Bi^4
C9^3CI^3CI^3Cib1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1B@00Y8mcY8mc
XhibXhibY8mcYI1dYY5eYY5eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXHicXHicXHicXHicXHicXHic
XHicXHicX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebXHicXHic
XHicXHicXHicXHicXHicXHicX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebWXa_WXa_WXa_WXa_WXa_WXa_
WXa_WXa_WX]`WX]`WX]`WX]`WX]`WX]`WX]`WX]`WhaaWhaaWhaaWhaaWhaaWhaaWhaaWhaaWHY_WHY_
WHY_WX]`WX]`WhaaWhaaWhaaWH]^WH]^WH]^WH]^WH]^W8Y]W8Y]W8Y]Wh]/Wh]/Wh]/Wh]/X8a]X8a]
X8a]X8a]WXY[WXY[WXY[Wh]/Wh]/Wh]/X8a]X8a]WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[W8QYW8QY
W8QYW8QYWHUZWHUZWHUZWXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WHUZWHUZWHUZWHUZWXY[WXY[
Wh]/Wh]/WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZ
WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZVhMXVhMXVhMXVhMXVhMXVhMX
VhMXVhMXW8QYW8QYVhMXVXIWVXIWVhMXW8QYW8QYWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUW8UTW8UT
W8UTW8UTW8UTW8UTW8UTW8UTVXMRVhQSVhQSVhQSW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTWHYUWHYU
WHYUWX]VVXMRVXMRVXMRVXMRVXMRVXMRVXMRVXMRV8EPVHIQVHIQVXMRVXMRVHIQVHIQV8EPVHIQVHIQ
VHIQVHIQVHIQVHIQVHIQVHIQVHIPVHIPVHIPV8EOV8EOUhANUhANUhANUH9LUX=MUX=MUhANV8EOV8EO
VHIPVHIPUhANUhANV8AKV8AKVH=IVH=IVhAGVhAGVHEFVHEFVHEFVHEFVHEFVHEFVHEFVHEFVXIGVXIG
VXIGVHEFVHEFVHEFVHEFVHEFVX=EVH9DVH9DV85CVH9DVH9DVX=EVhAFV8AEV8AEV8AEV8AEUh=DUh=D
Uh=DUh=DUh=DUh=DV8AEV8AEV8AEUh=DUX9CUH5BV8AEUX9CUH5BUH5BUh=DV8AEUh=DUH5BV85CV85C
V85CV85CV85CV85CV85CV85CUX1@UX1@UX1@UX1@UX1@UX1@UX1@UX1@VH9DVH9DV85CUh1BUh1BV85C
VH9DVH9DUh5AV89BV89BV89BVH=CVH=CVH=CVH=CUX1@Uh5AUh5AV89BVH=CVH=CVXADVXADUh9?Uh9?
Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?
Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?
Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?
Uh9?Uh9?UWm=UWm=UWm=Uh1>Uh1>V85?V85?V85?V8=<V8=<V8=<Uh9;Uh9;UX5:UX5:UX5:Uh9;Uh9;
Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;UX99UX99UX99UX99UX99UX99UX99UX99Uh18V859VH9:VH9:Uh18UWm7
V859VH9:UH58UH58UH58UX99UX99UX99Uh=:Uh=:UH58UX99UX99Uh=:Uh=:UX99UX99UH58Uh18Uh18
Uh18Uh18Uh18Uh18Uh18Uh18UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7
UWm7UWm7Tga4UGi6UWm7UGi6U7e5Tga4U7e5UWm7UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6
UGi6UGi6UGi6UGi6UGi6UGi6Tge3Tge3Tge3Tge3Tge3Tge3Tge3Tge3Tge3Tge3Tge3Tge3Tge3Tge3
Tge3Tge3UGm5UGm5UGm5UGm5UGm5UGm5UGm5UGm5TWdoTgi0Tgi1Tgi1U7i4U7e5U7e5U7e5Tge3Tge3
Tge3Tge3Tge3Tge3Tge3Tge3TWa2Tge3Tge3Tge3U7i4U7i4U7i4U7i4T7a2TWi4UH57UX16Ugm5UGe3
V7e4VGi5UH12UH12UH13UH13UGm5UGi6UGi6UGi6Tge3Tge3Tge3Tge3Tge3Tge3Tge3Tge3UGm5UGm5
UGm5UGm5UGm5UGm5UGm5UGm5VWm6VWm6VGi5V7e4V7e4VGi5VWm6VWm6U7m1U7m1U7m1U7m1UH12UH12
UH12UX53UGm5UGm5UGm5UGm5UGm5UGm5UGm5UGm5UX16UX16UX16UX16UX16UGm5UGm5UGm5VWm6VGi5
V7e4V7e4V7e4V7e4VGi5VWm6UGm5UGm5UGm5UGm5UGm5UGm5UGm5UGm5UX16UX16UX16UX16UX16UX16
UX16UX16U7i4U7i4U7i4U7i4UGm5UGm5UGm5UX16Uh18UWm7UGi6UGi6UGi6UGi6UWm7Uh18UWm7UWm7
UWm7UWm7UWm7UWm7UWm7UWm7UGm5UX16Uh57Uh57V898V898Uh57Uh57UGm5UX16Uh57V898V898V898
Uh57Uh57U7m1UX53V8=6Uh95UX16UWm7Uh18VH9:UWm7Uh18Uh18Uh18V859V859V859V859V898V898
V898V898V898V898V898V898V8=6VH=9VXA:VhA<W8E=Vh==Vh==VX9>W859W859W859W859W859W859
W859W859W859W859W859W859W859W859002TSg>TSg>SSW:SSW:SSW:TSg>UT7BVTGFST7FST7FST7FS
T7FST7FST7FST7FST7FQSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>PSG:PSG:PSG:PSG:PSG:PSG:PSG:P
SG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>PSG:PSG:PSG:P
SG:PSG:PSG:PSG:PSG:NS6nNS6nNS6nNS6nNS6nNS6nNS6nNS6nNRg2NRg2NRg2NRg2NRg2NRg2NRg2N
Rg2OS76OS76OS76OS76OS76OS76OS76OS76MRVnMRVnMRVnMRVnNRg2NRg2NRg2OS76LRVfLRVfLRVfL
RVfMRfjMRfjMRfjMRfjNRV^NRV^ORfbORfbPS6fPS6fQSFjQSFjMRFZMRFZNRV^NRV^ORfbORfbPS6fP
S6fMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZKQfRKQfRKQfRLR6VMRFZMRFZMRFZNRV^MRFZMRFZMRFZM
RFZMRFZMRFZMRFZMRFZLR6VLR6VMRFZMRFZNRV^NRV^NRV^NRV^LR6VLR6VLR6VLR6VLR6VLR6VLR6VL
R6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VL
R6VLR6VLR6VLR6VLR6VKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRLR6VKQfRKQfRJQVNJQVNKQfRKQfRL
R6VMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBJQf:JQf:JQf:K
R6>KR6>LRFBLRFBLRFBKR6>KR6>KR6>LRFBMRVFMRVFMRVFNRfJJQf:JQf:JQf:JQf:JQf:JQf:JQf:J
Qf:HQF2HQF2IQV6JQf:JQf:IQV6HQF2HQF2IQV6IQV6IQV6IQV6IQV6IQV6IQV6IQV6IQV2HQEnHQEnH
QEnGQ5jGQ5jGQ5jGQ5jDPE^DPE^EPUbFPefGQ5jHQEnIQV2IQV2FPefFPefHQ5^HQ5^IPeVIPeVJPeJJ
PeJHQ5FHQ5FHQ5FHQ5FHQ5FHQ5FHQ5FHQ5FIQEJIQEJIQEJIQEJIQEJJQUNJQUNJQUNKQ5JJPeFIPUBH
PE>HPE>HPE>IPUBIPUBFPU>GPeBGPeBGPeBGPeBGPeBHQ5FHQ5FFPU>FPU>GPeBGPeBFPU>EPE:DP56C
Oe2GPeBFPU>DP56EPE:GPeBHQ5FFPU>EPE:HPE>HPE>HPE>HPE>HPE>HPE>HPE>HPE>FP52FP52FP52F
P52FP52FP52FP52FP52IPUBHPE>HPE>GP5:GP5:HPE>HPE>IPUBGPE6GPE6GPE6HPU:HPU:IPe>IPe>I
Pe>EOdnFP52GPE6GPE6HPU:IPe>JQ5BJQ5BGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnG
PTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnG
PTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnG
PTnGPTnGPTnGPTnGPTnEP4fEP4fFPDjFPDjGPTnHPe2IQ56IQ56FOdfFOdfFOdfGP4jGP4jGP4jHPDnH
PDnHPdbHPdbGPT^GPT^GPT^FPDZFPDZFPDZGPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^FPTVFPTVFPTVF
PTVFPTVFPTVFPTVFPTVFOdNHPDVJPd^IPTZFOdNEOTJGP4RJPd^DP4NDP4NEPDREPDRFPTVFPTVGPdZG
PdZEPDREPDRFPTVGPdZGPdZFPTVEPDREPDRFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNEOTJEOTJEOTJE
OTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJBNd>EOTJFOdNEOTJCO4BBNd>DODFF
OdNDODFDODFDODFDODFDODFDODFDODFDODFDODFDODFDODFDODFDODFDODFDODFDODFCOD>COD>COD>C
OD>COD>COD>COD>COD>BO4:BO4:BO4:BO4:BO4:BO4:BO4:BO4:COD>COD>COD>COD>COD>COD>COD>C
OD>BOCnBOCnCOT6COT6COD>DODFDODFDODFANd6ANd6ANd6ANd6ANd6ANd6ANd6ANd6BO4:BO4:COD>C
OD>COD>DOTBDOTBDOTB@O4:BOTBDP4JFP4JFOTBEOD>HODBIOTFDP3nDOd6DOd6DOd:DOTBDODFDO4JD
O4JCOD>COD>COD>COD>COD>COD>COD>COD>DOTBDOTBDOTBDOTBDOTBDOTBDOTBDOTBIOTFHODBGO4>F
Nd:FNd:GO4>HODBIOTFCOcjCOcjDP3nDP3nDP3nEPD2EPD2EPD2DOTBDOTBDOTBDOTBDOTBDOTBDOTBD
OTBEOdFEOdFEOdFEOdFEOdFFP4JFP4JFP4JIOTFIOTFHODBGO4>GO4>HODBIOTFIOTFDOTBDOTBDOTBD
OTBDOTBDOTBDOTBDOTBEOdFEOdFEOdFEOdFEOdFEOdFEOdFEOdFCOD>COD>DOTBDOTBDOTBEOdFEOdFE
OdFFOdNFOdNEOTJDODFDODFEOTJFOdNFOdNEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJFP4JFP4JFP4JE
OdFFP4JGPDNHPTRHPTRDOTBEOdFFP4JGPDNHPTRHPTRGPDNGPDNDOd6FPD>GPTFGPTFFP4JEOTJGP4RI
PTZEOTJEOTJEOTJFOdNFOdNGP4RGP4RGP4RHPTRHPTRHPTRHPTRHPTRHPTRHPTRHPTRFPDBGPDNIPdVJ
Pd^KQ4bJPTbIPD^HP4bLPDVLPDVLPDVLPDVLPDVLPDVLPDVLPDVLPDVLPDVLPDVLPDVLPDVLPDT00:B?
Lj>>LZ>>LZ>>LZ>>LZB?LjF@M:JAMJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ6>Lj6>Lj6>Lj6>Lj6>
Lj6>Lj6>Lj6>Lj2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ6>
Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LYf;KYf;KYf;KYf;KYf;
KYf;KYf;KYf;KYf:Kif:Kif:Kif:Kif:Kif:Kif:Kif:Kin<LIn<LIn<LIn<LIn<LIn<LIn<LIn<LIb9
KYf:Kif:Kif:Kij;L9j;L9j;L9j;L9^9K9^9K9^9K9b:KIf;KYf;KYj<Kij<Kij:Jij:Jin;K9n;K:2<
KJ2<KJ6=KZ6=KYf9JYf9JYf9JYj:Jin;K9n;K:2<KJ2<KIf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYZ6
Ii^7J9^7J9b8JIb8JIf9JYf9JYj:Jif9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYb8JIb8JIf9JYf9JYf9
JYj:Jij:Jij:Jib8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8
JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JI^7J9^7J9^7J9^7J9^7
J9^7J9^7J9^7J9b8JI^7J9^7J9Z6IiZ6Ii^7J9^7J9b8JIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIb9
I9b9I9b9I9b9I9b9I9b9I9b9I9b9I9V6HIV6HIZ7HYZ7HY^8Hib9I9b9I9b9I9R5H9R5H9V6HIV6HIZ7
HYZ7HY^8Hi^8HiZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYR5H9R5H9V6HIZ7HYZ7HYV6HIR5H9R5H9V6
HIV6HIV6HIV6HIV6HIV6HIV6HIV6HIR5GiR5GiR5GiR5GiN4GYN4GYN4GYJ3GI>0FYB1FiF2G9J3GIN4
GYR5GiV6H9V6H9J3GIJ3GIR4FiN3FYV3FIV3FIZ3EYZ3EYR4EIR4EIR4EIR4EIR4EIR4EIR4EIR4EIR4
EIR4EIR4EIV5EYZ6EiZ6Ei^7F9^7F9^4EY^4EYV2E9R1DiR1DiR1DiR1DiR1DiF1DYJ2DiJ2DiN3E9N3
E9R4EIR4EIV5EYF1DYF1DYJ2DiJ2DiF1DYB0DI=oD99nCiN3E9F1DYB0DIF1DYN3E9N3E9J2DiB0DIR1
DiR1DiR1DiR1DiR1DiR1DiR1DiR1DiR2DYR2DYR2DYR2DYR2DYR2DYR2DYR2DYV2E9R1DiN0DYN0DYN0
DYN0DYR1DiV2E9J0D9J0D9N1DIN1DIR2DYV3DiV3DiV3DiEoCiEoCiJ0D9N1DIR2DYV3DiZ4E9^5EIN2
CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2
CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2
CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2Ci=nBiAoC9F0CIJ1CYN2
CiR3D9V4DIZ5DYEnC9IoCIIoCIIoCIN0CYN0CYN0CYR1CiR3C9N2BiN2BiN2BiJ1BYJ1BYJ1BYF0BIN2
BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiF1B9F1B9F1B9F1B9F1B9F1B9F1B9F1B9EnAYR1BIZ3BiV2BYIo
AiEnAYN0B9Z3BiB0AiB0AiB0AiF1B9J2BIJ2BIN3BYN3BYB0AiF1B9J2BIJ2BIJ2BIJ2BIF1B9B0AiIo
AiIoAiIoAiIoAiIoAiIoAiIoAiIoAiEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEn
AYEnAYEnAYEnAY9k@iEnAYN0B9IoAi=lA95j@YAmAIIoAiAmAIAmAIAmAIAmAIAmAIAmAIAmAIAmAIAm
AIAmAIAmAIAmAIAmAIAmAIAmAIAmAI=m@i=m@i=m@i=m@i=m@i=m@i=m@i=m@i9l@Y9l@Y9l@Y9l@Y9l
@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9m?i9m?i9m@9=n@I=m@i=lA9AmAIAmAI1j
@91j@91j@91j@91j@91j@91j@91j@99l@Y9l@Y9l@Y=m@i=m@i=m@iAnA9AnA91l@Y9nA9B0AYJ0AYIn
A9Em@iMl@iQmA9B0?iB0?iAo@IAo@YAnA9AmAIAlAYAlB9=m@i=m@i=m@i=m@i=m@i=m@i=m@i=m@iAn
A9AnA9AnA9AnA9AnA9AnA9AnA9AnA9UnAIMl@iIk@YEj@IEj@IIk@YMl@iUnAI=o?Y=o?Y=o?YB0?iB0
?iF1@9F1@9F1@9AnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9EoAIEoAIJ0AYN1AiN1AiUn
AIQmA9QmA9Ml@iMl@iQmA9QmA9UnAIAnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9EoAIEoAIEoAIEoAIEo
AIEoAIEoAIEoAI=m@i=m@i=m@iAnA9AnA9EoAIEoAIEoAIIoAiIoAiEnAYAmAIAmAIEnAYIoAiIoAiEn
AYEnAYEnAYEnAYEnAYEnAYEnAYEnAYN1AiJ0AYEoAIAnA9EoAIJ0AYR2B9V3BIAnA9AnA9J0AYN1AiR2
B9R2B9N1AiN1AiAo@IJ1@iN2AIN2AIJ0AYEnAYN0B9V2BY=lA9AmAIAmAIEnAYEnAYIoAiIoAiN0B9N1
AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiF0@iJ0AYR2B9V2BYV2BYV1BiR0BYMoBi^0B9^0B9^0B9^0B9^0
B9^0B9^0B9^0B9^0B9^0B9^0B9^0B9^0B9^0B000XhibXhibY8mcY8mcY8mcYI1dYI1dYI1dY8mdY8md
Y8mdY8mdY8mdY8mdY8mdY8mdXi1eXXmdXXmdXHicXHicX8ebX8ebWhaaXHicXHicXHicXHicXHicXHic
XHicXHicX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebWhe`Whe`Whe`X8iaX8iaX8iaXHmbXHmbX8iaX8ia
X8iaWhe`WXa_WXa_WH]^WH]^Whe`Whe`Whe`Whe`Whe`Whe`Whe`Whe`WHY_WHY_WX]`WhaaWhaaWX]`
WHY_WHY_X8]_X8]_X8]_X8]_X8]_X8]_X8]_X8]_XXebWhY_WHQ]WXU^XHaaXXebX8]`WHQ]W8Y]W8Y]
W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]X8]_X8]_WhY^WhY^WXU]WXU]WHQ/WHQ/WHUZWHUZWHUZWHUZWHUZWHUZ
WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QY
W8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QY
W8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYVhMXW8QYWHUZWHUZWHUZWHUZW8QYVhMXWHQYWHQY
WHQYWHQYWHQYWHQYWHQYWHQYW8MXW8MXW8MXW8MXW8MXW8MXW8MXW8MXVhMTVhMTVhMTVhMTVhMTVhMT
VhMTVhMTW8USW8USW8USW8USW8USW8USW8USW8USW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTXHUUX8QT
X8QTWhMSWhMSWXIRWXIRWHEQWXIRWXIRWXIRWXIRWXIRWXIRWXIRWXIRVHIQVHIQVHIQVHIQVHIQVHIQ
VHIQVHIQWHIPWHIPWHIPWHIPWHIPWHIPWHIPWHIPW8IMW8IMW8IMW8IMW8IMW8IMW8IMW8IMW8IMW8IM
VhELVhELVXAKVXAKVH=JVH=JVH9LVH9LVH9LVH9LVH9LVH9LVH9LVH9LWHALW8=KVh=IVX9HVH9EVH9D
VH9DVX=EVX=EVX=EVX=EVX=EVX=EVX=EVX=EVX=EVH9DVH9DVH9DVH9DVH9DVH9DVH9DVH9DVH=CVH=C
VH=CVH=CVH=CVH=CVH=CVH=CUh9>Uh9>Uh9?V8=@V89BVH9DVH9DVH9DV89BV89BV89BV89BV89BV89B
V89BV89BUh5AUh5AUh5AUh5AUh5AUh5AUh5AUh5AUX1@UX1@UX1@Uh5AUh5AUh5AV89BV89BUX1@UX1@
UX1@Uh5AUh5AUh5AV89BV89BUX1@UX1@UX1@Uh5AUh5AUh5AV89BV89BUGi@UGi@UGi@UGi@UWmAV85C
VH9DVX=EV85?V85?V85?V85?V85?V85?V85?V85?V85?V85?V85?V85?V85?V85?V85?V85?Uh9;Uh9;
Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;UX1@UX1@UX1@UX1@UX1@UX1@
UX1@UX1@UX9;UX9;UX5=UX5>UX5>UX1@UX1@UWmAUh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;
Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;VXE>VHA=VHA=V8=<V8=<Uh9;Uh9;UX5:UX5:UX5:UX5:UX5:UX5:UX5:
UX5:UX5:Th1=UH1=UH1=UWm=UWm=V7m=V7m=VWm=V859V859V859V859V859V859V859V859V859V859
V859V859V859V859V859V859UGi6UWm7UWm7UWm7Uh18Uh18Uh18V859UGi6UWm7UWm7UWm7Uh18Uh18
Uh18V859VH9:V859UWm7UGi6U7e5UGi6UWm7Uh18Uh18Uh18UWm7UWm7UGi6U7e5U7e5U7e5UGe9UGe9
U7a8Tg]7Tg]7U7a8UGe9UGe9Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18TW]3Tga4Tga4U7e5U7e5Tga4
Tga4TW]3Tga4Tga4Tga4Tga4Tga4Tga4Tga4Tga4TGY2TW]3TW]3Tga4Tga4U7e5U7e5UGi6UW]2UW]2
UW]2UW]2UW]2UW]2UW]2UW]2UGY1UGY1UGY1UW]2UW]2Uga3Uga3Uga3Tge3Tge3Tge3Tge3Tge3Tge3
Tge3Tge3UGY1UGY1UGY1UW]2UW]2Uga3Uga3Uga3TG]1TG]1TG]1TWa2TWa2Tge3Tge3Tge3UW]2UW]2
UW]2UW]2UW]2UW]2UW]2UW]2TWa2TWa2Tge3Tge3Tge3U7i4U7i4U7i4Tge3Tge3Tge3Tge3Tge3Tge3
Tge3Tge3U7i4U7i4U7i4Tge3Tge3Tge3TWa2TWa2TWa2TWa2Tge3Tge3Tge3U7i4U7i4U7i4Uge1Uge1
Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1V7i2V7i2V7i2VGm3VGm3VGm3V7i2V7i2V7i2V7i2V7i2V7i2
V7i2V7i2V7i2V7i2V7i2V7i2V7i2V7i2V7i2V7i2UW]2UW]2Uga3Uga3Uga3V7e4V7e4V7e4V7i2V7i2
V7i2V7i2V7i2V7i2V7i2V7i2VH10VH10V7loUghnUghnUWdmUWdmUG`lUWa0UWa0Uge1Uge1Uge1V7i2
V7i2V7i2UWm7UWm7UGi6U7e5U7e5UGi6UWm7UWm7UW]2Uga3V7e4VGi5VGi5VGi5VGi5V7e4Tgi0Tgi0
Tgi1U7m2U7i4UGi6UGi6UGi6Vh17VWm6VGi5V7e4V7e4VGi5VWm6Vh17Uga3Uga3V7e4V7e4V7e4VGi5
VGi5VGi5V7e4V7e4VGi5VGi5VGi5VWm6VWm6VWm6VWm6VWm6VWm6VWm6VWm6VWm6VWm6VWm6VGi5VWm6
Vh17Vh17Vh17Vh17VWm6VGi5VWm6VWm6VGi5VGi5VWm6Vh17W858W858WXE7WXE7WXA8WXA8WX=:WX=;
002SSW:SSW:SSW:TSg>TSg>TSg>UT7BUT7BTSgBTSgBTSgBTSgBTSgBTSgBTSgBTSgBRSgBRSgBRSgBQ
SW>PSG:PSG:PSG:OS76QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>PSG:PSG:PSG:PSG:PSG:PSG:PSG:P
SG:OSG2OSG2OSG2OSG2PSW6PSW6QSg:QSg:PSW6PSW6OSG2OSG2NS6nNS6nMRfjMRfjOSG2OSG2OSG2O
SG2OSG2OSG2OSG2OSG2LRFjMRVnNRg2NRg2NRg2NRg2MRVnLRFjORVjORVjORVjORVjORVjORVjORVjO
RVjQS76ORVnMR6fNRFjQS76RSG:PRg2MR6fLRVfLRVfLRVfLRVfLRVfLRVfLRVfLRVfPRfnORVjORVjO
RVjNRFfMR6bMR6bMR6bMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZM
RFZLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VL
R6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VL
R6VKQfRLR6VLR6VMRFZMRFZLR6VLR6VKQfRMR6VMR6VMR6VMR6VMR6VMR6VMR6VMR6VLQfRLQfRLQfRL
QfRLQfRLQfRLQfRLQfRKQfBKQfBKQfBKQfBKQfBKQfBKQfBKQfBLRF>LRF>LRF>LRF>LRF>LRF>LRF>L
RF>LRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBPR6BPR6BPR6BOQf>NQV:NQV:NQV:MQF6NQV:NQV:NQV:N
QV:NQV:NQV:NQV:NQV:IQV6IQV6IQV6IQV6IQV6IQV6IQV6IQV6MQV2MQV2MQV2MQV2MQV2MQV2MQV2M
QV2KQEbKQEbKQEbKQEbKQEbKQEbKQEbKQEbLQUfKQEbKQEbKQEbJQ5^IPeZIPeZIPeZIPUbIPUbIPUbI
PUbIPUbIPUbIPUbIPUbLPe^LPe^JPURIPENIPUFIPUBIPUBJPeFJPeFJPeFJPeFJPeFJPeFJPeFJPeFJ
PeFIPUBIPUBIPUBIPUBIPUBIPUBIPUBIPUBIPe>IPe>IPe>IPe>IPe>IPe>IPe>IPe>GPTjGPTjGPTnH
Pe2HPU:HPE>IPUBIPUBHPU:HPU:HPU:HPU:HPU:HPU:HPU:HPU:FP52FP52FP52FP52FP52FP52FP52F
P52FP52FP52FP52FP52GPE6GPE6HPU:HPU:FP52FP52FP52FP52GPE6GPE6HPU:HPU:DOTjDOTjEOdnE
OdnEOdnFP52FP52FP52FOe6FOe6EOU2EOU2FOe6GP5:HPE>IPUBHPDnHPDnHPDnHPDnHPDnHPDnHPDnH
PDnHPDnHPDnHPDnHPDnHPDnHPDnHPDnHPDnGPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^G
PT^GPT^GPT^GPT^GPT^FP52FP52FP52FP52FP52FP52FP52FP52FPT^FPT^FPDfFPDfFPDjFP52FP52F
P52GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^HPdbHPdbHPdbH
PdbGPT^GPT^GPT^GPT^EP4VEP4VEP4VEP4VEP4VEP4VEP4VEP4VBOdbDOdbDOdbEOTbEOTbGOTbGOTbI
OTbGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4REOTJEOTJFOdNF
OdNFOdNGP4RGP4RGP4REOTJEOTJFOdNFOdNFOdNGP4RGP4RGP4RIPTZHPDVFOdNEOTJEOTJEOTJFOdNG
P4RGP4RFOdNFOdNEOTJEOTJDODFDODFDODFEODNDO4JDO4JCNdFCNdFDO4JDO4JEODNEOTJEOTJEOTJE
OTJEOTJEOTJEOTJEOTJBNd>CO4BCO4BDODFDODFCO4BCO4BBNd>CO4BCO4BCO4BCO4BCO4BCO4BCO4BC
O4BBNd>BNd>CO4BCO4BCO4BCO4BCO4BDODFFNd:FNd:FNd:FNd:FNd:FNd:FNd:FNd:ENT6ENT6ENT6F
Nd:FNd:FNd:GO4>GO4>BO4:BO4:BO4:BO4:BO4:BO4:BO4:BO4:ENT6ENT6ENT6FNd:FNd:FNd:GO4>G
O4>ANd6ANd6ANd6BO4:BO4:BO4:COD>COD>FNd:FNd:FNd:FNd:FNd:FNd:FNd:FNd:BO4:BO4:BO4:C
OD>COD>COD>DOTBDOTBCOD>COD>COD>COD>COD>COD>COD>COD>DOTBDOTBCOD>COD>COD>BO4:BO4:B
O4:BO4:BO4:BO4:COD>COD>COD>DOTBDOTBGOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6H
OT:HOT:IOd>IOd>IOd>HOT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:H
OT:FNd:FNd:FNd:GO4>GO4>GO4>HODBHODBGOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6HOcnHOcnHOcnG
OSjGOSjFOCfFOCfEO3bFO42FO42FO42GOD6GOD6GOD6HOT:HOT:FOdNEOTJEOTJDODFDODFEOTJEOTJF
OdNFNd:GO4>HODBIOTFIOTFIOTFIOTFHODBDOd6DOd6DOd:DOd:EOdFEOTJFOdNFOdNKP4NJOdJIOTFH
ODBHODBIOTFJOdJKP4NGO4>GO4>HODBHODBHODBIOTFIOTFIOTFIOTFIOTFIOTFJOdJJOdJJOdJKP4NK
P4NKP4NKP4NKP4NKP4NKP4NKP4NKP4NKP4NIOTFJOdJKP4NKP4NKP4NKP4NJOdJIOTFJOdJJOdJIOTFI
OTFJOdJJOdJLPDRLPDRLPdFLPdFLPTJLPTJLPDRLPDT00:>>LZ>>LZ>>LZ>>LZB?LjB?LjB?LjF@M:B?
M:B?M:B?M:B?M:B?M:B?M:B?M:B?M:6>Lj6>Lj6>Lj6>Lj2=LZ2=LZ2=LYn<LJ2=LZ2=LZ2=LZ2=LZ2=
LZ2=LZ2=LZ2=LYn<LIn<LIn<LIn<LIn<LIn<LIn<LIn<LIj<Kij<Kin=L9n=L:2>LJ2>LJ2>LJ2>LIn=
L9n=L9n=L9j<Kij<Kij<Kif;KYf;KYj<Kij<Kij<Kij<Kij<Kij<Kij<Kij<Kib9KYf:Kif:Kij;L9j;
L9f:Kif:Kib9KYn:KYn:KYn:KYn:KYn:KYn:KYn:KYn:KZ2;L9n:Kij9KYj9KZ2;L:6<LIn:Kij9KYb:
KIb:KIb:KIb:KIb:KIb:KIb:KIb:KIn:KYn:KYj9KIj9KIj9KIf8K9f8K9f8K9f9JYf9JYf9JYf9JYf9
JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8
JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8
JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JI^7J9^7J9b8JIf9JYf9JYb8JI^7J9^7J9f8
JIf8JIf8JIf8JIf8JIf8JIf8JIf8JIb7J9b7J9b7J9b7J9b7J9b7J9b7J9b7J9^7I9^7I9^7I9^7I9^7
I9^7I9^7I9^7I9b9Hib9Hib9Hib9Hib9Hib9Hib9Hib9Hib9I9b9I9b9I9b9I9b9I9b9I9b9I9b9I9n7
Hin7Hin7Hin7Hij6HYj6HYj6HYf5HIf5HIf5HIf5HIf5HIf5HIf5HIf5HIf5HIR5H9R5H9R5H9R5H9R5
H9R5H9R5H9R5H9b5Gib5Gib5Gib5Gib5Gib5Gib5Gib5Gi^5G9^5G9^5G9^5G9^5G9^5G9^5G9^5G9^5
G9^5G9Z4FiZ4FiZ4FiV3FYV3FYV3FYV3FYV3FYV3FYV3FYV3FYV3FYV3FYV3FYb3Fi^2FYZ2F9V1EiV2
EIV2E9V2E9Z3EIZ3EIZ3EIZ3EIZ3EIZ3EIZ3EIZ3EIZ3EIV2E9V2E9V2E9V2E9V2E9V2E9V2E9V2E9V3
DiV3DiV3DiV3DiV3DiV3DiV3DiV3DiJ1CIN2CYN2CiN2CiR2DYR1DiR1DiR1DiN1DIN1DIN1DIN1DIN1
DIN1DIN1DIN1DIEoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiJ0D9J0D9N1DIN1DIN1DIN1DIEo
CiEoCiJ0D9J0D9N1DIN1DIN1DIN1DI=mCI=mCI=mCIAnCYAnCYAnCYEoCiEoCiN0DYIoDIIoDIEnD9En
D9IoDIN0DYR1DiN0CYN0CYN0CYN0CYN0CYN0CYN0CYN0CYN0CYN0CYN0CYN0CYN0CYN0CYN0CYN0CYN2
BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiF0CIF0CIF0CIF0CIF0
CIF0CIF0CIF0CIF2BIF1BYF1BYF0C9F0CIF0CIEoCiEoCiJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1
BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYN2BiN2BiN2BiN2BiN2BiR3C9F0BIF0BIF0BIF0BIF0
BIF0BIF0BIF0BI:0BiAoBiAoBiEoBiEoBiMoBiMoBiUnBiN0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0
B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9EnAYEnAYEnAYIoAiIoAiN0B9N0B9N0B9EnAYEnAYEnAYIoAiIo
AiN0B9N0B9N0B9R1BIN0B9IoAiEnAYEnAYEnAYEnAYIoAiIoAiIoAiEnAYEnAYEnAYAmAIAmAIAmAIEm
AiAlAY=kAI=kAI=kAI=kAIAlAYEmAi=lA9=lA9=lA9=lA9=lA9=lA9=lA9=lA99k@i9k@i=lA9AmAIAm
AI=lA99k@i9k@i=lA9=lA9=lA9=lA9=lA9=lA9=lA9=lA9=lA9=lA9=lA9=lA99k@i9k@i9k@i9k@iEj
@IEj@IEj@IEj@IEj@IEj@IEj@IEj@IAi@9Ej@IEj@IEj@IIk@YIk@YIk@YIk@Y1j@91j@91j@91j@91j
@91j@91j@91j@9Ai@9Ej@IEj@IEj@IIk@YIk@YIk@YIk@Y1j@95k@I5k@I5k@I9l@Y9l@Y9l@Y9l@YEj
@IEj@IEj@IEj@IEj@IEj@IEj@IEj@I9l@Y9l@Y9l@Y9l@Y=m@i=m@i=m@iAnA9=m@i=m@i=m@i=m@i=m
@i=m@i=m@i=m@iAnA9=m@i=m@i=m@i9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y=m@i=m@i=m@iAnA9Mm
@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IQn@YQn@YUo@iUo@iQn@YQn@YQn@YQn@YQn
@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YIk@YIk@YIk@YIk@YMl@iMl@iMl@iQmA9Ek
?iEk?iEk?iEk?iEk?iEk?iEk?iEk?iQo@IMn@9Mn@9Mn@9Im?iIm?iIm?iIm?iIl@9Il@9Il@9Il@9Mm
@IMm@IMm@IQn@YEnAYEnAYAmAI=lA9=lA9AmAIEnAYEnAYIk@YIk@YQmA9QmA9UnAIUnAIQmA9QmA9Ao
@IAo@IF0@iF0@iJ0AYIoAiIoAiIoAiYoAYUnAIQmA9QmA9QmA9QmA9UnAIYoAYMl@iMl@iQmA9QmA9Qm
A9UnAIUnAIUnAIUnAIYoAYYoAYYoAY^0Ai^0Ai^0Aib1B9^0Ai^0Ai^0Ai^0Ai^0Ai^0Ai^0Ai^0AiUn
AIYoAYYoAY^0Ai^0AiYoAYYoAYUnAIYoAYUnAIUnAIUnAIUnAIYoAY^0Aib1B9Z1@iZ1@iZ0A9Z0A9Yo
AYYoA`00XXeaXXeaXhibXhibXhibY8mcY8mcY8mcXhicXhicXhicXhicXhicXhicXhicXhicX8ebX8eb
X8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebWhaaWhaaWhaaWhaaWhaaWhaa
WhaaWhaaWXa_WXa_WXa_Whe`Whe`Whe`X8iaX8iaWXa_WXa_WXa_WXa_WXa_WXa_WH]^WH]^WXa_WXa_
WXa_WXa_WXa_WXa_WXa_WXa_W8U^W8U^WHY_WX]`WX]`WHY_W8U^W8U^WhY^WhY^WhY^WhY^WhY^WhY^
WhY^WhY^WhY_WhY_WXU^WXU^WhY_WhY_WhY_WXU^W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]WXU]WXU]
WXU]WXU]WHQ/WHQ/WHQ/WHQ/WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZW8QYW8QYW8QYW8QYW8QYW8QY
W8QYW8QYVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMX
VhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMX
VhMXVhMXVXIWVhMXW8QYW8QYW8QYW8QYVhMXVXIWW8MXW8MXW8MXW8MXW8MXW8MXW8MXW8MXVhIWVhIW
VhIWVhIWVhIWVhIWVhIWVhIWVhMTVhMTVhMTVhMTVhMTVhMTVhMTVhMTVhQRVhQRVhQRVhQRVhQRVhQR
VhQRVhQRVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSWXIRWXIRWXIRWXIRWXIRWXIRWXIRWXIRWHIPWHIP
WHIPWHIPWHIPWHIPWHIPWHIPV8EOV8EOV8EOV8EOV8EOV8EOV8EOV8EOW8EOW8EOW8EOW8EOW8EOW8EO
W8EOW8EOVhELVhELVhELVhELVhELVhELVhELVhELVXAKVXAKVXAKVXAKVH=JVH=JVH=JVH=JV89IV89I
V89IV89IV89IV89IV89IV89IVh9JVX5IVH5GV81FV85DVH9DVH9DVX=EVH9DVH9DVH9DVH9DVH9DVH9D
VH9DVH9DV85CV85CV85CV85CV85CV85CV85CV85CV89BV89BV89BV89BV89BV89BV89BV89BUX5=UX5=
UX5>Uh9?Uh5AV85CV85CV85CUh5AUh5AUh5AUh5AUh5AUh5AUh5AUh5ATge=Tge=Tge=Tge=Tge=Tge=
Tge=Tge=UGm?UGm?UGm?UX1@UX1@UX1@Uh5AUh5AUGm?UGm?UGm?UX1@UX1@UX1@Uh5AUh5ATge=Tge=
Tge=U7i>U7i>UGm?UGm?UGm?Uh5AUh5AUX1@UGm?UGm?UGm?UX1@UX1@Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>
Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;
Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;UH1=UH1=UH1=UH1=UH1=UH1=UH1=UH1=UH99UH99UH5:UH5:UH1<UH1=
UH1=UH1=UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:U7m8UH19
UH19UX5:UX5:Uh9;Uh9;V8=<UH19UH19UH19UH19UH19UH19UH19UH19TX1;U7m;U7m;UGm;UGm;Ugm;
Ugm;VGi;Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18U7e5UGi6
UGi6UGi6UWm7UWm7UWm7Uh18U7e5UGi6UGi6UGi6UWm7UWm7UWm7Uh18Uh18Uh18UWm7UGi6UGi6UGi6
UGi6UGi6UGi6UGi6UGi6U7e5U7e5U7e5U7e5U7e5U7e5U7e5Tga4TW]3TW]3Tga4U7e5U7e5Tga4Tga4
Tga4Tga4Tga4Tga4Tga4Tga4TGY2TW]3Tga4Tga4Tga4Tga4TW]3TGY2TW]3TW]3TW]3TW]3TW]3TW]3
TW]3TW]3U7e5Tga4Tga4TW]3TW]3TGY2TGY2TGY2UGY1UGY1UGY1UGY1UGY1UGY1UGY1UGY1U7U0U7U0
U7U0UGY1UGY1UW]2UW]2UW]2T7Y0T7Y0T7Y0T7Y0T7Y0T7Y0T7Y0T7Y0U7U0U7U0U7U0UGY1UGY1UW]2
UW]2UW]2T7Y0T7Y0T7Y0TG]1TG]1TWa2TWa2TWa2UGY1UGY1UGY1UGY1UGY1UGY1UGY1UGY1TG]1TG]1
TWa2TWa2TWa2Tge3Tge3Tge3TWa2TWa2TWa2TWa2TWa2TWa2TWa2TWa2Tge3Tge3Tge3TWa2TWa2TWa2
TG]1TG]1TG]1TG]1TWa2TWa2TWa2Tge3Tge3Tge3UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0
Uge1Uge1Uge1V7i2V7i2V7i2Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1
Uge1Uge1UGY1UGY1UW]2UW]2UW]2Uga3Uga3Uga3UG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oUWdoUWdo
UWdoUWdoUWdoUWdoUWdoUWdoUG/oUG/oUWa0UWa0UWa0Uge1Uge1Uge1U7i4U7i4Tge3TWa2TWa2Tge3
U7i4U7i4UGY1UW]2Uga3V7e4V7e4V7e4V7e4Uga3UH12UH12UH13UH13UX16UWm7Uh18Uh18VGi5VGi5
V7e4V7e4V7e4V7e4VGi5VGi5Uga3Uga3V7e4V7e4V7e4VGi5VGi5VGi5VWm6VWm6VWm6Vh17Vh17Vh17
W858W858Vh17Vh17Vh17Vh17Vh17Vh17Vh17Vh17VGi5VGi5VWm6VWm6VWm6VWm6VGi5VGi5VGi5VGi5
VGi5V7e4VGi5VWm6Vh17W858VX53VX53VX14VX14VWm6VWm7002RSG6RSG6RSG6RSG6SSW:SSW:TSg>T
Sg>SSW>SSW>SSW>SSW>SSW>SSW>SSW>SSW>OS76OS76OS76OS76PSG:PSG:PSG:PSG:PSG:PSG:PSG:P
SG:PSG:PSG:PSG:PSG:NRg2NRg2NRg2NRg2NRg2NRg2NRg2NRg2MRfjMRfjNS6nNS6nOSG2OSG2OSG2O
SG2MRfjMRfjMRfjMRfjMRfjMRfjNS6nNS6nMRfjMRfjMRfjMRfjMRfjMRfjMRfjMRfjKR6fLRFjMRVnM
RVnMRVnMRVnLRFjKR6fNRFfNRFfNRFfNRFfNRFfNRFfNRFfNRFfNRFjNRFjORVnNRFjNRFjNRFjNRFjO
RVnKRFbKRFbKRFbKRFbKRFbKRFbKRFbKRFbMR6bMR6bMR6bMR6bMR6bMR6bMR6bMR6bMRFZMRFZMRFZM
RFZMRFZMRFZMRFZMRFZLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VKQfRKQfRKQfRKQfRKQfRKQfRKQfRK
QfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRK
QfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRJQVNJQVNKQfRLR6VLR6VKQfRJQVNJ
QVNLQfRLQfRLQfRLQfRLQfRLQfRLQfRLQfRKQVNKQVNKQVNKQVNKQVNKQVNKQVNKQVNKQfBKQfBKQfBK
QfBKQfBKQfBKQfBKQfBKR6:KR6:KR6:KR6:KR6:KR6:KR6:KR6:KR6>KR6>KR6>KR6>KR6>KR6>KR6>K
R6>MQF6MQF6MQF6MQF6NQV:NQV:NQV:NQV:LQUfLQUfLQUfLQUfLQUfLQUfLQUfLQUfGQEbGQEbGQEbG
QEbGQEbGQEbGQEbGQEbKQ5jKQ5jKQ5jKQ5jKQ5jKQ5jKQ5jKQ5jJQ5^JQ5^JQ5^JQ5^JQ5^JQ5^JQ5^J
Q5^IPeZIPeZIPeZIPeZIPeZIPeZIPeZIPeZHPURHPURHPURHPURHPURHPURHPURHPURIP5RIP5RHP5JH
P5JHPEBIPUBIPUBJPeFIPUBIPUBIPUBIPUBIPUBIPUBIPUBIPUBHPE>HPE>HPE>HPE>HPE>HPE>HPE>H
PE>HPU:HPU:HPU:HPU:HPU:HPU:HPU:HPU:EP4bFPDfFPDjFPDjGPE6GP5:GP5:HPE>GPE6GPE6GPE6G
PE6GPE6GPE6GPE6GPE6CODfCODfCODfCODfCODfCODfCODfCODfDOTjDOTjEOdnEOdnFP52FP52FP52F
P52DOTjDOTjEOdnEOdnFP52FP52FP52FP52DOTjDOTjDOTjEOdnEOdnFP52FP52FP52GPTnFPDjEP4fE
P4fDOdbEP4fEP4fFPDjFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfF
OdfGPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^DOd^DOd^DOd^D
Od^DOd^DOd^DOd^DOd^DPTNDPTNDPDRDP4VDP4VDOd^DOd^DOdbEP4VEP4VEP4VEP4VEP4VEP4VEP4VE
P4VEP4VEP4VEP4VEP4VEP4VEP4VEP4VEP4VCOTNDOdRDOdREP4VEP4VFPDZFPDZGPT^DOdRDOdRDOdRD
OdRDOdRDOdRDOdRDOdRAP4RCOdRCOdRDOdRDOdRFOTRFOTRHOTRFOdNFOdNFOdNFOdNFOdNFOdNFOdNF
OdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNDODFDODFDODFEOTJEOTJFOdNFOdNFOdNDODFDODFDODFE
OTJEOTJFOdNFOdNFOdNFOdNFOdNFOdNFOdNEOTJEOTJDODFDODFDODFDODFDODFDODFDODFDODFDODFD
ODFDODFCO4BBNd>BNd>BNd>BNd>CO4BDODFCO4BCO4BCO4BCO4BCO4BCO4BCO4BCO4BANT:ANT:BNd>C
O4BCO4BBNd>ANT:ANT:BNd>BNd>BNd>BNd>BNd>BNd>BNd>BNd>CO4BCO4BCO4BBNd>ANT:ANT:@ND6@
ND6ENT6ENT6ENT6ENT6ENT6ENT6ENT6ENT6CN3nDND2DND2DND2ENT6ENT6ENT6FNd:ANd6ANd6ANd6A
Nd6ANd6ANd6ANd6ANd6CN3nDND2DND2DND2ENT6ENT6ENT6FNd:?NCn@NT2@NT2@NT2ANd6ANd6ANd6B
O4:ENT6ENT6ENT6ENT6ENT6ENT6ENT6ENT6ANd6ANd6ANd6ANd6BO4:BO4:COD>COD>BO4:BO4:BO4:B
O4:BO4:BO4:BO4:BO4:COD>COD>BO4:BO4:ANd6ANd6ANd6ANd6ANd6ANd6ANd6ANd6BO4:BO4:COD>C
OD>FO42FO42FO42FO42FO42FO42FO42FO42FO42FO42FO42GOD6GOD6GOD6HOT:HOT:GOD6GOD6GOD6G
OD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6ENT6ENT6ENT6ENT6FNd:FNd:GO4>G
O4>FO42FO42FO42FO42FO42FO42FO42FO42ENcnENcnENcnFO42FO42FO42FO42FO42ENcnENcnENcnE
NcnFO42FO42GOD6GOD6DOd:COT6BOD2BOD2BOD2BOD2COT6DOd:ENT6ENT6GO4>HODBHODBHODBGO4>G
O4>DOd6DOd6EP4>EP4>EOdFFOdNFOdNFOdNHODBHODBHODBHODBHODBHODBHODBHODBGO4>GO4>HODBH
ODBHODBIOTFIOTFIOTFIOTFIOTFJOdJJOdJKP4NKP4NKP4NKP4NJOdJJOdJJOdJJOdJJOdJJOdJJOdJJ
OdJHODBIOTFIOTFJOdJJOdJIOTFIOTFHODBIOTFIOTFHODBHODBHODBIOTFJOdJKP4NKPTBKPTBKPDFK
PDFKP4NKP4P00:6<L:6<L::=LJ:=LJ:=LJ>>LZ>>LZ>>LZ:=LZ:=LZ:=LZ:=LZ:=LZ:=LZ:=LZ:=LYj;
L9j;L9n<LIn<LIn<LJ2=LZ2=LZ2=LYn<LIn<LIn<LIn<LIn<LIn<LIn<LIn<LIj;L9j;L9j;L9j;L9j;
L9j;L9j;L9j;L9f;KYf;KYf;KYj<Kij<Kin=L9n=L9n=L9b:KIb:KIb:KIf;KYf;KYf;KYj<Kij<Kif;
KYf;KYf;KYf;KYf;KYf;KYf;KYf;KY^8KI^8KIb9KYf:Kif:Kib9KY^8KI^8KIj9KIj9KIj9KIj9KIj9
KIj9KIj9KIj9KIb7K9j9KYn:Kin:Kif8KIb7K9f8KIn:Ki^9K9^9K9^9K9^9K9^9K9^9K9^9K9^9K9b7
Jib7Jib7Jib7Jif8K9f8K9f8K9j9KIf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JY^7J9^7J9^7J9^7J9^7
J9^7J9^7J9^7J9Z6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6
IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6
IiZ6IiZ6IiZ6IiV5IYZ6Ii^7J9^7J9^7J9^7J9Z6IiV5IY^6Ii^6Ii^6Ii^6Ii^6Ii^6Ii^6Ii^6IiZ5
IYZ5IYZ5IYZ5IYZ5IYZ5IYZ5IYZ5IY^7I9^7I9^7I9^7I9^7I9^7I9^7I9^7I9Z7HIZ7HIZ7HIZ7HIZ7
HIZ7HIZ7HIZ7HIZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYb4H9b4H9f5HIf5HIf5HIj6HYj6HYj6HYb6
GIb6GIb6GIb6GIb6GIb6GIb6GIb6GIN5G9N5G9N5G9N5G9N5G9N5G9N5G9N5G9^4GY^4GY^4GY^4GY^4
GY^4GY^4GY^4GYZ4FiZ4FiZ4FiZ4FiZ4FiZ4FiZ4FiZ4FiR2FIR2FIR2FIR2FIV3FYV3FYV3FYZ4FiN1
EiN1EiN1EiN1EiN1EiN1EiN1EiN1EiQoEiQoEiMoEIMoEIR1E9R1DiZ3EIZ3EIR1DiR1DiR1DiR1DiR1
DiR1DiR1DiR1DiN0DYN0DYN0DYN0DYN0DYN0DYN0DYN0DYN1DIN1DIN1DIN1DIN1DIN1DIN1DIN1DIF0
C9F0C9F0CIJ1CYJ0D9N0DYN0DYN0DYJ0D9J0D9J0D9J0D9J0D9J0D9J0D9J0D9=mCI=mCI=mCI=mCI=m
CI=mCI=mCI=mCIAnCYAnCYAnCYEoCiEoCiJ0D9J0D9J0D9AnCYAnCYAnCYEoCiEoCiJ0D9J0D9J0D9An
CYAnCYEoCiEoCiEoCiJ0D9J0D9J0D9J1CYF0CIAoC9AoC9AoC9F0CIJ1CYJ1CYIoCIIoCIIoCIIoCIIo
CIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2
BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiAoBiAoBiAoBiAoBiAoBiAoBiAoBiAoBiB2AiB2AiB2AiB1B9B0
BIB0BIAoBiAoBiF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BI=n
AiAoB9AoB9AoB9AoB9AoB9F0BIF0BIAoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB960Ai>0Ai>0AiB0AiB0
AiIoAiIoAiQoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiAm
AIAmAIAmAIAmAIEnAYEnAYEnAYIoAiAmAIAmAIAmAIAmAIEnAYEnAYEnAYIoAiEnAYEnAYIoAiIoAiEn
AYAmAI=lA9=lA99k@i=lA9=lA9=lA9AmAIAmAIAmAIAmAI=m@i=m@i9l@Y5k@I5k@I9l@Y=m@i=m@i=l
A9=lA9=lA9=lA9=lA9=lA9=lA9=lA91i@I5j@Y9k@i9k@i9k@i9k@i5j@Y1i@I5j@Y5j@Y5j@Y5j@Y5j
@Y5j@Y5j@Y5j@Y9k@i9k@i9k@i5j@Y5j@Y5j@Y5j@Y5j@YAi@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@9=h
?i=h?i=h?iAi@9Ai@9Ej@IEj@IEj@I5k@I5k@I5k@I5k@I5k@I5k@I5k@I5k@I=h?i=h?i=h?iAi@9Ai
@9Ej@IEj@IEj@Hmi?hmi?hmi?i1j@91j@95k@I5k@I5k@IAi@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@91j
@91j@95k@I5k@I5k@I9l@Y9l@Y9l@Y5k@I5k@I5k@I5k@I5k@I5k@I5k@I5k@I9l@Y9l@Y9l@Y5k@I5k
@I5k@I1j@91j@91j@91j@95k@I5k@I5k@I9l@Y9l@Y9l@YEk?iEk?iEk?iEk?iEk?iEk?iEk?iEk?iEk
?iEk?iIl@9Il@9Mm@IMm@IMm@IMm@IIl@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il
@9Il@9Il@9Il@9Ai@9Ai@9Ej@IEj@IEj@IIk@YIk@YIk@YMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IAj
?YAj?YEk?iEk?iEk?iIl@9Il@9Il@9Aj?YAj?YEk?iEk?iEk?iIl@9Il@9Il@9=n@I9m@95l?i5l?i5l
?i5l?i9m@9=n@IAi@9Ej@IIk@YMl@iMl@iMl@iMl@iIk@Y=n@9=n@9=n@IAo@YAnA9EnAYEnAYEnAYIk
@YMl@iQmA9QmA9QmA9QmA9Ml@iIk@YMl@iMl@iQmA9QmA9QmA9UnAIUnAIUnAIQmA9QmA9UnAIUnAIUn
AIYoAYYoAYYoAYQmA9QmA9QmA9QmA9QmA9QmA9QmA9QmA9QmA9QmA9UnAIYoAYYoAYUnAIQmA9QmA9Un
AIQmA9QmA9Ml@iQmA9UnAIYoAY^0AiZ1@iZ1@iZ0A9Z0A9YoAYYoA`00XHa`XHa`XHa`XXeaXXeaXXea
XhibXhibXXebXXebXXebXXebXXebXXebXXebXXebWHY_WX]`WX]`WX]`WhaaX8ebX8ebX8ebWhaaWhaa
WhaaWhaaWhaaWhaaWhaaWhaaWX]`WX]`WX]`WX]`WX]`WX]`WX]`WX]`WH]^WH]^WH]^WH]^WXa_WXa_
WXa_Whe`VhU/VhU/W8Y]W8Y]WH]^WH]^WXa_WXa_W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]VXM/VhQ]
W8U^W8U^W8U^W8U^VhQ]VXM/WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/VhI[WXU^X8]`WhY_W8M/VhI[
WHQ]WhY_VXQ[VXQ[VXQ[VXQ[VXQ[VXQ[VXQ[VXQ[VhIZVhIZVhIZW8M[WHQ/WHQ/WHQ/WXU]WHUZWHUZ
WHUZWHUZWHUZWHUZWHUZWHUZVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVXIWVXIWVXIWVXIWVXIWVXIW
VXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIW
VXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVHEVVXIWVXIWVhMXVhMXVXIW
VXIWVHEVVhIWVhIWVhIWVhIWVhIWVhIWVhIWVhIWVXEVVXEVVXEVVXEVVXEVVXEVVXEVVXEVVhMTVhMT
VhMTVhMTVhMTVhMTVhMTVhMTVXMQVXMQVXMQVXMQVXMQVXMQVXMQVXMQVXMRVXMRVXMRVXMRVXMRVXMR
VXMRVXMRVh=OW8APW8APW8APWHEQWXIRWXIRWXIRW8ILW8ILW8ILW8ILW8ILW8ILW8ILW8ILUXEJUXEJ
UXEJUXEJUXEJUXEJUXEJUXEJVX=MVX=MVX=MVX=MVX=MVX=MVX=MVX=MVH=JVH=JVH=JVH=JVH=JVH=J
VH=JVH=JUh5HUh5HUh5HV89IVH=JVH=JVH=JVXAKUh9EUh9EUh9EUh9EUh9EUh9EUh9EUh9EV7mGUgiF
UgmEUgmEUh1CV85CVX=EVX=EV85CV85CV85CV85CV85CV85CV85CV85CUh1BUh1BUh1BUh1BUh1BUh1B
Uh1BUh1BUh5AUh5AUh5AUh5AUh5AUh5AUh5AUh5AUH1<UH1<UH1=UX5>UX1@UWmAUh1BUh1BUX1@UX1@
UX1@UX1@UX1@UX1@UX1@UX1@U7i>U7i>U7i>U7i>U7i>U7i>U7i>U7i>U7i>U7i>U7i>U7i>UGm?UGm?
UGm?UX1@U7i>U7i>U7i>U7i>UGm?UGm?UGm?UX1@Tge=Tge=Tge=U7i>U7i>U7i>UGm?UGm?U7m;U7m;
Tgi:Tgi:U7m;UH1<UX5=Uh9>UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=
UWm=UWm=Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Tgm8Tgm8
Tgm8Tgm8Tgm8Tgm8Tgm8Tgm8Th54Th54Th56Th56Th17Tgm8Tgm8Tgi:U7m8U7m8U7m8U7m8U7m8U7m8
U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7
Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7T7m6TWm6TWm6Tgm6Tgm6UGi6UGi6Ugi6UGi6UGi6UGi6UGi6UGi6UGi6
UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6Tga4Tga4U7e5U7e5U7e5UGi6UGi6UGi6Tga4Tga4
U7e5U7e5U7e5UGi6UGi6UGi6U7e5U7e5UGi6UWm7UWm7U7e5Tga4TW]3TW]3TW]3TW]3Tga4Tga4U7e5
U7e5UGi6Tge3TWa2TWa2TG]1TG]1TWa2TWa2Tge3TGY2TGY2TGY2TGY2TGY2TGY2TGY2TGY2T7U1T7U1
TGY2TW]3TW]3TGY2T7U1T7U1TGY2TGY2TGY2TGY2TGY2TGY2TGY2TGY2T7U1T7U1T7U1TGY2TGY2TGY2
TGY2TGY2U7U0U7U0U7U0U7U0U7U0U7U0U7U0U7U0TgPoTgPoTgPoU7U0U7U0U7U0UGY1UGY1T7Y0T7Y0
T7Y0T7Y0T7Y0T7Y0T7Y0T7Y0TgPoTgPoTgPoU7U0U7U0U7U0UGY1UGY1SgToSgToSgToT7Y0T7Y0T7Y0
TG]1TG]1U7U0U7U0U7U0U7U0U7U0U7U0U7U0U7U0T7Y0T7Y0T7Y0TG]1TG]1TG]1TWa2TWa2TG]1TG]1
TG]1TG]1TG]1TG]1TG]1TG]1TWa2TWa2TG]1TG]1TG]1T7Y0T7Y0T7Y0T7Y0T7Y0T7Y0TG]1TG]1TG]1
TWa2TWa2UG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oUWa0UWa0Uge1Uge1Uge1UWa0UWa0
UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0U7U0U7U0U7U0UGY1UGY1UGY1
UW]2UW]2UG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oTgPoU7U0U7U0UGY1UGY1UW]2UW]2UW]2U7XnU7Xn
U7XnUG/oUG/oUG/oUWa0UWa0TWdoTG`nTG`nT7/mT7/mTG`nTG`nTWdoU7U0UGY1UW]2Uga3Uga3Uga3
UW]2UW]2TWdoTWdoTWe0TWe0Tge3Tga4Tga4U7e5UW]2UW]2V7e4VGi5VGi5V7e4UW]2UW]2Uga3Uga3
V7e4V7e4V7e4VGi5VGi5VGi5Uga3Uga3Uga3Uga3V7e4V7e4VGi5VGi5Uga3Uga3Uga3Uga3Uga3Uga3
Uga3Uga3Uga3V7e4VGi5VGi5VGi5VGi5V7e4Uga3V7e4V7e4Uga3Uga3Uga3V7e4VWm6VWm6VH12VH12
VGm3VGm3VGi5VGi6002QS72QS72QS72QS72RSG6RSG6SSW:SSW:RSG:RSG:RSG:RSG:RSG:RSG:RSG:R
SG:MRVnMRVnNRg2NRg2OS76OS76PSG:PSG:OS76OS76OS76OS76OS76OS76OS76OS76MRVnMRVnMRVnM
RVnMRVnMRVnMRVnMRVnLRVfMRfjMRfjMRfjNS6nNS6nNS6nNS6nKRFbKRFbKRFbLRVfMRfjMRfjNS6nN
S6nLRVfLRVfLRVfLRVfLRVfLRVfLRVfLRVfJQfbKR6fLRFjLRFjLRFjLRFjKR6fJQfbMR6bMR6bMR6bM
R6bMR6bMR6bMR6bMR6bKQV^NRFjPRg2ORVnLQfbKQV^MR6fORVnJR6^JR6^JR6^JR6^JR6^JR6^JR6^J
R6^JQFVKQVZKQVZLQf^LQf^MR6bMR6bNRFfMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZKQfRKQfRKQfRK
QfRKQfRKQfRKQfRKQfRJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJ
QVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJ
QVNJQVNJQVNJQVNJQVNIQFJIQFJJQVNKQfRKQfRJQVNIQFJIQFJKQVNKQVNKQVNKQVNKQVNKQVNKQVNK
QVNJQFJJQFJJQFJJQFJJQFJJQFJJQFJJQFJKQfBKQfBKQfBKQfBKQfBKQfBKQfBKQfBJQf6JQf6JQf6J
Qf6JQf6JQf6JQf6JQf6JQf:JQf:JQf:JQf:JQf:JQf:JQf:JQf:KPenKPenLQ62LQ62MQF6MQF6NQV:N
QV:KQE^KQE^KQE^KQE^KQE^KQE^KQE^KQE^FQEZFQEZFQEZFQEZFQEZFQEZFQEZFQEZJPefJPefJPefJ
PefJPefJPefJPefJPefIPeZIPeZIPeZIPeZIPeZIPeZIPeZIPeZFP5NGPERGPERHPUVHPUVIPeZIPeZJ
Q5^GPUFGPUFGPUFGPUFGPUFGPUFGPUFGPUFGOUJGOUJFOUBFOUBGP5>HPE>JPeFJPeFHPE>HPE>HPE>H
PE>HPE>HPE>HPE>HPE>GP5:GP5:GP5:GP5:GP5:GP5:GP5:GP5:GPE6GPE6GPE6GPE6GPE6GPE6GPE6G
PE6DOd^EP4bEP4fEP4fFP52FOe6FOe6GP5:FP52FP52FP52FP52FP52FP52FP52FP52EOdnEOdnEOdnE
OdnEOdnEOdnEOdnEOdnCODfDOTjDOTjDOTjEOdnEOdnEOdnEOdnCODfDOTjDOTjDOTjEOdnEOdnEOdnE
OdnANd^ANd^BO4bBO4bBO4bCODfCODfCODfCOTZCOTZCOTZCOTZDOd^EP4bGPTjHPdnEOTbEOTbEOTbE
OTbEOTbEOTbEOTbEOTbEOTbEOTbEOTbEOTbEOTbEOTbEOTbEOTbGPT^GPT^GPT^GPT^GPT^GPT^GPT^G
PT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^COdRCOdRCOdRCOdRCOdRCOdRCOdRCOdRCPDBCPDBCPDJC
PDJCP4NCOdRCOdRCOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRD
OdREP4VDOdRDOdRCOTNCOTNBODJBODJAO4FCOTNCOTNCOTNCOTNCOTNCOTNCOTNCOTN@OdJBOdJBOdJC
OdJCOdJEOTJEOTJGOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJE
OTJCO4BCO4BCO4BDODFDODFEOTJEOTJEOTJCO4BCO4BCO4BDODFDODFEOTJEOTJEOTJCO4BDODFEOTJF
OdNFOdNDODFBNd>ANT:ANT:ANT:BNd>CO4BCO4BDODFDODFEOTJCOT6BOD2AO3nAO3nAO3nAO3nBOD2C
OT6?N42?N42?N42?N42?N42?N42?N42?N42@ND6@ND6ANT:BNd>BNd>ANT:@ND6@ND6ANT:ANT:ANT:A
NT:ANT:ANT:ANT:ANT:?N42?N42@ND6@ND6ANT:BNd>BNd>BNd>DND2DND2DND2DND2DND2DND2DND2D
ND2BMcjCN3nCN3nCN3nDND2DND2DND2ENT6>N3j>N3j>N3j>N3j>N3j>N3j>N3j>N3jBMcjCN3nCN3nC
N3nDND2DND2DND2ENT6>N3j?NCn?NCn?NCn@NT2@NT2@NT2ANd6DND2DND2DND2DND2DND2DND2DND2D
ND2@NT2@NT2@NT2@NT2ANd6ANd6BO4:BO4:ANd6ANd6ANd6ANd6ANd6ANd6ANd6ANd6BO4:BO4:ANd6A
Nd6@NT2@NT2@NT2@NT2@NT2@NT2@NT2@NT2ANd6ANd6BO4:BO4:ENcnENcnENcnENcnENcnENcnENcnE
NcnENcnENcnENcnFO42FO42FO42GOD6GOD6FO42FO42FO42FO42FO42FO42FO42FO42FO42FO42FO42F
O42FO42FO42FO42FO42DND2DND2DND2DND2ENT6ENT6FNd:FNd:DNSjDNSjDNSjDNSjDNSjDNSjDNSjD
NSjCN3nCN3nDND2DND2ENT6FNd:FNd:FNd:DNSjDNSjDNSjDNSjENcnENcnFO42FO42BOCnAO3j@Ncf@
Ncf@Ncf@NcfAO3jBOCnDND2DND2FNd:GO4>GO4>GO4>FNd:FNd:AO3jAO3jAO3nAO3nBO4:BNd>BNd>C
O4BENT6FNd:HODBIOTFIOTFHODBFNd:ENT6GO4>GO4>HODBHODBHODBIOTFIOTFIOTFFNd:FNd:FNd:G
O4>GO4>GO4>HODBHODBFNd:FNd:FNd:FNd:FNd:FNd:FNd:FNd:GO4>HODBHODBIOTFIOTFHODBHODBG
O4>HODBHODBGO4>GO4>GO4>HODBIOTFJOdJGOT2GOT2GOD6GOD6GO4>GO4@00::?KZ6>KJ2<KJ2<KJ2;
Kj2;L:6<LJ:=LZB?Lj>>LZ>>LZ:=LJ:=LJ6<L:2;Kj2;Kj:=LJ:=LJ:=LJ:=LJ:=LJ:=LJ:=LJ:=LJ:=
LZ:=LZ6<LJ6<LJ6<LJ2;L:2;L:2;L:2;Kj2;Kj2;Kj2;Kj2;Kj2;Kj2;Kj2;Kin:KYn:KYn:KYn:KZ2;
Kj2;Kj2;Kj6<L9b:KIb:KIb:KIb:KIb:KIb:KIb:KIb:KIZ8JiZ8Ji^9K9^9K9b:KIb:KIb:KIb:KIb9
KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYZ7K9Z7K9^8KI^8KIb9
KYb9KYb9KYb9KY^8KI^8KI^8KI^8KI^8KI^8KI^8KI^8KIf8K9f8K9f8K9f8K9f8K9f8K9f8K9f8K9b8
JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JI^7J9V5IYR4II^7J9^7J9^7J9^7J9^7
J9^7J9^7J9^7J9Z6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiV5IYV5IYV5IYZ6IiZ6Ii^7J9^7J9^7J9b9
IY^8II^8IIZ7I9Z7I9V6HiV6HiR5HYZ5JIZ5JIZ5JIZ5JIZ5JIZ5JIZ5JIZ5JIZ5IYZ5IYZ5IY^6Ii^6
Iib7J9b7J9b7J9^6Ii^6Ii^6Ii^6Ii^6Ii^6Ii^6Ii^6Ii^6JYZ5JIZ6IiV6IIV6HiR6HIN6GiN7GIV5
HYV5HYV5HYV5HYV5HYV5HYV5HYV5HYf5HIf5HIf5HIf5HIf5HIf5HIf5HIf5HJ6:I9f6H9Z3GIZ3GIj7
HJ29Hj29Hin8HYZ3GIZ3GIZ3GIZ3GIZ3GIZ3GIZ3GIZ3GIj8Gif7GYf7GYb6GI^5G9Z4FiZ4FiZ4Fij8
Gif7GY^5G9V3FYR2FIV3FYZ4Fi^5G9Z3GIZ3GI^4GYb5Gib5Gi^4GYZ3GIZ3GIR2FIR2FIR2FIR2FIR2
FIR2FIR2FIR2FIN2EIN2EIN2EIN2EIN2EIN2EIN2EIN2EIR3EYR3EYR3EYR3EYR3EYR3EYR3EYR3EYR1
DiR1DiR1DiR1DiR1DiR1DiR1DiR1DiJ0D9J0D9N1DIR2DYR2DYN1DIJ0D9J0D9J0D9J0D9J0D9J0D9J0
D9J0D9J0D9J0D9R2DYR2DYN1DIN1DIN1DIJ0D9J0D9J0D9AnCYAnCYAnCYAnCYEoCiEoCiEoCiJ0D9R2
DYR2DYJ0D9EoCiAnCYAnCYEoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiF0CIF0CIF0CIF0CIF0
CIF0CIF0CIF0CIIoCiIoCiIoCiIoCiIoCiIoCiIoCiIoCi1mBXmlBHikB8ejAhejAhmlBI5nBi9oC9En
C9EnC9EnC9EnC9IoCIIoCIN0CYN0CY=lBYAmBiAmBiAmBiEnC9EnC9EnC9IoCIJ1BYJ1BYJ1BYJ1BYJ1
BYJ1BYJ1BYJ1BYAmBiAmBiAmBiAmBiAmBiAmBiAmBiAmBiJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYAo
B9AoB9AoB9AoB9AoB9AoB9AoB9AoB9N2BiJ1BYAoB9=nAi9mAY=nAiAoB9F0BI9mAYAoB9F0BIAoB99m
AY9mAY=nAiF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BI9mAY9mAY=nAi=nAiAoB9AoB9AoB9AoB9B0
AiB0Ai=oAY=nAi9lB95kAi5jB95jB9=kAI=kAIAlAYAlAYAlAYEmAiEmAiEmAiAmAIAmAIAmAIAmAIAm
AIAmAIAmAIAmAI=m@i=m@i=m@iAnA9EoAIEoAIJ0AYJ0AY=n@IAo@YF0@iF0@iF0@iF0@iAo@Y=n@I5l
?i9l@YAnA9IoAiIoAiInB9EmAiAlB9=lA9=lA9=lA9=lA9=lA9=lA9=lA9=lA9=lA99k@i9k@i5j@Y5j
@Y9k@i9k@i=lA9=m@i=m@i=m@i9l@Y9l@Y5k@I5k@I5k@I9l@Y5k@I1j@91j@91j@91j@95k@I9l@Y1i
@I1i@I1i@I1i@I1i@I1i@I1i@I1i@I5j@Y5j@Y5j@Y5j@Y5j@Y5j@Y5j@Y5j@Y5k@I5k@I5k@I5k@I5k
@I5k@I5k@I5k@IEj@IEj@IEj@IEj@IEj@IEj@IEj@IEj@IAi@9=h?i9g?Y5f?I5f?I9g?Y=h?iAi@99h
?99h?95g>i5g>i9h?9=i?IAj?YEk?iAi@9Ai@9Ai@9=h?i9g?Y9g?Y5f?I5f?IAj?YAj?YAj?YAj?YAj
?YAj?YAj?YAj?YAi@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@8mj?Hmj?I5i?I5i?I=i?I=i?IEi?IEi?I5l
?i5l?i=k?i=k?iEk?iEk?iMk?iMk?iAj?YAj?YAj?YAj?YAj?YAj?YAj?YAj?YIl@9Il@9Il@9Ek?iEk
?iAj?Y=i?I=i?IAj?YAj?YAj?YEk?iEk?iEk?iIl@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Qn
@YMm@IMm@IIl@9Il@9Ek?iEk?iAj?YEk?iEk?iEk?iEk?iEk?iEk?iEk?iEk?iEk?iEk?iEk?iEk?iEk
?iEk?iEk?iEk?iAj?YAj?YAj?YAj?YAj?YAj?YAj?YAj?Y9h?99h?9=i?I=i?IAj?YEk?iEk?iEk?i=n
@I9m@9Al@9=k?iEk?iAj?YEi?IEi?IEj@IEj@IEj@IEj@IEj@IEj@IEj@IEj@IIl@9Ek?iAj?YAj?YAj
?YAj?YEk?iIl@9Ml@iMl@iMl@iMl@iMl@iMl@iMl@iMl@iMl@iMl@iMl@iMl@iMl@iMl@iMl@iMl@iZ0
A9Uo@iQn@YMm@IMm@IMm@IQn@YUo@iMl@iMl@iMl@iQmA9UnAIUnAIYoAYYoAYMl@iMl@iMl@iMl@iMl
@iMl@iMl@iMl@iIk@YMl@iUnAIYoAYYoAYUnAIMl@iIk@YMlA9MlA9QmAIUnAYYoAi^0B9b1BIb1BIYo
AYYoAYYoAYUnAIUnAIUnA@00XXm^XHi]X8a]X8a]X8]_X8]`XHaaXXebXhibXhibXXeaXXeaXHa`XHa`
X8]_X8]_XXeaXXeaXXeaXXeaXXeaXXeaXXeaXXeaXXebXHaaXHaaXHaaX8]`X8]`X8]`WhY_WhY^WhY^
WhY^WhY^WhY^WhY^WhY^WhY^WXU]WhY^WhY^WhY^X8]_X8]_X8]_X8]_W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]
W8Y]W8Y]VXQ[VXQ[VhU/VhU/VhU/W8Y]W8Y]W8Y]W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^
W8U^W8U^W8U^W8U^W8U^W8U^VXM/VXM/VhQ]VhQ]VhQ]W8U^W8U^W8U^VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]
VhQ]VhQ]WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/W8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYVhMXW8QY
W8QYW8QYW8QYVhMXVHEVV8AUVhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXVXIWVXIWVXIWVXIWVXIWVXIW
VXIWVXIWVHEVVHEVVHEVVXIWVXIWVXIWVhMXVhMXVhQUVhQUVhQUVXMTVHISVHISVHISV8ERVXEYVXEY
VXEYVXEYVXEYVXEYVXEYVXEYVXEVVXEVVXEVVhIWVhIWVhIWW8MXW8MXVhIWVhIWVhIWVhIWVhIWVhIW
VhIWVhIWVXEYVXIWVHEVVHIUV8ERV8IQUhIOUhIOVHERVHERVHERVHERVHERVHERVHERVHERWHEQWHEQ
WHEQWHEQWHEQWHEQWHEQWHEQX8USWHIPVX=MVhANWHIPX8USX8USWXMQVhANVhANVhANVhANVhANVhAN
VhANVhANVhELVhELVhELVhELW8IMW8IMW8IMW8IMWHMNW8IMVXAKVH=JV89IVH=JVXAKVXAKVH9LVX=M
VhANVhANVhANVhANVX=MVH9LV89IV89IV89IV89IV89IV89IV89IV89IUh9EUh9EUh9EUh9EUh9EUh9E
Uh9EUh9EUh9EUh9EUh9EUh9EUh9EUh9EUh9EUh9EV85CV85CV85CV85CV85CV85CV85CV85CUX1@UX1@
Uh5AV89BV89BUh5AUX1@UX1@UX1@UX1@UX1@UX1@UX1@UX1@UX1@UX1@UX1@UX1@UX1@UGm?UGm?UGm?
U7i>U7i>Tge=U7i>U7i>U7i>UGm?UGm?UGm?UGm?V89BUh5AUX1@UGm?U7i>U7i>UGm?UGm?U7i>U7i>
U7i>U7i>U7i>U7i>U7i>U7i>U7m<U7m<U7m<U7m<U7m<U7m<U7m<U7m<UGi>UGi>UGi>UGi>UGi>UGi>
UGi>UGi>TWe:TGa9T7]8T7]8T7]8TWe:Tgi;U7m<Tga:Tga:Tga:U7e;U7e;UGi<UGi<UGi<Tga:Tga:
U7e;U7e;U7e;UGi<UGi<UGi<UH19UH19UH19UH19UH19UH19UH19UH19UGi<UGi<UGi<UGi<UGi<UGi<
UGi<UGi<UH19UH19UH19UH19UH19UH19UH19UH19U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8Uh9;UX5:
U7m8Tgi7Tgi7Tgi7U7m8UH19TWe6Tgi7UH19U7m8TWe6TWe6Tgi7U7m8U7m8U7m8U7m8U7m8U7m8U7m8
U7m8U7m8TWe6TWe6Tgi7Tgi7Tgi7U7m8U7m8U7m8Tgm6Tgm6TWi5TWe6TWa8TWa8TGY8TGY8Tg]5Tg]5
Tg]5U7a6U7a6UGe7UGe7UGe7U7e5U7e5U7e5U7e5U7e5U7e5U7e5U7e5Tge3Tge3U7i4U7i4U7i4U7i4
UGm5UGm5U7i4U7i4UGm5UGm5UGm5U7i4Tge3TWa2TG`oTWa2U7i4UGi6UWm7UGe7UGe7U7a8Tga4Tga4
Tga4Tga4Tga4Tga4Tga4Tga4Tga4TW]3TGY2TGY2TGY2TGY2TW]3Tga4TG]1TG]1TG]1TG]1T7Y0T7Y0
SgToSgToTWa2TG]1T7Y0T7Y0T7Y0T7Y0TG]1TWa2T7U1T7U1T7U1T7U1T7U1T7U1T7U1T7U1TGY2TGY2
TGY2TGY2TGY2TGY2TGY2TGY2TG]1TG]1TG]1TG]1TG]1TG]1TG]1TG]1UGY1UGY1UGY1UGY1UGY1UGY1
UGY1UGY1U7U0TgPoTWLnTGHmTGHmTWLnTgPoU7U0TgTmTWPlTWPlTGLkTWPlTWPlTgTmU7XnU7U0U7U0
TgPoTgPoTWLnTWLnTGHmTGHmU7XnU7XnU7XnU7XnU7XnU7XnU7XnU7XnU7U0U7U0U7U0U7U0U7U0U7U0
U7U0U7U0SWTlSWTlT7PlT7PlTWPlTWPlU7PlU7PlTG`oTG`oTg/oTg/oUG/oUG/oUg/oUg/oU7XnU7Xn
U7XnU7XnU7XnU7XnU7XnU7XnUG/oUG/oUG/oUG/oUG/oU7XnU7XnU7XnU7XnU7XnU7XnU7XnUG/oUG/o
UWa0UWa0U7XnU7XnU7XnU7XnU7XnU7XnU7XnU7XnUWa0UWa0UG/oUG/oU7XnU7XnTgTmTgTmUG/oUG/o
UG/oUG/oUG/oU7XnU7XnU7XnUG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oU7XnU7XnU7XnU7XnU7XnU7Xn
U7XnU7XnTgTmTgTmTgTmTgTmU7XnU7XnU7XnU7XnTWe0TWe0Tg/oTg/oU7XnU7XnUGTmUGTmUGY1UGY1
UGY1UGY1UGY1UGY1UGY1UGY1UWa0UG/oU7XnU7XnU7XnU7XnUG/oUWa0Uga3Uga3Uga3Uga3Uga3Uga3
Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3VGm3VGm3V7i2Uge1Uge1Uge1V7i2VGm3Uga3Uga3
V7e4V7e4V7e4V7e4VGi5VGi5Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3V7e4V7e4VGi5VGi5V7e4
V7e4Uga3Uga4Uga4V7e5VGi6VWm7VWm7Vh18W859VGi5VGi5VGi5VGi5VGi5VGi5002QSVfQSVfPS6fO
RfbORVjPRg2QS76QS76RSG6RSG6RSG6RSG6QS72QS72QS72PRfnQS72QS72QS72QS72QS72QS72QS72Q
S72QS76QS76QS76PRg2PRg2PRg2ORVnORVnORVjORVjORVjORVjORVjORVjORVjORVjNRFfNRFfNRFfO
RVjORVjPRfnPRfnPRfnLRVfLRVfLRVfLRVfLRVfLRVfLRVfLRVfJR6^JR6^JR6^KRFbKRFbKRFbLRVfL
RVfLRFjLRFjLRFjLRFjLRFjLRFjLRFjLRFjLRFjLRFjLRFjLRFjLRFjLRFjLRFjLRFjJQfbJQfbJQfbK
R6fKR6fKR6fLRFjLRFjKR6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fMR6bMR6bMR6bMR6bMR6bMR6bMR6bM
R6bLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VKQfRKQfRLR6VLR6VKQfRJQVNIQFJIQFJKQfRKQfRKQfRK
QfRKQfRKQfRKQfRKQfRIQFJIQFJIQFJIQFJIQFJIQFJIQFJIQFJHQ6FIQFJIQFJIQFJJQVNJQVNJQVNJ
QVNJQfBJQfBJQfBJQfBIQV>IQV>IQV>HQF:IQFJIQFJIQFJIQFJIQFJIQFJIQFJIQFJIQ6FJQFJJQFJJ
QFJKQVNKQVNKQVNKQVNJQFJJQFJJQFJJQFJJQFJJQFJJQFJJQFJIQFJIQFJIQVFIQVFHQF:HQV6HQV6G
QF2JQV>JQV>JQV>JQV>JQV>JQV>JQV>JQV>LQ62LQ62LQ62LQ62LQ62LQ62LQ62LQ62NQf6LQEnJPefK
Q5jMQV2OR6:NQf6NQf6LQEnLQEnLQEnLQEnLQEnLQEnLQEnLQEnIPeZIPeZJQ5^KQEbLQUfLQUfMQejM
QejLQUfKQEbJQ5^IPeZIPeZIPeZJQ5^JQ5^IPeZIPeZJQ5^JQ5^JQ5^JQ5^IPeZIPeZHPURHPURHPURH
PURHPURHPURHPURHPURGPUFGPUFGPUFGPUFGPUFGPUFGPUFGPUFEP5>EP5>EP5>EP5>EP5>EP5>EP5>E
P5>GP5:GP5:GP5:GP5:GP5:GP5:GP5:GP5:EOdnFP52GPE6GPE6GPE6GPE6FP52EOdnEOdnEOdnEOdnE
OdnEOdnEOdnEOdnEOdnEOdnEOdnDOTjDOTjDOTjCODfCODfCODfCODfCODfCODfDOTjDOTjEOdnEOdnE
OdnGPE6FP52EOdnDOTjDOTjDOTjDOTjEOdnDOTjDOTjDOTjDOTjDOTjDOTjDOTjDOTjDOdbDOdbDOdbD
OdbDOdbDOdbDOdbDOdbEOTjEOTjEOTjEOTjEOTjEOTjEOTjEOTjBODZBODZAO4VAO4VBODZCOT^DOdbD
OdbBNdVBNdVBNdVBNdVCO4ZCO4ZCO4ZDOD^CO4ZCO4ZCO4ZDOD^DOD^EOTbEOTbEOTbEP4VEP4VEP4VE
P4VEP4VEP4VEP4VEP4VFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfEP4VEP4VEP4VEP4VEP4VEP4VEP4VE
P4VDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRFPDZEP4VDOdRCOTNCOTNCOTNCOTNDOdRAO4FCOTNDOdRD
OdRBODJAO4FCOTNDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRBODJBODJBODJCOTNCOTNCOTNDOdRD
OdRAODBAODBAODBBODJBO4RBO4RBNdVBNdVCNdFCNdFCNdFCNdFDO4JDO4JEODNEODNDODFDODFDODFD
ODFDODFDODFDODFDODFDOTBDOTBDOTBDOTBDOTBCOD>COD>COD>DOTBEOdFEOdFEOdFDOTBCOD>BO4:A
Nd6BOD2BO4:DOTBEOTJEOTJEODNDO4JDO4RCO4BCO4BCO4BCO4BCO4BCO4BCO4BCO4BBNd>BNd>ANT:@
ND6@ND6ANT:BNd>BNd>@NT2@NT2@NT2?NCn?NCn>N3j>N3j>N3jANd6ANd6@NT2?NCn?NCn@NT2ANd6A
Nd6?N42?N42?N42?N42?N42?N42?N42?N42@ND6@ND6@ND6@ND6@ND6@ND6@ND6@ND6@NT2@NT2@NT2@
NT2@NT2@NT2@NT2@NT2DND2DND2DND2DND2DND2DND2DND2DND2CN3nBMcjBMcjAMSfAMSfBMcjBMcjC
N3nDNSjCNCfBN3bAMc^AMc^AMc^BN3bBN3bCN3nCN3nCN3nBMcjBMcjBMcjAMSfAMSfCNCfCNCfCNCfC
NCfCNCfCNCfCNCfCNCfCN3nCN3nCN3nCN3nCN3nCN3nCN3nCN3n>NCb>NCb@N3b@N3bBN3bBN3bDN3bD
N3b@Ncj@NcjBNSjBNSjDNSjDNSjFNSjFNSjCNCfCNCfCNCfCNCfCNCfCNCfCNCfCNCfDNSjDNSjDNSjD
NSjDNSjENcnENcnENcnCNCfCNCfDNSjDNSjENcnENcnENcnENcnCNCfCNCfCNCfCNCfCNCfCNCfCNCfC
NCfDNSjDNSjCNCfCNCfCNCfBN3bBN3bBN3bFO42FO42ENcnENcnDNSjCNCfCNCfCNCfDNSjDNSjDNSjD
NSjDNSjDNSjDNSjDNSjCNCfCNCfCNCfCNCfCNCfCNCfCNCfCNCfDNSjDNSjDNSjCNCfCNCfCNCfCNCfC
NCfAO3nAO3nCNcnCNcnDNSjDNSjFNSjENCfDND2DND2DND2DND2DND2DND2DND2DND2ENcnENcnDNSjC
NCfCNCfDNSjENcnENcnFNd:FNd:FNd:FNd:FNd:FNd:FNd:FNd:GO4>GO4>GO4>GO4>GO4>GO4>GO4>G
O4>IOd>HOT:GOD6GOD6GOD6GOD6HOT:IOd>HODBHODBHODBHODBHODBGO4>GO4>GO4>GO4>GO4>GO4>G
O4>GO4>GO4>GO4>GO4>HODBHODBGO4>GO4>GO4>GO4>HODBHODBFNd>GO4BGO4BHODFIOTJJOdNJOdNJ
OdNGO4>GO4>HODBHODBIOTFJOdH00:6>KJ2=K9n;K9n;K9n:KYn:Kj2;L:6<LJ6<L:6<L:6<L:6<L:6<
L:6<L:6<L:6<L:6<L:6<L:6<L:6<L:6<L:6<L:6<L:6<L:6<LJ6<LJ2;L:2;L:2;L9n:Kin:Kin:Kin:
KYn:KYn:KYn:KYn:KYn:KYn:KYn:KYj9KIj9KIj9KIj9KIn:KYn:KZ2;Kj2;Kib:KIb:KIb:KIb:KIb:
KIb:KIb:KIb:KIV7JYV7JYZ8JiZ8Ji^9K9^9K9^9K9^9K9b9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9
KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYV6JiV6JiZ7K9Z7K9^8KI^8KI^8KI^8KIZ7K9Z7K9Z7K9Z7K9Z7
K9Z7K9Z7K9Z7K9b7Jib7Jib7Jib7Jib7Jib7Jib7Jib7Ji^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9V5
IYZ6Ii^7J9^7J9^7J9Z6IiV5IYV5IYZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiV5IYV5IYV5IYV5IYV5
IYV5IYV5IYV5IYR4IIR4IIR4IIV5IYV5IYZ6IiZ6IiZ6IiV6HiV6HiV6HiV6HiV6HiV6HiV6HiV6HiV5
IYV5IYV5IYV5IYV5IYV5IYV5IYV5IYV4IIV4IIV4IIZ5IYZ5IY^6Ii^6Ii^6IiZ5IYZ5IYZ5IYZ5IYZ5
IYZ5IYZ5IYZ5IYR5I9R5I9R5I9R5HYR5HYR5HYR5HYR5HYZ6HiZ6HiZ6HiZ6HiZ6HiZ6HiZ6HiZ6Hib4
H9b4H9b4H9b4H9b4H9b4H9b4H9b4H9b5Gi^4GY^4GY^4GYb5Gif6H9f6H9f6H9b5Gib5Gib5Gib5Gib5
Gib5Gib5Gib5GiV3FYV3FYZ4FiZ4Fi^5G9^5G9b6GIb6GIZ4FiZ4FiZ4FiV3FYV3FYV3FYV3FYZ4FiR2
FIR2FIV3FYZ4FiZ4FiV3FYR2FIR2FIN1EiN1EiN1EiN1EiN1EiN1EiN1EiN1EiJ1E9J1E9J1E9J1E9J1
E9J1E9J1E9J1E9F0DiF0DiF0DiF0DiF0DiF0DiF0DiF0DiN0DYN0DYN0DYN0DYN0DYN0DYN0DYN0DYEo
CiEoCiJ0D9N1DIN1DIJ0D9EoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiEoCiAnCYAn
CY=mCI=mCI=mCI=mCI=mCI=mCI=mCIAnCYAnCYEoCiEoCiEoCiEoCiAnCY=mCI=mCI=mCIAnCYAnCY=m
CI=mCI=mCI=mCI=mCI=mCI=mCI=mCI=nBi=nBi=nBi=nBi=nBi=nBi=nBi=nBiAmCIAmCIAmCIAmCIAm
CIAmCIAmCIAmCI=lBY=lBY=lBY=lBYAmBiAmBiEnC9EnC99kBI9kBI9kBI=lBY=lBY=lBYAmBiAmBi9k
BI=lBY=lBY=lBYAmBiAmBiAmBiEnC9F0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIIoCIIoCIIoCIIoCIIo
CIIoCIIoCIIoCIAoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9F0
BIF0BIAoB9=nAi=nAi=nAi=nAi=nAi5lAI=nAiAoB9=nAi5lAI5lAI9mAYAoB9=nAi=nAi=nAi=nAi=n
Ai=nAi=nAi=nAi5lAI5lAI9mAY9mAY=nAi=nAi=nAi=nAi1l@i1l@i1l@i5lAI9lB99lB9=lBY=lBY9j
A99jA9=kAI=kAI=kAIAlAYAlAYAlAY=lA9=lA9=lA9=lA9=lA9=lA9=lA9=lA9EoAIEoAIAnA9AnA9=m
@i9l@Y9l@Y9l@YAmAIAmAIEnAYEnAYAmAI=lA95j@Y1i@I=n@I=m@i=m@iAmAIAmAIAlAY=kAI=kAi9k
@i9k@i9k@i9k@i9k@i9k@i9k@i9k@i9k@i5j@Y5j@Y1i@I1i@I5j@Y5j@Y9k@i1j@91j@91j@8mi?hmi
?hmi?hih?Xih?Y5k@I1j@8mi?hmi?hmi?hmi?i1j@95k@Hmh@8mh@8mh@8mh@8mh@8mh@8mh@8mh@91i
@I1i@I1i@I1i@I1i@I1i@I1i@I1i@Hmi?hmi?hmi?hmi?hmi?hmi?hmi?hmi?i=h?i=h?i=h?i=h?i=h
?i=h?i=h?i=h?i9g?Y9g?Y5f?I5f?I5f?I5f?I9g?Y9g?YAj?Y=i?I9h?95g>i1f>Y1f>Y5g>i5g>i9g
?Y9g?Y9g?Y9g?Y9g?Y5f?I5f?I5f?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=h?i=h?i=h?i=h?i=h
?i=h?i=h?i=h?hii?8ii?91h?91h?99h?99h?9Ah?9Ah?8mj?Hmj?I5i?I5i?I=i?I=i?IEi?IEi?I=i
?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I9h?9=i?I=i?IAj?YAj?YEk?iEk?iEk?i=i?I=i?I=i?IAj?YAj
?YAj?YEk?iEk?i=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?IIl
@9Ek?iEk?iAj?Y=i?I=i?I9h?99h?9Aj?YAj?YAj?YAj?YAj?YAj?YAj?YAj?Y=i?I=i?I=i?I=i?I=i
?I=i?I=i?I=i?IAj?YAj?YAj?Y=i?I9h?99h?95g>i5g>i1k?Y1k?Y9j?Y9j?YAj?YAj?YIj?YIj?YAi
@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@9Ek?iAj?Y=i?I=i?I=i?I=i?IAj?YEk?iEj@IEj@IEj@IEj@IEj
@IEj@IEj@IEj@IIk@YIk@YIk@YIk@YIk@YIk@YIk@YIk@YQn@YMm@IIl@9Il@9Il@9Mm@IQn@YUo@iUn
AIUnAIQmA9QmA9Ml@iIk@YIk@YIk@YIk@YIk@YIk@YIk@YIk@YIk@YIk@YIk@YUnAIQmA9Ik@YEj@IEj
@IIk@YQmA9UnAIIk@YIk@YMl@iMl@iQmA9QmA9UnAIUnAIIk@YIk@YMl@iQmA9UnAIYoAP00X8e/X8e/
Wh]/WXY[WXU]WhY_X8]`X8]`X8]_X8]_X8]_X8]_X8]_XHa`XHa`XHa`X8]_X8]_X8]_X8]_X8]_X8]_
X8]_X8]_X8]`X8]`X8]`WhY_WhY_WhY_WXU^WXU^WXU]WXU]WXU]WXU]WXU]WXU]WXU]WXU]WHQ/WHQ/
WXU]WXU]WXU]WhY^WhY^WhY^VhU/VhU/VhU/VhU/VhU/VhU/VhU/VhU/VHMZVHMZVHMZVXQ[VXQ[VXQ[
VhU/VhU/VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VHI[VHI[
VHI[VXM/VXM/VXM/VhQ]VhQ]VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/W8M[W8M[W8M[W8M[W8M[W8M[
W8M[W8M[VhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMXV8AUVHEVVXIWVhMXVhMXVXIWVXIWVHEVVXIWVXIW
VXIWVXIWVXIWVXIWVXIWVXIWVHEVVHEVVHEVVHEVVHEVVHEVVHEVVHEVUh=TV8AUV8AUV8AUVHEVVHEV
VHEVVXIWV8ERV8ERV8ERV8ERVHISVHISVHISVHISVHIUVHIUVHIUVHIUVHIUVHIUVHIUVHIUV8=TVHAU
VHAUVHAUVXEVVXEVVXEVVhIWVXEVVXEVVXEVVXEVVXEVVXEVVXEVVXEVUhAQUhAQUhAQUhAQUhAQV8ET
V8ETV8ETVXISVXISVXISVXISVXISVXISVXISVXISVh=OVh=OVh=OVh=OVh=OVh=OVh=OVh=OVH9LVX=M
VhANVhANVhANVhANW8EOW8EOVhANVhANVhANVhANVhANVhANVhANVhANVhELVhELVhELVXAKVXAKVH=J
VH=JVH=JV89IVH=JVH=JVH=JVH=JVH=JVH=JVH=JUh5GUh5GV89HVH=IVH=IV89HUh5GUh5GUh9EUh9E
Uh9EUh9EUh9EUh9EUh9EUh9EUX5DUX5DUX5DUX5DUX5DUX5DUX5DUX5DUX5DUX5DUX5DUX5DUX5DUX5D
UX5DUX5DUh1BUh1BUh1BUh1BUh1BUh1BUh1BUh1BU7i>UGm?UX1@UX1@UX1@UX1@UGm?U7i>U7i>U7i>
U7i>U7i>U7i>U7i>U7i>U7i>UX1@UX1@UX1@UGm?UGm?U7i>U7i>U7i>TWa<TWa<Tge=Tge=Tge=U7i>
U7i>U7i>U7i>Tge=TWa<TWa<TWa<Tge=U7i>U7i>TWa<TWa<TWa<TWa<TWa<TWa<TWa<TWa<TWe:TWe:
TWe:TWe:TWe:TWe:TWe:TWe:Tga<Tga<Tga<Tga<Tga<Tga<Tga<Tga<TW]9TW]9Tga:Tga:U7e;U7e;
U7e;U7e;Tga:Tga:Tga:U7e;U7e;U7e;UGi<UGi<TW]9TW]9TW]9Tga:Tga:U7e;U7e;U7e;U7m8U7m8
U7m8U7m8U7m8U7m8U7m8U7m8UGi<UGi<UGi<UGi<UGi<UGi<UGi<UGi<Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7
Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7U7m8U7m8U7m8U7m8Tgi7Tgi7TWe6TWe6TGa5TWe6
Tgi7Tgi7TGa5T7]4TWe6Tgi7TWe6TWe6TWe6TWe6TWe6TWe6TWe6TWe6TGa5TGa5TGa5TWe6TWe6TWe6
Tgi7Tgi7Sg]2Sg]2T7a3T7]4TG]7TWa8TW]9TW]9TWY4TWY4TWY4Tg]5Tg]5Tg]5U7a6U7a6Tga4Tga4
Tga4Tga4Tga4Tga4Tga4Tga4U7i4U7i4U7i4Tge3TWa2TWa2TG]1TG]1Tga4Tga4U7e5U7e5Tga4TW]3
TGY2TGY2Tgi1Tge3Tge3TW]3TW]3TWY4Tg]5Tg]7TW]3TW]3TW]3TW]3TW]3TW]3TW]3TW]3TGY2TGY2
T7U1T7U1T7U1T7U1TGY2TGY2TG]1TG]1TG]1T7Y0T7Y0T7Y0SgToSgToT7Y0T7Y0SgToSWPnSWPnSgTo
T7Y0T7Y0SWLoSWLoSWLoSWLoSWLoSWLoSWLoSWLoSgQ0SgQ0SgQ0SgQ0SgQ0SgQ0SgQ0SgQ0SWPnSWPn
SWPnSWPnSWPnSWPnSWPnSWPnTWLnTWLnTWLnTWLnTWLnTWLnTWLnTWLnTGHmTGHmTGHmTGHmTGHmTGHm
TGHmTGHmU7XnTgTmTWPlT7HjT7HjT7HjT7HjTGLkTGHmTGHmTGHmTGHmTGHmTGHmTGHmTGHmTWPlTWPl
TWPlTWPlTWPlTWPlTWPlTWPlTWLnTWLnTWLnTWLnTWLnTWLnTWLnTWLnSGPkSGPkSgLkSgLkTGLkTGLk
TgLkTgLkSWTlSWTlT7PlT7PlTWPlTWPlU7PlU7PlTWPlTWPlTWPlTWPlTWPlTWPlTWPlTWPlTWPlTWPl
TWPlTgTmU7XnU7XnUG/oUG/oTWPlTWPlTgTmTgTmU7XnU7XnU7XnU7XnU7XnU7XnU7XnU7XnU7XnU7Xn
U7XnU7XnU7XnU7XnU7XnU7XnU7XnU7XnU7XnUG/oUG/oU7XnU7XnU7XnTgTmTgTmTWPlTWPlTgTmTgTm
TgTmTgTmTgTmTgTmTgTmTgTmTWPlTWPlTWPlTWPlTWPlTWPlTWPlTWPlU7XnU7XnTgTmTgTmTWPlTGLk
TGLkTGLkSgXmSgXmTGTmTGTmTgTmU7XnUWXnUWXnTgPoTgPoTgPoTgPoTgPoTgPoTgPoTgPoU7XnU7Xn
TgTmTWPlTWPlTgTmU7XnU7XnU7U0U7U0U7U0U7U0U7U0U7U0U7U0U7U0UW]2UW]2UW]2UW]2UW]2UW]2
UW]2UW]2UWa0UWa0UWa0UG/oUWa0Uge1V7i2VGm3V7e4V7e4V7e4Uga3UW]2UW]2UGY1UGY1UW]2UW]2
UW]2UW]2UW]2UW]2UW]2UW]2VGi5V7e4UW]2UGY1UGY1UW]2V7e4VGi5UWa0UWa0UWa0UWa0Uge1Uge1
Uge1Uge1UGY1UW]2UW]2Uga3V7e4VGi5002PSFbOS6^NRV^NRV^NRFfNRFjORVnPRg2ORVjORVjORVjP
RfnPRfnPRfnQS72QS72PRfnPRfnPRfnPRfnPRfnPRfnPRfnPRfnPRg2PRg2ORVnORVnORVnNRFjNRFjN
RFjNRFfNRFfNRFfNRFfNRFfNRFfNRFfNRFfMR6bMR6bMR6bMR6bNRFfNRFfORVjORVjKRFbKRFbKRFbK
RFbKRFbKRFbKRFbKRFbHQVVIQfZIQfZIQfZJR6^JR6^JR6^JR6^KR6fKR6fKR6fKR6fKR6fKR6fKR6fK
R6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fHQFZIQV^IQV^IQV^JQfbJQfbJQfbJQfbIQV^IQV^IQV^I
QV^IQV^IQV^IQV^IQV^KQVZKQVZKQVZKQVZKQVZKQVZKQVZKQVZJQVNJQVNJQVNJQVNJQVNJQVNJQVNJ
QVNGPfBHQ6FIQFJJQVNJQVNJQVNJQVNIQFJIQFJIQFJIQFJIQFJIQFJIQFJIQFJIQFJHQ6FHQ6FHQ6FH
Q6FHQ6FHQ6FHQ6FHQ6FGPfBGPfBGPfBHQ6FHQ6FIQFJIQFJIQFJGQ66GQ66HQF:HQF:HQF:IQV>IQV>I
QV>HQFBHQFBHQFBHQFBHQFBHQFBHQFBHQFBHPfBHPfBHPfBIQ6FIQ6FJQFJJQFJJQFJIQ6FIQ6FIQ6FI
Q6FIQ6FIQ6FIQ6FIQ6FFQ5nFQ5nFQ5nGQ66GQ6>GQ6>HQ6FHQ6FHQ66HQ66HQ66HQ66HQ66HQ66HQ66H
Q66KPenKPenKPenKPenKPenKPenKPenKPenGP5ZIPUbKQ5jLQEnJPefJPefJPefKQ5jJPefJPefJPefJ
PefJPefJPefJPefJPefLQUfLQUfKQEbJQ5^IPeZHPUVHPUVGPERGPERGPERHPUVIPeZJQ5^JQ5^IPeZH
PUVFP5JFP5JGPENHPURHPURGPENFP5JFP5JFPU>FPU>FPU>FPU>FPU>FPU>FPU>FPU>EP5>EP5>EP5>E
P5>EP5>EP5>EP5>EP5>GPUFGPUFGPUFGPUFGPUFGPUFGPUFGPUFFOe6FOe6FOe6FOe6FOe6FOe6FOe6F
Oe6DOTjEOdnEOdnFP52FP52EOdnEOdnDOTjDOTjDOTjDOTjDOTjDOTjDOTjDOTjDOTjFP52FP52FP52E
OdnEOdnEOdnDOTjDOTjBO4bBO4bBO4bBO4bCODfCODfDOTjDOTjBO4bBO4bANd^ANd^ANd^BO4bCODfD
OTjANd^ANd^ANd^ANd^ANd^ANd^ANd^ANd^AO4VAO4VAO4VAO4VAO4VAO4VAO4VAO4VBNd^BNd^BNd^B
Nd^BNd^BNd^BNd^BNd^BNDNCNTRDNdVEO4ZEO4ZEO4ZDNdVDNdVCO4ZCO4ZCO4ZDOD^DOD^EOTbEOTbE
OTbBNdVBNdVBNdVBNdVCO4ZCO4ZCO4ZDOD^DOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOD^DOD^DOD^D
OD^DOD^DOD^DOD^DOD^BODJBODJBODJBODJBODJBODJBODJBODJCOTNCOTNCOTNCOTNCOTNCOTNCOTNC
OTNCOTNCOTNDOdRDOdRCOTNBODJAO4FAO4F@NdBBODJCOTNBODJAO4F@NdBAO4FCOTNAO4FAO4FAO4FA
O4FAO4FAO4FAO4FAO4F@NdBAO4FAO4FAO4FBODJBODJBODJBODJ@O4>@O4>@O4>@NdB@NTJANdNANTRA
NTRAND>AND>BNTBBNTBCNdFCNdFCNdFCNdFBNd>BNd>BNd>BNd>BNd>BNd>BNd>BNd>COD>COD>COD>B
O4:BO4:BO4:BO4:BO4:AND>BNTBCNdFCNdFCNdFCNdFBNTBBNTBDOd:DOTBBO4:ANT:ANT:AND>BNTBB
NTJANT:ANT:ANT:ANT:ANT:ANT:ANT:ANT:ANT:@ND6@ND6?N42?N42@ND6@ND6ANT:ANd6ANd6ANd6A
Nd6@NT2@NT2?NCn?NCn@NT2?NCn?NCn>N3j>N3j?NCn?NCn@NT2>Mcn>Mcn>Mcn>Mcn>Mcn>Mcn>Mcn>
Mcn?N42?N42?N42?N42?N42?N42?N42?N42=Mcf=Mcf=Mcf=Mcf=Mcf=Mcf=Mcf=McfAMSfAMSfAMSfA
MSfAMSfAMSfAMSfAMSf@MCb@MCbAMSfBMcjBMcjAMSf@MCb@MCbBN3bBN3bAMc^@MSZ@MSZ@MSZAMc^A
Mc^@MCb@MCb@MCb@MCbAMSfAMSfAMSfBMcjBN3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bBMcjBMcjBMcjB
McjBMcjBMcjBMcjBMcj=N3^=N3^?Mc^?Mc^AMc^AMc^CMc^CMc^=N3^=N3^?Mc^?Mc^AMc^AMc^CMc^C
Mc^BN3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bCNCfCNCfCNCfCNCfCNCfDNSjBN3bBN3bBN3bC
NCfCNCfDNSjDNSjDNSjDNSjDNSjDNSjDNSjDNSjDNSjDNSjDNSjCNCfDNSjDNSjDNSjENcnENcnENcnE
NcnCNCfCNCfCNCfCNCfCNCfCNCfCNCfCNCfCNCfCNCfCNCfCNCfCNCfCNCfCNCfCNCfBN3bBN3bBN3bB
N3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bAMc^AMc^AMc^>NCb>NCb@N3bANCfCNCfCNCfFNSjF
NSjCN3nCN3nCN3nCN3nCN3nCN3nCN3nCN3nDNSjCNCfCNCfBN3bBN3bCNCfCNCfDNSjCN3nCN3nCN3nC
N3nCN3nCN3nCN3nCN3nENT6ENT6ENT6ENT6ENT6ENT6ENT6ENT6ENcnENcnENcnENcnFO42GOD6HOT:I
Od>GO4>GO4>GO4>FNd:FNd:FNd:FNd:FNd:ENT6ENT6ENT6ENT6ENT6ENT6ENT6ENT6GO4>GO4>FNd:F
Nd:FNd:FNd:GO4>GO4>FO42FO42FO42FO42FO42FO42FO42FO42FNd:FNd:FNd:GO4>HODBHOD@009n<
Jin<Jij:Jif9JYf8K9j9KYn:Kin:Kij9KIj9KIn:KYn:KZ2;Kj2;Kj6<L:6<L:2;Kj2;Kj2;Kj2;Kj2;
Kj2;Kj2;Kj2;Kj2;L9n:Kin:Kin:Kij9KYj9KYj9KYf8KIf8K9f8K9f8K9f8K9f8K9f8K9f8K9f8K9b7
Jib7Jif8K9f8K9j9KIj9KIj9KIj9KIZ8JiZ8JiZ8JiZ8JiZ8JiZ8JiZ8JiZ8JiR6JIR6JIV7JYV7JYV7
JYZ8JiZ8JiZ8JiZ7K9Z7K9Z7K9Z7K9Z7K9Z7K9Z7K9Z7K9Z7K9Z7K9Z7K9Z7K9Z7K9Z7K9Z7K9Z7K9R5
JYR5JYV6JiV6JiV6JiZ7K9Z7K9Z7K9V6JiV6JiV6JiV6JiV6JiV6JiV6JiV6Ji^6JY^6JY^6JY^6JY^6
JY^6JY^6JY^6JYZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiJ2HiN3I9R4IIZ6IiZ6IiZ6IiZ6IiV5IYV5
IYV5IYV5IYV5IYV5IYV5IYV5IYV5IYR4IIR4IIR4IIR4IIR4IIR4IIR4IIR4IIN3I9N3I9N3I9R4IIR4
IIR4IIV5IYV5IYJ3H9N4HIN4HIN4HIR5HYV6HiV6HiV6HiR5HYR5HYR5HYR5HYR5HYR5HYR5HYR5HYR3
I9R3I9R3I9V4IIV4IIV4IIZ5IYZ5IYV4IIV4IIV4IIV4IIV4IIV4IIV4IIV4IIF4GIF4GIJ4GiJ3H9N4
HiN3I9R4IIR3IiN3H9N3H9N3H9N3H9N3H9N3H9N3H9N3H9Z2GYZ2GYZ2GYZ2GYZ2GYZ2GYZ2GYZ2GYEn
F9R1Fib5Gib5GiZ3GIR1FiV2G9^4GYV2G9V2G9V2G9V2G9V2G9V2G9V2G9V2G9Z4FiZ4FiZ4FiV3FYV3
FYV3FYV3FYV3FYEoEYJ0EiR2FIV3FYZ4FiZ4FiV3FYR2FIF0DiJ1E9J1E9N2EIN2EIJ1E9J1E9F0DiJ2
DiJ2DiJ2DiJ2DiJ2DiJ2DiJ2DiJ2DiF0DiF0DiF0DiF0DiF0DiF0DiF0DiF0DiF0DiF0DiF0DiF0DiF0
DiF0DiF0DiF0DiIoDIIoDIIoDIIoDIIoDIIoDIIoDIIoDIAnCYAnCYEoCiJ0D9J0D9EoCiAnCYAnCY=m
CI=mCI=mCI=mCI=mCI=mCI=mCI=mCIEoCiEoCiAnCYAnCYAnCY=mCI=mCI=mCI5kBi5kBi9lC99lC9=m
CI=mCI=mCI=mCI5kBi5kBi1jBY1jBY5kBi9lC9=mCIAnCY1jBY1jBY1jBY1jBY1jBY1jBY1jBY1jBY1k
B91kB91kB91kB91kB91kB91kB91kB95jBY5jBY5jBY5jBY5jBY5jBY5jBY5jBY1gAI5hAY=jB9AkBIAk
BIAkBI=jB99iAi5jB99kBI9kBI9kBI=lBY=lBY=lBYAmBi5jB95jB99kBI9kBI9kBI=lBY=lBY=lBY=n
Ai=nAi=nAi=nAi=nAi=nAi=nAi=nAi=lBY=lBY=lBY=lBY=lBY=lBY=lBY=lBY5lAI5lAI5lAI5lAI5l
AI5lAI5lAI5lAI9mAY9mAY9mAY9mAY9mAY9mAY9mAY9mAY9mAY9mAY=nAiAoB9AoB99mAY5lAI1kA91k
A95lAI=nAi9mAY1kA91kA95lAI9mAY1kA91kA91kA91kA91kA91kA91kA91kA91kA91kA95lAI5lAI5l
AI9mAY9mAY9mAY5mA95mA91l@i1kA91jAY1jAXmhAXmhAY5i@i5i@i5i@i9jA99jA9=kAI=kAI=kAI9k
@i9k@i9k@i9k@i9k@i9k@i9k@i9k@i5k@I5k@I9l@Y9l@Y9l@Y9l@Y=m@i=m@hmg@I1h@Y5i@i=kAI=k
AIAlAY=kAI=kAIF0@iAnA99l@Y5j@Y1i@I5i@i5i@i9jAY5j@Y5j@Y5j@Y5j@Y5j@Y5j@Y5j@Y5j@Y5j
@Y1i@Hmh@8mh@8mh@8mh@91i@I5j@Y1j@91j@8mi?hmi?hmi?hih?Xih?Xih?Y1j@8mi?hih?Xih?Xih
?Xih?Xmi?i1j@8ef?Xef?Xef?Xef?Xef?Xef?Xef?Xef?Xmh@8mh@8mh@8mh@8mh@8mh@8mh@8mh@8af
?8af?8af?8af?8af?8af?8af?8af?91e?91e?91e?91e?91e?91e?91e?91e?8md>i1e?95f?I9g?Y9g
?Y5f?I1e?8md>i5g>i1f>Y1f>Xme>Hme>I1f>Y5g>i9h?8md>hmd>i1e?91e?95f?I5f?I9g?Y9g?Y5g
>i5g>i5g>i5g>i5g>i5g>i5g>i5g>i5f?I5f?I5f?I5f?I5f?I5f?I5f?I5f?Hag>Xag>Xif>Xif>Y1f
>Y1f>Y9f>Y9f>Xag>Xag>Xif>Xif>Y1f>Y1f>Y9f>Y9f>Y5g>i5g>i5g>i5g>i5g>i5g>i5g>i5g>i=i
?I=i?I=i?I=i?I9h?99h?99h?99h?99h?99h?99h?99h?9=i?I=i?I=i?IAj?Y=i?I=i?I=i?I=i?I=i
?I=i?I=i?I=i?I5g>i9h?99h?9=i?I=i?IAj?YAj?YAj?Y5g>i5g>i5g>i9h?9=i?IAj?YAj?YEk?i=i
?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I5g>i5g>i5g>i5g>i5g>i5g>i5g>i5g>i5g>i5g>i5g>i5g>i9h
?99h?99h?99h?8eh>heh>i1h?91h?9=i?I=i?IIj?YIj?Y=h?i=h?i=h?i=h?i=h?i=h?i=h?i=h?iAj
?Y=i?I9h?99h?99h?99h?9=i?IAj?Y=h?i=h?i=h?i=h?i=h?i=h?i=h?i=h?iEj@IEj@IEj@IEj@IEj
@IEj@IEj@IEj@IAj?YAj?YAj?YAj?YEk?iMm@IQn@YUo@iEj@IEj@IIk@YIk@YIk@YIk@YMl@iMl@iEj
@IEj@IEj@IEj@IEj@IEj@IEj@IEj@IEj@IIk@YIk@YMl@iMl@iIk@YIk@YEj@IEl?YEl?YEl?YEl?YEl
?YEl?YEl?YEl?YMl@iMl@iMl@iMl@iMl@iMl@`00Wha[Wha[WXY[WHUZWHQ/WXU^WhY_WhY_WXU]WXU]
WXU]WhY^X8]_X8]_XHa`XHa`WhY^WhY^WhY^WhY^WhY^WhY^WhY^WhY^WhY_WhY_WhY_WXU^WXU^WXU^
WHQ]WHQ]WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/W8M[W8M[WHQ/WHQ/WHQ/WXU]WXU]WXU]VXQ[VXQ[
VXQ[VXQ[VXQ[VXQ[VXQ[VXQ[V8IYV8IYV8IYVHMZVHMZVHMZVXQ[VXQ[VXM/VXM/VXM/VXM/VXM/VXM/
VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/V8EZV8EZV8EZVHI[VHI[VHI[VXM/VXM/VHI[VHI[
VHI[VHI[VHI[VHI[VHI[VHI[VhIZVhIZVhIZVhIZVhIZVhIZVhIZVhIZVXIWVXIWVXIWVXIWVXIWVXIW
VXIWVXIWUX9SUh=TV8AUVHEVVXIWVXIWVXIWVHEVVHEVVHEVVHEVVHEVVHEVVHEVVHEVVHEVV8AUV8AU
V8AUV8AUV8AUV8AUV8AUV8AUUX9SUh=TUh=TUh=TV8AUV8AUV8AUVHEVUX=PUX=PUhAQUhAQV8ERV8ER
VHISVHISV8ERV8ERV8ERV8ERV8ERV8ERV8ERV8ERUh9SV8=TV8=TV8=TVHAUVHAUVHAUVXEVVHAUVHAU
VHAUVHAUVHAUVHAUVHAUVHAUUHEKUHAMUH=NUX=PUhASUh=TV8=WV8=WUX9OUX9OUX9OUX9OUX9OUX9O
UX9OUX9OVX9NVX9NVX9NVX9NVX9NVX9NVX9NVX9NU7eGV85KW8EOW8EOVX=MV85KVH9LVhANV85KV85K
V85KV85KV85KV85KV85KV85KUh5HUh5HV89IVH=JVXAKVXAKVhELVhELUGmFUX1GV89IVH=JVXAKVXAK
VH=JV89IUH1CUH1CUX5DUh9EUh9EUX5DUH1CUH1CUX9CUX9CUX9CUX9CUX9CUX9CUX9CUX9CUH1CUH1C
UH1CUH1CUH1CUH1CUH1CUH1CU7mBU7mBU7mBU7mBU7mBU7mBU7mBU7mBUWmAUWmAUWmAUWmAUWmAUWmA
UWmAUWmATge=U7i>UGm?UGm?UGm?UGm?U7i>Tge=Tge=Tge=Tge=Tge=Tge=Tge=Tge=Tge=Tge=Tge=
Tge=TWa<TWa<TWa<TG];TG];TG];TG];TWa<TWa<TWa<Tge=Tge=Tge=T7Y:T7Y:T7Y:T7Y:T7Y:TG];
Tge=U7i>T7Y:T7Y:T7Y:T7Y:T7Y:T7Y:T7Y:T7Y:T7]8T7]8T7]8T7]8T7]8T7]8T7]8T7]8TGY:TGY:
TGY:TGY:TGY:TGY:TGY:TGY:TGI4TWM5U7U7UGY8UW]9UGY8U7U7TgQ6T7U7T7U7T7U7TGY8TGY8TGY8
TW]9TW]9TGY8TGY8TGY8TW]9TW]9Tga:Tga:Tga:Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7TW]9TW]9
TW]9TW]9TW]9TW]9TW]9TW]9TGa5TGa5TGa5TGa5TGa5TGa5TGa5TGa5TWe6TWe6TWe6TWe6TWe6TWe6
TWe6TWe6TGa5TWe6Tgi7U7m8U7m8TWe6T7]4SgY3T7]4TGa5TWe6TWe6T7]4SgY3TGa5TWe6T7]4T7]4
T7]4T7]4T7]4T7]4T7]4T7]4T7]4T7]4T7]4TGa5TGa5TGa5TWe6TWe6TGe4TGe4TGe4T7]4SgU5SgU5
SWM5SWM5TGU3TGU3TGU3TWY4TWY4TWY4Tg]5Tg]5TW]3TW]3TW]3TW]3TW]3TW]3TW]3TW]3T7Y0T7Y0
TG]1TG]1TWa2Tge3Tge3Tge3SWI2SgM3T7Q4TWY6Tg]7U7a8U7a8U7a8UH13U7i4TWa2T7U1T7U1T7Q2
TGU3TWY6TGY2TGY2TGY2TGY2TGY2TGY2TGY2TGY2TGY2T7U1SgQ0SgQ0SgQ0SgQ0T7U1TGY2SWPnSWPn
SWPnSGLmSGLmSGLmS7HlS7HlSgToSgToSWPnSGLmSGLmSWPnSgToSgToSGHnSGHnSGHnSGHnSGHnSGHn
SGHnSGHnSWLoSWLoSWLoSWLoSWLoSWLoSWLoSWLoS7HlS7HlS7HlS7HlS7HlS7HlS7HlS7HlT7DlT7Dl
T7DlT7DlT7DlT7DlT7DlT7DlSW<jSg@kTGHmTWLnTWLnTGHmSg@kSW<jT7HjSgDiSgDiSgDiSgDiTGLk
TWPlTgTmSW<jSg@kSg@kT7DlT7DlTGHmTWLnTWLnTGLkTGLkTGLkTGLkTGLkTGLkTGLkTGLkTGHmTGHm
TGHmTGHmTGHmTGHmTGHmTGHmS7LjS7LjSWHjSWHjT7HjT7HjTWHjTWHjS7LjS7LjSWHjSWHjT7HjT7Hj
TWHjTWHjTGLkTGLkTGLkTGLkTGLkTGLkTGLkTGLkU7XnU7XnTgTmTgTmTWPlTGLkTGLkTGLkTGLkTWPl
TWPlTWPlTgTmTgTmTgTmTgTmTGLkTGLkTGLkTGLkTGLkTGLkTGLkTGLkT7HjT7HjT7HjTGLkTWPlTWPl
TgTmTgTmSgDiT7HjTGLkTWPlTgTmU7XnUG/oUWa0TWPlTWPlTWPlTWPlTWPlTWPlTWPlTWPlTGLkTGLk
TGLkTGLkTGLkTGLkTGLkTGLkT7HjT7HjT7HjTGLkTWPlTWPlTgTmTgTmSGPkSGPkSgLkT7PlTgTmTgTm
UWXnUWXnTWLnTWLnTWLnTWLnTWLnTWLnTWLnTWLnTgTmTgTmTWPlTGLkTGLkTWPlTgTmTgTmTWLnTWLn
TWLnTWLnTWLnTWLnTWLnTWLnUGY1UGY1UGY1UGY1UGY1UGY1UGY1UGY1U7XnU7XnU7XnU7XnUG/oUge1
VGm3VGm3U7U0U7U0UGY1UGY1UW]2Uga3Uga3Uga3UGY1UGY1UGY1UGY1UGY1UGY1UGY1UGY1U7U0UGY1
Uga3V7e4V7e4Uga3UGY1U7U0UG`nUG`nUG`nUG`nU7/mU7/mU7/mU7/mUga3Uga3Uga3Uga3Uga3Uga3
000400009`7oo`<000000140000<0000200000/0000@0000N`8002D100090000400007/2000U0@00
8@0000P0000:000040000000000000002@000100003]0P00F@400340000@10000@00000300400000
001E0000ZP000?l002@0000TE@009:X002Co00190000BED004VZ0019o`00K@0006eE001]ZP00KOl0
0980002BE@00TZX009;o002f0000]UD00;JZ002fo`00f`000=]E003KZP00fol00?l0003oE@00ojX0
0?oo02@0000T05D0902Z02@0o`0T900092AE02@TZP0T9?l094T002A9E@0TBJX094Wo02A]000TKED0
96fZ02A]o`0TTP00999E02BBZP0TT_l09;H002BfE@0T]ZX09;Ko02CK000TfeD09=^Z02CKo`0To`00
9?mE02CoZP0Tool0B@0004T0E@190:X0B@3o04TT001995D0BBBZ04TTo`19B@00BDUE04U9ZP19BOl0
BFd004U]E@19KJX0BFgo04VB0019TUD0BI:Z04VBo`19]P00BKIE04VfZP19]_l0BM/004WKE@19fjX0
BM_o04Wo0019oeD0BOnZ04Woo`1]0000K@1E06d0ZP1]0?l0KB@006dTE@1]9:X0KBCo06e9001]BED0
KDVZ06e9o`1]K@00KFeE06e]ZP1]KOl0KI8006fBE@1]TZX0KI;o06ff001]]UD0KKJZ06ffo`1]f`00
KM]E06gKZP1]fol0KOl006goE@1]ojX0KOoo0980002B05D0TP2Z0980o`2B9000TRAE098TZP2B9?l0
TTT00999E@2BBJX0TTWo099]002BKED0TVfZ099]o`2BTP00TY9E09:BZP2BT_l0T[H009:fE@2B]ZX0
T[Ko09;K002BfeD0T]^Z09;Ko`2Bo`00T_mE09;oZP2Bool0]P000;H0E@2f0:X0]P3o0;HT002f95D0
]RBZ0;HTo`2fB@00]TUE0;I9ZP2fBOl0]Vd00;I]E@2fKJX0]Vgo0;JB002fTUD0]Y:Z0;JBo`2f]P00
][IE0;JfZP2f]_l0]]/00;KKE@2ffjX0]]_o0;Ko002foeD0]_nZ0;Koo`3K0000f`1E0=/0ZP3K0?l0
fb@00=/TE@3K9:X0fbCo0=]9003KBED0fdVZ0=]9o`3KK@00ffeE0=]]ZP3KKOl0fi800=^BE@3KTZX0
fi;o0=^f003K]UD0fkJZ0=^fo`3Kf`00fm]E0=_KZP3Kfol0fol00=_oE@3KojX0fooo0?l0003o05D0
o`2Z0?l0o`3o9000obAE0?lTZP3o9?l0odT00?m9E@3oBJX0odWo0?m]003oKED0offZ0?m]o`3oTP00
oi9E0?nBZP3oT_l0okH00?nfE@3o]ZX0okKo0?oK003ofeD0om^Z0?oKo`3oo`00oomE0?ooZP3oool0
<00000`000010000=00000P0000E0000300000<0001A0000<>@;000000000000N`8002D100000000
0000000000000000kP8005X1001@0000:00007P0002hh`/000000200c03^0P00FP4002P0003^0P00
FP40004060000000^><;0<@>00343P0000000000003He=WEe=S@dmS;dMK;dMS@dM_EdMcHd]gDeMWD
eMWEeM_Fe]cFeMkEe=kDdmgDdmgDe]kDe]kDe]kDe]kDe]kDe]kDe]kDe]kIfn?4a/kBe=cJg>C;cMGN
h>SWjO71`l_4`lgFeMoPgnWHen7BdM_FeMoHen7Cd]cAe]oAe]oCeMoCeMoDeMoDeMoFeMoFeMoCe=kC
e=kDeMoEe^3Ee^3DeMoCe=kCe=kDeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoEe^3Ee^3E
e^3Fen7Fen7Ee^3DeMoCe=kCe=kCe=kCe=kDeMoEe^3De]kDe]kDe]kDe]kDe]kDe]kDe]kDe]kEe^3F
en7Fen7Ee^3Ce=kCe=kEe^3Gf>;De]kDe]kDe]kDe]kDe]kDe]kDe]kDe]kDem_Dem_Ef=gFfMkFf>3E
e^3DeMoDeMoCe]kCe]kDe]kDe]kFeMkHeMkHeMkHeMkGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoE
emoEemoEemoEemoEemoEemoEemoFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oDe]kDe]kDe]kDe]kDe]kDe]kDe]kDe]kFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkCe]_C
e]_Ce]_Ce]_Ce]_Ce]_Ce]_Ce]_CeMgCeMgCeMgCeMgCeMgCeMgCeMgCeMgBe]_Be]_Ce]_Ce]_EeM_G
eM_GeM_GeM_Fe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cEemSEemSEemSFf=WFf=WFf=WGfM[GfM[Ff=WF
f=WFf=WFf=WFf=WFf=WFf=WFf=WGfM[Ff=WEemSEemSEemSEemSFf=WGfM[CfMSCfMSDfMSDf=WFem_H
em_He]cHe]cFf=WFf=WFf=WGfM[GfM[GfM[Hf]_Hf]_IemgIemgIemgIemgIemgIemgIemgIemgFe=[F
e=[Fe=[Fe=[GeM_GeM_He]cHe]cBemKDe]KDe]KFeMOFeMWHe=WHe=[Jdm[EdmWEdmWDdmOCd]KCd]CD
e=CEeMGEeMGEdm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Dd];D
d];Dd];Dd];Dd];Dd];Dd];Dd];EeLoEeLoDdloCd/kCdM3Dd];Edm?Edm?CdM7CdM7Dd];Dd];Dd];E
dm?Edm?Edm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?E
dm?Edm?Edm?Edm?Edm?Edm?Edm?Bd];Cdm?De=CEeMGFe]KEeMGEeMGDe=CEdm;Edm;Edm;Edm;Edm;E
dm;Edm;Edm;Fe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CDd]7E
dm;Fe=?GeMCHe]GGeMCGeMCFe=?He]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KIemKGeMCFe=?GeMCHe]GI
emKHe]GFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=?F
e=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Dd]7Dd]7Edm;Edm;Edm;F
e=?Fe=?Fe=?Ce=;Ce=;Bdm7CdM3EdM3Fd]7Hdm;Hdm;Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Dd]7D
d]7Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7Ed<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gAd<cBdLgCd/kCd/kAd<c@
cl_BdLgCd/kBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oDclcDclcDclcEd<gEd<gEd<gFdLkFdLkAd<cA
d<cAd<cBdLgBdLgBdLgCd/kCd/kBdLgBdLgBdLgBdLgBdLgBdLgBdLgBdLg?c/[?c/[Ad<cBdLgBdLgB
dLgAd<cAd<cCd/kBdLgAd<cBdLgDdloEe=3DdloCd/kEe/gEe/gEe/gEe/gEe/gEe/gEe/gEe/gCe/gC
e/gCe/gEe/gGeLgGeLgHeLgHeLgFelkFelkGeLgFe<cGe<cHeLgKeLkKeLkIe/kIe/kIe/kIe/kIe/kI
e/kIe/kIe/kHeLgHeLgIe/kIe/kJeloJeloJeloJeloFelkFelkFelkFelkFelkFelkFelkFelkHeLgH
eLgHeLgHeLgHeLgHeLgHeLgHeLgGe<cGe<cHeLgHeLgHeLgIe/kIe/kIe/kGe<cGe<cHeLgHeLgHeLgI
e/kIe/kIe/kEe/gEe/gGeLgGeLgHeLgHeLgJe<gJe<gHeLgHeLgHeLgHeLgHeLgHeLgHeLgHeLgIelgI
elgIelgIelgIelgIelgIelgIelgGeL_He/cIelgIelgIelgIelgHe/cGeL_IelgIelgIelgIelgIelgI
elgIelgIelgEe/cEe/cEe/cEe/cEe/cEe/cEe/cEe/cEe/cEe/cGe/cGe/cHe/cHe/cJeLcJeLcHe/cH
e/cIelgIelgJf<kJf<kJf<kJf<kHe/cHe/cIelgIelgJf<kJf<kJf<kJf<kHfM3HfM3HfM3HfM3HfM3H
fM3HfM3HfM3He/cIelgJf<kJf<kJf<kJf<kIelgHe/cJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJf<kJ
f<kIelgHe/cHe/cIelgJf<kJf<kKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gEe/cEe/cHelgHelgJf<kJ
f<kLelkLelkJeLcJeLcKe/gKe/gLelkLelkLelkLelkKelcKelcKelcKelcKelcKelcKelcKelcKe/gK
e/gKe/gKe/gKe/gKe/gKe/gKe/gJe/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_GeL[GeL[GeL[GeL[GeL[G
eLX00=SDfMGDf=3Cf<_Ae/_Af=3AfmGAg=SBgMCEfMCEfMGEfmKFg=KEg]GDg]CCgMCCgMCFg]CFg]CF
g]CFg]CFg]CFg]CFg]CFg][Li=CFg^3Rj/[<e:b^]/73bi6CV`L94@002EUHHZNV/;Rg`KbkaM7@f]gL
i]GDg]7Fgm7Fgm?Egm?EgmCEgmCEgmKEgmKEgm?Dg]?Dg]CEgmGFh=GFh=CEgm?Dg]?Dg]CEgmCEgmCE
gmCEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmGFh=GFh=GFh=KGhMKGhMGFh=CEgm?Dg]?Dg]?Dg]?Dg]CE
gmGFh=CFg]CFg]CFg]CFg]CFg]CFg]CFg]CFg]GFh=KGhMKGhMGFh=?Dg]?Dg]GFh=OHh]CFg]CFg]CF
g]CFg]CFg]CFg]CFg]CFg]CGfmCGfmGHgMKIg]KHh=GFh=CEgmCEgm?Fg]?Fg]CFg]CFg]KEg]SEg]SE
g]SEg]OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmKEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmCFg]CFg]CFg]CFg]CFg]CFg]CF
g]CFg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]?Ffm?Ffm?Ffm?Ffm?Ffm?Ffm?Ffm?Ffm?EgM?EgM?E
gM?EgM?EgM?EgM?EgM?EgM;Ffm;Ffm?Ffm?FfmGEfmOEfmOEfmOEfmKFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=GGf=GGf=GGf=KHfMKHfMKHfMOIf]OIf]KHfMKHfMKHfMKHfMKHfMKHfMKHfMKHfMOIf]KHfMGG
f=GGf=GGf=GGf=KHfMOIf]?If=?If=CIf=CHfMKGfmSGfmSFg=SFg=KHfMKHfMKHfMOIf]OIf]OIf]SJ
fmSJfmWGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMKDf]KDf]KDf]KDf]OEfmOEfmSFg=SFg=;Ge]CFe]CF
e]KEemKEfMSDfMSDf][Cf]GCfMGCfMCCem?Be]?Be=CDe=GEeMGEeMGCdmGCdmGCdmGCdmGCdmGCdmGC
dmGCdmGCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]GEcmGEcmCC
cm?Bc]?Ad=CBd]GCdmGCdm?AdM?AdMCBd]CBd]CBd]GCdmGCdmGCdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?CdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdm;Bd]?CdmCD
e=GEeMKFe]GEeMGEeMCDe=GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]KDe=KDe=KDe=KDe=KDe=KDe=KD
e=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=CBdMGCd]KDdmOEe=SFeMOEe=OEe=KDdmSFe]SFe]SF
e]SFe]SFe]SFe]SFe]SFe]WGe]OEe=KDdmOEe=SFeMWGe]SFeMKDdmKDdmKDdmKDdmKDdmKDdmKDdmKD
dmKDdmKDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdm?Dd]?Dd]?D
d]?Dd]?Dd]?Dd]?Dd]?Dd]CBdMCBdMGCd]GCd]GCd]KDdmKDdmKDdm?Dd]?Dd];CdM?Ad=GAd=KBdMSC
d]SCd]GDd=GDd=GDd=GDd=GDd=GDd=GDd=GDd=CBdMCBdMCBdMCBdMCBdMCBdMCBdMCBdMG@cMG@cMG@
cMG@cMG@cMG@cMG@cMG@cM7@c=;AcM?Bc]?Bc]7@c=3?bm;AcM?Bc];@cm;@cm;@cm;@cm;@cm;@cm;@
cm;@cmC?c=C?c=C?c=G@cMG@cMG@cMKAc]KAc]7@c=7@c=7@c=;AcM;AcM;AcM?Bc]?Bc];AcM;AcM;A
cM;AcM;AcM;AcM;AcM;AcLo>b/o>b]7@c=;AcM;AcM;AcM7@c=7@c=?Bc];AcM7@c=;AcMCCcmGDd=CC
cm?Bc]GFcMGFcMGFcMGFcMGFcMGFcMGFcMGFcM?FcM?FcM?FcMGFcMOEcMOEcMSEcMSEcMKGc]KGc]OE
cMKDc=ODc=SEcM_Ec]_Ec]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]SEcMSEcMWFc]WFc][Gcm[Gcm[G
cm[GcmKGc]KGc]KGc]KGc]KGc]KGc]KGc]KGc]SEcMSEcMSEcMSEcMSEcMSEcMSEcMSEcMODc=ODc=SE
cMSEcMSEcMWFc]WFc]WFc]ODc=ODc=SEcMSEcMSEcMWFc]WFc]WFc]GFcMGFcMOEcMOEcMSEcMSEcM[D
cM[DcMSEcMSEcMSEcMSEcMSEcMSEcMSEcMSEcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMOEbmSFc=WG
cMWGcMWGcMWGcMSFc=OEbmWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMGFc=GFc=GFc=GFc=GFc=GFc=GF
c=GFc=GFc=GFc=OFc=OFc=SFc=SFc=[Ec=[Ec=SFc=SFc=WGcMWGcM[Hc][Hc][Hc][Hc]SFc=SFc=WG
cMWGcM[Hc][Hc][Hc][Hc]SId=SId=SId=SId=SId=SId=SId=SId=SFc=WGcM[Hc][Hc][Hc][Hc]WG
cMSFc=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Hc][Hc]WGcMSFc=SFc=WGcM[Hc][Hc]_FcM_FcM_F
cM_FcM_FcM_FcM_FcM_FcMGFc=GFc=SGcMSGcM[Hc][Hc]cGc]cGc][Ec=[Ec=_FcM_FcMcGc]cGc]cG
c]cGc]_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM[Fbm[Fbm[F
bm[Fbm[Fbm[Fbm[Fbm[FbmOEb]OEb]OEb]OEb]OEb]OEbP00e]CJe]CJe]CJe]CJe]CJe]CJe]CJe]CJ
f=OPf=OPc<_Dg]gVe=?LgmkWaLC=g=_TdM3Ih^7Zc/gFfMSQe=?LhN3Ybl[CalK?/K>dZjf^VIZNY:FY
Q8B:c/kDf=OPeMCMi>?/`/7:emKO^;O0NgZ3WijWZJRaZJRabLSAd<oHe=?LclkGi>?/dM3Idm;Ke]GN
eMSLg^7Ud]GJfMcQeMOOf=WSf]_Ud]?MdmCNdmCNdmCNe=GOe=GOe=GOeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
e=GOe=GOe=GOe=GOe=GOdmCNdmCNdmCNeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=KNe=KNe=KNeMOO
eMOOeMOOe]SPe]SPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOdmGMdmGMdmGMe=KNe=KNe=KNeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
e=KNe=KNe=KNe=KNe=KNe=KNe=KNe=KNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLdm?Idm?Idm?Idm?Idm?Idm?Idm?Idm?Icm?DdM?DdM?Ddm;D
dm;DeM;DeM;Dem;DeMCFeMCFe=?Edm;Ddm;Dd]7Cd]7CdM3Bdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dM7AdM7AdM7AdM7AdM7AdM7AdM7AdM7AdmC@dmC@dmC@dmC@dmC@dmC@dmC@dmC@dmC@dmC@dmC@dmC@
dmC@dmC@dmC@dmC@dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Ce=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ed]7Cd]7Cdm;Ddm;D
dm;De=?Ee=?Ee=?Ee=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KF
e=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KF
f=KFf=KFf=KFf=KFe=CDe=CDeMGEeMGEeMGEe=CDdm?Cdm?Ce=GAe=GAe=GAe=GAe=GAe=GAe=GAe=GA
e=GAe=GAe=GAe=GAe=GAe=GAe=GAe=GAe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=GAe=GAe=GAe=GA
e=GAe=GAe=GAe=GAdmG?dmG?dmG?dmG?dmG?dmG?dmG?dmG?e]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CC
eM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?Be=;Ae=;Ae=;Ae=;A
e=;Ae=;Ae=;Ae=;Ad]??d]??d]??d]??d]??d]??d]??d]??d]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?A
d]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?Ad]?AdM;>dM;>dM;>d]??
d]??dmC@dmC@dmC@d]??d]??d]??d]??d]??d]??d]??d]??dmK=dmK=dmK=dmK=dmK=dmK=dmK=dmK=
e]GAe]GAe]GAe]GAe]GAe]GAe]GAe]GAe]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]GAe]GAe]GAe]GA
e]GAe]GAe]GAe]GAe]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>
e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O>e]O>e]O>e]O>
e]O>e]O>e]O>e]O>e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=e]O=
e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>e]O>
e]O>e]O>e]O>e]O>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>
fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>c/_3i>7Id<g5j^OOeM;:dLk6hMkFf]O?h=gEblS0iN;JfMK>
h]oGcL[2f]O?e=79g=WAf=G=fmS@fMK>iN;JeM;:iN;Je=79iN?Ia/Bjf]S>gmgCe=;8g]cBhn7GemG;
d/o7hn3Hdm38hn3Hh=gEblS0h=gEfmS@dLk6hMkFf=G=g=WAi^?Kf=G=d/o7f=G=cL[2h=gEf]O?f=G=
emC<g=WAe=79hn3HeM;:gmcDg]_Cc<W1f]O?f]O?d<g5jNKNf]O?e=79f]O?iN;JdLk6emC<l^oWfMK>
e]?;g]_CiN;JdLk6g=WAd<g5h=gEMgA/f=G=h]oGdm38fMK>f=G=emC<emC<g=WAMG9ZbLJng=WAgmcD
d/o7i>7I003Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Ad=WDdmcXio32`L[NgNKBdM[Sh^_Og^O@cmSO
g^O8am3=c=FSXZ]NGFIdLgcRhN[=cm2j_;fj^km7B4c0`<I<C59VIFiLFfBZZK;Sh^_@cmQHEf1VIFkP
gnRe];gMg>G3`/]YJ761P8U>CEJi^<7Cd]_in?o1`<W?d]K0`lOMh>G=d=GDe]k>cmW;c=KMg^SCe=kC
e=kCe=kDeMoDeMoDeMoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3DeMoDeMoDeMoDeMoDeMoDeMoEe^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3De]kDe]kDe]kEemoEemoEemoFf>3Ff>3EemoEemoEemoEemoEemoE
emoEemoEemoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3EemoEemoEemoEemoEemoEemoEemoEemoCeMgCeMgCeMgDe]kDe]kD
e]kEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoDe]kDe]kDe]kDe]kDe]kDe]kDe]kDe]kFeMkF
eMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cDe=[D
e=[De=[De=[De=[De=[De=[De=[?dmCAdmCAdmCCd]CCd]CEd]CEd]CGd]CEe=KEe=KDdmGDdmGCd]CC
d]CBdM?BdM?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Ce=;C
e=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Ce=;Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?DdmGD
dmGDdmGDdmGDdmGDdmGDdmGDdmGBdM?BdM?Cd]CCd]CDdmGDdmGDdmGDdmGDe=CDe=CDe=CDe=CDe=CD
e=CDe=CDe=CFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CHe]KH
e]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KCdm?De=CEeMGEeMGFe]KE
eMGDe=CDe=CDeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?De=CD
e=CDe=CDe=CDe=CDe=CDe=CDe=CDeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?CeLoCeLoCeLoCeLoCeLoC
eLoCeLoCeLoFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;E
dm;Edm;Edm;Edm;Edm;Edm;Edm;Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7BdloBdloBdloBdloBdloB
dloBdloBdloBdm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7B
dm7Bdm7Bdm7Bdm7Bdm7Bdm7Bdm7Ad/kAd/kBdloBdloBdloCe=3Ce=3Ce=3BdloBdloBdloBdloBdloB
dloBdloBdloCe/gCe/gCe/gCe/gCe/gCe/gCe/gCe/gFeM7FeM7FeM7FeM7FeM7FeM7FeM7FeM7FelkF
elkFelkFelkFelkFelkFelkFelkFeM7FeM7FeM7FeM7FeM7FeM7FeM7FeM7FelkFelkFelkFelkFelkF
elkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelgF
elgFelgFelgFelgFelgFelgFelgFelkFelkFelkFelkFelkFelkFelkFelkFelgFelgFelgFelgFelgF
elgFelgFelgFelgFelgFelgFelgFelgFelgFelgFelgFelkFelkFelkFelkFelkFelkFelkFelkFelkF
elkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkFelkIe/kIe/kIe/kIe/kIe/kI
e/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kOg=CR
gmOAc/K;b<1fLf]nNg??c<CQg]KDdLWPgMG=b/;DdLUSH5QeLV[`kNGJelmbKfMgM6cNfm?Ed/Y?C4B2
OgM[J61aKVK>c<;^k>;?cL=nO79[JEoBd<KMfm5aKfEgM6ajMfmcL6S7a;cLfM5cL6QcL6S?c<CRgmOO
g=CHeLeYIUiZIeo@cLGak^KJeln9QWiRGeO@cLGZimmiMViVHe]_K6A^Jf=jMfoMf];<bL5aKVIkN73W
i=cGe<aWI5aeLVYfLf]iMVk9a[k[j>3Ge<c6`k_Fdl_Fdl_Ed/YZIemZIemoO7AoO7A`KFGEd/[Cd<SB
clOPgMEmNW9RGeMfLf]iMViZIeoIe/k]j^;@cLGJeloDdLWGe<`00=KDf]KDf]KDf]KDf]KDf]KDf]KD
f]KDf][Ih]KEg]?Bfm[Ih][Ih]CCg<c;e<c;e=_KhLS8cZRX[V5QIiJFW<;2b=GEflC4bWj0PA`N7d11
ALW:c/_;dC@d>]KEg[2_^>CSk<k=e]CCg1lN9jJU[P001WelQMgLiM;Bf<G5biZJX8b<TS<c>EYJH;6a
]nOWkM_Nh^GXk=?Fflg@eL_=eMKGhM[KiL[;eM?Dg]?Dg]?Dg]CEgmCEgmCEgmGFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CFg]CFg]CF
g]GGgmGGgmGGgmKHh=KHh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgm?EgM?EgM?EgMCFg]CFg]CFg]GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmCFg]CFg]CFg]CFg]CFg]CFg]CFg]CFg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=CDf]CDf]CDf]CDf]CDf]CDf]CDf]CDf]3DeM;DeM;D
eMCCeMCCeMKCeMKCeMSCeMGDe]CCeMCCeMCCeM?Be=?Be=?Be=?Be=CDe=CDe=CDe=CDe=CDe=CDe=CD
e=CDe=?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?CdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCE
dmCEdmCEdmCEdmCEdmCEdmCDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CD
e=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeM?Be=?Be=?B
e=?Be=CCeMCCeMGDe]GDe]GEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMKFe]KFe]KFe]KFe]KFe]KFe]KF
e]KFe]GEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMSFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SF
e]SFe]SFe]SFe]SFe]SFe];Bd]?CdmCDe=GEeMKFe]KFe]KFe]KFe]GFe=GFe=GFe=GFe=GFe=GFe=GF
e=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGFe=GFe=GF
e=GFe=GFe=GFe=GFe=GFe=CEdMCEdMCEdMCEdMCEdMCEdMCEdMCEdMKDdmKDdmKDdmKDdmKDdmKDdmKD
dmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmGCd]GCd]GC
d]GCd]GCd]GCd]GCd]GCd]?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?D
d]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd]?Dd];Ccm;Ccm;C
cm;Ccm?Dd=?Dd=?Dd=CEdM?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=?Dd=CFd=CFd=CFd=CFd=CFd=CFd=CF
d=CFd=OFd]OFd]OFd]OFd]OFd]OFd]OFd]OFd]OGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOFd]OFd]OF
d]OFd]OFd]OFd]OFd]OFd]OGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOG
dMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOGdMOHc]OHc]OHc]OHc]OHc]OHc]OHc]OHc]OGdMOGdMOG
dMOGdMOGdMOGdMOGdMOGdMOHc]OHc]OHc]OHc]OHc]OHc]OHc]OHc]OHc]OHc]OHc]OHc]OHc]OHc]OH
c]OHc]OHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOHcmOH
cmOHcmOHcmOHcmOHcmOHcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[G
cm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm7>a]GBb^CQfN?Pf6QUGFeZH]?@b=cIdMkKdn[Wgn7N
e^7NeWQeKG]hL<G2^^3MeG=`J5aIDM_Hd96>QW1]INOTg=ODc7EbJVaZH=WGcGYhKWEcJMWGcMOEbg5_
IG5_IMkKdmoLe6eZHX1mMM?@b7mlM6]XH>SUgMKCbmKCbnSUgH1mMGYgKmCAbLO4_6aYHFUVGVaYHNSU
gFQUGFISFmWFc__hl7MdK7AaJM_Hd7AaJGIcJn7Ne]3=aFUVGX9oMmgJd]gJdVeZHWIcJmODc>OTg<O4
_?SekN?Pf7ikLhB1NN7Ne]3=aGIcJeeJD^gZh^7Ne^k[hg9_IgMdK=cIdMgJdV=PF8>0N=;?anOTg<g:
`^3MeMoLe=WFcP00e]CJe]CJe]CJe]CJe]CJe]CJe]CJe]CJd<oHgMcUdm;Kh=oXbl[CemKOg]gVgmkW
VYZP8b<YW9bRe]KLb<S>0004lO7gf][PMgUjM7Igc<gAXZ>W_[k4FEUOdM3Ih^7Zd]7Jbl[Cd<oH:2L`
De9K0006VYVRcLcEi>CZ=3@j4a<IBTY@`l?9_;c24Q8HK6ab`/G9f=_Oa<O<i>O/e=KNemSRemSRdM;L
dmCNdmCNdmCNe=GOe=GOe=GOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe]OQe]OQe]OQ
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOdmGMdmGMdmGMe=KN
e=KNe=KNeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOe=KNe=KNe=KNe=KNe=KNe=KNe=KNe=KN
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KL
e=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJd=CEd]CEd]CEe=?Ee=?Ee]?Ee]?Ef=?Ee=?Ee=?Ee=?Ee=?E
e=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?E
e=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CD
e=CDe=CDe=CDe=CDe=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CD
e=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Edm;Ddm;De=?Ee=?Ee=?EeMCFeMCFeMCFeMGEeMGEeMGEeMGE
eMGEeMGEeMGEeMGEe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGE
f=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFd];Bdm?Ce=CDe]KF
emOGemOGemOGemOGeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGE
eMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEe=GAe=GAe=GAe=GA
e=GAe=GAe=GAe=GAe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CC
e]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BdmC@dmC@dmC@dmC@
dmC@dmC@dmC@dmC@dmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCB
dmCBdmCBdmCBdmCBdmCBdmCBdmCBdmCBd]??d]??d]??dmC@dmC@e=GAe=GAe=GAdmC@dmC@dmC@dmC@
dmC@dmC@dmC@dmC@e=K@e=K@e=K@e=K@e=K@e=K@e=K@e=K@emKBemKBemKBemKBemKBemKBemKBemKB
emOAemOAemOAemOAemOAemOAemOAemOAemKBemKBemKBemKBemKBemKBemKBemKBemOAemOAemOAemOA
emOAemOAemOAemOAemOAemOAemOAemOAemOAemOAemOAemOAemOAemOAemOAemOAemOAemOAemOAemOA
emS?emS?emS?emS?emS?emS?emS?emS?emOAemOAemOAemOAemOAemOAemOAemOAemS?emS?emS?emS?
emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?
emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?emS?f]O?f]O?f]O?f]O?
f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?f]O?
hn3Hf]O?f=G=f=G=L6eUOGYbg=WAhMkFb<FmiN;J^kR`b<FmSX^3HEiFh]oGfMK>L6eUPGifg=WAEeA<
NgQ``[nghn3HLFiVO7Uae=79IV=KOGYbclc4d/o7OW]cMG9Zhn3HaL:jNWM_RXMo`l2hfMK>i^?Kd<g5
j>GMiN;J_;VaLg1XPWmginCLf=G=S8V1LVmWM75YfmS@MgA/RXMoclc4f]O?IV=KJVMOg]_CMgA/N7E]
b<FmiN;JSHZ2H5eEf=G=gmcDiN;Jh]oGeM;:dm38inCLblS0IV=KM75YaL:jm_?[LVmWf]O?RHInH5eE
d/o7HUmGLFiViN;Jd/o7NWM_e]?;KfaTNGI^dLk6fmS@h=gEfmS@h]oG003Fe=[Fe=[Fe=[Fe=[Fe=[F
e=[Fe=[Fe=[3`/_Ge]oThnb_[[OXio3JfN:XYk0000I[K70000@000>7R8cbloNe][YnOh?Gf=cCeMH0
004D5AVFUi^`/;I7AdgViNk>cMK;b]?If>7Qh>Ti>44B4A[Ad=WQh>WLfnCCe=R9RXkFem]hNGfATYJm
_/;Ad]J:Rhl520`b=CWFfMjl_lCNh>S?d=[;c=KRhngCe=kCe=kCe=kDeMoDeMoDeMoEe^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ce=kDeMoDeMoEe^3Ee^3Fen7Fen7Fen7Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3De]kD
e]kDe]kEemoEemoEemoFf>3Ff>3EemoEemoEemoEemoEemoEemoEemoEemoEe^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3EemoE
emoEemoEemoEemoEemoEemoEemoCeMgCeMgCeMgDe]kDe]kDe]kEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoDe]kDe]kDe]kDe]kDe]kDe]kDe]kDe]kFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkF
eMkFeMkFeMkFeMkFeMkFeMkFeMkGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cEeM_EeM_EeM_EeM_EeM_EeM_EeM_EeM_AeMKC
eMKCeMKEe=KEe=KGe=KGe=KIe=KDdmGDdmGDdmGEe=KEe=KEe=KEe=KEe=KEe=SEe=SEe=SEe=SEe=SE
e=SEe=SEe=SEe=SEe=SEe=SEe=SEe=SEe=SEe=SEe=SEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGE
eMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEe=SEe=SEe=SEe=SEe=SE
e=SEe=SEe=SEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGD
dmGDdmGDdmGEe=KEe=KFeMOFeMOFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KH
e]KHe]KHe]KHe]KHe]KHe]KHe]KBd];Cdm?EeMGFe]KGemOHf=SHf=SGemOFe]KFe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]KEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CFe=?Fe=?Fe=?Fe=?Fe=?F
e=?Fe=?Fe=?GeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCFe=?F
e=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?DeM7DeM7DeM7DeM7DeM7DeM7DeM7DeM7DeM?DeM?DeM?DeM?DeM?D
eM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?BdloC
e=3Ce=3Ce=3DeM7DeM7DeM7Ee];DeM7DeM7DeM7DeM7DeM7DeM7DeM7DeM7Ee];Ee];Ee];Ee];Ee];E
e];Ee];Ee];Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?H
em?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?H
em?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hem?H
em?Hem?Hem?Hem?Hem?Hem?Hem?Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;Hf=;H
f=;Hf=;Hf=;HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3HfM3H
fM3HfM3HfM3HfM3HfM3HfM3HfM3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Ac/KMf];Fdl_HeLejMfmNFe=jMfmXIEeiMVi^
Jf?fln_`kNEOG5AbKfO>bl?Og=AcL6QeLVZo_;AaKVJ<RH7JeloPgMEnNg=VHUgdl>]eLFabKVWQgMSL
f==XI5m`K6OGe<c[j>1cL6QTHEWFdl_RgmOBclO^jn?BclO]j^;@cLEbKfMaKVKIe/ijMfmSH5Q]JV9m
NW;Og=C=b/9[J621OWJj]jnASXIfLf_Qg]IQGUIdLFWOg=C@cLEYIUj0OGEjMfmkN71JEdmVHe_/jN7S
h=SOg=CYi]j0OGEYIUkOg=CLfM7Jelo?c<AlNG5lNG7Yi]j;R81;B43`kNGEd/[@cLG]j^9YIUiVHe_K
f=3Uh][DdLW=b/;RgmL00=KDf]KDf]KDf]KDf]KDf]KDf]KDf]KDf^g/mKZi`/o>eo;an]SGh6IUKZ:Q
Z/k=eQ@E6LO8c:n`]3`m@LG6b/;3adA5BMCEfMKHf@P:2ibMXIZKWl;2b6EUJlK5c^;Qj^OVkm7@fLS7
d5UHHEmNIm;Af/2ob<S7d6EVJ[Zk_moPi;Jg^gMhO=[Kg`T:3SXk?kBg^iBGVahQ9/?6bloAfLo@f]OH
h][KiM?Dg]?Dg]?Dg]CEgmCEgmCEgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=;CgM;CgM;CgM?Dg]CEgmGFh=GF
h=KGhMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=GGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgm?EgM?EgM?E
gMCFg]CFg]CFg]GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmCFg]CFg]CFg]CFg]CFg]CFg]CF
g]CFg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]OGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SFg=SFg=SFg=SFg=SFg=SFg=SF
g=SFg=GEfmGEfmGEfmGEfmGEfmGEfmGEfmGEfm7Ee]?Ee]?Ee]GDe]GDe]ODe]ODe]WDe]CCeMCCeMGD
e]GDe]GDe]KEemKEemKEemGDf=GDf=GDf=GDf=GDf=GDf=GDf=GDf=CCemCCemCCemCCemCCemCCemCC
emCCemGDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GEeMGEeMGE
eMGEeMGEeMGEeMGEeMGEeMGDf=GDf=GDf=GDf=GDf=GDf=GDf=GDf=GEeMGEeMGEeMGEeMGEeMGEeMGE
eMGEeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMGDe]GDe]KEemKEemKEemKFe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KF
e]KFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]CDe=CDe=KF
e]OGemSHf=SHf=OGemOGemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKE
emKEemKFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KEemKEemKEemKEemKEemKEemKEemKEemGEeMGEeMGE
eMGEeMGEeMGEeMGEeMGEeMKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmOEe=OEe=OEe=OEe=OEe=OEe=OE
e=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=KDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmCEdMCEdMCE
dMCEdMCEdMCEdMCEdMCEdMCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCE
dmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdm?Dd=?Dd=?Dd=CEdMCEdMGFd]GFd]GFd]CEdMCEdMCE
dMCEdMCEdMCEdMCEdMCEdMGFd]GFd]GFd]GFd]GFd]GFd]GFd]GFd]SGdmSGdmSGdmSGdmSGdmSGdmSG
dmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSG
dmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSG
dmSGdmSHd]SHd]SHd]SHd]SHd]SHd]SHd]SHd]SGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmSHd]SHd]SH
d]SHd]SHd]SHd]SHd]SHd]SHd]SHd]SHd]SHd]SHd]SHd]SHd]SHd]SId=SId=SId=SId=SId=SId=SI
d=SId=SId=SId=SId=SId=SId=SId=SId=SId=SId=SId=SId=SId=SId=SId=SId=SId=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=WFc^?Pf=7>a/c9`H1mMHJ3Nm;?anOTg>3MeGIcJf1MEM;?afeZHX>0N=CAbN3MeG=`J6QUGOSe
kGYgKf9OElo<a=[GcfYWGgahLm??bVIRGFiZIMgIe<k:aFiZIHj:QLk;`mWFcWIcJh1mMNOTg>;Oelg:
`^CQfMgJd]GBb^OTg7QeKFm/I=ODc7IcJn?Pf7YgKfISFm3=aMgJd^?Pf7IcJhJ3Nf1MEG5^I]gJdWml
M7ejL^?Pf=oLe79_If]XH=cIdLc9`I2=QGEbJ]WFc]KCbmWFc]CAbFYWGh9oMm3=aN?Pf>;Oeo7^iUmL
E7AaJMWFcVi[Hh1mMLK3^nWVg]GBb^OTg7YgKg]hL=kKdm_Hd=;?amODc>;Oe`00e]CJe]CJe]CJe]CJ
e]CJe]CJe]CJe]CJclkGi>?/e]GNc<_DY:>/WijW`;o8SHbERH^<TI>D<38ca/S9_l72e=KGQHN8A4I7
H69SOh62TiBHc/oCc/kDfm_Qa/G>fMSQalK?hn;[dM3IdM3IalK?fm[Sh=oXi>?/S8j?cm7Be=KG92HW
UINHH69S];Jgb<[;Ngj2R8^?gN3UIVU^XZB/iNK`hN;/_;g7dmCNdmCNdmCNe=GOe=GOe=GOeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPd=7Kd=7KdM;Ld]?MdmCNe=GOe=GOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
e=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOdmGMdmGMdmGMe=KNe=KNe=KNeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOe=KNe=KNe=KNe=KNe=KNe=KNe=KNe=KNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
dMGFdmGFdmGFeMCFeMCFemCFemCFfMCFe=?Ee=?EeMCFeMCFe]GGe]GGemKHemKHeM?IeM?IeM?IeM?I
eM?IeM?IeM?IeM?Ie=;He=;He=;He=;He=;He=;He=;He=;HeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCF
eMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeM?IeM?IeM?IeM?I
eM?IeM?IeM?IeM?IeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEe=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?E
e=?EeMCFeMCFeMCFe]GGe]GGe]GGe]GGemOGemOGemOGemOGemOGemOGemOGemOGe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFemOGemOGemOGemOGemOGemOGemOGemOGf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KF
f=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFeMGEe]KFemOGemOGf=SHemOGe]KFe]KFemKHemKHemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemOGemOGemOGemOGemOGemOGemOGemOG
emKHemKHemKHemKHemKHemKHemKHemKHeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEe]CCe]CCe]CCe]CC
e]CCe]CCe]CCe]CCemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGD
e]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe=GAe=GAe=GAe=GAe=GAe=GAe=GAe=GAe=GCe=GCe=GCe=GC
e=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GC
dmC@dmC@e=GAe=GAe=GAeMKBeMKBeMKBe=GAe=GAe=GAe=GAe=GAe=GAe=GAe=GAeMKDeMKDeMKDeMKD
eMKDeMKDeMKDeMKDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOF
fMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOF
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSD
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSD
fMSDfMSDfMSDfMSDfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[A
fM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[Ag=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WA
g=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAfmS@g]_CiN;Ji>7ILg1XMG9ZcL[2dm38
eM;:KV]SKfaTiN;JNWM_IfALQH9jdm38M75YKV]SemC<LFiVMG9Zi^?Kj>GMJVMOLFaYd/g:Q7mlJ6=P
in;OjNCQKFQUH5]Hf]O?jNKNJfQPIV=K`l2hRhR0LFiVdLk6h=gEalBlg]_CMgA/I65IQH9jKFYRgmcD
KFYROGYbeM;:M75YfmS@dm38fmS@NGI^NgQ`bLJnLg1XH5eEh=gEg=WAJfQPMG9ZemC<gmcDL6eUI65I
g=WAnOK^dLk6h=gELFiVM75Yh=gEbLJnemC<emC<O7UaJFINf]O?KFYRMgA/j^OOf=G=fmS@`l2hLg1X
M75Yf=G=f=G=f=G=hn3Hi>7I003Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[@cmS=c=Fn_LJ=S9GKf^?U
i>gAd=T000KHf]]5AdPi>ccDe]L_<C;:c<de=cQ8BT^d][OOhN;Ce=S>cm?Bd]S;bm5/JgASHV]WIVmQ
H6W5a<gEe=gIf>7<bmCAd=W9b=4X:R]VJ6T];c0Y:ba3ADHZ;2e^L77CeMK:cM7Wj^k6bLk:cM:SYJfZ
ZkG=c]SPhN_Ce=kCe=kCe=kDeMoDeMoDeMoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3>cmW?d=[@dM_Ad]cBdmgC
e=kDeMoDeMoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3De]kDe]kDe]kEemoEemoEemoFf>3Ff>3EemoE
emoEemoEemoEemoEemoEemoEemoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3EemoEemoEemoEemoEemoEemoEemoEemoCeMgC
eMgCeMgDe]kDe]kDe]kEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoDe]kDe]kDe]kDe]kDe]kD
e]kDe]kDe]kFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHe]cHe]cHe]cHe]cHe]cH
e]cHe]cHe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cBe]ODe]ODe]OFeMOFeMOHeMOHeMOJeMODdmGD
dmGEe=KEe=KFeMOGe]SGe]SGe]SFe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[CdMOCdMOCdMOCdMOCdMOC
dMOCdMOCdMOFeMWFeMWFeMWFeMWFeMWFeMWFeMWFeMWFeMWFeMWFeMWFeMWFeMWFeMWFeMWFeMWFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]KFe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe]KFe]KFe]KFe]KFe]KF
e]KFe]KFe]KDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGEe=KEe=KEe=KEe=KFeMOFeMOFeMOGe]SGemOG
emOGemOGemOGemOGemOGemOGemOFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KGemOGemOGemOGemOGemOG
emOGemOGemOHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KFe]KG
emOGemOHf=SHf=SGemOFe]KEeMGGe][Ge][Ge][Ge][Ge][Ge][Ge][Ge][Ge][Ge][Ge][Ge][Ge][G
e][Ge][Ge][GemOGemOGemOGemOGemOGemOGemOGemOGe][Ge][Ge][Ge][Ge][Ge][Ge][Ge][Fe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]KFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?He]GHe]GHe]GHe]GHe]GH
e]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?DeM7D
eM7DeM7DeM7DeM7DeM7DeM7DeM7DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?D
eM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?DeM?Ce=3DeM7DeM7DeM7Ee];Ee];Ee];Fem?DeM7D
eM7DeM7DeM7DeM7DeM7DeM7DeM7FemGFemGFemGFemGFemGFemGFemGFemGIf=CIf=CIf=CIf=CIf=CI
f=CIf=CIf=CIemKIemKIemKIemKIemKIemKIemKIemKIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIemKI
emKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKI
emKIemKIemKIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIemKIemKIemKIemKIemKIemKIemKIemKIf=CI
f=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf]7If]7If]7If]7If]7I
f]7If]7If]7If]7If]7If]7If]7If]7If]7If]7If]7If]7If]7If]7If]7If]7If]7If]7If]7LfM7L
fM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7L
fM7LfM7LfM7Qg]K;b<3PgMGWi=aRGeMfLf_[j>3RgmOFdl]fLf]bKfOJelmhMFe^Jf??c<AlNG5aKVKI
e/kRgmOWi=a[J61fLf]WI5ajMfoNfMIaK6U_JVMdKfaaK6W<alCUh=ecKV]iMVi]JV9jMfoRgmOSh=QZ
IemhMFgSh=SDdLW/jN7JelmeLVYbKfMlNG7Ed/[Mf]9gM6aVHe_Uh][Og=A/JF5cL6Q`KFEaKVKIe/ih
MFeeLVYeLVYeLV[>bl?RgmMcL6QfLf]cL6QbKfOLfM7LfM7Og=C@cLGZimm`KFEmNW;>bl?]j^;Og=CI
e/iWI5anNg?Cd<QlNG5XIEgBclOWi=cCd<SZimmbKfMZIeoRgmOUh][DdLWGe<cPgMD00=?AemWGgL_9
cmkLh][Hg]3>e<W7cMGCfM7?eLW7cLS6c8F3RKRf_=OEfg5_MB4O9Kfn`Z6RYQPI7@X;3hR9SNCUjL[;
cmcMhLK7biVJWUUJGR//<2`]<EeNHZBUZMKGfmWHhJVX/EUHHBDT;Bl^=eeLIIVHXL_:dkk1aLS;cl33
ak:e^FEXK=gPi:V//3@g>l_;dLW9chB4RT51AmSHg]GEfk2`]]gMhmKHh<oAfLk@f=oPj/_;en[Zm/G5
dn?SlMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CEgmCEgmCE
gmCEgmCEgmCEgmCEgmCEgm7Bg=;CgM;CgM;CgM?Dg]?Dg]?Dg]CEgmGFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=CFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]KEg]KEg]KEg]KE
g]KEg]OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKFg=KFg=KFg=OGgMOGgMOGgMSHg]SHg]OGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMKFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]CCeMCCeMCC
eMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMCC
eMCCeMGDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GD
e]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GD
e]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OGemOGemOGemOGemOGemOGemOG
emOGemOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OGemOGemOG
emOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOEeMOEeMOE
eMOEeMOEeMOEeMOEeMOEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMCDe=GEeMGEeMGEeMKFe]KFe]KF
e]KFe]OGemOGemOGemOGemOGemOGemOGemOGemCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmCE
dmCEdmCEdmCEdmCEdmCEdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmCDe=CDe=CDe=CDe=CDe=CDe=CD
e=CDe=CEdmCEdmCEdmCEdmCEdmCEdmCEdmCEdmGFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GEeMGEeMGE
eMGEeMGEeMGEeMGEeMGEeMOHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]WGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe][Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemWGe]WGe]WG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe][Hem_If=_If=[HemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe]OEe=SFeMSFeMSFeMWGe]WGe]WGe][HemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WHe=WHe=WH
e=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=OFd]SGdmSGdmSGdmWHe=WHe=WH
e=[IeMWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=OFd]SGdmSGdmSGdmWHe=WHe=WHe=[IeM[IeM[IeM[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM_Je/k=bNGTh<W8a7IeLGmnN/_:
a^?Rg^3OfeQGDhf<R<g<b6e/J7QgLmkMfM7@c=_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je^7Pg<O6`Y6@
S65PG=;AcM[IeMcKemOFd][IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeMkIe][Ed]_FdfQSH7IaKWMbKmOB
cnKQgVYWGg=`J>GRf^SUgMgJd][Gcm_Hd=cIdN[Uh/[5`Xj9QV=NFmSCd>ORgn?Nfm_FdmkKdmkKdmkK
dmkKdmkKdmkKdmkKdmkKdmKAcX=nNfQSH=kIe]kIeVQSH8=nNmKAc]_FdmgHeGA_K6MRGnORgm_Fdg=^
JgIaK]cIdMcIdMcIdMgJd]gJd]gJdP00aL?9gM_QjnW_`/36gmgSf=KLj>K/gmgS_K_1h^3VblW?9R@Z
JFM]0004ViVOXj6WVibPhN;V`L;6]kRlg]oSinS/UiRL9bP/WIjRZjb``L;6dmCHg=gQgMkRf]_OemSL
c/gFfMSQfm[SgMcUg]gVa/G>Y:>/UYFN:2/_[K2de=OKi^W]LGAh>ci2[[6eem[NXJ6W0P882`/AFe]Q
aLG;dM7Gi>CZ_Kg3d=?HinWablgEdM;Lfm_WbLWEh^;`^k_9eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOd]?Md]?Md]?MdmCN
dmCNdmCNe=GOe=GOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SP
emKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNemKOemKOemKOemKOemKOemKOemKOemKO
e]KLe]KLe]KLemOMemOMemOMf=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOMf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMemOM
emOMemOMemOMemOMe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?E
e=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKH
emKHemKHemKHemKHemOGemOGemOGemOGemOGemOGemOGemOGemKHemKHemKHemKHemKHemKHemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOG
emOGemOGemOGemOGemKHemKHemKHemKHemKHemKHemKHemKHemOGemOGemOGemOGemOGemOGemOGemOG
emOGemOGemOGemOGemOGemOGemOGemOGf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFeMGEeMGEeMGEeMGEe]KFe]KFe]KFemOGemOGemOGemOGemOGemOGemOGemOGemOG
e=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GCe]CCe]CCe]CCe]CC
e]CCe]CCe]CCe]CCe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=GCe=GCe=GCe=GCe=GCe=GCe=GCe=GC
e]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFemSFemSFemSFemSF
emSFemSFemSFemSFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFemSFemSFemSFemSFemSFemSFemSFemSF
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf]SGfmWH
fmWHf]SGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf=KEf=KEf=KEfMOFfMOFfMOFf]SGf]SG
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSD
fMSDfMSDfMSDfMSDf=OCf=OCf=OCfMSDfMSDfMSDf]WEf]WEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSD
f=OCf=OCf=OCfMSDfMSDfMSDf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEg=_GdM3<h=oKa/G1NWUeHV5MLW5]J6MSJfYVM7=_c/g9g=_GMgIbMgIbd]7=jNST
fm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[FhN3Lf=OC][FaTY6=emKBf]WEf]WEfMSDf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEe]7>j^GRf]GBR8>0Thj;`[fjkNSUe<o<OW]cNGI^dm38e]?;eM;:g]_Chn3HiN;J
hMcIg=OD`kjkUY6>f]GBeM3=g]WFhMcIg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_CjNCQal:oOGQeNGAa
NGAaOGQeal:ojNCQd<_8mo;_al:oQX5nO7MdJVEROGQed/g:g=WAg=WAg=WAgM[BgM[BgM[B003/j_3:
b<k?cM?Dd]SGeM_4`/S<b]2VY:[Dd]Re/kW^k?9^K79GEE_AcmFUXjT000A=CE?YjNoAdMOVi^bNWZA4
A4[Jf^3CdmWAdMOGemgOgnGShnWPh>KJf^3De=[AdMOJfN;LfnCCd]_@cmSKf^?Kf^?FeMkKf^?Tinbd
]ka5B4fg^[oen?fa];VXZk1VJFiHF5je]K/U9B_Fe]b_[kD000GJf^39bLnc][_9c=7De]k2a<cSi>kL
g>Rl_<SalOgEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3DeMoD
eMoDeMoDeMoDeMoDeMoDeMoDeMoBdmgBdmgBdmgCe=kCe=kDeMoDeMoDeMoEe^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3De]kDe]kDe]kEemoEemoEemoFf>3Ff>3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkFeMkFeMkF
eMkFeMkFeMkGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFe]cFe]cFe]cGemgGemgGemgHf=kHf=kGemgG
emgGemgGemgGemgGemgGemgGemgHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgGemgGemgGemgGemgGemgFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOEe=KE
e=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KE
e=KEe=KEe=KFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGemOGemOGemOGemOGemOG
emOGemOGemOGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGemOG
emOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOHe]KH
e]KHe]KHe]KHe]KHe]KHe]KHe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KEeMGEeMGEeMGFe]KFe]KG
emOGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CE
e]CEe]CEe]CEe]CEe]CEe]CEe]CGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCEeMGEeMGEeMGEeMGEeMGE
eMGEeMGEeMGEe]CEe]CEe]CEe]CEe]CEe]CEe]CEe]CFemGFemGFemGFemGFemGFemGFemGFemGFe]KF
e]KFe]KFe]KFe]KFe]KFe]KFe]KGf=KGf=KGf=KGf=KGf=KGf=KGf=KGf=KIemKIemKIemKIemKIemKI
emKIemKIemKGf=KGf=KGf=KGf=KGf=KGf=KGf=KGf=KJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIemKI
emKIemKIemKIemKIemKIemKIemKIemKIemKJf=OKfMSKfMSJf=OIemKIemKIemKIemKIemKIemKIemKI
emKIemKIemKHe]GHe]GHe]GIemKIemKJf=OJf=OJf=OIemKIemKIemKIemKIemKIemKIemKIemKIf=CI
f=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CHem?Hem?Hem?If=CIf=CJ
fMGJfMGJfMGIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CHem?Hem?Hem?If=CIf=CJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGIf=CEe=3Pgm_ThmoGe];G
e];Mg=SFeM7Kf]KKf]KKf]KFeM7If=CWi^;Sh]k;b/KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KT
hmoIf=C9b<CGe];Kf]KJfMGMg=SJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGNfMKTgmc=b<G=b<G6`KkZ
iN;TgmcLemCMf];5`[[`kNGSh=SKf=3RgmOMf];HeLgKe]?Tgmc[i^?8`l3Qg=W@blSNfMKNfMKNfm?N
fm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Dclc[i^?Ie=7NfMKNfMKIe=7[i^?DclcPfmSSg]_NfMKFdLkDclcG
d/oOf]O/inCLfM7LfM7LfM7Mf];Mf];Mf]800=_Igl[8c^;Pi/c:d>7OiM[Hg[Fc^J:PY/K4bYjLX/k<
d]KDfTE3BEeKHNOUjmgKhI>CVL_;dKJf_7inQ=KFg>OWkLK6c<k>e=cLh]SHg]7Ael_;dLS8c/c<d]CD
f][Jh<k=e]GDgM;Af]?BfmcKi=SGh<k=e]3?f<c?e=SKh=KIg]?FffmbMkFh_N3Sj<;5b]oOiI6AUaHF
74Y:D3Xj@0001=OGgMCDfXZ=TL_>dm;Ef][Li<[<e=SIhm3@g=;Bg]GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgm;CgM?Dg]?D
g]?Dg]CEgmCEgmCEgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CFg]CFg]CFg]GGgmGGgmGGgmKH
h=KHh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]OFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmKFg=KFg=KFg=OGgMOGgMOGgMSHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMKFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KEemKEemKEemKEemKEemKEemKE
emKEemKEemKEemKEemKEemKEemKEemKEemKEemGDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GD
e]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]KEemKEemKEemKEemKEemKEemKE
emKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKE
emKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKE
emKEemSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFe]KFe]GEeMGEeMKFe]KFe]OGemOGemOGemOGemOGemOGemOGemOGemOGemOGemOG
emOGemGFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=GFe=OEe=OEe=OE
e=OEe=OEe=OEe=OEe=OEe=GEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGFe=GFe=GFe=GFe=GFe=GFe=GF
e=GFe=KGeMKGeMKGeMKGeMKGeMKGeMKGeMKGeMKFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]SIemSIemSI
emSIemSIemSIemSIemSIem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemSIemSIemSIemSIemSIemSIemSI
emSIem_If=_If=_If=_If=_If=_If=_If=_If=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemWGe]WGe][H
em_If=_If=[HemWGe]WGe][Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemSFeMWGe]WGe]WGe][Hem[Hem[H
em_If=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeM[IeM[IeMSGdmWHe=WHe=WHe=[IeM[IeM[IeM_Je][IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeMSGdmWHe=WHe=WHe=[IeM[IeM[IeM_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM[I
eM[IeM[IeM[IeM[IeM[IeN7Pg=gLf=CCcm7@c=SGdm[IeMSGdmWHe=OFd^;QgMcKemCCcmCCclW8a<g<
b>[YiM_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]CCcn3OfmoNf^GTh=3?bmkMfM_Je]kMfM_Je]_Je]_J
e]_Je]_Je]_Je]_Je]_Je]gHeN3Kf=G@cO?^jmcGe>KQg]C?c>GPgNcYhMCAbNKSfmgJd]SEcN?Pf=kK
dmcIdMgHeM[Ed^[Uh][Ed^ORgmcGe>GPgMG@cMkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmoJemoJelo:
amkIe]kIe/o:amoJemoJemcGe<o:am3;b=[Ed^?NfnWThN?Nfm7<bMcIdMcIdMcIdMgJd]gJd]gJdP00
d]3FbLO=k^cbemGKd<kD/JneIF=Ydm7Ge]CJ;bdcYjF[HEmUb<K<[J^aRXR>e]CJgmkWOWf6e]GNg=_T
`l;;d]7Jg=_TgMcUd<oHe=?LfMSQfm[Sfm[Sf]WRfMSQf]WRinK_iNC]e]GNc<_Dd]7Je=?LeMCMgmkW
c<kFhN?[aLO?alWAemWQalWAM7Inh>;Zbl_A1`L=EUILZ:R^:2P^/[:hf=SNY:BZal[>HVEY^;^obLcA
i>K^d]CLeMKPcLkHeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
e=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOdmCNdmCNdmCNe=GOe=GOeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPemKOemKOemKOemKOemKOemKOemKOemKO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNemKOemKOemKOemKOemKOemKOemKOemKOe]KLe]KLe]KLemOMemOMemOMf=SNf=SN
emOMemOMemOMemOMemOMemOMemOMemOMf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOMe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKH
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGemOGemOGemOGemOGemOGemOGemOGemOGe]KFe]KFe]KFemOG
emOGemOGf=SHf=SHemOGemOGemOGemOGemOGemOGemOGemOGe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OE
e]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEe]KFe]KFe]KFe]KF
e]KFe]KFe]KFe]KFe]OEe]OEe]OEe]OEe]OEe]OEe]OEe]OEemSFemSFemSFemSFemSFemSFemSFemSF
emOGemOGemOGemOGemOGemOGemOGemOGf=WGf=WGf=WGf=WGf=WGf=WGf=WGf=WGf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf=WGf=WGf=WGf=WGf=WGf=WGf=WGf=WGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMOFfMOFf]SGfmWHfmWHf]SGfMOFfMOFf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGfMOFfMOFfMOFf]SGf]SGfmWHfmWHfmWHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEfMSDfMSDfMSDf]WE
f]WEfm[Ffm[Ffm[Ff]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEfMSDfMSDfMSDf]WEf]WEfm[Ffm[Ffm[F
fm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ff]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEcLc8fMSDfMSDf]WE
iNCPhN3LfMSDh=oKiNCPd<o;c/g9hn;NkNcXi>?Og]gIh=oKfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[F
f=OCf]WEe=??iNCPbLS4h=oKg=_Gf]WEfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Fd/g:j>?Pin;Oh=_H
dlk;iN3MhMcIfMCAfMK>dLk6fMK>f]O?e]?;hn3HgmcDh]oGh=_He<o<gm[Gg=ODh]gJhMcIjNCQe]7>
g]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cem;?i^7Ni=oLiN3MiN3Mi=oLi^7Nem;?g=ODk>OTk>OTh]gJ
gMSEe]7>fMCAjnKSg=WAg=WAg=WAgM[BgM[BgM[B003Mfn7ShNO4`/SFe=Zc/KLT8RSKfMnDTYQFE5[J
f=hQ7bDo?D?Th^SHe]c:b<kRh>IQH6[BdM_NgNOCd]cJfN??c]S_k_SEe=kLfnGLfnGIf>;Ddmg@cmW>
cMO?c]SAd=[2`L[>cMKBdM[Ge]oQh>WKf^?Ad=WCd]_Ad]cIf^C`lO_JfnGJfnG=c]R_/;YZJgFi^Ko6
a/cRh^RGUieSHfWKfn5:BU1lO8;YkNk1aLHT9b^[[[;JgN;Ifn?GfN7Ui_3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3DeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoCe=kD
eMoDeMoDeMoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3De]kDe]kDe]kEemoEemoE
emoFf>3Ff>3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oFe]cFe]cFe]cGemgGemgGemgHf=kHf=kGemgGemgGemgGemgGemgGemgGemgGemgHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgG
emgGemgGemgGemgGemgGemgGemgFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHemWHemWHemWHemWHemWHemWHemWHemWHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SIemOIemOIemOIemOIemOIemOIemOIemOGemOG
emOGemOGemOGemOGemOGemOGemOFe]KFe]KGemOGemOHf=SHf=SHf=SHf=SGemOGemOGemOGemOGemOG
emOGemOGemOFemGFemGFemGFemGFemGFemGFemGFemGFemGFemGFemGFemGFemGFemGFemGFemGHe]GH
e]GHe]GHe]GHe]GHe]GHe]GHe]GFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KFemGFemGFemGFemGFemGF
emGFemGFemGGf=KGf=KGf=KGf=KGf=KGf=KGf=KGf=KGemOGemOGemOGemOGemOGemOGemOGemOHfMOH
fMOHfMOHfMOHfMOHfMOHfMOHfMOJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OHfMOHfMOHfMOHfMOHfMOH
fMOHfMOHfMOLf]WLf]WLf]WLf]WLf]WLf]WLf]WLf]WJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIemKI
emKJf=OKfMSKfMSJf=OIemKIemKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIemKJf=OJf=OJf=OKfMSK
fMSKfMSKfMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGIf=CJfMGJfMGJfMGKf]KKf]KKf]KKf]KJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGIf=CJfMGJfMGJfMGKf]KKf]KKf]KKf]KLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGIf=CThmoSh]kMg=SJfMGAd<c<blODdloJfMGCd/kRhMgThmo<blO>
cLWKf]K>cLWKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KQh=cLfmO@cl_Og][<blOPgm_If=CHem?LfmOL
fmOLfmOLfmOLfmOLfmOLfmOLfmOQg=WLemCIe=7FdLkNfMKQg=WSg]_NfMKSh=SXiMgSh=SYi]kMf];R
gmOIe/kMf];Of]OKe]?Sg]_PfmSJeM;JeM;TgmcQg=WNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Of]ON
fMKHdm3BcL[BcL[Hdm3NfMKOf]O>bLKKe]?DclcEd<gYi>7TgmcDclcKe]?LfM7LfM7LfM7Mf];Mf];M
f]800=GCfMGCfMSFg=SFg0L52m3>e>?Qijj//Q4?5FYXKZFSZCDc>Jn]/m;@e/k<dP@22=CCgMWHh][I
hlg<e]WHh^7Pj[^ja=oNj<[9dm3?fMSGhMcKiMgLi]_Ji=[IhmWHh]_Jhn3Oj=SGh=;Af]KEg];Af/k=
e]GDgM[KiLK7dLG6d<K7dM[KiM;CgNc]mlK7dAHF7<O7cLK6c3`l@ZFUZc`l@Y6AUl[:d=GIf[o3a:fa
/PhA5L[=d]CGg=kPj<C6c]GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=CEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmGFh=GFh=GFh=KGhMKGhMGFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=CFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=OFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKFg=KFg=KFg=OGgMOGgMOGgMSH
g]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMKFg=KFg=KF
g=KFg=KFg=KFg=KFg=KFg=SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=OGemOGemOG
emOGemSHf=SHf=WIfMWIfMOGemOGemOGemOGemOGemOGemOGemOGemOHe]OHe]OHe]OHe]OHe]OHe]OH
e]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]OGemOGemOG
emOGemOGemOGemOGemOGemOHe]OHe]OHe]OHe]OHe]OHe]OHe]OHe]SIemSIemSIemSIemSIemSIemSI
emSIemSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=WJf=WJf=WJf=WJf=WJf=WJf=WJf=WJf=_If=_If=_I
f=_If=_If=_If=_If=_If=WJf=WJf=WJf=WJf=WJf=WJf=WJf=WJf=cJfMcJfMcJfMcJfMcJfMcJfMcJ
fMcJfM_If=_If=_If=_If=_If=_If=_If=_If=WGe]WGe][Hem_If=_If=[HemWGe]WGe]_If=_If=_I
f=_If=_If=_If=_If=_If=[Hem[Hem[Hem_If=_If=_If=cJfMcJfM_If=_If=_If=_If=_If=_If=_I
f=_If=_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM[I
eM_Je]_Je]_Je]cKemcKem_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM[IeM_Je]_Je]_Je]cK
emcKemcKemcKemcKemcKemcKemcKemcKemcKem[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeMOFd]KEdMKE
dMGDd=GDd=_Je^GTh>_Zi]kMfMKEdMgLf=_Je]7@c>;QgO7`k>;QgM_Je]_Je]_Je]_Je]_Je]_Je]_J
e]_Je]gLf=kMfMOFd]gLf=OFd]gLf=SGdmcKemcKemcKemcKemcKemcKemcKemcKemcKen[Uh]KAc/o:
anCOg>GPgMcGe=WDdNWThLo<a=kKdm7>a^3MeMWFc^;Oem_Hd>CQfMgHeN7LfN?Nfn;Mf]_FdmWDdMgH
eNGPgMkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdn;Mf]KAc^3Kf>gXiNgXiN3Kf=KAc^;Mf^oZin_Vhn?N
fm_FdmKAc]SCd=oJenGPgMcIdMcIdMcIdMgJd]gJd]gJdP00fmWObLO=gM_QVINMEUAJNgUo/[2fg=[P
928Xd]3F0004aL?9f]SNf=KL0004hn7We]GOgMcVcLcFiNC^fm[Tg=_UdM3Jg=_Uf=OQfMSRf=OQe]GO
e=?Me=?MemKPfMSRd]7Jf]WRemKOeMCMg=_TfMSQeMCMgMcUdmCNfM[TfM[Tg=gWc/oIfmcVb<WCf=WS
c/kD0005g]kTfm_QCTiDM7AjcloEemOMOhB3=CTjal_<HFAXUIRLc]7FemWQf]cTeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GO
e=GOe=GOe=GOeMKPeMKPe]OQe]OQe]OQeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=KNe=KNe=KNeMOO
eMOOeMOOe]SPe]SPemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNemKOemKOemKOemKO
emKOemKOemKOemKOe]KLe]KLe]KLemOMemOMemOMf=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOM
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
emOMemOMemOMemOMemOMemOMemOMemOMe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIemKHemKHemKHemKHemKHemKHemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHemOGemOGemOGf=SHf=SHf=SHfMWIfMWIemOGemOGemOGemOG
emOGemOGemOGemOGemSFemSFemSFemSFemSFemSFemSFemSFemSFemSFemSFemSFemSFemSFemSFemSF
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFemOGemOGemOGemOGemOGemOGemOGemOGemSFemSFemSFemSF
emSFemSFemSFemSFf=WGf=WGf=WGf=WGf=WGf=WGf=WGf=WGf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
fM[HfM[HfM[HfM[HfM[HfM[HfM[HfM[HfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfM[HfM[HfM[HfM[H
fM[HfM[HfM[HfM[Hg=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[IfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fMOFfMOFf]SGfmWHfmWHf]SGfMOFfMOFfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]SGf]SGf]SGfmWH
fmWHg=[Ig=[Ig=[IfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[F
fm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ff]WEf]WEf]WEfm[Ffm[Fg=_Gg=_Gg=_Gfm[Ffm[Ffm[Ffm[F
fm[Ffm[Ffm[Ffm[Ff]WEf]WEf]WEfm[Ffm[Fg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_G
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEh=oKf=OCf]WEg]gIf]WEg=_Gg=_Gd]7=gmkJemKBfMSDhN3L
h=oKfMSDe]GAe]GAfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Fd]7=g=_GgMcHg]gIh=oKf]WEf=OCi>?O
g=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gdlk;k>OTin;Oin;Ocl[7i^7Ngm[Ggm[GgM[Bk>WQe=79hn3H
f]O?hn3HfmS@hn3Hg=ODhMcIf]GBgm[GhmkKhmkKf]GBhMcIg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
h=_Hgm[Gh]gJe]7>e]7>h]gJgm[Gh=_HgMSEc/W6gm[Gj^GRfMCAh=_Hj^GRem;?g=WAg=WAg=WAgM[B
gM[BgM[B003>cLoDdmGKf]`E51Jm_;jSXZ@i>3Z?SY0d=CW3a<SDe=[2`/SThnaNGFOHen7DdmgEd^7I
f>9WJ6a>D53De]KHfMgAd=[LfNSDdmgDdmgEe=kFeMoIf>;JfN?If>;Ge^3FeMoFeMoFeMoGe^3Ge^3G
e^3Hen7Hen7?c=_EdmoEe=kNgNKKfn7BdmO1`lAOHF;BdM_LfnEQH6[JfN;Kfn4<31:6Qh/E5QZWYZo?
c]OGe]oBdMX:2A;Thnc5a<gJfN;Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Gf>;Fen7Fen7Ee^3Ee^3DeMoCe=kCe=kDeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEe^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3EemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoE
emoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGemgGemgGemgGemgGemgG
emgGemgGemgHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgHf=kHf=kI
fMoIfMoIfMoHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgGemgGemgGemgGemgGemgFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWEe=KE
e=KEe=KEe=KEe=KEe=KEe=KEe=KHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWIf=[I
f=[If=[If=[If=[If=[If=[If=[HemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[I
f=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIf=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[Hf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SIemOIemOIemOIemOIemOI
emOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemKIemKIemKIemKIemKIemKIemKIemKFe]KF
e]KFe]KFe]KGemOGemOHf=SHf=SGemOGemOGemOHf=SHf=SHf=SIfMWIfMWHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SIemKIemKIemKJf=OJf=OJf=OKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWMfm[Mfm[Mfm[Lf]WKfMSJ
f=OHe]GGeMCKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSFeM7Ge];If=CJfMGKf]KLfmOLfmOLfmOJfMGJ
fMGJfMGKf]KKf]KKf]KLfmOLfmOKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJfMGJfMGJfMGKf]KKf]KK
f]KLfmOLfmOJfMGJfMGKf]KLfmOLfmOKf]KJfMGJfMGIf=CJfMGKf]KLfmOLfmOLfmOKf]KKf]KKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOKf]KKf]KKf]KLfmOLfmOM
g=SMg=SMg=SLf]WLf]WLf]WLf]WLf]WLf]WLf]WLf]WOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]ONfMKN
fMKNfMKOf]OOf]OPfmSPfmSPfmSOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OPfmSPfmSPfmSPfmSPfmSP
fmSPfmSPfmSNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKOg=COg=COg=COg=COg=COg=COg=COg=COg=CO
g=COg=COg=COg=COg=COg=COg=CMf];Mf];Mf];Mf];Mf];Mf]800=gLg]cKgHf<STa;CNKUiahM7hV8
RWEdMR8S9i2AUMOGgMcLhWEdOMSGhMOFh=7@f]WFiLo>f820QTA6AgQjNnCTj/k=emcIj=WHh]OFh=GD
g]KEgmCCgM;Afm?Bg=KEgmKEgmKEgmKEgmOFh=OFh=OFh=SGhMSGhMoMjM[Hi=oNj=WHhM;Bf<?4b4]<
D4Y<CMcKiK^ja=KEgi2?V<K6c:ZZ/0000lk?dlG4cNKUk/c;e=GDgEUHHI2?V=GDgMcKi=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=KGhMKGhMKGhMGFh=GFh=CEgmCE
gm?Dg]CEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=OFh=OFh=OFh=OFh=OFh=OFh=OF
h=OFh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMSHg]SHg]WIgmWIgmWIgmSHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMKFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=SGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMKEemKEemKEemKEemKEemKEemKEemKEemSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWG
emWGemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]KFe]KFe]KFe]KFe]OGemOGemSHf=SHf=OGemOGemOG
emSHf=SHf=SHf=WIfMWIfMSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=WGe]WGe]WGe][Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=[Hem[Hem[H
em[Hem[Hem[Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM_If=cJfMcJfMcJfM_If=[HemWGe]SFeM_If=_If=_If=_If=_If=_If=_I
f=_If=KEdMOFd]WHe=[IeM_Je]cKem_Je]_Je][IeM[IeM[IeM_Je]_Je]_Je]cKemcKem_If=_If=_I
f=_If=_If=_If=_If=_If=[IeM[IeM[IeM_Je]_Je]_Je]cKemcKem[IeM[IeM_Je]cKemcKem_Je][I
eM[IeMWHe=[IeM_Je]cKemcKemcKem_Je]_Je]_If=_If=_If=_If=_If=_If=_If=_If=cKemcKemcK
emcKemcKemcKemcKemcKem_Je]_Je]_Je]cKemcKemgLf=gLf=gLf=cJfMcJfMcJfMcJfMcJfMcJfMcJ
fMcJfMoJemoJemoJemoJemoJemoJemoJemoJemkIe]kIe]kIe]oJemoJen3Kf>3Kf>3Kf=oJemoJemoJ
emoJemoJemoJemoJemoJen3Kf>3Kf>3Kf>3Kf>3Kf>3Kf>3Kf>3Kf=kIe]kIe]kIe]kIe]kIe]kIe]kI
e]kIe]oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=gJd]gJd]gJ
d]gJd]gJd]gJdP00dm;D`L32?ci0a<?5d]7C]kJh71/MaLC6N7Um>CXne]KLb/[@g=_TemKPdM3Je]GO
eM?Og=_U`l?9HfAX<S<g[JfcemKPe=;Nf]WSe]GOemKPfm[TfMSRd]7Ke=?Mfm[Te]GOe]GOe]GOemKP
emKPemKPf=OQf=OQf]WS`l;<cLcFemKOdM7GDE5GFEYNYjR/g]gWi^G_dm;La<?<g]kThn?Y>CXnY:FY
cloEf][Ph>3VemOM]kNm=cLme]KLcLgCeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPe]OQe]OQeMKPeMKPeMKPe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPemKPemKPemKPemKPemKPemKPemKPemKPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemOMemOMemOMemOM
emOMemOMemOMemOMf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMf=SN
f=SNfMWOfMWOfMWOf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOM
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOF
e]KFe]KFe]KFe]KFemOGemOGf=SHf=SHemOGemOGemOGf=SHf=SHf=SHfMWIfMWIf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHfMOFfMOFfMOFf]SGf]SGf]SGfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SGf]SGfmWHfmWH
fmWHfmWHf]SGfMOFfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHemKBf=OCfMSDf]WEfm[Ffm[Ffm[Ffm[F
f]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_GfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]WEf]WEf]WEfm[F
fm[Ffm[Fg=_Gg=_Gf]WEf]WEfm[Fg=_Gg=_Gfm[Ff]WEf]WEfMSDf]WEfm[Fg=_Gg=_Gg=_Gfm[Ffm[F
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gfm[Ffm[Ffm[Fg=_G
g=_GgMcHgMcHgMcHg=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[Ig=[Igm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[G
g]WFg]WFg]WFgm[Ggm[Gh=_Hh=_Hh=_Hgm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Gh=_Hh=_Hh=_Hh=_H
h=_Hh=_Hh=_Hh=_Hg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcD
gmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgM[BgM[BgM[BgM[BgM[BgM[B003Mg=k?c]0_;S3Wi^SGe]Q9
B4YkNW`N7Ao>cm?<cM7Gemf`/;K/joCAd=[LfnGGe^3RhNZo_/O/k?;CdmU?CeDl?4;@cmS6aLkFeMoA
d=[DdmgLfnGMg>KFeMoEe=kKf^CFeMoFeMoFeMoGe^3Ge^3Ge^3Hen7Hen7JfN;Qh>W;b]?[j_=RHFX^
;SB8R8k`l?K5a<kMg>K@cmWPgnRWYjfo_lG5a/Z4QHWCdmWCdmUYJFlV9Rb`/;Hh>3kPh>KHf=kEe^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3DeMoDeMoDeMoDeMoDeMoDeMoDeMoDeMoEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ge^3Ge^3Ge^3Ge^3Ge^3G
e^3Ge^3Ge^3EemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGemgGemgGemgGemgGemgGemgGemgGemgHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgHf=kHf=kIfMoIfMoIfMoHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kGemgGemgGemgGemgGemgGemgGemgGemgFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[If=[If=[If=[HemWH
emWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[Hf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOI
emOIemOIemOIemKIemKIemKIemKIemKIemKIemKIemKFe]KFe]KFe]KFe]KGemOGemOHf=SHf=SGemOG
emOGemOHf=SHf=SHf=SIfMWIfMWHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SIemKIemKIemKJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSHe]GIemKJf=OKfMSKfMSKfMSJf=OJf=OKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSGe];Hem?If=CJfMGKf]KKf]KKf]KJfMGJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOJfMGJfMGKf]KLfmOLfmOK
f]KJfMGJfMGIf=CJfMGKf]KLfmOLfmOLfmOKf]KKf]KKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKf]KK
f]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KLfmOLfmOMg=SMg=SMg=SLf]WLf]WLf]WLf]WLf]WL
f]WLf]WLf]WOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]ONfMKNfMKNfMKOf]OOf]OPfmSPfmSPfmSOf]OO
f]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]ONfMKNfMKNfMKNfMKNfMKN
fMKNfMKNfMKNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Mf];M
f];Mf];Mf];Mf];Mf]800<O6b5MFF9>BU5EDEP000@/:30X92`000BHW:m3AeK^k`MKFg<C3c<W8d]KE
gmgLi/K6c>CTj/[9d]_Jhn?RjcPg@3Lg?LG5bm[IhmKEgmCCgMGDg]GDg]?Bg=GDg]SGhMKEgmKEgmKE
gmOFh=OFh=OFh=SGhMSGhMWIgm;Bf?CdnVe/MDI5CWMfOlK5c]SGh>7Pj]cKiMOFh=_JhmSHg[fm`l?4
b2HW:genPP000i:CUlS9cNGVjZ6RYU=DF<S9cMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CEgmCEgmCEgmCEgmCEgmCEgmCE
gmCEgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=OFh=OFh=OFh=OFh=OFh=OFh=OFh=OFh=GGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOG
gMSHg]SHg]WIgmWIgmWIgmSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMKFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWG
emWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe]KFe]KFe]KFe]KFe]OGemOGemSHf=SHf=OGemOGemOGemSHf=SHf=SHf=WIfMWIfMSHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=WGe]WGe]WGe][Hem[Hem[Hem_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]SFeMWGe][H
em[Hem_If=[Hem[HemWGe]_If=_If=_If=_If=_If=_If=_If=_If=SGdmWHe=[IeM_Je]_Je]_Je][I
eMWHe=[IeM[IeM[IeM_Je]_Je]_Je]cKemcKem_If=_If=_If=_If=_If=_If=_If=_If=[IeM[IeM[I
eM_Je]_Je]_Je]cKemcKem[IeM[IeM_Je]cKemcKem_Je][IeM[IeMWHe=[IeM_Je]cKemcKemcKem_J
e]_Je]_If=_If=_If=_If=_If=_If=_If=_If=_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_J
e]cKemcKemgLf=gLf=gLf=cJfMcJfMcJfMcJfMcJfMcJfMcJfMcJfMoJemoJemoJemoJemoJemoJemoJ
emoJemkIe]kIe]kIe]oJemoJen3Kf>3Kf>3Kf=oJemoJemoJemoJemoJemoJemoJemoJemoJemoJemoJ
emoJemoJemoJemoJemoJemkIe]kIe]kIe]kIe]kIe]kIe]kIe]kIe]kKdmkKdmkKdmkKdmkKdmkKdmkK
dmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmgJd]gJd]gJd]gJd]gJd]gJdP00e]GGNGQjemKH^kZl
fMSJa/G7alK8aLC6i>GYa<G9Xj>Yc<cBg]gVh=oYh^7[b<OAfmcPcLgCcLcFh^3/dLoKViZT=CDkDU=G
clkHf]WSg]gWeMCNclkHe=?Mf]WSf]WSe]GOe]GOe]GOemKPemKPemKPf=OQf=OQdmCHdmCHLg=i@d=9
K6]diNC^gMcVd]7KclkHclkHd]7Kd<oHcloEUIFKm?GiaLK:3PlCf]_Og]oSc<gAdmCH^[^oHfAXiNKZ
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=GOe=GOe=GOeMKP
eMKPeMKPe]OQe]OQe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPemKPemKPemKPemKP
emKPemKPemKPemKPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
emKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemOMemOMemOMemOMemOMemOMemOMemOMf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMf=SNf=SNfMWOfMWOfMWOf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOMe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIemKHemKHemKHemKHemKHemKHemKHemKH
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFe]KFe]KFe]KFe]KFemOGemOGf=SHf=SH
emOGemOGemOGf=SHf=SHf=SHfMWIfMWIf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHfMOFfMOFfMOFf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ff=KEfMOFf]SGf]SGf]SGfMOFf=KEf=KEfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfMSDfMSDf]WEfm[Ffm[Ff]WEfMSDfMSDf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_G
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_Gf]WEf]WEfm[Fg=_G
g=_Gfm[Ff]WEf]WEfMSDf]WEfm[Fg=_Gg=_Gg=_Gfm[Ffm[FfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_GgMcHgMcHgMcHg=[Ig=[Ig=[Ig=[I
g=[Ig=[Ig=[Ig=[Igm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Gg]WFg]WFg]WFgm[Ggm[Gh=_Hh=_Hh=_H
gm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Ggm[Gg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WFg]WF
g]WFg]WFg]WFg]WFgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[B
gM[BgM[BgM[BgM[BgM[BgM[B003Ee=IPGf7>cLmoOX0k>S`f=CMVIFNXYjWFem^LWJ7Jf^3/k?;5a<gJ
fN?Kf^CEe=kIfmcMgN?NgNO<bMS2_lkQh>Z2PXPm?d28Qi6i^<;NgNOLfnGCd]cIf>;NgNOHen7FeMoF
eMoFeMoGe^3Ge^3Ge^3Hen7Hen7CeMJJVim2@dM/K7;Ge]o9b=;Pg^[@c][ZjO>e];kYj?;NgNKNg^CD
e=ZXZJgCe=Q[KFjYZja`LW<`<S=TIVM<CTmNH674a/OEe^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ce=kDeMoDeMoEe^3Ee^3Fen7Fen7Fen7DeMoDeMoDeMoDeMoDeMoD
eMoDeMoDeMoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEe^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3EemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoE
emoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGemgG
emgGemgGemgGemgGemgGemgGemgHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgG
emgGemgHf=kHf=kIfMoIfMoIfMoHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgGemgGemgG
emgGemgGemgFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWIf=[If=[If=[If=[If=[If=[If=[If=[HemWHemWHemWHemWHemWHemWHemWHemWIf=[I
f=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIf=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[Hf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SIemOI
emOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemKIemKIemKIemKIemKI
emKIemKIemKFe]KFe]KFe]KFe]KGemOGemOHf=SHf=SGemOGemOGemOHf=SHf=SHf=SIfMWIfMWHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SIemKIemKIemKJf=OJf=OJ
f=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfmGKfmGKfmGKfmGKfmGKfmGKfmGKfmGIemKJ
f=OJf=OJf=OIemKHe]GGeMCFe=?KfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSIf=CJfMGJfMGKf]KKf]KJ
fMGIf=CHem?JfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJfMGJ
fMGJfMGKf]KKf]KKf]KLfmOLfmOJfMGJfMGKf]KLfmOLfmOKf]KJfMGJfMGIf=CJfMGKf]KLfmOLfmOL
fmOKf]KKf]KKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGKf]KK
f]KKf]KLfmOLfmOMg=SMg=SMg=SLf]WLf]WLf]WLf]WLf]WLf]WLf]WLf]WOf]OOf]OOf]OOf]OOf]OO
f]OOf]OOf]ONfMKNfMKNfMKOf]OOf]OPfmSPfmSPfmSOf]OOf]OOf]OOf]OOf]OOf]OOf]OOf]ONfMKN
fMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKNfMKMf];Mf];Mf];Mf];Mf];M
f];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf]800<_:c;jm_mWH
fU=BE:j][mGDe]7@d]_Jg=3AeFQYKM;Bf<S8c^o^mlK5cm_Ji=OFh=OIfM3AeMKEgn3Mk>?Pklc;eMcM
hI>EUC4`>XF4S]3?fMgLi]GDg][IhmWHh/k=emKEgmKEgmKEgmOFh=OFh=OFh=SGhMSGhHb>ScTk?6UZ
K/o?eNGTkMOFh<?1cNGRlLS7dNOVl=KEglo>emOGgM3@eVIWJmCEfL;4a@000F]]KV]]K]7Ce3/m?X^=
S/oAd]GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=?Dg]?Dg]CE
gmGFh=GFh=KGhMKGhMOHh]CEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=OFh=OFh=OF
h=OFh=OFh=OFh=OFh=OFh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMSHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMSHg]SHg]WIgmWIgmWIgmSHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMKFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]KFe]KFe]KFe]KFe]OGemOGemSH
f=SHf=OGemOGemOGemSHf=SHf=SHf=WIfMWIfMSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SHf=SHf=SHf=WGe]WGe]WGe][Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_KeM_KeM_KeM_KeM_KeM_KeM_KeM_KeM[Hem[Hem[Hem[HemWGe]OEe=KDdmGCd]_If=_If=_I
f=_If=_If=_If=_If=_If=WHe=[IeM_Je]_Je]_Je][IeMWHe=SGdm[IeM[IeM[IeM_Je]_Je]_Je]cK
emcKem_If=_If=_If=_If=_If=_If=_If=_If=[IeM[IeM[IeM_Je]_Je]_Je]cKemcKem[IeM[IeM_J
e]cKemcKem_Je][IeM[IeMWHe=[IeM_Je]cKemcKemcKem_Je]_Je]_If=_If=_If=_If=_If=_If=_I
f=_If=[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM_Je]_Je]_Je]cKemcKemgLf=gLf=gLf=cJfMcJfMcJ
fMcJfMcJfMcJfMcJfMcJfMoJemoJemoJemoJemoJemoJemoJemoJemkIe]kIe]kIe]oJemoJen3Kf>3K
f>3Kf=oJemoJemoJemoJemoJemoJemoJemoJemkIe]kIe]kIe]kIe]kIe]kIe]kIe]kIe]kIe]kIe]kI
e]kIe]kIe]kIe]kIe]kIe]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJ
d]gJd]gJd]gJd]gJd]gJd]gJd]gJdP00[jfcbLO=iN?YfmWOSXbBOWb2cL_Ae=;HdM;F^kc0f][PdM7G
eMCMclkHg=_Ue=?MemKPemKPemKPemKPemKPemKPemKPemKPQHN7<38bOh62c<gAfm_QinK_d<oIh=oY
hMk]`l7=dM3Jg=_TemOMcLkBe=KGX::S;RdgShjHe]GOf]WSe=?Mf=OQf=OQeMCNemSRgMkXcm3JdmCN
cm3Jf]_U_;g7d]?Mf]cTBTaDbL_C4Q@Lh>;ZEeUQKW1hZjfef][Xd];Pg=cZe]KTfMWWfMWWdm?Qe=CR
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPd]OPd]OPd]OPd]OP
d]OPd]OPd]OPd]OPe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOOeMOOe]SPe]SPemWQemWQemWQ
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SP
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOe]GNe]GNe]GNemKOemKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKO
e]KLe]KLe]KLemOMemOMemOMf=SNf=SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf=OPf=OPf=OPf=OP
f=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJemWJemWJemWJemWJemWJemWJemWJemWJf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OIf=OIfMSJ
fMSJfMSJf]WKf]WKf=OIf=OIf=OIfMSJfMSJfMSJf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WK
f][Jf][Jf][Jf][Jf][Jf][Jf][Jf][JfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf=OIf=OIemKHemKHe]GGe]GGeMCFeMCFfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMSLfMSLfMSLfMSLfMSLfMSLfMSLfMSLfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIf]SHf]SHf]SHfmWIfmWIfmWIg=[Jg=[Jf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=WGf=WGf=WGf=WG
f=WGf=WGf=WGf=WGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf=WGf=WGf=WGfM[H
fM[HfM[Hf]_If]_If=WGf=WGf=WGfM[HfM[HfM[Hf]_If]_IfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfMOFfMOFfMOFf]SGf]SGf]SGfmWHfmWHg=[Ig=[Ig=[Ig=[I
g=[Ig=[Ig=[Ig=[IfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ff]WEf]WEfm[Fg=_G
g=_Gfm[Ff]WEf]WEf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_Gf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_G
fMSDf]WEfm[Fg=_Gg=_Gg=_Gfm[Ffm[Ff]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_Gfm[Ffm[Ffm[Ffm[F
fm[Ffm[Ffm[Ffm[Fg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gfm[Ffm[Ffm[Fg=_Gg=_GgMcHgMcHgMcH
g=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_GhMkFh=gEh=gEgmcD
gmcDg]_Cg]_CgM[BgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcD
g]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]_Cg]_Cg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_A002IUig`
k_Bo_L?CdMOPg^BLVZ091`gJf=j>Si>g^;cHf=kIfMoPgnSIf>;JfN?@cmWGe^3Ge^3Ge^3Ge^3Ge^3G
e^3Ge^3Ge^3Hf]Y0@T9LGUo>cm?>c]C@cmSSh^bn_LOBd=cPg^[LfnGCd]_=cM?Oh>CZjnmLGUm]K7Ja
/;[LfnGIf>;Ee=kIf>;Ge^3Ee=k?d=[If^CGf>;Mg^SFen7Ee^2e]/2<SIO2a<anP8S1`l^[[KFVZ;3N
h>Rl_/J[[KGEeN7;bmO@d=c=cMW;bmOBd]kIfNGNg^[Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ben3Ben3Ben3Ben3Ben3Ben3Ben3Ben3De]kDe]kDe]kEemoEemoE
emoFf>3Ff>3EemoEemoEemoFf>3Ff>3GfN7GfN7GfN7Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ge]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoDe]kDe]kDe]kEemoEemoEemoFf>3Ff>3EemoEemoEemoEemoEemoEemoEemoEemoGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oG
e]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFe]cFe]cFe]cGemgGemgGemgHf=kHf=kJf=kJ
f=kJf=kJf=kJf=kJf=kJf=kJf=kHen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3H
en3Hen3Hen3Hf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgGemgGemgG
emgGemgGemgIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[GfM[G
fM[GfM[GfM[GfM[GfM[GfM[GfM[HemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[HemWHemWHemWIf=[If=[If=[JfM_JfM_HemWHemWHemWIf=[If=[I
f=[JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][If=[I
f=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWHemWH
emWHemWGe]SFeMOFeMOFeMOEe=KIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIf=[If=[If=[If=[If=[If=[If=[If=[KfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SKfMWKfMWK
fMWLf][Lf][Jf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OHf=SH
f=SHf=SHf=SHf=SHf=SHf=SHf=SHfMOHfMOHfMOHfMOHfMOHfMOHfMOHfMOIemKIemKIemKIemKIemKI
emKIemKIemKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OHfMOHfMOHfMOIf]SIf]SIf]SJfmWJfmWHfMOHfMOHfMOIf]SIf]SI
f]SJfmWJfmWKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSIemKI
emKIemKJf=OJf=OJf=OKfMSKfMSLf]WLf]WLf]WLf]WLf]WLf]WLf]WLf]WKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKf]KK
f]KKf]KKf]KKf]KKf]KKf]KKf]KJfMGJfMGKf]KLfmOLfmOKf]KJfMGJfMGJfMGJfMGJfMGKf]KKf]KK
f]KLfmOLfmOJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOIf=CJfMGKf]KLfmOLfmOLfmOKf]KKf]KJfMGJ
fMGJfMGKf]KKf]KKf]KLfmOLfmOKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KLfmOLfmOLfmOLfmOLfmOL
fmOLfmOLfmOKf]KKf]KKf]KLfmOLfmOMg=SMg=SMg=SLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOL
fmOLfmOLfmOLfmOLfmOLfmOLfmOPgMGPgMGPgMGOg=COg=CNfm?Nfm?Nfm?Og=COg=COg=COg=COg=CO
g=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=CNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Ng=;Ng=;Ng=;Ng=;Ng=;N
g=;Ng=;Ng=;Mfm7Mfm7Mfm7Mfm7Mfm7Mfm4009NEVlo=dmkLh^OUjkjl`]GCfMGCfLS6c5mPI<o@e=WI
gm?CfMOFgmSGhM[IhmOFh=OFh=OFh=OFh=OFh=OFh=OFh=OFh=OFh=GGf=cNgbd^<S/l@<;2b<k>e>KU
k^WXlLo>f<g<e^;QjmKEg/_;dMKFg38c=cdn@[>b_=?Bg=kMimKEgmOFh=SGhMGDg]SGhMCEgmOHh]KG
hMGFh=7Bg=OHh/g>f5aMInOYlJBV[^c^m/S:d/?5cL_=eN;Tk7j0R=KFh]GEhMgMjNGUlMKFh]GEhMCD
h<g=fMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=;Gh=;Gh=;G
h=;Gh=;Gh=;Gh=;Gh=;Gh=CFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=GGgmGGgmGGgmKHh=KHh=OIhMOI
hMOIhMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmCFg]CFg]CFg]GGgmGGgmGGgmKH
h=KHh=GGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOFgmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmKFg=KFg=KFg=OGgMOGgMOGgMSHg]SHg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg]SGh=SGh=SG
h=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]OIf]OIf]OIf]OIf]OIf]OIf]OIf]OIf]SGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SGfMSGfMSG
fMWHf]WHf]WHf][Ifm[IfmSGfMSGfMSGfMWHf]WHf]WHf][Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[I
fm[Ifm[Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfMSGfMSGfMSGfMOFf=OFf=OFf=KEemKEemWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[Hf=_IfM_IfM_IfMcJf]cJf][Hem[Hem[Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SIemSIemSI
emSIemSIemSIemSIemSIemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe][Hem[Hem[Hem[Hem[Hem[Hem[H
em[Hem[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemSIemSIemSI
emWJf=WJf=WJf=[KfM[KfMSIemSIemSIemWJf=WJf=WJf=[KfM[KfM_If=_If=_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=WGe]WGe]WGe][Hem[Hem[Hem_If=_If=cJfMcJfMcJ
fMcJfMcJfMcJfMcJfMcJfM_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM_J
e]cKemcKem_Je][IeM[IeM[IeM[IeM[IeM_Je]_Je]_Je]cKemcKem[IeM[IeM[IeM_Je]_Je]_Je]cK
emcKemWHe=[IeM_Je]cKemcKemcKem_Je]_Je][IeM[IeM[IeM_Je]_Je]_Je]cKemcKem_Je]_Je]_J
e]_Je]_Je]_Je]_Je]_Je]cKemcKemcKemcKemcKemcKemcKemcKem_Je]_Je]_Je]cKemcKemgLf=gL
f=gLf=cKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKemcKen3MeN3MeN3M
eMoLe=oLe=kKdmkKdmkKdmoLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oL
e=oLe=kKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkK
dmkKdmkKdmkKdmkKdmkKdmkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]gKdMgKdMgKdMgKdMgKdMgKd@00
RXR>d]3Fc/cB`l77iN?YcL_Ai^CZeM?I>CXngMkRemOMcLgCclkGeMCNe]GOf=OQemKPemKPemKPemKP
emKPemKPemKPemKPf=WMhN;V][Nk@T=7GEeS_[k4_Kg3emOMgmkWfMSQi>?/aLC=f=OPBDU?DU9H][Jl
e=?Mg=_Uf=OQd]7KemKPe]GOe=?Mg=_Ue]OQeMKPe]OQdM;Lcm3JfM[TgMkX>3U3cm7IdmGMgMoWdM?K
j>[be=KNemWQTYBL/[>ma/OAb/_Eg]oYd]?MfM[TfM[Tc/oIeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPd]OPd]OPd]OPd]OPd]OPd]OPd]OPd]OPe=KNe=KNe=KNeMOO
eMOOeMOOe]SPe]SPeMOOeMOOeMOOe]SPe]SPemWQemWQemWQeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
emKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNemKO
emKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKOe]KLe]KLe]KLemOMemOMemOMf=SNf=SN
f]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OP
f=OPf=OPf=OPf=OPf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMemOM
emOMemOMemOMemOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
emWJemWJemWJemWJemWJemWJemWJemWJf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OIf=OIfMSJfMSJfMSJf]WKf]WKf=OIf=OIf=OIfMSJ
fMSJfMSJf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][J
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
f=OIf=OIf=OIf=OIemKHemKHemKHemKHfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHfmWI
fmWIfmWIg=[Jg=[Jf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=WGf=WGf=WGf=WGf=WGf=WGf=WGf=WGfMOFfMOFfMOFfMOF
fMOFfMOFfMOFfMOFf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf=WGf=WGf=WGfM[HfM[HfM[Hf]_If]_If=WGf=WGf=WGfM[H
fM[HfM[Hf]_If]_IfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fMOFfMOFfMOFf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ff]WEf]WEfm[Fg=_Gg=_Gfm[Ff]WEf]WEf]WEf]WEf]WEfm[F
fm[Ffm[Fg=_Gg=_Gf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_GfMSDf]WEfm[Fg=_Gg=_Gg=_Gfm[Ffm[F
f]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_Gfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Fg=_Gg=_Gg=_Gg=_G
g=_Gg=_Gg=_Gg=_Gfm[Ffm[Ffm[Fg=_Gg=_GgMcHgMcHgMcHg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_G
g=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_GgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcD
gmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]cBg]cBg]cBg]cB
g]cBg]cBg]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_A003Ng>;7aL_Lf^3Rh>KFe=[Jf=jk^Ko/j_0S92S?
d=CEeM_De=[JfN;Kf^CDdmgAd=[Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Bd]SCdmWTi>[3`lTl?D57
B4cGf=c@dMG4a<[QhNO;bm7PgnQ<BeA6ADjOWZOThncFeMoJfN?DdmgCd]cIf>;DdmgBdM_Mg>K>cmWC
e=kKg>KLgNOGf>;Gf>;?d=XS92k5alodm_jl_/K8b];=cmOOhNWCeMg@d]Ze]/3Qh^c;c=KBdmg5a]3F
en7LgNOHfN?Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ben3B
en3Ben3Ben3Ben3Ben3Ben3Ben3De]kDe]kDe]kEemoEemoEemoFf>3Ff>3EemoEemoEemoFf>3Ff>3G
fN7GfN7GfN7Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoE
emoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoEemoDe]kDe]kDe]kEemoEemoE
emoFf>3Ff>3EemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oGe]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oFe]cFe]cFe]cGemgGemgGemgHf=kHf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kHen3H
en3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kGemgGemgGemgGemgGemgGemgGemgGemgIf=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[GfM[GfM[GfM[GfM[GfM[GfM[GfM[GfM[HemWH
emWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[HemWH
emWHemWIf=[If=[If=[JfM_JfM_HemWHemWHemWIf=[If=[If=[JfM_JfM_JfM_JfM_JfM_JfM_JfM_J
fM_JfM_JfM_Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][If=[If=[If=[If=[If=[If=[If=[If=[IfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWHemWHemWHemWHemWHemWHemWHemWHemWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SKfMWKfMWKfMWLf][Lf][Jf=OJf=OJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHfMOH
fMOHfMOHfMOHfMOHfMOHfMOHfMOIemKIemKIemKIemKIemKIemKIemKIemKJf=OJf=OJf=OJf=OJf=OJ
f=OJf=OJf=OJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OHfMOH
fMOHfMOIf]SIf]SIf]SJfmWJfmWHfMOHfMOHfMOIf]SIf]SIf]SJfmWJfmWKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSIemKIemKIemKJf=OJf=OJf=OKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KJfMGJ
fMGKf]KLfmOLfmOKf]KJfMGJfMGJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOJfMGJfMGJfMGKf]KKf]KK
f]KLfmOLfmOIf=CJfMGKf]KLfmOLfmOLfmOKf]KKf]KJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOKf]KK
f]KKf]KKf]KKf]KKf]KKf]KKf]KLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOKf]KKf]KKf]KLfmOLfmOM
g=SMg=SMg=SLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOOg=CO
g=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=CO
g=COg=COg=CNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Mfm7Mfm7Mfm7Mfm7Mfm7M
fm400<g;dMkLh]kLh/C2b=_IgmkLh/K4b[fk`F5RI];CemcLh]KFg=WHhMWHh]WHh]KEgmOFh=OFh=OF
h=OFh=OFh=OFh=OFh=OFh=[Ih]7@fMcLh/W9cgioPfY[Kjf_/>3RhmWJg]GFf]WIgkZj`7]jPkZi`mWH
h]3?fM;AfmWHh]OFh=OFh=cKiMGDg]3?fM[Ihm7Bg=GFh=KGhMOHh]GFh=cMim7Bg61QJlW;dloAfM[L
i=gOin?UkLG7clk@f=_MiHJ8T>g_mmWKhm[Li<g?em_MiM?EgM?EgMGFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=;Gh=;Gh=;Gh=;Gh=;Gh=;Gh=;Gh=;Gh=CFg]CFg]CF
g]GGgmGGgmGGgmKHh=KHh=GGgmGGgmGGgmKHh=KHh=OIhMOIhMOIhMGFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmCFg]CFg]CFg]GGgmGGgmGGgmKHh=KHh=GGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KE
g]OFgmOFgmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKFg=KFg=KFg=OGgMOGgMOGgMSH
g]SHg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg]SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SGh=SG
h=SGh=SGh=SGh=SGh=SGh=SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]OGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]OIf]OIf]OIf]OIf]OIf]OIf]OIf]OIf]SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SGfMSGfMSGfMWHf]WHf]WHf][Ifm[IfmSGfMSGfMSG
fMWHf]WHf]WHf][Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Jf][Jf][Jf][Jf][Jf][Jf][J
f][Jf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfMOFf=SGfMSGfMSGfMWHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWJf=WJf=WJf=WJf=WJf=WJf=WJ
f=WJf=_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[H
f=_IfM_IfM_IfMcJf]cJf][Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[H
em[HemSHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SIemSIemSIemSIemSIemSIemSIemSIemWGe]WGe]WG
e]WGe]WGe]WGe]WGe]WGe][Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemSIemSIemSIemWJf=WJf=WJf=[KfM[KfMSIemSIemSI
emWJf=WJf=WJf=[KfM[KfM_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=WGe]WGe]WGe][Hem[Hem[Hem_If=_If=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem_If=_If=_I
f=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=_I
f=_If=_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM_Je]cKemcKem_Je][IeM[IeM[IeM[IeM[I
eM_Je]_Je]_Je]cKemcKem[IeM[IeM[IeM_Je]_Je]_Je]cKemcKemWHe=[IeM_Je]cKemcKemcKem_J
e]_Je][IeM[IeM[IeM_Je]_Je]_Je]cKemcKem_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]cKemcKemcK
emcKemcKemcKemcKemcKem_Je]_Je]_Je]cKemcKemgLf=gLf=gLf=cKemcKemcKemcKemcKemcKemcK
emcKemcKemcKemcKemcKemcKemcKemcKemcKemkKdmkKdmkKdmoLe=oLe>3MeN3MeN3MeMoLe=oLe=oL
e=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=kKdmkKdmkKdmkKdmkKdmkKdmkK
dmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkLd]kLd]kL
d]kLd]kLd]kLd]kLd]kLd]gKdMgKdMgKdMgKdMgKdMgKd@00emGKinG[blW?`/36dLoEe=;HhMoUM79h
^;VmeMKJhn?Ydm?Idm;Kd]7KgMcVfm[TemKPemKPemKPemKPemKPemKPemKPemKPfm[Ti>?]clkGjNW_
dM;FW9jOYJNWR8Z:/;:caLK:KFibWinU/:nhfMSRjnWefMOSdM3Jf]WSemKPe=?Mfm[TfMSRdm;LemKP
emSRf]_Uc/oId=7Kd=7KhN;/eMKP^[_5NWb4];Jnh^C/d=;J];JnhnG]cLoGf=[R2`dE_l79a/S@dmGM
dmGMh>;Zcm7IfM_SeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
d]OPd]OPd]OPd]OPd]OPd]OPd]OPd]OPe=KNe=KNe=KNeMOOeMOOeMOOe]SPe]SPeMOOeMOOeMOOe]SP
e]SPemWQemWQemWQeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPemKOemKOemKOemKOemKOemKOemKOemKO
eMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOe=KNe=KNe=KNeMOO
eMOOeMOOe]SPe]SPeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNemKOemKOemKOf=OPf=OPemKOemKOemKOemKO
emKOemKOemKOemKOe]KLe]KLe]KLemOMemOMemOMf=SNf=SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SN
f=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNemOMemOMemOMemOMemOMemOMemOMemOMfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJemWJemWJemWJemWJemWJemWJemWJemWJ
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
f=OIf=OIf=OIfMSJfMSJfMSJf]WKf]WKf=OIf=OIf=OIfMSJfMSJfMSJf]WKf]WKf]WKf]WKf]WKf]WK
f]WKf]WKf]WKf]WKf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][JfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIemKHf=OIf=OIf=OIfMSJf]WKf]WKf]WK
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfM[HfM[HfM[HfM[HfM[HfM[HfM[HfM[HfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHfmWIfmWIfmWIg=[Jg=[Jf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SH
f=WGf=WGf=WGf=WGf=WGf=WGf=WGf=WGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f=WGf=WGf=WGfM[HfM[HfM[Hf]_If]_If=WGf=WGf=WGfM[HfM[HfM[Hf]_If]_IfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfMOFfMOFfMOFf]SGf]SGf]SGfmWHfmWH
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[F
f]WEf]WEfm[Fg=_Gg=_Gfm[Ff]WEf]WEf]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_Gf]WEf]WEf]WEfm[F
fm[Ffm[Fg=_Gg=_GfMSDf]WEfm[Fg=_Gg=_Gg=_Gfm[Ffm[Ff]WEf]WEf]WEfm[Ffm[Ffm[Fg=_Gg=_G
fm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Fg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gfm[Ffm[Ffm[Fg=_G
g=_GgMcHgMcHgMcHg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_Gg=_G
g]_Cg]_Cg]_CgmcDgmcDh=gEh=gEh=gEgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcD
gmcDgmcDgmcDgmcDg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgM_AgM_AgM_AgM_A
gM_AgM_A003Mfn79alejN7ho?D<000CLf^3?cM=SHFO?d=Bl_L7OgnGHf=kKf^?Cd]cKf^C@cmWGe^3G
e^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ddmg=c=KThnc:b]3TiNW:c<ecMGG5alNRY:EdMWOMg^:j^/3Sh^_6
aLoFe>3Cd=o@cmWIf>;Cd]c>cMOIf>;Mg>KFeMoFeMo@dM_JfnGAd]cIf^CGf>;PhN_0`L_DeMmKGFGH
f^;CeMd000H00@Vf^<3Jg>CFf>0000CDemcKg^?Ig>7Ae=WJgN;7b/oNhNKEe^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ben3Ben3Ben3Ben3Ben3Ben3Ben3Ben3De]kD
e]kDe]kEemoEemoEemoFf>3Ff>3EemoEemoEemoFf>3Ff>3GfN7GfN7GfN7Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoEemoEemoE
emoEemoEemoEemoEemoEemoEemoDe]kDe]kDe]kEemoEemoEemoFf>3Ff>3EemoEemoEemoEemoEemoE
emoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkF
eMkFeMkGe]oGe]oGe]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFe]cFe]cFe]cGemgGemgG
emgHf=kHf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kHen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3H
en3Hen3Hen3Hen3Hen3Hen3Hen3Hf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kGemgG
emgGemgGemgGemgGemgGemgGemgIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[GfM[GfM[GfM[GfM[GfM[GfM[GfM[GfM[HemWHemWHemWHemWHemWHemWHemWHemWIf=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[HemWHemWHemWIf=[If=[If=[JfM_JfM_HemWH
emWHemWIf=[If=[If=[JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_JfM_Jf][Jf][Jf][Jf][Jf][J
f][Jf][Jf][If=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWGe]SHemWHemWIf=[If=[JfM_JfM_Kf]cIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIf]KIf]KIf]KIf]KIf]KI
f]KIf]KIf]KKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJ
f=SJf=SKfMWKfMWKfMWLf][Lf][Jf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJ
f=OJf=OJf=OHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHfMOHfMOHfMOHfMOHfMOHfMOHfMOHfMOIemKI
emKIemKIemKIemKIemKIemKIemKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OHfMOHfMOHfMOIf]SIf]SIf]SJfmWJfmWHfMOH
fMOHfMOIf]SIf]SIf]SJfmWJfmWKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSIemKIemKIemKJf=OJf=OJf=OKfMSKfMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KJfMGJfMGKf]KLfmOLfmOKf]KJfMGJfMGJfMGJ
fMGJfMGKf]KKf]KKf]KLfmOLfmOJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOIf=CJfMGKf]KLfmOLfmOL
fmOKf]KKf]KJfMGJfMGJfMGKf]KKf]KKf]KLfmOLfmOKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KLfmOL
fmOLfmOLfmOLfmOLfmOLfmOLfmOKf]KKf]KKf]KLfmOLfmOMg=SMg=SMg=SLfmOLfmOLfmOLfmOLfmOL
fmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOLfmOMf];Nfm?Nfm?Og=COg=CPgMGPgMGQg]KOg=CO
g=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=COg=CNfm?Nfm?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Ng=;N
g=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Mfm7Mfm7Mfm7Mfm7Mfm7Mfm400<g;dN7OiClm@c/i?`001>_Yklc:
d6ARJ<[;clo@e=CDf/o?eN;Qj/g<e^7Pj]WHh]cKiMOFh=7@f][IhnCSkMOFh<c;eMKEgm[Gim;?gmCA
h=OEhLo>f=CCg=kNi=kNi:BS[9>BVk6`^McKi=_Jhm3?f=KEg]WHhMKEgm[IhmcKiM7@f]oNj<[9dn3O
jM?Bg=GDgN3Oj<k=e^7PjLc;e=7@fM7@fM7@fFMVKmOFgl;1bP@332PW<6m^MnCSk=WHh@X;5L;3cNSY
lm;CgMKGhLo@f]gNj=7Bg=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=KEgmKEgmKEgmOFh=OFh=OFh=SGhMSGhMOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmSG
h=SGh=SGh=WHhMWHhMWHhMOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGG
gmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmKEg]KEg]KEg]OFgmOFgmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMOGgMOGgMOGgMSHg]SHg]WIgmWI
gmWIgmSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg][Hg][Hg][H
g][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg]OGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfMGIf]OIf]OIf]WHf]WHf]_Hf]_Hf]gHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM[Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][Ifm[Ifm[I
fm[Ifm[Ifm[Ifm[Ifm[Ifm_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_I
f=_If=SIemSIemSIemSIemSIemSIemSIemSIem_If=_If=_If=_If=_If=_If=_If=_If=_If=[HemWG
e]WGe]WGe]WGe][Hem_If=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[H
em[HemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]SFeMSFeMSF
eMSFeMWGe]WGe][Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_I
f=_If=_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM_Je]_Je]_J
e]_Je]_Je]_Je]_Je]_Je][IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM_Je]_Je]_Je]_Je]_Je]_Je]_J
e]_Je][IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je][Kd][Kd][J
e=[Je=[IeM[IeM[Hem[Hem[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeM[Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd]gJd]gJd]gJ
d]gJd]gJd]gJd]gJd]gJd]WJdMWJdMWJdM[Kd][Kd][Kd]_Ldm_LdmgJd]gJd]gJd]gJd]gJd]gJd]gJ
d]gJd]kKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmoLe=kKdmkKdmkKdmkKdmkKdmgJd]gJd]oLe=oLe=oL
e=oLe=oLe=oLe=oLe=oLe=kKdmoLe=oLe>3MeN3MeMoLe=oLe=kKdmkKdmkKdmkKdmkKdmkKdmkKdmkK
dmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]oMdmoMdmoM
dmoMdmoMdmoMdmoMdmoMdn3Ne=oMdmoMdmkLd]kLd]oMdmoMdn3Ne=kLd]kLd]kLd]kLd]kLd]kLd]kL
d]kLd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgK
dMgKdMgKdMgKd@00fmWOb<K<blW?THnE`Ko5a/C:g=[PK6Y`[Jjbh^?WgmoUemOMh^7Zc/gGfMSRd]7K
bl[DgmkXf=OQe]GOc<_Ef]WSf=OQh^7[blSHh]o^h]o^fmWUemKPj>O`];BjIfM]b/WBd<oHb/WB]kJo
_;_4h=oXkNcee]GNcLcFemKPg=_Ue=?MgMcVbLSBhn;/g]gWd]7Jf]WRclkGhN3YeMCMg]gVhn;[/:nh
JFQaemKOdM3IVYVRUIBMbl[Cg]gVbLSAU9FOfmcVb<WCc<gGhnC^dmCNf]_UdmCNeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe]GOe]GOe]GOemKPemKPemKPf=OQf=OQ
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOf=OPf=OPf=OPfMSQfMSQemKOemKOemKOemKO
emKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNemKOemKOemKOf=OPf=OP
emKOemKOemKOemKOemKOemKOemKOemKOemOMemOMemOMemOMemOMemOMemOMemOMfMOMfMOMfMOMfMOM
fMOMfMOMfMOMfMOMemOMemOMemOMf=SNf=SNfMWOfMWOfMWOf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SN
f]SNf]SNf]SNf]SNemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIeMWJemWJemWJfMSJ
fMSJfmSJfmSJgMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
f][Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf]WKf]WKf]WKf]WKf]WKf]WKf]WKf]WKfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf=WGf=WGf=WGf=WGf=WGf=WGf=WGf=WG
fmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]SGfMOFfMOFfMOFfMOFf]SGfmWHf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOF
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf=KEf=KEf=KEf=KEfMOFfMOFf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[F
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ff]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEfm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ff]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WE
fm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ffm[Ff]_Bf]_Bf][Df][Df]WEf]WEf]SGf]SGf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_B
f]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BfM[AfM[AfM[Af]_B
f]_Bf]_BfmcCfmcCgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[Bg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_CgM[BgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDg]_CgmcDgmcDh=gE
h=gEgmcDgmcDg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgmgCgmgCgmgCgmgCgmgCgmgCgmgCgmgCh=kDgmgCgmgCg]cB
g]cBgmgCgmgCh=kDg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_A
gM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_A003Bd=KOgN?>c=;Rh>K@c]CE
dmWAcmG8a/aQHVKNgn?GemgBd]SMg>GBdM_Ge^3Ee=kBdM_Og^SEe=kFeMo9b=;JfN?BdM_BdM_He^;6
a=32`<c]k?KFeMk1`<Ve]K_IfMoMg>G<bmBk^/?0_lS>cMK;b]?8am3DdmcHen7FeMo>cMO@cmWNgNO?
c]SKf^C;b]CIf>7If>7BdM[LfnCBdM[Ge]oNgNIPGfRm_<GViNk>cMKCd]_2`L[Sh^_Kf^?8am32`lgK
g>K:bmGKg>KSi>k;c=KGf>;HfN?Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3FeMoFeMoFeMoGe^3Ge^3Ge^3Hen7Hen7Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oHen3Hen3Hen3If>7Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoE
emoEemoEemoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oGe]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGemgG
emgGemgGemgGemgGemgGemgGemgIemgIemgIemgIemgIemgIemgIemgIemgGemgGemgGemgHf=kHf=kI
fMoIfMoIfMoHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kJf=kJ
f=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgIf=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[IfMWI
fMWIfMWIfMWIfMWIfMWIfMWIfMWEfM[GfM[GfM[If=[If=[Kf=[Kf=[Mf=[If=[If=[If=[If=[If=[I
f=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWJf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][JfM_J
fM_JfM_JfM_JfM_JfM_JfM_JfM_KfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSK
fMSKfMSKfMSHfMOHfMOHfMOHfMOHfMOHfMOHfMOHfMOKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJ
f=OIemKIemKIemKIemKJf=OKfMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJ
f=OJf=OJf=OIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKHe]GH
e]GHe]GHe]GIemKIemKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJ
f=OJf=OJf=OJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfm;J
fm;Jf]CJf]CJfMGJfMGJf=OJf=OJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Mf];M
f];Mf];Mf];Mf];Mf];Mf];Mf];If]7If]7If]7Jfm;Jfm;Jfm;Kg=?Kg=?Mf];Mf];Mf];Mf];Mf];M
f];Mf];Mf];Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Og=CO
g=COg=COg=COg=COg=COg=COg=CNfm?Og=COg=CPgMGPgMGOg=COg=CNfm?Nfm?Nfm?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;OgM?O
gM?OgM?OgM?OgM?OgM?OgM?OgM?Pg]COgM?Ng=;Ng=;Ng=;Ng=;OgM?Pg]CNg=;Ng=;Ng=;Ng=;Ng=;N
g=;Ng=;Ng=;Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7M
fm7Mfm7Mfm7Mfm7Mfm4009BBV=7?eLo=dmkLh/g;dMSFg=CBf=cJh2HW:m7Be/k>e<k>e=OFgmOFh=OF
h=[Ihn?Rjm3?f<o>emGDgNGTkN?RjmCCg;Nf_mgLi^OVl<o>emGDgLO6cm_Jhl?2bl2ob=_Jhn?Rjkjm
aYJEWZFT[LG4cMOFgnGTkMgLiMkMi]CCg=gLiN?RjmOFgmgLiM;Af]kMi]SGh=GDgMKEg]7@fM;Af]?B
fb@S;=oNimGDgMWHhM3?f>7PjLo>em;AfYNFWjn`^]?Dg]_Li]oPj]7Bg<c=en7Rk=?Dg]GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=KEgmKEgmKEgmOFh=OFh=OFh=SG
hMSGhMOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]OFgmOFgmOFgmSGh=SGh=SGh=OFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOFgmOFgmSG
h=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWGgMWGgMWG
gMWGgMWGgMWGgMWGgMWGgMOGgMOGgMOGgMSHg]SHg]WIgmWIgmWIgmSHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][H
g][Hg][Hg][Hg][Hg][Hg]OGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMGIf]OIf]OI
f]WHf]WHf]_Hf]_Hf]gHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfM[Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hem[Hem[H
em[Hem[Hem[Hem[Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=SIemSIemSIemSIemSIemSIemSI
emSIem_If=_If=_If=_If=_If=_If=_If=_If=_If=[HemWGe]WGe]WGe]WGe][Hem_If=[Hem[Hem[H
em[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemWGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]SFeMSFeMSFeMSFeMWGe]WGe][Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[Kd][Kd][Je=[Je=[IeM[IeM[Hem[Hem[IeM[IeM[I
eM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[Kd][Kd][Kd][Kd][Kd][Kd][K
d][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]WJdMWJdMWJ
dM[Kd][Kd][Kd]_Ldm_LdmgJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]kKdmkKdmkKdmkKdmkKdmkKdmkK
dmkKdmgJd]gJd]gJd]kKdmkKdmkKdmkKdmoLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=kKdmoLe=oL
e>3MeN3MeMoLe=oLe=kKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkK
dmkKdmkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]oMdmoMdmkL
d]gKdMgKdMkLd]oMdmoMdmkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]gKdMgKdMgKdMgKdMgKdMgKdMgK
dMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKd@00RXR>dLoEiN?Yc<[@
gmgSeM?Ig=[PblW?<S<gd]?GfMWOemOMf=OPf]WSe=?MemKPalO=cLgCk^kdcLgCe]KLbl_Ag]kT^KVo
alO=f][Pd=3Ff][Pf=OPgmkWdM3IgmkW_Kc5fm[SgMcUdM3IeMCMd<oHalK?d<oHb<S>e=CJcloEg]kT
e]KLc<cBfMWOg]kTf=OPdm;KemKOf=OPfm[SgmkWe]GN<c8kdM3Ib<O@i>?/a/G>j^Wbd<oHgMcUPX6:
dmCNfM[Te=GOcLkHbL[Dg=gWj>Wcb/_EeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPe]GOe]GOe]GOemKPemKPemKPf=OQf=OQemKOemKOemKOemKOemKOemKOemKOemKO
e]GNe]GNe]GNe]GNemKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOO
eMOOeMOOeMOOeMOOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOe]GNe]GNe]GNemKOemKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKO
emOMemOMemOMemOMemOMemOMemOMemOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMemOMemOMemOMf=SN
f=SNfMWOfMWOfMWOf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SN
f]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIeMWJemWJemWJfMSJfMSJfmSJfmSJgMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][J
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfmWHfmWHfmWHfmWH
fmWHfmWHfmWHfmWHf=WGf=WGf=WGf=WGf=WGf=WGf=WGf=WGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWH
fmWHf]SGfMOFfMOFfMOFfMOFf]SGfmWHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOF
f=KEf=KEf=KEf=KEfMOFfMOFf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WE
f]_Bf]_Bf][Df][Df]WEf]WEf]SGf]SGf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_B
gM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BfM[AfM[AfM[Af]_Bf]_Bf]_BfmcCfmcCgM[BgM[BgM[BgM[B
gM[BgM[BgM[BgM[Bg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg=WAgM[BgM[Bg]_Cg]_CgmcDgmcDgmcD
gmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcDg]_CgmcDgmcDh=gEh=gEgmcDgmcDg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cB
g]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgmgCg]cBgM_AgM_AgM_AgM_Ag]cBgmgCg]cBg]cBg]cBg]cB
g]cBg]cBg]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_A
gM_AgM_AgM_AgM_AgM_AgM_A002^[;;ShNO=bm7GeM_:b<kNg>;Dd]SJf=iQHVK0`LGLg>;Kfn7Ge]oJ
fN?Ee=kFeMoUiN_=cM?6a/bEUI^l_<;IfMo@d=IWIff][k3WjN[Qh^JWZ:bYZJo8am3Ge]oFeMkUi>gE
e=g@cmSMg>GFeMjf]Kje];gHen3MgN?AdMNd];[=cM?De=[IfMoIfMoCdmWEe=gCd]_If>7If>7Og^OQ
h>W4`laTHfcEe=gKf^?NgNK6aLkAd=WJfN;Sh^^JVJ;Si>kCe=k?d=[DeMoEe^3JfnGKg>K@dM_Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3FeMoFeMoFeMoGe^3Ge^3G
e^3Hen7Hen7Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oEe=gEe=gFeMkFeMkFeMkGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oEemoEemoEemoEemoEemoEemoEemoEemoGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oG
e]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGemgGemgGemgGemgGemgGemgGemgGemgIemgI
emgIemgIemgIemgIemgIemgIemgGemgGemgGemgHf=kHf=kIfMoIfMoIfMoHf=kHf=kHf=kHf=kHf=kH
f=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kHf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJf=kJ
f=kJf=kJf=kJf=kJf=kJf=kJf=kGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgG
emgGemgGemgGemgGemgGemgGemgGemgGemgGemgGemgIf=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWEfM[G
fM[GfM[If=[If=[Kf=[Kf=[Mf=[If=[If=[If=[If=[If=[If=[If=[If=[IfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWJf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][HemWHemWHemWHemWHemWHemWHemWHemWKfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSHfMOHfMOHfMOHfMOHfMOH
fMOHfMOHfMOKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSKfMSJf=OIemKIemKIemKIemKJf=OKfMSJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIemKIemKIemKIemKIemKI
emKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKHe]GHe]GHe]GHe]GIemKIemKJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OIemKIemKIemKIemKIemKIemKIemKIemKIf=CIf=CIf=CIf=CIf=CI
f=CIf=CIf=CJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CJfm;Jfm;Jf]CJf]CJfMGJfMGJf=OJf=OJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfm;Jfm;Jfm;Jfm;Jfm;J
fm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Jfm;Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];If]7I
f]7If]7Jfm;Jfm;Jfm;Kg=?Kg=?Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Nfm?Nfm?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?LfM7LfM7Mf];Mf];Nfm?Og=CPgMGPgMGOg=COg=COg=COg=COg=COg=COg=COg=CNfm?O
g=COg=CPgMGPgMGOg=COg=CNfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?Nfm?N
fm?Nfm?Nfm?Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Ng=;N
g=;Mfm7Lf]3Lf]3Mfm7Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Mfm7Mfm7Mfm7Mfm7Mfm7M
fm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm400;Jd^/o=dmGC
fMOEfnCRj=3>e=OEflg;dINHW:6RY]GEfmOGgM?BfmOFh=SGhMOFh<C5bMoPi>g^l[bm`GMhO7ioPhb=
TFm`M7]mOEiPH5mQHX:3QmoOiLo>elc;e=gLi/;1b][Ih^GTkMKEg]3?f=[Ih/2ob8^:TmSIgL31aI>D
V;6b][fn`]7Be]GFf]CEfMGDgMSGh=[Ih]OFgm[Ih]OFgjBS[9ZIX/_:dmcKi=_JhmgLiMcKi=_Jhm7@
fJ2OZ<g>f<c=emWJi=oPj]_Li];CgLg>f=[KiMGFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=KEgmKEgmKEgmOFh=OFh=OFh=SGhMSGhMOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmGDgMGDgMGDgMKEg]KEg]KEg]OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmGGgmGGgmGG
gmGGgmGGgmGGgmGGgmGGgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOFgmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMOGgMOGgMOG
gMSHg]SHg]WIgmWIgmWIgmSHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SHg]SH
g]SHg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg][Hg]OGgMOGgMOG
gMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOGgMOG
gMOGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMGIf]OIf]OIf]WHf]WHf]_Hf]_Hf]gHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM[Jf][Jf][Jf][Jf][Jf][Jf][J
f][Jf]SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem_If=_If=_I
f=_If=_If=_If=_If=_If=SIemSIemSIemSIemSIemSIemSIemSIem_If=_If=_If=_If=_If=_If=_I
f=_If=_If=[HemWGe]WGe]WGe]WGe][Hem_If=[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[H
em[Hem[Hem[Hem[Hem[HemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe]SFeMSFeMSFeMSFeMWGe]WGe][Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemWGe]WGe]WG
e]WGe]WGe]WGe]WGe]WGe]WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeMWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeMWHe=WHe=WH
e=WHe=WHe=WHe=WHe=WHe=[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeMWHe=WHe=WHe=WHe=WHe=WHe=WH
e=WHe=[Kd][Kd][Je=[Je=[IeM[IeM[Hem[Hem[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeM[IeM[IeM[IeM[IeM[Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][Kd][K
d][Kd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]WJdMWJdMWJdM[Kd][Kd][Kd]_Ldm_LdmgJd]gJd]gJ
d]gJd]gJd]gJd]gJd]gJd]kKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdm_Hd=cIdMcIdMgJd]kKdmoLe>3M
eN3MeMoLe=oLe=oLe=oLe=oLe=oLe=oLe=oLe=kKdmoLe=oLe>3MeN3MeMoLe=oLe=kKdmkKdmkKdmkK
dmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkKdmkLd]kLd]kLd]kLd]kLd]kLd]kL
d]kLd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMkLd]gKdMcJd=cJd=cJd=cJd=gKdMkLd]kLd]kLd]kL
d]kLd]kLd]kLd]kLd]kLd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgK
dMgKdMgKdMgKdMgKdMgKdMgKdMgKd@00blW?h=kTd]3FemGKblW?d]3Ff]SNe]CJalS<UYNKemOMf=SN
d]7Jdm;Le]GOdm;Lg]oSeMKJbL[>f]_OPX>7P865JV]_I6EYI6MUIVQXKW1`IFMXd=3FfMSQh^7Ze=?M
hn;[dM3IdM3IeMCMemKOh=oXb/WBUiJOLgAhNgb0I6EYNW]oJV]_P865ZZ^_eMKJd]7JfMSQf]WRf=OP
f]WRemKOUYFNbLSAe]GNdM3IclkGclkGhN3Ybl[CeMCM`;o8eMKPfmcVg=gWcm3JdmCNfM[Td=7KfM[T
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe]GOe]GOe]GOemKP
emKPemKPf=OQf=OQemKOemKOemKOemKOemKOemKOemKOemKOeMCMeMCMeMCMeMCMe]GNe]GNemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOeMOOeMOOeMOOeMOOeMOOeMOOeMOOeMOOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNemKO
emKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKOemOMemOMemOMemOMemOMemOMemOMemOM
fMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMemOMemOMemOMf=SNf=SNfMWOfMWOfMWOf=SNf=SNf=SNf=SN
f=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf=SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SN
f]SNf]SNf]SNf]SNf]SNf]SNf]SNf]SNemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOM
emOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMemOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWI
eMWJemWJemWJfMSJfMSJfmSJfmSJgMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIf][Jf][Jf][Jf][Jf][Jf][Jf][Jf][Jf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfmWIfmWIfmWIfmWI
fmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf=WGf=WGf=WGf=WG
f=WGf=WGf=WGf=WGfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHfmWHf]SGfMOFfMOFfMOFfMOFf]SGfmWH
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMOFfMOFfMOFfMOF
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf=KEf=KEf=KEf=KEfMOFfMOFf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMSDfMSDfMSDfMSD
fMSDfMSDfMSDfMSDf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSD
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf]WEf]WEf]WEf]WE
f]WEf]WEf]WEf]WEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf]_Bf]_Bf][Df][Df]WEf]WEf]SGf]SG
f]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]_Bf]_Bf]_Bf]_B
f]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_Bf]_BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[B
fM[AfM[AfM[Af]_Bf]_Bf]_BfmcCfmcCgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[Bg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]_Cg]_CfmS@g=WAg=WAgM[Bg]_CgmcDh=gEhMkFgmcDgmcDgmcDgmcDgmcDgmcDgmcDgmcD
g]_CgmcDgmcDh=gEh=gEgmcDgmcDg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_Cg]_C
g]_Cg]_Cg]_Cg]_Cg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_A
g]cBgM_Ag=[@g=[@g=[@g=[@gM_Ag]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgM_AgM_AgM_AgM_A
gM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_A0036aLO<
blgQh>;DdmGFeMOHemWLfmg7a/S8bLd`<3KMgN?:bM;RhN_Ad=[MfnOBd=cFe=[GeM_Kf]jd/kMXIfUh
N7QaLG5RHV9^L721Ph=fN7QADeCAd]K7b<cQhNOFe]cAd=WKf^?Zj_33`lWQh^K>cm?7bLYcMGIcLg=T
I6A[Jf]UIFE_KfmXJ6RJVY[:b/[Mg>G@cmSPgnSAd=WJfN;;b]<e=3g=c=ERI6Fo`L;Fem_9b/kDe=[?
cmGNgNK3`/_Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ge]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oGe]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oHen3Hen3Hen3Hen3Hen3Hen3Hen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cEeM_EeM_EeM_Fe]cFe]cFe]cGemgGemgHemWHemWHemWHemWHemWHemWHemWHemWGemgG
emgHf=kHf=kHf=kIfMoIfMoIfMoIemgIemgIemgIemgIemgIemgIemgIemgLf^3Lf^3KfMoJf=kJf=kI
emgIemgHe]cIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[IemgI
emgIemgIemgIemgIemgIemgIemgIf=[If=[If=[If=[If=[If=[If=[If=[JfM_JfM_JfM_JfM_JfM_J
fM_JfM_JfM_If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[Hf=SHf=SHf=SIfMWIfMWI
fMWJf][Jf][IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWKf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[K
f=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][KfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWKfMWKfMWLf][Lf][Lf][Mfm_Mfm_Mfm_Lf][L
f][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][Lf][L
f][Lf][Lf][Jf=SJf=SJf=SKfMWKfMWKfMWLf][Lf][Jf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SKfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=OJf=OJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIemKIemKIemKJf=OJf=OJf=OKfMSKfMSKfMSK
fMSKfMSKfMSKfMSKfMSKfMSKfMSJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIf=CIf=CIf=CIf=CIf=CI
f=CIf=CIf=CKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KKf]KIf=CI
f=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CHem?Hem?Hem?Hem?If=CI
f=CJfMGJfMGKe]?Ke]?Ke]?Ke]?LemCLemCMf=GMf=GIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGLemCLemCLemCLemCLemCLemCLemCLemCMf];Mf];Mf];Mf];Mf];M
f];Mf];Mf];LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7If]7If]7If]7If]7If]7If]7If]7If]7Mf];M
f];Mf];Mf];Mf];Mf];Mf];Mf];LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7Mf];Mf];M
f];Nfm?Nfm?Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Kf=3K
f=3Kf=3Kf=3LfM7LfM7Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];LfM7LfM7LfM7Mf];Mf];M
f];Nfm?Nfm?Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mf];M
f];Mf];Mf];Mf];Mf];Mf];Mf];Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Lf]3Lf]3Lf]3Mfm7Mfm7M
fm7Ng=;Ng=;OgM?OgM?OgM?OgM?OgM?OgM?OgM?OgM?Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;N
g=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Of]7Of]7Of]7Pfm;Pfm;Pfm;Qg=?Qg=?Pfm;Pfm;Pfm;Pfm;Pfm;P
fm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7O
f]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7O
f]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]400=?Be8R7RL?2a=7@d^OVj;fl_]WHf^WXj][KgiJGVlW9
cm?Bfl[9d]kMilW8d^3Nj/_9ckZh_Z^Z[X>2QVQWJGUiNGalO8F5QLS:b[Zl_:2RXXnATZFVZ[Nh_=gM
hlg=dm;Af/S7d;fm`nSXk^7Ri];Cegn1PUYLGH^;RgalO9BDU;2`/:^[Ze=CDfYZJ/c<c=KEg]WHhM3?
f<K5c^g/mM;AfY6@VM_JheaNGlc>caPI7Jj_/k2`]/k>e6YYL]oNimOFh=OFh=OFh=OFh=OFh=OFh=OF
h=OFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOFgmOFgmSG
h=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmSGh=SGh=SGh=SGh=SGh=SGh=SG
h=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=GEfmGEfmGEfmKFg=KFg=KFg=OG
gMOGgMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMOGgMOGgMOGgMSHg]SHg]SHg]WIgmWIgmWGgMWGgMWG
gMWGgMWGgMWGgMWGgMWGgM_Igm_Igm_Igm[Hg][Hg]WGgMWGgMSFg=WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMWHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf][Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[Ifm[IfmWHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]SHf=SHf=SHf=WIfMWIfMWIfM[Jf][Jf]WIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfM_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]cJf]cJf]cJ
f]cJf]cJf]cJf]cJf]cJf]_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfMWIfMWIfMWIfMWIfMWIfMWIfMWI
fMWIfM_IfM_IfM_IfMcJf]cJf]cJf]gKfmgKfmcJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJ
f]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf]cJf][Hf=[Hf=[Hf=_IfM_IfM_IfMcJ
f]cJf][Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[H
em[HemWGe]WGe]WGe]WGe][Hem[Hem_If=_If=_If=_If=_If=_If=_If=_If=_If=_If=[Hem[Hem[H
em[Hem[Hem[Hem[Hem[HemWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=_Je]_Je]_Je]_Je]_Je]_Je]_J
e]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]_Je]WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WH
e=WHe=WHe=WHe=WHe=WHe=SGdmSGdmSGdmSGdmWHe=WHe=[IeM[IeM_Fdm_Fdm_Fdm_FdmcGe=cGe=gH
eMgHeMWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeMcGe=cGe=cG
e=cGe=cGe=cGe=cGe=cGe=gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]cIdMcIdMcIdMcIdMcIdMcIdMcI
dMcIdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMgJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]cIdMcIdMcI
dMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMgJd]gJd]kKdmkKdmgJd]gJd]gJd]gJd]gJd]gJd]gJ
d]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]_Hd=_Hd=_Hd=_Hd=cIdMcIdMgJd]gJd]gJd]gJd]gJ
d]gJd]gJd]gJd]gJd]gJd]cIdMcIdMcIdMgJd]gJd]gJd]kKdmkKdmgJd]gJd]gJd]gJd]gJd]gJd]gJ
d]gJd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gKdMgKdMgK
dMgKdMgKdMgKdMgKdMgKdMcJd=cJd=cJd=gKdMgKdMgKdMkLd]kLd]oMdmoMdmoMdmoMdmoMdmoMdmoM
dmoMdmkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]oJdMoJdMoJ
dN3Kd^3Kd^3Kd^7Ldn7Ldn3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3K
d^3Kd]oJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJ
dMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJd@00
e=?EI6=Ub/W;DE1Bhn;Th^7SNgYl0001O7f1k^ocD55Eg=cRj>O`dm;KeMCNg=_Uh^3VclgC_;^oTi:F
MWEgL71`IFEULW9bcLo?oOoocm7AQhV:YZN[c/oCh^;XeMGKj^Wbf=OPfMWO_ko5WIjRM7EiGf5RX::S
VYZJSXj>T92@/[:bgMgMTI6ARXZ:h>3P`L77lO7gcLgCh^;Xd];H@D57i^K/MgMm];JgRH^<2@X>cLkB
H61Vc/kDCdiGi>?/emKPemKPemKPemKPemKPemKPemKPemKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
eMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPe=GOe=GOe=GOe=GOe=GOe=GOe=GOe=GOemKOemKOemKOemKO
emKOemKOemKOemKOe]GNe]GNe]GNemKOemKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOf=OPf=OPf=OPf=OPf=OPf=OPf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKO
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLeMGKeMGKeMGKe]KLe]KLe]KLemOMemOMf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
emOMemOMemOMemOMf=SNf=SNf=SNfMWOfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfmWOf]SNf]SNf]SN
fMOMfMOMfMOMfMOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf]WKf]WKf]WKf]WK
f]WKf]WKf]WKf]WKfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=SHf=SHf=SHfMWI
fMWIfMWIf][Jf][JfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJ
fmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHfmWIfmWIfmWIfmWIg=[Jg=[Jg=[JgM_K
g=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[Jg=[J
g=[Jg=[Jg=[Jg=[Jf]SHf]SHf]SHfmWIfmWIfmWIg=[Jg=[Jf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOFfMOFfMOFfMOF
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFf=KEf=KEfMOFfMOFf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMSDfMSDfMSDfMSD
fMSDfMSDfMSDfMSDf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WEf]WE
fMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf=OCf=OCf=OCf=OC
fMSDfMSDf]WEf]WEfmKCfmKCfmKCfmKCg=ODg=ODgMSEgMSEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSD
fMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=WAg=WAg=WAg=WA
g=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[A
g=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAfmS@fmS@g=WAg=WA
gM[BgM[BgM[BgM[Bg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WA
fmS@fmS@fmS@fmS@g=WAg=WAgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[Bg=WAg=WAg=WAgM[B
gM[BgM[Bg]_Cg]_CgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_A
gM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_Ag=[@g=[@g=[@gM_A
gM_AgM_Ag]cBg]cBgmgCgmgCgmgCgmgCgmgCgmgCgmgCgmgCg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cB
g]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBgm[Agm[Agm[Ah=_Bh=_Bh=_BhMcChMcCh=_Bh=_Bh=_Bh=_B
h=_Bh=_Bh=_Bh=_Bgm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[A
gm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Ag]W@g]W@g]W@g]W@
g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@0036aLNYZ:ZKVYbCTY@30P@00062PH?Sh^CJg=gE
emRLWJ6o`<CBd]SBdM[Thnc@cmWFe=[EdmWIf=c6aLV1P8:=SHf2PX:4Q8Be]kOfn?SGfMV0PX?BdmOG
f=cRh^S>c]C<bmC;b]?Xj>k?cmGKg>2h^Ke/KVmkOGjl_;bXZ:R9RHVJVY[Lg=bEUIE_KfnZZZZo_lG?
cmG<c=;AdMOKfn6i^KoGemfXZ:hR92D0005jNgne][ZPX:JDU9ZSXZ_Ge]oGe^3Ge^3Ge^3Ge^3Ge^3G
e^3Ge^3Ge^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3DeMoD
eMoDeMoDeMoDeMoDeMoDeMoDeMoGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oG
e]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cEeM_EeM_EeM_Fe]cFe]cF
e]cGemgGemgHemWHemWHemWHemWHemWHemWHemWHemWFe]cFe]cGemgGemgGemgHf=kHf=kHf=kIemgI
emgIemgIemgIemgIemgIemgIemgIemgIemgIemgIemgIemgIemgIemgIemgIf=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[IemgIemgIemgIemgIemgIemgIemgIemgIf=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[Hf=SHf=SHf=SIfMWIfMWIfMWJf][Jf][IfMWIfMWIfMWIfMWIfMWI
fMWIfMWIfMWKf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[KfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SHf=SHf=SHf=SHf=SHf=SH
f=SHf=SHf=SJf=SJf=SKfMWKfMWKfMWLf][Lf][Lf][KfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWK
fMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWJf=SJf=SJf=SKfMWKfMWK
fMWLf][Lf][Jf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKIemKI
emKIemKIemKHe]GHe]GHe]GIemKIemKIemKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CJfMGJfMGJfMGJfMGJfMGJ
fMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGJfMGIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CI
f=CIf=CIf=CIf=CIf=CIf=CIf=CHem?Hem?Hem?Hem?If=CIf=CJfMGJfMGKe]?Ke]?Ke]?Ke]?LemCL
emCMf=GMf=GIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CLemCL
emCLemCLemCLemCLemCLemCLemCLfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7L
fM7LfM7LfM7If]7If]7If]7If]7If]7If]7If]7If]7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7L
fM7LfM7LfM7LfM7LfM7LfM7LfM7Kf=3Kf=3Kf=3LfM7LfM7LfM7Mf];Mf];LfM7LfM7LfM7LfM7LfM7L
fM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7Kf=3Kf=3Kf=3Kf=3LfM7LfM7Mf];Mf];Mf];M
f];Mf];Mf];Mf];Mf];Mf];Mf];LfM7LfM7LfM7Mf];Mf];Mf];Nfm?Nfm?Mf];Mf];Mf];Mf];Mf];M
f];Mf];Mf];Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mfm7M
fm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Lf]3Lf]3Lf]3Mfm7Mfm7Mfm7Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;N
g=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Of]7O
f]7Of]7Pfm;Pfm;Pfm;Qg=?Qg=?Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;Of]7Of]7Of]7Of]7Of]7O
f]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7O
f]7Of]7Of]7Of]7Of]7Of]7Of]7NfM3NfM3NfM3NfM3NfM3NfM3NfM3NfM3NfM3NfM3NfM3NfM3NfM3N
fM000=WHf/K5aeIEEmKEe`000M?Be>7Ph/[9bjb^[ZV[[>W[k7=dN>3Pi]7AemOFgmOFgm?Aem7?eMWH
g=[IgG1_LJZZZZ6QXHB4Q7YlO6]]KGeoOiFGV=CEfL?4b=oOiLk>e<[9d^3Oj=WIgmkNi<72a]cMhGj0
PIfOX9fMWIFEUI^KVlO7aoKfmYVIVH>3Pm[Jf]gNh/c=dN7Ri]SIgFIWJm[Kgg]lP=kOhn3RhkJh^INH
W10A5LK6c5QHG^CSk<k=e]OFh=OFh=OFh=OFh=OFh=OFh=OFh=OFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=CEgmCEgmCEgmCEgmCEgmCEgmCEgmCEgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KEg]OFgmOFgmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmKFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=KFg=KFg=GEfmGEfmGEfmKFg=KFg=KFg=OGgMOGgMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMKFg=KFg=KFg=KFg=OGgMOGgMSHg]SHg]WGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMSFg=SFg=SF
g=WGgMWGgMWGgMWGgMWGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SHf=SHf=SH
f=WIfMWIfMWIfM[Jf][Jf]WIfMWIfMWIfMWIfMWIfMWIfMWIfMWIfM_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_H
f]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=SHf=[Hf=[Hf=[Hf=[Hf=_IfM_IfMcJ
f]cJf]_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_IfM_I
fM_IfM_IfM_IfM_IfM_IfM[Hf=[Hf=[Hf=_IfM_IfM_IfMcJf]cJf][Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=SFeMSFeMSF
eMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMOEe=OEe=SFeMSFeMWGe]WGe]WG
e]WGe][Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemWHe=WHe=WH
e=WHe=WHe=WHe=WHe=WHe=[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[IeM[I
eM[IeMWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=SGdmSGdmSG
dmSGdmWHe=WHe=[IeM[IeM_Fdm_Fdm_Fdm_FdmcGe=cGe=gHeMgHeMWHe=WHe=WHe=WHe=WHe=WHe=WH
e=WHe=SGdmSGdmSGdmSGdmSGdmSGdmSGdmSGdmcGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=cIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMWJdMWJdMWJdMWJdMWJdMWJdMWJ
dMWJdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=cIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdM[Gcm[Gcm_H
d=_Hd=cIdMcIdMcIdMcIdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=cIdMcIdMgJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]cIdMcIdMcI
dMgJd]gJd]gJd]kKdmkKdmgJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gKdMgKdMgKdMgKdMgKdMgKdMgK
dMgKdMgJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMcJd=cJd=cJ
d=gKdMgKdMgKdMkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kL
d]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]oJdMoJdMoJdN3Kd^3Kd^3Kd^7Ldn7Ldn3Kd^3Kd^3K
d^3Kd^3Kd^3Kd^3Kd^3Kd]oJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJ
dMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMgHcmgHcmgH
cmgHcmgHcmgHcmgHcmgHcmgHcmgHcmgHcmgHcmgHcmgHc`00d<oAmOCfNgYlYJBV/:naS8^=^[VkA4=5
ADM7/kFedM?DY:JW_;g1g]kTd];HemOMi>;XfMOMf]WMf]WMNGQj/[:bSXj>CTi>BD];I6IVGf5QWZ2Q
c<gAf=WMc/kDg=cRhN3Yc/gFbLW?fMWOh>7UalS<GV1QB4Y;Jf][Jf][PX:2V9RHYjNWJVYZN7Qh_[jn
e=GIcLkBf=WMc<gA[k2db<W=00035aPLOX21][Rid=7Ec<gAXJ6WX:2VfMSQd]7JemKPemKPemKPemKP
emKPemKPemKPemKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKPeMKP
dmCNdmCNdmCNdmCNdmCNdmCNdmCNdmCNemKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNemKO
emKOemKOf=OPf=OPemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKO
emKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOemKOe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNemKOemKOemKOemKOemKOemKOemKOemKOe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLeMGKeMGKeMGKe]KL
e]KLe]KLemOMemOMf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIeMGKeMGKe]KLe]KLe]KLemOMemOMemOM
fMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOMemGKemGKf=KLf=KLf=KLfMOMfMOMfMOMfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMOMfMOMfMOMfMOMfMOMfMOMfMOMfMOM
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=SHf=SHf=SHfMWIfMWIfMWIf][Jf][JfMWIfMWIfMWIfMWI
fMWIfMWIfMWIfMWIfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJfmSJ
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGemOGemOGemOGemOG
emOGemOGemOGemOGfMOGfMOGf]SHf]SHf]SHfmWIfmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfmWI
fmWIfmWIg=[Jg=[Jf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KE
f=KEf=KEf=KEf=KEemGDemGDemGDf=KEf=KEfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOF
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSD
fMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSD
fMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf=OCf=OCf=OCf=OCfMSDfMSDf]WEf]WEfmKCfmKCfmKCfmKC
g=ODg=ODgMSEgMSEfMSDfMSDfMSDfMSDfMSDfMSDfMSDfMSDf=OCf=OCf=OCf=OCf=OCf=OCf=OCf=OC
g=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@g=WAg=WAg=WAg=WA
g=WAg=WAg=WAg=WAfM[AfM[AfM[AfM[AfM[AfM[AfM[AfM[AfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
g=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAf]O?f]O?f]O?fmS@fmS@g=WAg=WAg=WAfmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@g=WAg=WAgM[BgM[B
gM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[Bg=WAg=WAg=WAgM[BgM[BgM[Bg]_Cg]_CgM[BgM[BgM[BgM[B
gM[BgM[BgM[BgM[BgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_AgM[BgM[BgM[BgM[BgM[BgM[BgM[BgM[B
gM_AgM_AgM_AgM_AgM_AgM_AgM_AgM_Ag=[@g=[@g=[@gM_AgM_AgM_Ag]cBg]cBgM_AgM_AgM_AgM_A
gM_AgM_AgM_AgM_Ag]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cBg]cB
gm[Agm[Agm[Ah=_Bh=_Bh=_BhMcChMcCh=_Bh=_Bh=_Bh=_Bh=_Bh=_Bh=_Bh=_Bg]W@g]W@g]W@g]W@
g]W@g]W@g]W@g]W@gm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[A
gm[Agm[Agm[Agm[Agm[Agm[Agm[Agm[AgMS?gMS?gMS?gMS?gMS?gMS?gMS?gMS?gMS?gMS?gMS?gMS?
gMS?gMS?003DdmG>cLoMg=h];2kMg=iVIFMoOX1?CU2o`/33aLG@d];moomZK6g8bLgGemgBd]SDd]SB
d=KIf=c;b/ja/;;:b/ZVYZIjNWYYJf_De]Jn`<2l_[oLgN7XjNg4a<[Fe]cAd=W<bmCcloWCdmW?d=Al
OH5eMgQ_LG9^KViEEEEWIfM`L71hN7QfMWJb/[;Ng]k7bL[Ph^?@d]=dMWOHf]_4a/LJ71eGFEYGFEY6
B4VATYKOh>@U9B_Bd]SDdmcOg^OGe^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ge^3Ee^3Ee^3Ee^3Ee^3Ee^3E
e^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ee^3Ce=kCe=kCe=kCe=kCe=kCe=kCe=kCe=kGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkGe]oGe]oGe]oHen3Hen3Ge]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oGe]oGe]oGe]oGe]oFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkGe]oGe]oGe]oGe]oGe]oG
e]oGe]oGe]oFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cEeM_EeM_EeM_Fe]cFe]cFe]cGemgGemgHemWHemWHemWHemWHemWH
emWHemWHemWEeM_EeM_EeM_Fe]cFe]cFe]cGemgGemgIemgIemgIemgIemgIemgIemgIemgIemgFe=[G
eM_GeM_He]cHe]cIemgIemgIemgIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[IemgIemgIemgIemgIemgIemgIemgIemgIf=[If=[If=[If=[If=[If=[If=[If=[HemWH
emWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[Hf=SH
f=SHf=SIfMWIfMWIfMWJf][Jf][IfMWIfMWIfMWIfMWIfMWIfMWIfMWIfMWKf=[Kf=[Kf=[Kf=[Kf=[K
f=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Kf=[Jf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SIemOI
emOIemOIemOIemOIemOIemOIemOGemOGemOGemOGemOGemOGemOGemOGemOIemOIemOIemOJf=SJf=SJ
f=SKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SKfMWKfMWKfMWLf][Lf][Jf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOHe]GH
e]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GGeMCGeMCGeMCGeMCHe]GH
e]GHe]GIemKIemKIemKIemKIemKIemKIemKIemKIemKJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OIf=CI
f=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CI
f=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CIf=CHem?H
em?Hem?Hem?If=CIf=CJfMGJfMGKe]?Ke]?Ke]?Ke]?LemCLemCMf=GMf=GIf=CIf=CIf=CIf=CIf=CI
f=CIf=CIf=CHem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?LemCLemCLemCLemCLemCLemCLemCLemCKf=3K
f=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7If]7If]7If]7If]7If]7I
f]7If]7If]7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3LfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7JeloJ
eloJeloJeloKf=3Kf=3Kf=3LfM7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3LfM7LfM7Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];LfM7L
fM7LfM7Mf];Mf];Mf];Nfm?Nfm?Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mfm7Mfm7Mfm7Mfm7Mfm7M
fm7Mfm7Mfm7Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mf];Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Lf]3L
f]3Lf]3Mfm7Mfm7Mfm7Ng=;Ng=;Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Mfm7Ng=;Ng=;Ng=;Ng=;Ng=;N
g=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Ng=;Of]7Of]7Of]7Pfm;Pfm;Pfm;Qg=?Qg=?Pfm;P
fm;Pfm;Pfm;Pfm;Pfm;Pfm;Pfm;NfM3NfM3NfM3NfM3NfM3NfM3NfM3NfM3Of]7Of]7Of]7Of]7Of]7O
f]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Of]7Mf<oM
f<oMf<oMf<oMf<oMf<oMf<oMf<oMf<oMf<oMf<oMf<oMf<oMf<l00=?Be<g<c^OVj9BCUINFV=cKgM;A
dkVh^Wf0O/[=bde?CkBf]]?EeUeNH]3AeMgMhmKDf]kLh^;QiKJe^MWHf]SHf=?CdmcLg6e_KkVk^nGW
imKHfMKGflG6b]_KhM?CfMKEg]?Bfl_;dLk>e<O8c<K7bmGGf<c>cl[:bWIfMX:2PYRHV7IfMTm?CiRH
V=SHf=kPhL32`fMYJ/oAdYFGV9jPXKfo`0000M3Bdl;4aMSIgJNX[:6QYlW9cmcKi=?BfmOFh=OFh=OF
h=OFh=OFh=OFh=OFh=OFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GFh=GF
h=GFh=?Dg]?Dg]?Dg]?Dg]?Dg]?Dg]?Dg]?Dg]OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KE
g]OFgmOFgmOFgmSGh=SGh=OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOF
gmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]OFgmOFgmOFgmOFgmOFgmOFgmOFgmOFgmKFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=GEfmGEfmGE
fmKFg=KFg=KFg=OGgMOGgMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMGEfmGEfmGEfmGEfmKFg=KFg=OG
gMOGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMWGgMKDf]KDf]OEfmOEfmSFg=WGgMWGgMWGgMWHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WGgMWGgMWGgMWGgMWGgMWGgMWG
gMWGgMWHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SHf=SHf=SHf=WIfMWIfMWIfM[Jf][Jf]WIfMWIfMWI
fMWIfMWIfMWIfMWIfMWIfM_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_Hf]_H
f]_Hf][Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWGemWGemWGemWGemOGemOGemOG
emOGemOGemOGemOGemOGemWGemWGemWGemWGem[Hf=[Hf=_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=_IfM_IfM_IfMcJf]cJf][Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGemWGemWGemWGemOEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OE
e=OEe=OEe=OEe=OEe=OEe=KDdmOEe=OEe=OEe=SFeMSFeMSFeMSFeMWGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe][Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WH
e=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WH
e=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=SGdmSGdmSGdmSGdmWHe=WHe=[IeM[IeM_Fdm_Fdm_F
dm_FdmcGe=cGe=gHeMgHeMWHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=OFd]OFd]OFd]OFd]OFd]OFd]OF
d]OFd]cGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[GcmcIdMcIdMcI
dMcIdMcIdMcIdMcIdMcIdMWJdMWJdMWJdMWJdMWJdMWJdMWJdMWJdM[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[G
cm[GcmcIdMcIdMcIdMcIdMcIdMcIdMcIdMcIdMWFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=_Hd=[Gcm[Gcm[G
cm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm_Hd=_Hd=_Hd=_Hd=cIdMcIdMgJ
d]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]gJd]cIdMcIdMcIdMgJd]gJd]gJd]kKdmkKdmgJd]gJd]gJ
d]gJd]gJd]gJd]gJd]gJd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMgJd]gJd]gJd]gJd]gJd]gJd]gJ
d]gJd]gKdMgKdMgKdMgKdMgKdMgKdMgKdMgKdMcJd=cJd=cJd=gKdMgKdMgKdMkLd]kLd]gKdMgKdMgK
dMgKdMgKdMgKdMgKdMgKdMkLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kLd]kL
d]kLd]oJdMoJdMoJdN3Kd^3Kd^3Kd^7Ldn7Ldn3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd^3Kd]kId=kId=kI
d=kId=kId=kId=kId=kId=oJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJ
dMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMoJdMcGc]cGc]cGc]cGc]cGc]cGc]cGc]cGc]cGc]cGc]cG
c]cGc]cGc]cGcP00e=3Fgm_QdLgCfMGK0P04hmoUdloEdLgC00010001[Jb^b<O9UYFG/[6c0@02h=oQ
d];Hh>3VdM7Gfm_QemOMdm?Ifm_QcLgC]kNme]KLbl_Ae=CJdM7GgMgSc<cBh>3Vc/kDf=SNc/kDdM7G
emOMcLgCdM7Gf=SNg]kTGemUemOMhN7Wb<S>g]kTT92Fe=CJg=kO0042][RieMOHhN?TYJNXG5iO4Q@E
H61Ve]KLf][P10@:a/K<jNW_eMGKbLW?dmGMdmGMdmGMe=KNe=KNe=KNeMOOeMOOe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KL
f=KLf=KLf=KLf=KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
f=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KL
f=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLemGKemGKemGKemGKemGKemGKemGKemGKf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
emKHemKHemKHemKHemKHemKHemKHemKHemOGemOGemOGf=SHf=SHf=SHfMWIfMWIf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfmWIfmWIfmWIfmWIfmWIfmWIfmWIfmWI
fMOGfMOGfMOGf]SHf]SHf]SHfmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SGf]SGf]SG
f]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SGg=ODg=ODg=ODg=OD
g=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=OD
g=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCf=OCf=OCf=OCfMSD
fMSDfMSDf]WEf]WEg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WA
gM[BgM[BgM[Bg=WAfmS@fmS@f]O?f]O?gM[BgM[BgM[Bg=WAfmS@fmS@f]O?f]O?g=WAg=WAg=WAg=WA
g=WAg=WAg=WAg=WAfMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WA
fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WA
fMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@g=WAg=WAg=WAg=WAg=WAg=WAg=WAg=WAfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@fmW?fmW?fmW?fmW?
fmW?fmW?fmW?fmW?g=[@g=[@g=[@g=[@g=[@g=[@g=[@g=[@fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?
fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fMO=f]S>f]S>f]S>fmW?fmW?fmW?g=[@gMW>gMW>gMW>gMW>
gMW>gMW>gMW>gMW>fmW>fmW>fmW>fmW>g=[?g=[?gM_@gM_@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@
g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?gm_@gm_@gm_@gm_@
gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@
h=cAh=cAh=cAh=cAh=cAh=cAh=cAh=cAhM_@hM_@hM_@hM_@hM_@hM_@hM_@hM_@g][?g][?g][?g][?
g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?
gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>g][?g][?g][?g][?g][?g][?003MfMo;algBc]CHe=ZZYZb5
PHNJUY`n>T2SXZCMg=jd/kE_KW3:bL_DdmG4`lD0007@d=K2`/SMgN?Gemg@d=KLg>;?cmGOgnG7algO
gnGBd]SGemgBd]SJf^38b<kFe]cEeM_MgN?AdMOAdMOPh>KPh>KHf=k?cmGAdMO7alg>c]C9bLo`l?K@
d=K1`LN`/;H00072a<GBe=Db=3DJ71gEemS:c<fa/k@^;SC>c]B6QXbf][cEeM_=cM?OgnGRh^SCeMgC
eMgCeMgDe]kDe]kDe]kEemoEemoFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkF
eMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkHe]cH
e]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cGeM_G
eM_GeM_GeM_GeM_GeM_GeM_GeM_HemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[HemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWIf=[If=[If=[If=[If=[If=[If=[If=[Ge]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGemOG
emOGemOHf=SHf=SHf=SIfMWIfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SKfMWKfMWKfMWKfMWKfMWKfMWKfMWKfMWIemOIemOIemOJf=SJf=SJf=SKfMWKfMWJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SIemOIemOIemOIemOIemOIemOIemOIemOJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=OJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=OJ
f=OJf=OJf=OJf=OJf=OJf=OJf=OLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCL
emCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCLemCJeM;J
eM;JeM;JeM;JeM;JeM;JeM;JeM;Ge];Hem?Hem?Hem?If=CIf=CIf=CJfMGLemCLemCLemCLemCLemCL
emCLemCLemCLfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7Mf];Mf];LfM7LfM7Kf=3Kf=3JeloJeloMf];M
f];LfM7LfM7Kf=3Kf=3JeloJeloLfM7LfM7LfM7LfM7LfM7LfM7LfM7LfM7Ie/kJeloJeloJeloKf=3K
f=3Kf=3LfM7Ie/kJeloJeloJeloKf=3Kf=3Kf=3LfM7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Ie/kIe/kIe/kIe/kIe/kI
e/kIe/kIe/kIe/kJeloJeloJeloKf=3Kf=3Kf=3LfM7Ie/kJeloJeloJeloKf=3Kf=3Kf=3LfM7Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3LfM7LfM7LfM7LfM7LfM7L
fM7LfM7LfM7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Lf]3Lf]3Lf]3Lf]3Lf]3Lf]3Lf]3Lf]3Lf]3L
f]3Lf]3Lf]3Lf]3Lf]3Lf]3Lf]3KfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoLf]3Lf]3Lf]3Lf]3Lf]3L
f]3Lf]3Lf]3KfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoIelgJ
f<kJf<kJf<kKfLoKfLoKfLoLf]3MfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkKfLkKfLkKfLkKfLkLf/oL
f/oMfm3Mfm3NfM3NfM3NfM3NfM3NfM3NfM3NfM3NfM3Nf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oN
f/oNf/oNf/oNf/oNf/oNf/oNf/oOfm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3O
fm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Pg=7Pg=7Pg=7Pg=7Pg=7Pg=7Pg=7Pg=7Qfm3Q
fm3Qfm3Qfm3Qfm3Qfm3Qfm3Qfm3Nf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oN
f/oNf/oNf/oPf/oPf/oPf/oPf/oPf/oPf/oPf/oPf/oMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkNf/oN
f/oNf/oNf/oNf/oNf/l00=;>e=_GgM_GgMgIgm_GgG5]LlC0a/C0a/c;cJb[[EEDEY>BU=gLg/_:c=[I
fnCSiG1`M]KFg=cLh[fm`mgMhmoOiM3@e];Bf=3@e]cLh/g=dlc<d/c<d]SHg]7AemcLh]GEfmcLh];B
f<O7cM?CfMcLh]KFg=;Bf>?SjMSHg][Jh=_KhLG5bm7Aem[Jh1LG7L?5a[fo`8F7R=kPhJ>UYR/];/O9
b/g?d=;Bf;jna7emPl_;dMSHg]OGgLg=dlk>e=?EgM?EgM?EgMCFg]CFg]CFg]GGgmGGgmKEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SF
g=SFg=SFg=SFg=SFg=SFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=SFg=SFg=SFg=SFg=SFg=SFg=SF
g=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMWHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OGemOGemOGemSHf=SHf=SHf=WIfMWIfM[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=WGemWGemWGem[Hf=[Hf=[Hf=_IfM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGe]WGe]WG
e]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe]WGemWGemWGemWGemWGemWGemWGemWGemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]_Fdm_Fdm_F
dm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_F
dm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm[Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed]OFd]OFd]SG
dmSGdmSGdmWHe=WHe=WHe=_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=cIdMcIdMcIdM_Hd=_Hd=_Hd=[Gcm[GcmcIdMcIdMcIdM_Hd=_Hd=_Hd=[Gcm[Gcm_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=WFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdMWFc][Gcm[Gcm[Gcm_Hd=_Hd=_H
d=cIdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc]WFc][Gcm[Gcm[Gcm_Hd=_Hd=_H
d=cIdMWFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_I
cm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_I
cm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_IcmWGcM[Hc][Hc][Hc]_Icm_Icm_IcmcJd=gIc]gIc]gI
c]gIc]gIc]gIc]gIc]gIc]_Ic]_Ic]_Ic]_Ic]cJcmcJcmgKd=gKd=kId=kId=kId=kId=kId=kId=kI
d=kId=kJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmoKd=oKd=oK
d=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oK
d=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd>7Kd>7Kd>7Kd>7Kd>7Kd>7Kd>7Kd>7Kd=kJcmkJcmkJ
cmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmoIc]oIc]oIc]oIc]oIc]oIc]oI
c]oIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIcP00f]KLe=3FeM7GeM7G
d<cBcLW?`ko5g=SN][FgGeiPg=_M<c8d@D12FeYLQXF7emKHcLgCO7b2g=cRgmoUe]KLiNG[`/;8hn?Y
bl_AeMGKe]KLfm_QgMgShN7We]KLdM7GalO=e=CJhN7WgMgSg]kTf][PcLgCf=SNcLgC_ko5i^K/cloE
gmoUeMGKL71ff=SNd=;C_Ko00001K6i_d]CEX::S>S`m^kfngmoUXJ6We]KLalO=fMWOgmoUbLW?e]KL
dmGMdmGMdmGMe=KNe=KNe=KNeMOOeMOOe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GN
f=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KL
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KL
emGKemGKemGKemGKemGKemGKemGKemGKf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJ
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OI
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIemKHemKHemKHemKHemKHemKHemKHemKH
emOGemOGemOGf=SHf=SHf=SHfMWIfMWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGf]SHf]SHf]SHfmWIfmWI
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOF
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOF
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKC
fmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKCfmKC
f]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBemKBemKBemKBf=OCf=OCf=OCfMSDfMSDfmKCfmKCfmKCfmKC
fmKCfmKCfmKCfmKCfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@f]O?f]O?
fmS@fmS@fmS@fmS@fmS@fmS@f]O?f]O?fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fMK>f]O?f]O?f]O?
fmS@fmS@fmS@g=WAfMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fMK>fMK>fMK>fMK>
fMK>fMK>fMK>fMK>fMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WA
fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?
fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?
fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?
fMO=f]S>f]S>f]S>fmW?fmW?fmW?g=[@gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>fmW>fmW>fmW>fmW>
g=[?g=[?gM_@gM_@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g]W@g][?g][?g][?g][?g][?g][?g][?g][?
g][?g][?g][?g][?g][?g][?g][?g][?gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@
gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@
hM_@hM_@hM_@hM_@hM_@hM_@hM_@hM_@g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?
g][?g][?g][?g][?gmW>gmW>gmW>gmW>gmW>gmW>gmW>gmW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>
gMW>gMW>gMW>gMW>gMW>gMW>003QgN>o^l7Th>K;algIeM_]jNna[K>?Ri7JfM/[:Rb^[Jlg=SRWYZSC
d]CIf=YPGf7<c=;1`LO2`/R`/;K:b]3:b]3De=[2`/SLg>;Fe]cCdmW:b]3:b]3>c]CDe=[=cM?Jf^3>
c]CCdmW;bm7@d=KAdMO7algWingGemgNg^CDe=[MgN>=SI=hN7kIfMn0P8I6B4W9blaHFU]CEEIjO7gN
h>6k_KkXj^^:RY3:b]3Bd]SVi^c=cM?De=[OgnGJf^3CeMgCeMgCeMgDe]kDe]kDe]kEemoEemoFeMkF
eMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkF
eMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cH
e]cHe]cHe]cHe]cHe]cHe]cHe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cHe]cHe]cHe]cHe]cHe]cH
e]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_HemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWIf=[If=[If=[If=[If=[I
f=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[HemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGemOGemOGemOHf=SHf=SHf=SIfMWIfMWJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SIemOIemOIemOJf=SJf=SJf=SKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KH
e]KHe]KHe]KIemOIemOIemOIemOIemOIemOIemOIemOHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]GH
e]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GH
e]GHe]GHe]GHem?Hem?Hem?Hem?Hem?Hem?Hem?Hem?He]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GJeM;J
eM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;J
eM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7FeM7F
eM7Ge];Ge];Ge];Hem?Hem?Hem?JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeloJeloJeloJeloJeloJ
eloJeloJeloJeloJeloJeloJeloJeloJeloKf=3Kf=3JeloJeloJeloJeloJeloJeloKf=3Kf=3JeloJ
eloJeloJeloJeloJeloJeloJeloIe/kJeloJeloJeloKf=3Kf=3Kf=3LfM7Ie/kJeloJeloJeloKf=3K
f=3Kf=3LfM7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Ie/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kJeloJeloJeloKf=3K
f=3Kf=3LfM7Ie/kJeloJeloJeloKf=3Kf=3Kf=3LfM7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3JeloJeloJeloJeloJeloJeloJeloJeloKf=3Kf=3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Jf<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kKfLoK
fLoKfLoKfLoKfLoKfLoKfLoKfLoJf<kJf<kJf<kJf<kJf<kJf<kJf<kJf<kKfLoKfLoKfLoKfLoKfLoK
fLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoIelgJf<kJf<kJf<kKfLoKfLoKfLoLf]3MfLkM
fLkMfLkMfLkMfLkMfLkMfLkMfLkKfLkKfLkKfLkKfLkLf/oLf/oMfm3Mfm3NfM3NfM3NfM3NfM3NfM3N
fM3NfM3NfM3Nf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oOfm3O
fm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3O
fm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Qfm3Qfm3Qfm3Qfm3Qfm3Qfm3Qfm3Qfm3Nf/oN
f/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf<gNf<gNf<gNf<gNf<gN
f<gNf<gNf<gMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkLf<gLf<gLf<gLf<gLf<gLf<d00=GAem7=dm_G
gN3Lh/[6c=KBf=KBf<C0a[fl_/W8bPX92`000M3?dMgLgUACEJf/[WemPd92B<k>e=WIgk>c^K:b^=3@
e^_[lMCDf]3@e^3Pi][Jh=cLh]SHg^;Rj=;Bf>;Rj<k>e=SHg];Bf=oOiNCTj/C4b]OGgM7Aem7AejFU
ZfEUJl[:d<c<d]7Aen?Sj@000KRj^g9dMM3BddmADZJXZOCfmkZl_K6a]o7amkZj`=CDf];Bf=7AemgM
hlg=dm?EgM?EgM?EgMCFg]CFg]CFg]GGgmGGgmKEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KE
g]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KEg]KE
g]KEg]SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=KFg=KFg=KF
g=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=SFg=SFg=SFg=SFg=SFg=SFg=SF
g=SFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KFg=KF
g=KFg=KFg=KFg=KFg=KFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=SF
g=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMOFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WHf]WH
f]WHf]OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=SGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OGemOGemOGemSHf=SHf=SHf=WIfMWIfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGem[Hf=[Hf=[Hf=_I
fM_IfM[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=SFe]SFe]SF
e]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]WGemWGemWGemWGemWGemWGemWG
emWGemSFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSF
eMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMSGdmSGdmSGdmSGdmSGdmSGdmSG
dmSGdmSFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeM[Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][E
d][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][E
d][Ed]WDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMKEdMKEdMKEdMOFd]OFd]OFd]SGdmSGdm[Ed][Ed][E
d][Ed][Ed][Ed][Ed][Ed][Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[GcmWFc]WFc]WFc][Gcm[Gcm[Gcm_H
d=_Hd=WFc]WFc]WFc][Gcm[Gcm[Gcm_Hd=_Hd=[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[Gcm[GcmWFc][Gcm[G
cm[Gcm_Hd=_Hd=_Hd=cIdMWFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_H
d=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=WFc]WFc]WF
c]WFc]WFc]WFc]WFc]WFc]WFc][Gcm[Gcm[Gcm_Hd=_Hd=_Hd=cIdMWFc][Gcm[Gcm[Gcm_Hd=_Hd=_H
d=cIdM_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=[Gcm[Gcm[G
cm[Gcm[Gcm[Gcm[Gcm[Gcm_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=_Hd=[Hc][Hc][Hc][Hc][Hc][Hc][H
c][Hc][Hc][Hc][Hc][Hc][Hc][Hc][Hc][Hc]_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm[Hc][Hc][H
c][Hc][Hc][Hc][Hc][Hc]_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_Icm_I
cm_IcmWGcM[Hc][Hc][Hc]_Icm_Icm_IcmcJd=gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]_Ic]_Ic]_I
c]_Ic]cJcmcJcmgKd=gKd=kId=kId=kId=kId=kId=kId=kId=kId=kJcmkJcmkJcmkJcmkJcmkJcmkJ
cmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmoKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oK
d=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=oKd=kJcmkJcmkJcmkJcmkJcmkJcmkJ
cmkJcn7Kd>7Kd>7Kd>7Kd>7Kd>7Kd>7Kd>7Kd=kJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJ
cmkJcmkJcmkJcmkJcmkJcmkHcMkHcMkHcMkHcMkHcMkHcMkHcMkHcMgIc]gIc]gIc]gIc]gIc]gIc]gI
c]gIc]cHcMcHcMcHcMcHcMcHcMcHc@00dLgChMgS^kNmi^;Xd<cBgm_Qd/kDbLG;e=?Efm[L`L32hN3R
gmkPEEAFF5MIemKH`L77cLgCVi^QGUiT[jnealO=/k>iBTY@]KFk/k>idm?Id=3Fe=CJcLgCgMgSbLW?
b<S>c<cBiNG[bl_AcLgCfMWO/[:h^KVoIFE[Rh^AgMgS][JlXJ6Wh>3V^k_1MGEkYjVZ0@<44Q@E_l72
dmGFXJ>Tc<k?bL_<^k_1eMGKh^;Xf=SNi>CZe=CJcloEfm_QdmGMdmGMdmGMe=KNe=KNe=KNeMOOeMOO
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GN
e]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNe]GNf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KL
f=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KL
e]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLe]KLf=KLf=KLf=KLf=KL
f=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLemGKemGKemGKemGKemGKemGKemGKemGK
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIemKHemKHemKHemKHemKHemKHemKHemKHfMSJfMSJfMSJfMSJ
fMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJfMSJemKHemKHemKHemKHemKHemKHemKHemKH
f=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIemKHemKHemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemOGemOGemOGf=SHf=SHf=SHfMWIfMWI
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGf]SHf]SHf]SHfmWIfmWIf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SH
f]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KF
f=KFf=KFf=KFf=KFfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KF
f=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KE
f=KEf=KEf=KEf=KEf=SBf=SBf=SBf=SBf=SBf=SBf=SBf=SBf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KE
fMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCA
fMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAf=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@
eMC@e]GAe]GAe]GAemKBemKBemKBf=OCfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMK>fMK>fMK>fMK>
fMK>fMK>fMK>fMK>f=G=f=G=fMK>fMK>f]O?f]O?fmS@fmS@f=G=f=G=fMK>fMK>f]O?f]O?fmS@fmS@
fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfMK>f]O?f]O?f]O?
fmS@fmS@fmS@g=WAfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>f]O?f]O?f]O?
fmS@fmS@fmS@g=WAfMK>f]O?f]O?f]O?fmS@fmS@fmS@g=WAfmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fmS@fmS@fmS@fmS@fMK>fMK>fMK>fMK>fMK>fMK>fMK>fMK>fmS@fmS@fmS@fmS@
fmS@fmS@fmS@fmS@fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=
fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fmW?fmW?fmW?fmW?
fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fmW?fMO=f]S>f]S>f]S>fmW?fmW?fmW?g=[@
gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>fmW>fmW>fmW>fmW>g=[?g=[?gM_@gM_@g]W@g]W@g]W@g]W@
g]W@g]W@g]W@g]W@g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?
gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@gm_@
gm_@gm_@gm_@gm_@g][?g][?g][?g][?g][?g][?g][?g][?hM_@hM_@hM_@hM_@hM_@hM_@hM_@hM_@
g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?gMO<gMO<gMO<gMO<
gMO<gMO<gMO<gMO<gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>fmO<fmO<fmO<fmO<fmO<fmO<003;algP
g>;He=[8a<[Lf=kGdmW=bLoLf=kCd]Bf]KOGe]S?c]2JVI]6ADNn_KmYJ6YiNGoGemfl_<851@/000@f
=Sb^[[CQhNO9bLnATIMZJW0_;cD_;cEIFEne]K_De=[>c]C0`<JRXZPi>ClS8bUZJW2DU9[Bd]SHf=kE
eM_Bd]Rm_L=bLWRn_/@l?4::RY3Hf]]JG5d00074a/ORi>G;cLjb];GNh>7Fe]cOgnG9bLoJf^3=cM?H
f=kDe=[Fe]cCeMgCeMgCeMgDe]kDe]kDe]kEemoEemoFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkF
eMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkFeMkF
eMkFeMkFeMkHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cHe]cHe]cHe]cHe]cHe]cH
e]cHe]cHe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cFe]cF
e]cFe]cFe]cFe]cFe]cFe]cFe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cH
e]cHe]cHe]cGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_HemWHemWHemWHemWHemWHemWHemWHemWGe]SG
e]SGe]SGe]SGe]SGe]SGe]SGe]SIf=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[If=[I
f=[If=[If=[Ge]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SHemWHemWHemWHemWHemWHemWHemWHemWHemWH
emWHemWHemWHemWHemWHemWHemWGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SGemOGemOGemOHf=SHf=SHf=SIfMWIfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJ
f=SJf=SJf=SJf=SJf=SJf=SJf=SIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOJf=SJf=SJ
f=SKfMWKfMWJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SJf=SGeMGG
eMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGIemOIemOIemOIemOIemOI
emOIemOIemOGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCG
eMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGem7Gem7Gem7Gem7Gem7G
em7Gem7Gem7GeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCIe=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7I
e=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7I
e=7Ie=7Ie=7Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Ee=3Ee=3FeM7FeM7FeM7Ge];Ge];Ge];Ie=7I
e=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kHeLgHeLgHeLgIe/kJeloJ
eloKf=3Kf=3HeLgHeLgHeLgIe/kJeloJeloKf=3Kf=3Ie/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kJ
eloJeloJeloKf=3Kf=3Kf=3LfM7Ie/kJeloJeloJeloKf=3Kf=3Kf=3LfM7Kf=3Kf=3Kf=3Kf=3Kf=3K
f=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Ie/kI
e/kIe/kIe/kIe/kIe/kIe/kIe/kIe/kJeloJeloJeloKf=3Kf=3Kf=3LfM7Ie/kJeloJeloJeloKf=3K
f=3Kf=3LfM7Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Ie/kI
e/kIe/kIe/kIe/kIe/kIe/kIe/kKf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3Kf=3IelgIelgIelgIelgIelgI
elgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoIelgI
elgIelgIelgIelgIelgIelgIelgKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoKfLoK
fLoKfLoKfLoIelgJf<kJf<kJf<kKfLoKfLoKfLoLf]3MfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkKfLkK
fLkKfLkKfLkLf/oLf/oMfm3Mfm3NfM3NfM3NfM3NfM3NfM3NfM3NfM3NfM3Nf/oNf/oNf/oNf/oNf/oN
f/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oOfm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3O
fm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Ofm3Nf/oNf/oNf/oNf/oNf/oN
f/oNf/oNf/oQfm3Qfm3Qfm3Qfm3Qfm3Qfm3Qfm3Qfm3Nf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oNf/oN
f/oNf/oNf/oNf/oNf/oNf/oNf/oMelcMelcMelcMelcMelcMelcMelcMelcMfLkMfLkMfLkMfLkMfLkM
fLkMfLkMfLkKelcKelcKelcKelcKelcKel`00=C@e]C@e]C@e]C@e]C@e]C@e]C@e]C@e]3?dNGTi[2_
/HV8R^;QhhJ5QdI5Am;AdmGDe]?Be5]JG:^Z[>3OhE]JG6i]KmoNh<o>d=;Adm;AdmGDe];Adm3?dF1O
HFYYJg=bM4e<CYVHV]KEelW8b/;1`lk=cmGDe];AdeEDE/g<cRDT9W=bM<?2a=[IfmoNh=SHg/o?eMCD
f];Bf96AUkJf_=GEfm?CfMCDf]CDf]CDf]CDf]CDf]CDf]CDf]CDf]GEfmGEfmCDf]CDf]?CfM?CfM;B
f=;Bf=GEfmGEfmGEfmGEfmGEfmGEfmGEfmGEfmCDf]CDf]CDf]CDf]CDf]CDf]CDf]CDf]CCg=CCg=CC
g=CCg=CCg=CCg=CCg=CCg=GEfmGEfmGEfmGEfmGEfmGEfmGEfmGEfmKDf]KDf]KDf]KDf]OEfmOEfmSF
g=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSFg=SFg=SF
g=SFg=SFg=SFg=SFg=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSGfMSGfMSG
fMSGfMSGfMSGfMSGfMSGfMOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=WFf=WFf=WFf=WFf=WFf=WFf=WFf=WFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=[Hf=[Hf=[H
f=[Hf=[Hf=[Hf=[Hf=[Hf=WGemWGemWGemWGemWGemWGemWGemWGem[Hf=[Hf=[Hf=[Hf=[Hf=[Hf=[H
f=[Hf=WGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemSFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]WGemWGemWGemWGemWGemWGemWG
emWGem[Hem[Hem[Hem[Hem[Hem[Hem[Hem[HemWGe]WGe]WGe]WGe]WGe]WGe]WGe]WGe]_FeM_FeM_F
eM_FeM_FeM_FeM_FeM_FeMWGemWGemWGemWGemWGemWGemWGemWGem_FeM_FeM_FeM_FeM_FeM_FeM_F
eM_FeMcGe=cGe=cGe=cGe=cGe=cGe=cGe=cGe=_FeM_FeM_FeM_FeM_FeM_FeM_FeM_FeMSAe=WBeM[C
e]_Dem_Dem[Ce]WBeMWBeMWHe=_He=[Gdm_Fdm_FdmkGe>7HeN7HeN3Kf=gHeM_Fdm_Fdm_Fdm_FdmWD
dMOBcmKDe=[FeM[FeMWEe=[Ed]cGe=gIe=kHdn?LfMcEd]OBcmcGe=_He=KCcmGBc]OFd][Gdm[Gdm[G
dmWFd]WFd]SEdMSEdMSEdMOBdm_FemgHfMcGf=OBdmC?d=G@dMSCe=CBdMGCd]OCd]OCd]WDdmcDe=cD
e=kDe=OBcmOBcmSCd=WDdM[Ed]_Fdm_FdmcGe=KDb]GBb]ODc=[Hd=gJeMWIdmOFd]SGdm?@bm?@bm?@
bmGBc]SDdmWEe=OBdmKAd]cEf]C=d]7:cmSAe=_Ee]SBdmOBdM_FeM?EbM?EbMCFb];CbM7BbM;Cb]GE
cmSHd][FdMC@bm??b]WEd=cHdmWEd=WEd=gIe=[Cd=SAc]SAc]_DdMoHeMkGe=[Cd=G>bmKCcmKCcmKC
cmODd=SEdM[Gdm_He=cIeMgHcmcGc][Ec=WDbm_FcMcGc]cGc]_FcMoLc]kKcMcIbm_Gc=_FcMcGc]cF
cmgGd=WGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWG
cMWGcMWGcMWGcMWGcMWGcMWDbmWDbm[Ec=[Ec=[Ec=_FcM_FcM_FcMgHcmgHcmcGc]cGc]_FcM_FcM[E
c=[Ec=_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM[Ec=[Ec=[E
c=[Ec=[Ec=[Ec=[Ec=[Ec=_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_F
cM_FcM[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=gHcmgHcmgHcmgHcmgHcmgHcmgHcmgHcm[Fbm[Fbm[F
bm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm_Gc=_Gc=_Gc=cHcMcHcMcHcMgIc]_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_G
c=_Gc=SGcMSGcMWGcMWGcM_FcMgFcMgFcMgFcM[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm_Gc=_Gc=_G
c=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=gIc]gIc]gIc]gIc]gIc]gIc]gI
c]gIc][Fbm[Fbm_Gc=_Gc=cHcMcHcMcHcMcHcMgIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]kJcmkJcmkJ
cmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcmkJcn3JcN3JcN3JcN3JcN3JcN3JcN3J
cN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3J
cn3Jcn3Jcn3Jcn3Jcn3JcmoIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc>3JcN3JcN3JcN3JcN3JcN3JcN3J
cN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcMoIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oI
c=oIc=oIc=oIc=oIc=oIc=cFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMgGb]gGb]gGb]gGb]gGb]gGbP00
e=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3Fc/g?gMcN`/73h=oQViZL`l;4UIBFJ6MYf=OIa/G7Shj@NgYl
YZFWe]GGh=oQR8N9h=oQg=_M0P43`;o1j^W[c/g?g=_MdM3Be=?Ed]7Cg=_Mf=OI<C0b<2la@d94=SDg
`/73Y:>UBDQ:00014a8D?SdocLc>d]7CdM7Gdm?IemOMHF5W][Jld=3FdM7Ge=CJe=CJe=CJe=CJe=CJ
e=CJe=CJe=CJe=CJeMGKeMGKe=CJe=CJdm?Idm?Id];Hd];HeMGKeMGKeMGKeMGKeMGKeMGKeMGKeMGK
e=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=?Le=?Le=?Le=?Le=?Le=?Le=?Le=?LeMGKeMGKeMGKeMGK
eMGKeMGKeMGKeMGKe]CJe]CJe]CJe]CJemGKemGKf=KLf=KLemGKemGKemGKemGKemGKemGKemGKemGK
emGKemGKemGKemGKemGKemGKemGKemGKf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLemGKemGKemGKemGK
emGKemGKemGKemGKemKHemKHemKHemKHemKHemKHemKHemKHemGKemGKemGKemGKemGKemGKemGKemGK
emGKemGKemGKemGKemGKemGKemGKemGKf=OIf=OIf=OIf=OIf=OIf=OIf=OIf=OIemKHemKHemKHemKH
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHfMKHfMKHfMKHfMKHfMKHfMKHfMKHfMKH
emKHemKHemKHemKHemKHemKHemKHemKHf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGf]SHf]SHf]SHf]SHf]SHf]SHf]SHf]SHfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGf=KFf=KFf=KFf=KF
f=KFf=KFf=KFf=KFfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGf]SGf]SGf]SGf]SGf]SGf]SGf]SGf]SG
fMOFfMOFfMOFfMOFfMOFfMOFfMOFfMOFfmKEfmKEfmKEfmKEfmKEfmKEfmKEfmKEfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfmKEfmKEfmKEfmKEfmKEfmKEfmKEfmKEg=ODg=ODg=ODg=ODg=ODg=ODg=ODg=OD
f]GDf]GDf]GDf]GDf]GDf]GDf]GDf]GDg=KGg=KGg=KGfmGFfmGFf]CEf]CEfM?De=GAdmC@e=??eM;>
eM;>eM3=eM3=e/o<e=7=e=7=e=7=e]??f]OCg=WEg=WEg=WEf=CCfMGDfMKBe]??eM3=e]7>f=C?fMG@
f=G@dm3;dm3;f=G@f]OBeMG?eMG?f][De=7<eM;=e]?>f=G@f]OBfmSCgM[EgM[Ee]??f=GAfmSDg=WE
g=WEgM[Fg]_GgmcHg=WDg=WDfmSCfmOBg=KAfmG@g=??g=??f=K<f=K<emG;eM?9dm77d]36dLo5d<k4
fmW>iN?HgM_Aclk4d]77eMC:clk4c<[2fM_8emS8e=G5d];4d=32c<c0b<Rla<>i`l2h`Kne`Kne`;jc
]kFZ[:^MZZZJ[jnO[JfM/k>S_;^]a/Fgclg2e=;8emG;emG;gmgCf]S>f]S>gM_Ag=[@emG;e]C:fmW?
h=[CfmG>eLo8d/c5eLo8f]C=gmWBh]cEgM[EfmSCfMKAe]?>eM;=e=7<eM;=eM;=e<k7e]39f]C=g]SA
h]cEhmgFh]cEh=[Ce];7em?8f=?:f]G<fmG>g=KAg=KAg=KAfMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=
fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMO=fMC;fMC;f]G<f]G<
f]G<fmK=fmK=fmK=gMS?g=O>g=O>g=O>fmK=f]G<f]G<f]G<fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=
fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<fmK=fmK=fmK=fmK=
fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=fmK=f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<
g=O>g=O>g=O>g=O>g=O>g=O>g=O>g=O>f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;fmO<fmO<
fmO<g=S=g=S=g=S=fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<f=O=f=O=fMO=fMO=fmK=gMK=gMK=gMK=
f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<
fmO<fmO<fmO<fmO<g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=f]K;f]K;fmO<fmO<g=S=g=S=g=S=g=S=
gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?g][?
g][?g][?g][?g][?h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=
h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?gmW<gmW<gmW<gmW<
gmW<gmW<gmW<gmW<h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=
g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g=K9g=K9g=K9g=K9
g=K9g=K9g=K9g=K9gMO:gMO:gMO:gMO:gMO:gMO:003Dd=KDd=KDd=KDd=KDd=KDd=KDd=KDd=KGe]S=
c<kSh^CPgn7DdmENGEoLfmgRhN?JfM/g=SR9R8[Ge]Rm_;jWYZS1`<:TXjDm?3k5a<H;2PcCd]C>cLoN
gMmoOX0D4aDM71h20@<o?T2o_/00006XYjWKf]bTXjEMG5kJfM/30PA3@TBIV9X0007:bL_Yj>[De=[C
dmTK6b6b/[SQhNO<c=;>c]CMgN?De=[De=[De=[De=[De=[De=[De=[De=[De=[De=[De=[De=[CdmWC
dmWCdmWCdmWEeM_EeM_EeM_EeM_EeM_EeM_EeM_EeM_De=[De=[De=[De=[De=[De=[De=[De=[DdmcD
dmcDdmcDdmcDdmcDdmcDdmcDdmcEeM_EeM_EeM_EeM_EeM_EeM_EeM_EeM_Fe=[Fe=[Fe=[Fe=[GeM_G
eM_He]cHe]cGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_He]cH
e]cHe]cHe]cHe]cHe]cHe]cHe]cGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_Ge]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SGeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_Ge]SG
e]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SIe]SIe]SIe]SIe]SIe]SIe]SIe]SIe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SIemOI
emOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOI
emOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOHe]KH
e]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KH
e]KHe]KHe]KIemKIemKIemKIemKIemKIemKIemKIemKHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GKe]GK
e]GKe]GKe]GKe]GKe]GKe]GKe]GHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KKe]GKe]GKe]GKe]GKe]GK
e]GKe]GKe]GKe]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;Gd]7G
d]7Gd]7Gd]7Gd]7Hdm;Ie=?JeMC<clg>dLoCe=;FemGKfMSOfm[QgMcQgMcMfm[KfMSIemKHe]GIemKH
e]GFe=?Dd]7Je]7IeM3IeM3Je]7Jem;LfMCNfmKOg=OLgM?If]3HfLoKg=;Jfm7FelgFelgIf]3Lf]3K
fLoJf<kHe/cFe<[EdlWCdLOCdLOIelcGeL[Dd/OCdLKAclC>c<7:b;g7aK[>cKo=c;k;b[c:akW:a;O7
`KC7_k;6_[6l^JZk^:Vh]JJd/J:`[Ij/ZIZYYYNXYIJ=S7jNWHn9R7Y`Kf5kNVb3Pg=gMfMdM6A^LEM[
KUAVJE1QI4]LGTQFEd=@DCe;C3Q6B398BSA:C3I5B2lk?R@g>R13AbYBESUJET=FDSmEDCiKEdEZIEIj
MFJ7PGB=QgZZZI^^[Ing]ZS1`;;7a[S:bK_BdL?JfL_EdLKHe<WLf<gNf/oMfLkJe/_IeL[He<WEdlWE
dlWFe<[He/cJf<kNg=;QgmGShMOMem;Le]7KeM3IdlkFd<_CcLSAblK?bLCIe<_JeLcLe/oMem;Mem;K
e=7Id/oHd=3IelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgIelgI
elgIelgIelgIelgIelgIelgIelgIe<_Ie<_JeLcJeLcJeLcKe/gKe/gKe/gLelkLelkKe/gKe/gKe/gJ
eLcJeLcJeLcKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gJeLcJ
eLcJeLcJeLcJeLcJeLcJeLcJeLcKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gKe/gK
e/gKe/gKe/gJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJe/_J
e/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_KelcKelcLf<gLf<gLf<gKelcKelcKelcKelcKelcK
elcKelcKelcHelgHelgIelgIelgKe/gMe/gMe/gMe/gJe/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_KelcK
elcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcLf<gLf<gLf<gLf<gLf<gL
f<gLf<gLf<gJe/_Je/_KelcKelcLf<gLf<gLf<gLf<gMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkM
fLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkOfLcOfLcOfLcOfLcOfLcO
fLcOfLcOfLcPf/gPf/gPf/gPf/gPf/gPf/gPf/gPf/gPf/oPf/oPf/oPf/oPf/oPf/oPf/oPf/oOfLkO
fLkOfLkOfLkOfLkOfLkOfLkOfLkOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcO
fLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcOfLcNf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_N
f<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Le/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WMel[Mel[Mel[Mel[Mel[M
elX00=C@e]C@e]C@e]C@e]C@e]C@e]C@e]C@e]SGfM7@d/[9bmCCeM7@d^GTiT=2A6=RI<K5amcKgHN6
R0000H60P]kMglk=cnWXj/[9bl[9b`@31Jf/[ZFTY^CSiHJ5Qk2_/MSGfM3?dB/Z;;fl_U=BE;Rg^M7@
d];AdadL7]gLgYfLWS@c=A/J79VHV]oNh;nn`6EUJ`001;Jf_<k>e=?CfMcLh]gMhlW9cmCDf]CDf]CD
f]CDf]CDf]CDf]CDf]CDf]CDf]CDf]CDf]CDf]?CfM?CfM?CfM?CfMGEfmGEfmGEfmGEfmGEfmGEfmGE
fmGEfmCDf]CDf]CDf]CDf]CDf]CDf]CDf]CDf]CCg=CCg=CCg=CCg=CCg=CCg=CCg=CCg=GEfmGEfmGE
fmGEfmGEfmGEfmGEfmGEfmKDf]KDf]KDf]KDf]OEfmOEfmSFg=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOE
fmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmSFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=OEfmOEfmOE
fmOEfmOEfmOEfmOEfmOEfmOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OEfmOEfmOEfmOEfmOEfmOEfmOE
fmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=WFf=WFf=WFf=WFf=WFf=WFf=WF
f=WFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=WGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWG
emWGemWGemWGemWGemWGemWGemWGemWGemWGemSFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SF
e]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]WGe]WGe]WGe]WGe]WGe]WGe]WG
e]WGe]SFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeM_FeM_FeM_FeM_FeM_FeM_FeM_FeM_FeMSFeMSFeMSF
eMSFeMSFeMSFeMSFeMSFeM_FeM_FeM_FeM_FeM_FeM_FeM_FeM_FeM_Fdm_Fdm_Fdm_Fdm_Fdm_Fdm_F
dm_Fdm[Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed^7LfMoJemkIe]cGe=cGe=cGe=cGe=gHeM7Gd]7Gd]?G
d]CEdM?Dd=?Bc]3?bm7>b];AcM7@c=;AcMCCcmSGdm[IeM[IeMWHe=gHcmGCbM7?aMGCbMKDc=;@b<_8
`lC4_/O;_lK:_/C8_<C6^[k0];Vk[kVi[KVi[KBaXk>`X[2]WjbYVjRUUjBQTj:OTJ2MSiNFPY:AOHb;
MhV8M8N6LX:1KG]jIWEdH6YYE6UXDfUVDFISCVEPBfAMBF9KAf5JAUUD?eQC?UE@>e9=>4i9=4]6<DQ3
;TM2;DM8>4Y;>bl_7B4Q3c/j9T0o:c8a7CLd7cm2:C`n:3Tk9CHg8c<d82l_7BXZ6RHV5RHW4bDW4B8T
3QdP1ahQ1bha5d]?<V=WBVQTC5mK@eMC>eMB?F5KB6eWE7A]G7I_GUQHAV9RD75aGgalJX>3LHZ:N9BD
PYjNS;ZhY/;0[/g;^M?A_mCB`=;@_];@_]?A_n3NdmoMd]kLdM_Ic]OEb]?Aa/o=`/c:_mcFdM_Ed=SB
cMK@bmK@bmWCc]oIe>CNfMWCc=WCc=[Dcm[Dcm[Cd=_Cdm[Bd][Bd]WGcMWGcMWGcMWGcMWGcMWGcMWG
cMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWGcMWDbmWDbm[E
c=[Ec=[Ec=_FcM_FcM_FcM_FcM_FcM_FcM_FcM[Ec=[Ec=[Ec=[Ec=_FcM_FcM_FcM_FcM_FcM_FcM_F
cM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=_FcM_FcM_F
cM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM_FcM[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[E
c=[Ec=WDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[FbmWEb][Fbm[F
bm[Fbm_Gc=_Gc=_Gc=cHcM_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=SGcMSGcMWGcMWGcM_FcMgFcMgF
cMgFcM[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_G
c=_Gc=_Gc=_Gc=_Gc=_Gc=cHcMcHcMcHcMcHcMcHcMcHcMcHcMcHcM[Fbm[Fbm_Gc=_Gc=cHcMcHcMcH
cMcHcMgIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gIc]gI
c]gIc]gIc]gIc]gIc]gIc]oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc>3JcN3JcN3JcN3JcN3JcN3JcN3J
cN3JcN3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3JcmoIc]oIc]oIc]oIc]oIc]oIc]oIc]oIc]oIc=oIc=oI
c=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oI
c=oIc=kHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmcFbMcFbMcF
bMcFbMcFbMcFbMcFbMcFbMgGb]gGb]gGb]gGb]gGb]gGbP00e=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3F
aLC6iNCViNCV`;o1f=OIe]GGgmkP_KbnIFAVEEAFclk@jNSZd<oA]kJhi>?Ub/W;eMCF/K2b0001QXF7
X9nQ]kJhSXf?[jj`d]7ChN3R:BPZh=oQd<oAIFAVfMSJd]7CLW5c/k:dhn;TCDa>^[Vkbl[<E5=E4Q4C
Ti>IiNG[i>CZc<cB`l?9gMgSa/K<hN7We=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJdm?Idm?Idm?Idm?I
e=CJe=CJe=CJe=CJeMGKeMGKeMGKeMGKeMGKeMGKeMGKeMGKe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJ
e=?Le=?Le=?Le=?Le=?Le=?Le=?Le=?LeMGKeMGKeMGKeMGKeMGKeMGKeMGKeMGKe]CJe]CJe]CJe]CJ
emGKemGKf=KLf=KLemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGK
f=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KLemGKemGKemGKemGKemGKemGKemGKemGKemKHemKHemKHemKH
emKHemKHemKHemKHemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGK
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKH
emKHemKHemKHemKHfMKHfMKHfMKHfMKHfMKHfMKHfMKHfMKHemKHemKHemKHemKHemKHemKHemKHemKH
f=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGf=KFf=KFf=KFf=KF
f=KFf=KFf=KFf=KFfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOG
emGEemGEemGEemGEemGEemGEemGEemGEf=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFemGEemGEemGEemGE
emGEemGEemGEemGEf=KEf=KEf=KEf=KEf=KEf=KEf=KEf=KEemGDemGDemGDemGDemGDemGDemGDemGD
fmKEfmKEfmKEfmKEfmKEfmKEfmKEfmKEemKBemKBemKBemKBemKBemKBemKBemKBfmKEfmKEfmKEfmKE
fmKEfmKEfmKEfmKEf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBfMG@fMG@fMG@fMG@fMG@fMG@fMG@fMG@
fmOBf]KAfMG@em?>e];=eM7<eM7<eM7<dmS?e=W@e]W@e]W@f=W@f]S@fMO?fMO?gM_Cf=K>dLo7b/S0
`l6i_;Zb]K>[/:jVX9^<TXn0RXMiRhUnRHQnNGYaIFIMEeUCC58oCeE2DeM4DUA1CdlmCDdkCT`jCD/i
C4HcC4HcBdDbBT@aBD<`B48_B48_Ad4^B4@/AT8ZA40XAd<[BdL_C4P`BDD]AD4YB4L[B4L[BDHZB4@X
Ad<WB44VAd0UB3lTAd8YAd8YAT4XAD0W@chU@SdT@C`S@C`S>c`/9BHF3@d06QT5>CHQ=S<N:bL?=C4I
:bPJ:RLI:2@I:2<J:2<J9R0I8adF81XE7Q`A6QP=518751<5820@>CTYEUI4JFUGI617IV99JVI>LFeE
M6mJKVQEH5Y7DddjDeA0G5e9IFIBIVMCHfA@HV=?IFIBJ6UEGUe9I6=?KVeINgYVS8]gXZ6=^[VUb/Ve
aL>abLNed<jlemG3fmW7gM_9gM_9gM_9fmK=fmK=fmK=f=?:eM37eM37f=?:fmK=f=?:em;9e]39e]3;
f=;=fmCAgMKCgmOGf=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<
f=K<f=K<f=K<f=K<f=K<f=K<f=K<f=K<fMC;fMC;f]G<f]G<f]G<fmK=fmK=fmK=f]G<f]G<f]G<f]G<
f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<
f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<
f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;
f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;fMG:fMG:fMG:f]K;f]K;fmO<fmO<fmO<f]K;f]K;f]K;f]K;
f]K;f]K;f]K;f]K;emK<emK<f=K<f=K<f]G<g=G<g=G<g=G<f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;
fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<
fmO<fmO<fmO<fmO<f]K;f]K;fmO<fmO<g=S=g=S=g=S=g=S=gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>
g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=g=S=g]S;g]S;g]S;g]S;
g]S;g]S;g]S;g]S;h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[=h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?
g]S=g]S=g]S=g]S=g]S=g]S=g]S=g]S=gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<g]S;g]S;g]S;g]S;
g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:
gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9
g=K9g=K9003Dd=KDd=KDd=KDd=KDd=KDd=KDd=KDd=KNgMo:bL_BdM?LfmgMg=k?c]3@cm7Og^3HemW=
c<ibLG<e=3JSXZC?c]3If=[Ge]SDdmEoOX00005KFUbk^[cKf]b`[k6HUiVLVida<39OGV38alW7a/Q=
C4kThnGLfmfd/kGIf=[?c]2AT98b<C<[:RbOWZ3<blfo_lGEeM^i^KoIfMoVi^cEeM_Ng^C0`<KDe=[D
e=[De=[De=[De=[De=[De=[De=[CdmWCdmWCdmWCdmWDe=[De=[De=[De=[EeM_EeM_EeM_EeM_EeM_E
eM_EeM_EeM_De=[De=[De=[De=[De=[De=[De=[De=[DdmcDdmcDdmcDdmcDdmcDdmcDdmcDdmcEeM_E
eM_EeM_EeM_EeM_EeM_EeM_EeM_Fe=[Fe=[Fe=[Fe=[GeM_GeM_He]cHe]cGeM_GeM_GeM_GeM_GeM_G
eM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_He]cHe]cHe]cHe]cHe]cHe]cHe]cHe]cGeM_G
eM_GeM_GeM_GeM_GeM_GeM_GeM_Ge]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGeM_GeM_GeM_GeM_GeM_G
eM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_GeM_FeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOGe]SG
e]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SIe]SIe]SIe]SIe]SIe]SI
e]SIe]SIe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SGe]SHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KIemOI
emOIemOIemOIemOIemOIemOIemOHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KIemOIemOIemOIemOIemOI
emOIemOIemOIemOIemOIemOIemOIemOIemOIemOIemOGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGHe]KH
e]KHe]KHe]KHe]KHe]KHe]KHe]KGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGHe]GHe]GHe]GHe]GHe]GH
e]GHe]GHe]GGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCKe]GKe]GKe]GKe]GKe]GKe]GKe]GKe]GGe];G
e];Ge];Ge];Ge];Ge];Ge];Ge];Ke]GKe]GKe]GKe]GKe]GKe]GKe]GKe]GJeM;JeM;JeM;JeM;JeM;J
eM;JeM;JeM;IeM3IeM3IeM3IeM3IeM3IeM3IeM3IeM3BclOCd<SFdl_Ie/kLfM7Mf];Nfm?Nfm?Ce/O?
d/?;bkg4a;Jn_Jnj]jVf/jFd/J>BS7n:Q7MnN6]_JEaQFdiBC3m6@3<n>2]=AcA1?BXl>RPo?bll?30X
:AlE60l;40LP9A0[;ATc=20f=B4h=250>BI6?2Y7?B]9A2]8@bY7@RU5@2M3?RE2?BA1?2=0>b8i=ATi
=ATk=a/o>am4@2A7@bM7@bM6@RI3@B=4@2=4@2=6@2=8@2=8@2=:?b=:?b=4?B94?B94?B95?R=5?R=6
?bA6?bA7@2Dg>BdC4`D:2P0X9Q@k=b@g<1`d;1Dj<aX`:B0_:1l]9Qd^9Ql^9B4^9B4[8QlX7a`L61<M
6A@N6a<V8a/j>2iDDTMVI5U]Jf1/JU9_KEEeLe]lNFAnNVMiMF9]JEMTH4iZJUQdM69kNfUjNVQhN6Ig
MfEfMVAdM69gMV9cLUi[JUIPGd]EE41=C3Q;BSI:BCE[IeAdL5f3OfbGTh2ZYY>j]Z?5`Jk;akC5`[C=
b[cGe<KKf<[JelWGe<KFdlGFdlGThM?Rgm7Ofm3LelkJeLcIdlcIdlcIdlkHe/cHe/cHe/cHe/cHe/cH
e/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cHe/cIe<_I
e<_JeLcJeLcJeLcKe/gKe/gKe/gIe<_Ie<_Ie<_Ie<_JeLcJeLcJeLcKe/gJeLcJeLcJeLcJeLcJeLcJ
eLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJ
eLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJeLcJ
eLcJeLcJeLcIe<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Je/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_IeL[I
eL[IeL[IeL[Je/_Je/_Je/_KelcJe/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_Ge/cGe/cHe/cHe/cJeLcL
eLcLeLcLeLcJe/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_KelcKelcKelcKelcKelcKelcKelcKelcKelcK
elcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcKelcJe/_Je/_KelcKelcLf<gL
f<gLf<gLf<gMfLkMfLkMfLkMfLkMfLkMfLkMfLkMfLkLf<gLf<gLf<gLf<gLf<gLf<gLf<gLf<gLf<gL
f<gLf<gLf<gLf<gLf<gLf<gLf<gNf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Pf/gPf/gPf/gPf/gPf/gP
f/gPf/gPf/gPf/oPf/oPf/oPf/oPf/oPf/oPf/oPf/oNf<gNf<gNf<gNf<gNf<gNf<gNf<gNf<gOfLcO
fLcOfLcOfLcOfLcOfLcOfLcOfLcNf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_N
f<_Nf<_Nf<_Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Le/WL
e/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/T00=C@e]C@e]C@e]C@e]C@e]C@e]C@
e]C@e/?2a?Gdm[jm_mSGfMgLg/[9bm_Jg=OFf=OFf<_:c=gLg/_:c96@TUaKGHB3QLW8b/[9bnSWjMOF
f5MFF4m>D<?2a=CCeLW8bZ:QXeUHF]cKgMcKgOCcmLC3aKJe]mgLg/[9bgAcMG=bM5iMGlc;cM?Be=GD
e^KUimWIgn_[lNGUjlO7cM3@e/[:d=_KhM[Jh=CDf]CDf]CDf]CDf]CDf]CDf]CDf]CDf];Bf=;Bf=?C
fM?CfMCDf]CDf]GEfmGEfmGEfmGEfmGEfmGEfmGEfmGEfmGEfmGEfmCDf]CDf]CDf]CDf]CDf]CDf]CD
f]CDf]CCg=CCg=CCg=CCg=CCg=CCg=CCg=CCg=GEfmGEfmGEfmGEfmGEfmGEfmGEfmGEfmKDf]KDf]KD
f]KDf]OEfmOEfmSFg=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOE
fmOEfmSFg=SFg=SFg=SFg=SFg=SFg=SFg=SFg=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=OEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOEfmOE
fmOEfmKEemKEemKEemKEemKEemKEemKEemKEemOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=OFf=OFf=OFf=OFf=WFf=WFf=WFf=WFf=WFf=WFf=WFf=WFf=OFf=OFf=OFf=OFf=OFf=OFf=OF
f=OFf=SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]WGemWGemWGemWGemWGemWGemWGemWGemSFe]SFe]SF
e]SFe]SFe]SFe]SFe]SFe]WGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWGemWG
emWGemKDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=SFe]SFe]SFe]SFe]SFe]SFe]SFe]SFe]KDe=KDe=KD
e=KDe=KDe=KDe=KDe=KDe=SFeMSFeMSFeMSFeMSFeMSFeMSFeMSFeMKDdmKDdmKDdmKDdmKDdmKDdmKD
dmKDdm_FeM_FeM_FeM_FeM_FeM_FeM_FeM_FeMKFd=KFd=KFd=KFd=KFd=KFd=KFd=KFd=_FeM_FeM_F
eM_FeM_FeM_FeM_FeM_FeMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMSEcMSEcMSEcMSEcMSEcMSEcMSE
cMSEcMcJd=cJd=_IcmWGcMCBb<k<`/O5^lC2^:b]VJ:SSiBCOh=oK71/FF9LBEMA?U=<>EE;>E98=Tm5
<de3<Da2<4Y0;TLm:d@j:3Tc73Ha73Pd8CTi9bh^81TM4A4F3AHN52<V3C4a6C`j8T0j8d@l9Di1:eA6
<5M6<DY49dU39TM194@n8D4k7Sdg6S/e63Xd5d<l8DDn8dQ19TQ19TM09DHo94M09DQ19Ti:;E1:;E1:
;E=;;UE:;UI;;eM;;eM;;da2:Ta2:Ta2:Ta2:Te3:de3:de3:de3:c0a:10?1AdK43dj;3df9Cle8dXo
:D8g8C@`7C<_7C8^73<^7c@_83<]834[7RhX7AlM4b@R5bTW738a8dE4=UeMCF][FFa/FW=eGg9dGW=d
H7AeHGQhIWalK820L8:2LV][FgEeIGalK7inKX61LHB4M861LG]kJg=aGgIdHWYhIWajJ7UgIFm]Ff9P
CUUGADI4;4I4;4M5;DY8<4m==EME?EiLA69PB7]jIXR7Li^JQZb[UkZiYLK5/M;A_M_Ja]3>_=;@_]GB
`mODaMSEamOCb=GAa]??a=OEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOE
bmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmOEbmWDbmWDbm[Ec=[Ec=[Ec=_FcM_FcM_FcMSCb]SCb]SC
b]WDbm[Ec=[Ec=[Ec=_FcMWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWD
bmWDbm[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=WDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWDbmWD
bmWDbmWDbmWDbmWDbmWDbm[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[Ec=[E
c=[Ec=[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[FbmSDbMSDbMWEb]WEb]WEb][Fbm[Fbm[FbmWEb]WEb]WE
b]WEb]WEb]WEb]WEb]WEb]KEbmKEbmOEbmOEbmWDbm_Dbm_Dbm_Dbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[F
bm[Fbm_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=[Fbm[Fbm[F
bm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm_Gc=_Gc=cHcMcHcMcHcMcHcMgIc]gIc]gIc]gIc]gIc]gIc]gI
c]gIc]_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=_Gc=gGb]gGb]gG
b]gGb]gGb]gGb]gGb]gGb^3JcN3JcN3JcN3JcN3JcN3JcN3JcN3JcN3Jcn3Jcn3Jcn3Jcn3Jcn3Jcn3J
cn3JcmgGc=gGc=gGc=gGc=gGc=gGc=gGc=gGc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=oIc=gGb]gGb]gG
b]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]cFbMcFbMcFbMcFbMcFbMcFbMcF
bMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbM_Eb=_Eb=_E
b=_Eb=_Eb=_Eb000e=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe]GGa<?5inKXe]GGf]WKhN3Rb/W;gMcN
dM3Bf=OIgMcNc<_=g=_MiNCV_;^mc<_=`l;4V9NIXj:TQhJ8ZjZ/f]WKf]WKeMCFgmkPa/G7eMCFc/g?
MWEgZ:NY/K2bYZFWa/G7`/73f=OIdM3BemKHg=_Mc/g?eMCFdm?I_;c2d=3FgMgSdm?Ig=cRc/kDeMGK
e=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJd];Hd];Hdm?Idm?Ie=CJe=CJeMGKeMGKeMGKeMGKeMGKeMGK
eMGKeMGKeMGKeMGKe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=CJe=?Le=?Le=?Le=?Le=?Le=?Le=?Le=?L
eMGKeMGKeMGKeMGKeMGKeMGKeMGKeMGKe]CJe]CJe]CJe]CJemGKemGKf=KLf=KLemGKemGKemGKemGK
emGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKf=KLf=KLf=KLf=KLf=KLf=KLf=KLf=KL
emGKemGKemGKemGKemGKemGKemGKemGKemKHemKHemKHemKHemKHemKHemKHemKHemGKemGKemGKemGK
emGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKemGKeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCF
emKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHemKHfMKHfMKHfMKHfMKH
fMKHfMKHfMKHfMKHemKHemKHemKHemKHemKHemKHemKHemKHemGEemGEemGEemGEemGEemGEemGEemGE
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGemGEemGEemGEemGEemGEemGEemGEemGEfMOGfMOGfMOGfMOG
fMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGfMOGe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CD
f=KFf=KFf=KFf=KFf=KFf=KFf=KFf=KFe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDemGDemGDemGDemGD
emGDemGDemGDemGDe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCfmKEfmKEfmKEfmKEfmKEfmKEfmKEfmKE
e]K@e]K@e]K@e]K@e]K@e]K@e]K@e]K@fmKEfmKEfmKEfmKEfmKEfmKEfmKEfmKEfMCAfMCAfMCAfMCA
fMCAfMCAfMCAfMCAf=G=f=G=f=G=f=G=f=G=f=G=f=G=f=G=d]35c<Zo`Knd[jfRV9J;PGmdKVaQHV1E
EeDmE58jDDdeCDTaCDL`DDTbE4`eEThgDTD_Cd8/BchXBC`VAcXTA3LQ@C@N?S4K>SDL?3PP@3dX>CTW
8R<C1`/020h35alE<S4G@3`SBD@[BT0XBShVDT8[EdD^Ed8/BdHWC4LXC4LXC4LXCDPYCDPYCTTZCTTZ
C4D/D4T`E4ddE4ddDDXaD4T`DT/bEDheDD/^DD/^Dd/^Dd/^ET/_Ed/_Ed/_Ed/_Ed/cEd/cETXbEDTa
E4P`DdL_DdL_DTH^81lK30T4:RLOAd4f=BhO@3HTET/gACPR?3`N>c/M>cXN?C`P?chT?cdU?S`T?3XR
<30N<c@P<c@P<cDO?d4[DeHmHFA:I6M=JFiIKgAOMWYWO81]Oh9bP8=dPXEfPhEiRHQjSXeoT8n1RhYl
RHQjQhIhOGa^LG1RNWQVN7ITMgESNGMUNgUWNGMULg5OKF]IH5m5FEPnCTdcA4<Y?chT@3lUA4<YB4L]
>c/S@D4YB4P`CThfEUHnI6A<MGEMPX9ZW9^6YJB?/k:N`l6_clfke]?4fMK7fMK8emG;emG;emG;emG;
emG;emG;emG;emG;emG;emG;emG;emG;emG;emG;emG;emG;emG;emG;emG;emG;emG;emG;emG;emG;
fMC;fMC;f]G<f]G<f]G<fmK=fmK=fmK=em;9f=?:f=?:fMC;fMC;f]G<f]G<fmK=fMC;fMC;fMC;fMC;
fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<
fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;fMC;f]G<f]G<f]G<f]G<
f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]G<f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;
f=C9f=C9f=C9fMG:fMG:f]K;f]K;f]K;fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:e]G;e]G;emG;emG;
fMC;fmC;fmC;fmC;f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<
fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;fmO<fmO<
g=S=g=S=g=S=g=S=gMW>gMW>gMW>gMW>gMW>gMW>gMW>gMW>fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<
fmO<fmO<fmO<fmO<fmO<fmO<fmO<fmO<gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:h=[=h=[=h=[=h=[=
h=[=h=[=h=[=h=[=h=[?h=[?h=[?h=[?h=[?h=[?h=[?h=[?gMO<gMO<gMO<gMO<gMO<gMO<gMO<gMO<
gmW<gmW<gmW<gmW<gmW<gmW<gmW<gmW<gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:
gMO:gMO:gMO:gMO:g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9
g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9fmG8fmG8fmG8fmG8fmG8fmG8003Fcm;Fcm;Fcm;Fcm;Fcm;F
cm;Fcm;Fcm;GdmWGdmWGdmWGdmWHe=[He=[He=[IeM_Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Fe=[Bd=KK
fMo@c]Bl^/2j^;jYYjeJF5h100D000@>31:4PXRo_L>e/kWBd=KLf^3=bm7Fe=[Fe=[Fe=[Fe=[Fe=[F
e=[Fe=[Fe=[Dd]SDd]SDd]SDd]SDd]SDd]SDd]SDd]SCdmWCdmWCdmWCdmWDe=[De=[De=[EeM_CdmWC
dmWCdmWCdmWDe=[De=[De=[EeM_Bd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SB
d]SBd]SBd]SDe=[De=[De=[EeM_EeM_EeM_Fe]cFe]cFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMODdmGE
e=KEe=KEe=KFeMOFeMOFeMOGe]SFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOGe]SGe]SGe]SGe]SGe]SG
e]SGe]SGe]SFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOGe]SG
e]SGe]SGe]SGe]SGe]SGe]SGe]SFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFe]KFe]KFe]KFe]KFe]KFe]KFe]KFe]KHe]KH
e]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]KHe]GHe]GHe]GHe]GHe]GH
e]GHe]GHe]GHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe=WHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GH
e]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GH
e]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GHe]GFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?FeM7F
eM7FeM7FeM7FeM7FeM7FeM7FeM7Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?Ke]?K
e]?Ke]?Ke]?Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7FdLkF
dLkHe<oJem;Mfm?LgM?IfloGfLgDd<oFd]7IeMCJeM;Ke=7Je<oLdloMe=3@dl[Ce<_Ee/cIfLgIe/S=
b;Vi]J>/YY>?Q6inLee/HTYTFT9OECeID3EEC35EC35NCbmKCRiJC2mHCBmHC31GC35FCC9FC3AAAblk
<1Y0>25;@RiMET90>RMKE4==BCM9B3=2@2i6@cA0?34U8AH;200V918`;aY>BC1>BC1?B2mAAbmAAbmC
AbmCAbmDARmEBC5GBc=HC3AGBc=DB31DB31GBc=KCcMHCcAGCS=GCS=ID3EKDSMKDSMID3EFCC9ABSID
C3EFCcIJDCILDCELDSALDC5KD31JDCI@AbaCBC5GCCEBAc5CB39EBSI>@blE4PdF4@Q2>B]A@c16>25C
ARaBARi:@2Q?@b]9?bM8?BM8@2U8?b]3?2U2?2U6@2df>2Di>BLi>BLk>BM3?be=BCMCC3]ABSUEFTEI
GTURIe9[L5]eNVEmPVf2Qg:5RWF7QWb<Rh6BTHNFUH^EU8ZCTXRBTHNAT8J9PWV7P7N8PGR9QGZ:R7f6
Q7UkNfebLVAmNVagM6E_KE]UI51KFTE>CSHo@2He=Qa2?BPo>RDo>b=1?BDn>R4k>1a1?R9=BRi2@BM?
CSALFd5SHTQ[JU1jNEn>SG>MW8:c[ibn^ZO<b;KCckgCc[oDc/7IdlKNf<_Hd/GIdlKJe<WJe<WId/WI
d/WLe<gNe/o=al3KeLkGd/W@bl;GdlSLf<gIeL[KelcFe/SGe/SGe/SJelWLe/WLe/WOel[Oel[Ke<_I
d/WJdl[Of<oPfM3Ke<_Jdl[Me/gIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SHdl[Hdl[Hdl[Hdl[Hdl[H
dl[Hdl[Hdl[GdlSHe<WIeL[Je/_Je/_Je/_IeL[IeL[Je/_Je/_Je/_Je/_Je/_Je/_Je/_Je/_IeL[I
eL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[I
eL[IeL[IeL[GdlSHe<WIeL[Je/_Je/_Je/_Je/_IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[I
eL[IeL[IeL[IeL[IeL[IeL[IeL[KeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSJelWJelWJelWJelWJelWJ
elWJelWJelWJelWJelWJelWJelWJelWJelWJelWJelWMel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Le/WL
e/WLe/WLe/WLe/WLe/WLe/WLe/WMel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[M
el[Mel[Mel[Kf<[Kf<[Kf<[Kf<[Kf<[Kf<[Kf<[Kf<[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[OfLcO
fLcOfLcOfLcOfLcOfLcOfLcOfLcOflWOflWOflWOflWOflWOflWOflWOflWNf<_Nf<_Nf<_Nf<_OfLcO
fLcOfLcPf/gMel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[OflWOflWOflWOflWOflWOflWOflWOflWOflWO
flWOflWOflWOflWOflWOflWOflWMfLOMfLOMfLOMfLOMfLOMfLOMfLOMfLOLf<KLf<KLf<KLf<KLf<KL
f<KLf<KLf<KMfLOMfLOLf<KKelGKelGJe/CJe/CIeL?KelGKelGKelGKelGKelGKelGKelGKelGKelGK
elGKelGKelGKelGKelD00=K?d]K?d]K?d]K?d]K?d]K?d]K?d]K?d]KBf=OCfMOCfMOCfMSDf]SDf]SD
f]SDf]GCfMGCfMGCfMGCfMGCfMGCfMGCfMGCfM3>e=KDf]GCfM;@e]SFg>7OiMOEflG3bM;@e[bj`>CR
j>7OiL2na<k<d]KDf]3>e=GCfMGCfMGCfMGCfMGCfMGCfMGCfMGCfMCBf=CBf=CBf=CBf=CBf=CBf=CB
f=CBf=;Bf=?CfM?CfM?CfMCDf]CDf]CDf]CDf];Bf=?CfM?CfM?CfMCDf]CDf]CDf]CDf];Bf=;Bf=;B
f=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=?CfMCDf]CDf]CDf]GEfmGEfmGE
fmKFg=KEemKEemKEemKEemKEemKEemKEemKEemCCeMGDe]GDe]GDe]KEemKEemKEemOFf=KEemKEemKE
emKEemKEemKEemKEemKEemOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=KEemKEemKEemKEemKEemKEemKE
emKEemKEemKEemKEemKEemKEemKEemKEemKEemOFf=OFf=OFf=OFf=OFf=OFf=OFf=OFf=KEemKEemKE
emKEemKEemKEemKEemKEemGDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]KEemKEemKEemKEemKEemKEemKE
emKEemGEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOEeMOE
eMOEeMOEeMOEeMOEeMOEeMOEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=ODe]ODe]ODe]ODe]ODe]ODe]OD
e]ODe]OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OE
e=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OEe=OE
e=OEe=KDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKEdMKEdMKEdMKEdMKEdMKEdMKEdMKEdM[Ed][Ed][E
d][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed][Ed]WDdMWDdMWDdMWDdMWDdMWDdMWD
dMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdN7LfMgHeMWEd=GBcMCAc=?@bm;@b=3>a][Hf=SFeMOC
d]GBc]GAc=OAb]OBbM[DbMkNd]3?`KRgZJ:OT8j:N7YdHFQQCE]D@6]NA65D>UY=<eY=<eY=<eQ<<5I:
;UQ<<5U;;UU;;UM;;eI:;UI;<5A:<UE;<eE;<eQ@>DQ0:DPo:eaE@FQRCe]D@fm[FFUUDemNBV1NC6AQ
DeYFBb8N4adJ33/i9dE4<51<=51:<dm9<U59<UA9<eE:=5Y==e]>>5A:<UM==EY@>5Y@>5U?=eY@>5eC
>f1F?UU@=EQ?=5M><eQ?=5YA=UU@=EM><eA;<59<=E===UM@=e]A>EaC>5iC=eeC=EiC=EmF>eE<<EQ>
=UaB>UM<=UQ==eU>>U15<@d:1ALB2DY1<eU>>U53;5Y=<eE9<De3:e16;Ta2:T]0:Ta4;DY3;dM0;DM1
;T]5<SPj9c`n:d10;TA2<4Y8=UA@?UIB@5A=?4e>>U5B?UMHA5iOBfEVDV]/F6i_Fg1aGGemLH>3Mhb<
P9FERIZJSYnOTj>SUjFUVJ:MU9bGSYBBQi6?Q92@Q8f?PhR;O866MhF5NH>3MH61LgioKgQjIfa^FUiQ
BeAG@DQ4<Chj9cPe83dk8d4o9cln93dl8Shm8CTh7Sdl8T0o9D509T=2:4M6;4e<<U5@=Ta:<UQF?VUV
DGYfHhZ6Li^GQJbXU[RcY<S4//g9]mG@`M[Ea]_Eb=_Eb]cFbmcFbn3Kd^COe]oJdMWEb]gIc]cHcMKB
amKCaMGEbMCDb=GCb=OCb=OCb=WCb=WCb=_Bb=[Ec=OBbMSCb]cGc]_FcMOBbMKAb=WDbmKBamOCb=OC
b=SDbMWEb][Fbm_Gc=_Gc=OBbMOBbMOBbMOBbMOBbMOBbMOBbMOBbMWEb][Fbm_Gc=_Gc=cHcM_Gc=[F
bm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[Fbm[FbmWEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WE
b]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]OCb=SDbMWEb][Fbm[Fbm[Fbm[F
bmWEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]WEb]_Eb=_Eb=_E
b=_Eb=_Eb=_Eb=_Eb=_Eb=[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[G
bM[GbMgGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]cFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMgGb]gGb]gG
b]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]_Hb]_Hb]_Hb]_Hb]_Hb]_Hb]_H
b]_Hb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]kHbmkHbmkHbmkHbmkHbmkHbmkHbmkHbmkJb=kJb=kJ
b=kJb=kJb=kJb=kJb=kJb=gGb]kHbmkHbmkHbmoIc=oIc=oIc=oIc=gGb]gGb]gGb]gGb]gGb]gGb]gG
b]gGb]kJb=kJb=kJb=kJb=kJb=kJb=kJb=kJb=kJb=kJb=kJb=kJb=kJb=kJb=kJb=kJb=gIamgIamgI
amgIamgIamgIamgIamgIamcHa]cHa]cHa]cHa]cHa]cHa]cHa]cHa]gIamcHa]cHa]_GaM_GaM[Fa=[F
a=[Fa=_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_Ga@00e/oBe/oBe/oBe/oB
e/oBe/oBe/oBe/oBe];He];He];Hem?Iem?If=CJf=CJf=CJeM?IeM?IeM?IeM?IeM?IeM?IeM?IeM?I
emGKe=;HeM?If]SNe]CJd<kDf=KLinG[inG[e=;Hg]cReM?IbLO=e=;He]CJf=KLeM?IeM?IeM?IeM?I
eM?IeM?IeM?IeM?Ie=;He=;He=;He=;He=;He=;He=;He=;Hd];Hd];Hd];Hdm?Idm?Ie=CJe=CJe=CJ
d];Hd];Hd];Hdm?Idm?Ie=CJe=CJe=CJd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];H
d];Hd];Hd];Hd];Hdm?Idm?Ie=CJe=CJe=CJeMGKeMGKeMGKe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e=?EeMCFeMCFeMCFe]GGe]GGe]GGemKHe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGeMCFeMCFeMCFeMCF
eMCFeMCFeMCFeMCFe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGE
emGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGEemGDemGDemGDemGD
emGDemGDemGDemGDemCFemCFemCFemCFemCFemCFemCFemCFemGDemGDemGDemGDemGDemGDemGDemGD
emGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGD
emGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDemGDe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CC
e]GAe]GAe]GAe]GAe]GAe]GAe]GAe]GAf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GBf]GB
f]GBf]GBf]GBf]GBfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCA
d<c7d/k9eM7<fMCAgMSEg]WHfmKEfMCCb/S8cL_:dm;>f]S@fmW>d];2aL>a^[VUThejQGm/LV]GHEY6
FU8kFDhhEddeED/cEdT/E4HYEDLZFdd`GDlbFT`_FT`_GU0cEDT]ETT_Ed`aFThfG58jGEDnH5M3HEQ4
GUM3ETlkC4DbLF]HKVYHMW5RPWm`Ph1aMWITPX9bQXAiMWAZ71X@?C/`Gem?IfMEIF5>Hem<HE]8GEM4
FeA1Fe4oFe4oFe4oFe@iG5DjGEHkG5DjFU<hFU<hFe@iGEHkFe@kFE8iEe0gF54hFE8iFE8iEe0gEDhe
DddfEDlhEe8iFe@kGUDjGeHkHEHjHEHjHU]0FE8gFe@kGULnFE4jFU8kFU4mCTDa1PH06QP>CdPiG54m
E4P`G54fEddeE4ddED/cDDL_CdL`DTXcD4TeC4HcCDLdCd/h>S`Y@48_A4HcBDTgDDlmF5I4FUI4EE4o
DThkE50mEe=0FeM4GUY7HEe:HUi;Hem<IVEGKFaNMgIXPH1bRXUkTY63VYV;X9nA/k>U[JfOXjJGWZ6B
VYn@UIb?T9N:S9>6RXj3RXj3Rhn4SI65SI:3RXn0QH]jPHMfPGm]KVaJEeE3AdHb?C`W>CPS?3`T@T8Z
@T0X@3hV?cdU@ClWA48ZA48Z@3hV?C/S?chR?SdQ?SdS@3lUAD<[CT/fEU<nG5U4JfUAM79JQ85/UI9m
YZ:?][:P`kn]blJgblRjblRjc/^meM;4fMK8emC6e=73e=73eMG9eMG9eMG9e]C9f=C9em?8fM?8fM?8
f]S>e]C:eM?9f=K<f=K<eM?9eM?9fMO=eM?8e]C9e]C9e]C9emG:emG:emG:emG:f]G<f]G<f]G<f]G<
f]G<f]G<fMC;fMC;fMG:f]K;fmO<fmO<fmO<f]K;fMG:f=C9f]K;f]K;f]K;f]K;f]K;f]K;f]K;f]K;
fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:
fMG:fMG:fMG:fMG:em?8em?8fMG:fMG:f]K;f]K;fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:
fMG:fMG:fMG:fMG:fMG:fMG:fMG:fMG:fmG8fmG8fmG8fmG8fmG8fmG8fmG8fmG8f]O9f]O9f]O9f]O9
f]O9f]O9f]O9f]O9f]O9f]O9f]O9f]O9f]O9f]O9f]O9f]O9gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:
g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:
gMO:gMO:gMO:gMO:fmS:fmS:fmS:fmS:fmS:fmS:fmS:fmS:gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:
g]S;g]S;g]S;g]S;g]S;g]S;g]S;g]S;g][8g][8g][8g][8g][8g][8g][8g][8gMO:gMO:gMO:g]S;
g]S;gmW<gmW<gmW<gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:g][8g][8g][8g][8g][8g][8g][8g][8
g][8g][8g][8g][8g][8g][8g][8g][8gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7g=S6g=S6g=S6g=S6
g=S6g=S6g=S6g=S6g=S6g=S6g=S6fmO5fmO5fmO5f]K4f]K4fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5
fmO5fmO5fmO5fmO5fmO5fmO5003Fcm;Fcm;Fcm;Fcm;Fcm;Fcm;Fcm;Fcm;Fd]SFd]SFd]SFd]SGdmWG
dmWHe=[He=[EdmWEdmWEdmWEdmWEdmWEdmWEdmWEdmWHe]c>c=;>c=;He]cIemg>c=;:b<k@c]C0_/C5
`lW=bm7AcmGIemgIemg?cM?@c]CEdmWEdmWEdmWEdmWEdmWEdmWEdmWEdmWDd]SDd]SDd]SDd]SDd]SD
d]SDd]SDd]SBd]SBd]SBd]SBd]SCdmWCdmWDe=[De=[Bd]SBd]SBd]SBd]SCdmWCdmWDe=[De=[Bd]SB
d]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SCdmWCdmWCdmWDe=[De=[D
e=[EeM_EeM_FeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMODdmGEe=KEe=KEe=KFeMOFeMOFeMOGe]SFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMOFeMOFeMOFeMOFeMOEe=KEe=KEe=KEe=KEe=KEe=KEe=KEe=KFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMOEeMGEeMGEeMGEeMGEeMGEeMGEeMGEeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGGeMGG
eMGGeMGGeMGGeMGGeMGGeMGGeMGGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMGGeMGGeMGGeMGGeMGG
eMGGeMGGeMGGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCG
eMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCGeMCG
eMCGeMCGeMCFe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?Fe=?FeM7FeM7FeM7FeM7FeM7FeM7FeM7FeM7JeM;J
eM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;JeM;Ie=7Ie=7Ie=7Ie=7Ie=7I
e=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Ie=7Lf];Jf=3IeM3Hdm3Ke=7Jd];Hd=7HcLoPgm_H
f=;?cLG2`;F_[ifFUH1gMemTHdUPECYKD3EEBRmBAbaDBBiGBS1HC31HC31LCBaKC2aNCbmRDc=PD3=L
C2mLBc1QD3EICCELD3QPECmXGDU]I51bJeQgL5eiLV5]IeA/IU=DD3j6PW1dLF:;RWb?SX2DTXN7QgNH
UhVIUhf6PWdI5A1VI5Z7QWR:RWZ7QgF4Q7:0OVahMVAaKE]ZHe9SG4]PF4MNFD1MF3mJECaGDSUFDCQH
DcYKESeMF3mNEciLECaJDcYJDcYKE3]MESeMESeLECaEDCUFDSYHDcYJECaNEciRF41SFD5UFD5SG45K
E3UNEciOF3mJDS]MECiJDCe:@Bd71`4R81ICC3eGCSYCAbmLDCIHCSINEciGD3MCC3=CBcADCSMCCSUA
BcQ@C3UDD3dl@2e0A356B3E8BSM?CceIEdEIEdEGDd5KED9LET=MEdAOFDIPFTMQFdQQFdQRG4UGEdMK
Fd]QHE5WIeM/K5acLf=iNFUnOVjCUXJCVHRFW8^JXI:NYIJKY9NEWi:AVhjEWI>CVi6?Uhf>UXb>UXbA
VHjDW96EWI:WYYROWY2=SGebLV9DE493A312@bm8BCE3@BU0?RI2@2Q9Abm=Bc=<BS99Abm7ABe;C2a5
ARHm?Alk>adn?B53@RQ6AB]7ARa7AbU7ARY8Ab]:BBmBD3QNG4A]JUEgM5nETh6ETh6WYI>k^:W1_Zo9
a[SHeLORgm7Ad/SBdlWDdlWEe<[GeL_JeLcJeLcLeLcEdl_AclO@c/KCdLWDd/[Bd<SDd/[IeloHe/cH
e/cGeL_GeL_Fe<[EdlWEdlWEdlWIe<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_Ie<_He<WHe<WIeL[IeL[IeL[H
e<WGdlSFd/OIeL[IeL[IeL[IeL[IeL[IeL[IeL[IeL[He<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WH
e<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WFd/OGdlSHe<WIeL[IeL[I
eL[IeL[He<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WHe<WJe<OJ
e<OJe<OJe<OJe<OJe<OJe<OJe<OIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SI
e/SIe/SIe/SMel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[KeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSMel[M
el[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Kf<[Kf<[Kf<[Kf<[Kf<[K
f<[Kf<[Kf<[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf<_Nf/SN
f/SNf/SNf/SNf/SNf/SNf/SNf/SMel[Mel[Mel[Mel[Nf<_Nf<_OfLcOfLcMel[Mel[Mel[Mel[Mel[M
el[Mel[Mel[Nf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SNf/SMfLOM
fLOMfLOMfLOMfLOMfLOMfLOMfLOKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGK
elGKelGKelGJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/@00=K?d]K?d]K?
d]K?d]K?d]K?d]K?d]K?d]GAemGAemKBf=KBf=KBf=OCfMOCfMOCfMCBf=CBf=CBf=CBf=CBf=CBf=CB
f=CBf=[Hg]GCfLo=dlo=dmCBf=[Hg]cJh=_Igm?AemkLh]GCfM?AemWGgM;@e]3>e=KDf]CBf=CBf=CB
f=CBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=CBf=7Aem7Aem;Bf=;Bf=;Bf=?CfM?C
fM?CfM7Aem7Aem;Bf=;Bf=;Bf=?CfM?CfM?CfM;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;B
f=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=?CfM?CfM?CfMCDf]CDf]CDf]KEemKEemKEemKEemKEemKEemKE
emKEemCCeMGDe]GDe]GDe]KEemKEemKEemOFf=KEemKEemKEemKEemKEemKEemKEemKEemGDe]GDe]GD
e]GDe]GDe]GDe]GDe]GDe]KEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKE
emKEemGDe]GDe]GDe]GDe]GDe]GDe]GDe]GDe]KEemKEemKEemKEemKEemKEemKEemKEemCCeMCCeMCC
eMCCeMCCeMCCeMCCeMCCeMKEemKEemKEemKEemKEemKEemKEemKEemCDe=CDe=CDe=CDe=CDe=CDe=CD
e=CDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDdmKDdmKD
dmKDdmKDdmKDdmKDdmKDdmKDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=KDdmKDdmKDdmKDdmKDdmKDdmKD
dmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKD
dmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmGCd]GCd]GCd]GCd]GCd]GCd]GC
d]GCd]GDd=GDd=GDd=GDd=GDd=GDd=GDd=GDd=WDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWDdMWD
dMWDdMWDdMWDdMWDdMWDdMSCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SC
d=SCd=WGcmKDc=?@b=G?b=W@c=cCcmoCdMoCdL_9_[JbYiFBPgUeHfERCEUE?4i;;dQ49e]=<5Y<;eY<
;e]=<5]=<EQ<<5E9;E96:U]?;EU=:eY=;Ee?<Ue?<e]<<Ui?=FAD?FMLB6UOCG5WEGM_GWmhIhIoL8V3
MXb6NH=oKHF0LFMTEIRGRH1nLibLT9ZISifNU9>CQJ:QUifJUH>0O1XG4hF2OIfLTY^KSIfOTifOTifM
TINGRhn=PXJ2Mg]gK7EaIVUTCfEPBeiIA5UD?eQC?UYE@5eH@f1KAUaF?eUC?5MA>UMA>UYD?EeG@5mI
@UmI@UED>UQD>eUE?E]E?UmG@65I@VEJA6IKAF9N@UaH?5iI@5mJ@E]E?UmI@UYC?dHo:`@602TX7UQC
A5]B?UY@>61G?5E>=EeH?eYC>UA?=U===UEA>EE@>e1<>Dm>>U=B?T16<dE9=TE9=TM9=Ti>?5MGAEaJ
B5UGAEeGA5eGA5eGA5iHAEmIAV1JAf1JAf5KB5iLBUmMBf5OCF5OCF5OCF=QCfITDVUWEF=XDfI]F71f
Hg^3LXJ=OXbFQXjHRhjHRi^TVYZSVIVRV9NPUYFNU9FMUYJNUiRPVIbKTJBSVJVXWZ>SUi6APgEeIeUJ
BTM8>4a9=4Q5<4U6<Di;=Tm<=d]8<dY7<Ti;=TI79D938Cho7d518dQ8:Ti=<Dm><Tm>=4i?;dY;:d92
93Xj73He6CPg7Chm8dA2:Shn9SXi94]:=EUHA5]IAgIcI:6NT;JcYL;6^lG6_<O8_/_:`<k<`]3>a=?>
aMC?a/O7`L?3_L?3_LO7`LW9`lW9`lc<a];Bc=7@a]7@a]7@a];Aam?Bb=?Bb=CCbMCCbMG@amG@amG@
amKAb=KAb=OBbMOBbMOBbMSDbMSDbMWEb]WEb]WEb]WEb]SDbMOCb=WEb]WEb]WEb]WEb]WEb]WEb]WE
b]WEb]SDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSD
bMSDbMSDbMSDbMSDbMSDbMKBamKBamSDbMWEb]WEb]WEb]SDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSD
bMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbM[Dam[Dam[Dam[Dam[Dam[Dam[Dam[DamWFb=WFb=WF
b=WFb=WFb=WFb=WFb=WFb=WFb=WFb=WFb=WFb=WFb=WFb=WFb=WFb=cFbMcFbMcFbMcFbMcFbMcFbMcF
bMcFbM_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=cFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcFbMcF
bMcFbMcFbMcFbMcFbMcFbM[GbM[GbM[GbM[GbM[GbM[GbM[GbM[GbMcFbMcFbMcFbMcFbMcFbMcFbMcF
bMcFbMgGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gIamgIamgIamgIamgIamgIamgIamgIamcFbMcFbMgG
b]gGb]gGb]kHbmkHbmkHbmgGb]gGb]gGb]gGb]gGb]gGb]gGb]gGb]gIamgIamgIamgIamgIamgIamgI
amgIamgIamgIamgIamgIamgIamgIamgIamgIamcHa]cHa]cHa]cHa]cHa]cHa]cHa]cHa]_GaM_GaM_G
aM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[F
a=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa000e/oBe/oBe/oBe/oBe/oBe/oBe/oBe/oBeM7GeM7GeM7GeM7G
e];He];Hem?Iem?Ie=;He=;He=;He=;He=;He=;He=;He=;Hc/cBf]SNgM_QdLoEbLO=c/cBdm7Gd]3F
b/S>emGKb/S>cL_Ad]3Fc<[@f=KLgM_Qe=;He=;He=;He=;He=;He=;He=;He=;He=;He=;He=;He=;H
e=;He=;He=;He=;HdM7GdM7GdM7GdM7Gd];Hd];Hdm?Idm?IdM7GdM7GdM7GdM7Gd];Hd];Hdm?Idm?I
d];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hd];Hdm?I
dm?Idm?Ie=CJe=CJe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe=?EeMCFeMCFeMCFe]GGe]GGe]GGemKH
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCFe]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGeMCFeMCFeMCFeMCFeMCFeMCFeMCFeMCF
e]GGe]GGe]GGe]GGe]GGe]GGe]GGe]GGe=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee]GGe]GGe]GGe]GG
e]GGe]GGe]GGe]GGe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CD
e]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CC
e]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CC
e]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CC
e]CCe]CCe]CCe]CCeM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?BeMC@eMC@eMC@eMC@eMC@eMC@eMC@eMC@
fMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAfMCAf=?@f=?@f=?@f=?@
f=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@alRod<k6f]S>h]kCh=[?e<^n`[NY/jRJ
O7EQKVMCG5HoDDTbD4H^E4/`G54fGe@iEdPXEdPXF4P[EdT/F4``FdhdGE8gGU<hETd/DdXYED/]GE8g
I5Q0JEa6L69?MfUGNW9QOWIUPgY/RH5dS8IiT8YoTHf2TXf4T8eoTI22MWEWXJ6EQhQnX:6GW9nFVijE
XJ2F[J^SXIjJNWIe920OVIJBY::JXZ6GXJNLXjVNZ:bQZ:bQYjRNXj:HW9^AVIN=SX]lQX=dNGIWKFYK
I65BGU]<FEI7EU=4GUQ1FU@mEU0iEU0iFE<lGEM0H5Y3HE]4F5LmF5LmFUHnFeLoGUM3HEQ4HeU7IE]9
Hem3GUXnHUe4HEa3GeU2IEm8GUM3ASl[0080:b`RFeQ9GUM3Hea3IUm4DTddFEDlFUDlEU4hE50hEU8j
E54lCTdiCdhjDU4mAT`iAddjB4`iATXgCDllEeM5FUY8F5Q6G5Q5G5Q5G5Q5G5Q5GEU6GUY7H5a9H5a9
HEi9Hf1;Hf1;HUm:HEi9HEi9Hf1;IF9=FUi5FUe7FEi9GF5>HFMFIVeNKWEXLWQ]OHIiQHj1T9R=VJ6F
WZJLX:NPXZVRXjZSYjNQYjNQZJZQ/;6X]KJ/YjVMPXAhHF=GFUI3D4`iC4PeCd/hCd/hBdLdCTXgEe=0
CDh^BDXZADDWA4@VA4<W@T4W?C`R>CPN>S/K?ChN?clQ@40R@3lS?chT@3lU@T0XADLZ>C/N?SlU>cXU
=SDQHf5?XIj?]kBV/KB[/KB[]KJ]]kR__;Zb_kbd`Kjf`[ng];Rb/KF_/[J`]k^e^Kfg^Kfg^kni`<Bn
`Kng`l6iaL>kb<JnblW1cL_3d<k6dLo7e<o6eM37e]78em;9f=?:fMC;f]G<fmK=em?8f=C9fMG:fmO<
fmO<fmO<fmO<f]K;f=C9f=C9f=C9f=C9f=C9f=C9f=C9f=C9em?8em?8em?8em?8em?8em?8em?8em?8
em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8eM76e];7em?8f=C9
f=C9f=C9f=C9em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8em?8
fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7f=G7
f=G7f=G7f=G7f=G7g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9f]C7f]C7f]C7f]C7f]C7f]C7f]C7f]C7
g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9f]O9f]O9f]O9f]O9
f]O9f]O9f]O9f]O9g=K9g=K9g=K9g=K9g=K9g=K9g=K9g=K9gMO:gMO:gMO:gMO:gMO:gMO:gMO:gMO:
gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7g=K9g=K9g=K9g=K9gMO:gMO:g]S;g]S;gMO:gMO:gMO:gMO:
gMO:gMO:gMO:gMO:gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7gMW7
g=S6g=S6g=S6g=S6g=S6g=S6g=S6g=S6f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4fmO5fmO5
fmO5g=S6g=S6g=S6fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3003Fcm;F
cm;Fcm;Fcm;Fcm;Fcm;Fcm;Fcm;Dd=KDd=KEdMOEdMOFd]SFd]SFd]SFd]SCdMOCdMOCdMOCdMOCdMOC
dMOCdMOCdMO2`<KAcmGLf^3KfMoGeM_He]cKfMoJf=k=bm7Iemg>c=;IemgGeM_<b]3He]c=bm7CdMOC
dMOCdMOCdMOCdMOCdMOCdMOCdMODd]SDd]SDd]SDd]SDd]SDd]SDd]SDd]S@d=K@d=KAdMOAdMOBd]SB
d]SBd]SBd]S@d=K@d=KAdMOAdMOBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SBd]SB
d]SBd]SBd]SBd]SBd]SBd]SBd]SAdMOBd]SBd]SBd]SCdmWCdmWCdmWDe=[FeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMODdmGEe=KEe=KEe=KFeMOFeMOFeMOGe]SFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMODdmGD
dmGDdmGDdmGDdmGDdmGDdmGDdmGFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOF
eMOFeMOFeMODdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOCd]CC
d]CCd]CCd]CCd]CCd]CCd]CCd]CFeMOFeMOFeMOFeMOFeMOFeMOFeMOFeMOCdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm;E
dm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;E
dm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;E
dm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Dd]7Dd]7Dd]7Dd]7Dd]7D
d]7Dd]7Dd]7DdloDdloDdloDdloDdloDdloDdloDdloHdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3H
dm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Gd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oG
d/oGd/oGd/oJf]CJf=3Dd/O8aKJb[9VCRgAcJTmME3UOESENE3ILDC=JCS9IBS1IAc1FA2eE@baRDc=P
DC5KCC1EBBeBAbaAAbmCB39CBcAKESMHDSEKE3UXH4UeK5QmLf:3N6Z9OG6:PWF=QGRBRWfEShBGTXVH
ThZGU8bGU8bFU8VFUXZ2PWJSY9Z@ThZRYIbPY9jKWiVWZ9nc/jfVY:=aKflb<32RX9nVYZ2ZZj:TZjBV
[JJX[jR//:Z_/J^^/:Z_[jV^[ZR^[::WYI^LVY2AShF5PgUgMF]ZJ5iQGeEUH4]QG4MKET5IE3mKET5N
FDAQG4MRGDQHFCmJFCmIEcmKEcmLEd9OF4ESFDQTFTUOG41LFCePG4=OFd9NFT9UHDUMF4=2?BP00P0[
;29CD45AC3MNEciVGdACCSENFT5MF3mHE3]FDSYFE3aBDCa>CCU<CCU@DCe2BcM6C3U6C3U7BcQ;CcaD
ET=FETABDT1HFDEGF4AFEd=FEd=FEd=GF4AIFTIJFdMIEcmKFD5NG4AOGDENG4AOGDEQGdMSHDUTID]R
HTYKGDMGF4ACE4ABEDIDED]EFDiIHE1RJUU_MVMlPgJ7SH:AUXfKX9NQYInb/k6^[j^YZZJ[[JNd][2g
^[6X[:6EVHi/J5EGDd17@c18A35:AS=7@c1:AS=ACCY5ABM5ABM5A2Q5A2Y5A2Y4@RY2@2Q0?BPl?1i0
@292@BE2@BDm?28g=Adc<ATa;aM7BRXj?1hn@2<h>Ald<ai/JURYYYN^ZibW[:>Z[JB[[ZF^[jJ_/:Nb
/:Rd/JVe/ZZZ/:^X[ZVY[jZ^]:n`][6]/jj]/jja]k:d]Jbe]Zff]jji^[6k_;>m_[Fo`;O0`KS:aKc;
a[g<akk>bL3@bl;Cc/GDclKEd<OCclCDd<GFd/OGdlSIeL[IeL[IeL[IeL[He<WHe<WHe<WHe<WHe<WH
e<WHe<WHe<WGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSG
dlSGdlSGdlSGdlSGdlSGdlSGdlSEdLKFd/OGdlSHe<WHe<WHe<WGdlSGdlSGdlSGdlSGdlSGdlSGdlSG
dlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSGdlSIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKHeLOH
eLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOHeLOKeLSKeLSKeLSKeLSKeLSK
eLSKeLSKeLSJe<OJe<OJe<OJe<OJe<OJe<OJe<OJe<OKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSKeLSK
eLSKeLSKeLSKeLSKeLSKeLSKeLSIe/SIe/SIe/SIe/SIe/SIe/SIe/SIe/SKeLSKeLSKeLSKeLSKeLSK
eLSKeLSKeLSLe/WLe/WLe/WLe/WLe/WLe/WLe/WLe/WLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KKeLSK
eLSLe/WLe/WMel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Mel[Lf<KLf<KLf<KLf<KLf<KL
f<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KKelGKelGKelGKelGKelGKelGKelGKelGJe/CJ
e/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CKelGKelGLf<KLf<KMfLOIeL?IeL?IeL?IeL?IeL?I
eL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL<00=K?d]K?d]K?d]K?d]K?d]K?d]K?d]K?d]C@e]C@e]GA
emGAemGAemKBf=KBf=KBf=?Aem?Aem?Aem?Aem?Aem?Aem?Aem?AemgKhM?Aelc:d<g;dM7?eM;@e];@
e]?Aem;@e]KDf/S6c=OEfmCBf<c:d=oMhl_9cm?Aem?Aem?Aem?Aem?Aem?Aem?Aem?AemCBf=CBf=CB
f=CBf=CBf=CBf=CBf=CBf=3@e]3@e]7Aem7Aem7Aem;Bf=;Bf=;Bf=3@e]3@e]7Aem7Aem7Aem;Bf=;B
f=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=;Bf=7Aem7Aem;B
f=;Bf=;Bf=?CfM?CfM?CfMKEemKEemKEemKEemKEemKEemKEemKEemCCeMGDe]GDe]GDe]KEemKEemKE
emOFf=KEemKEemKEemKEemKEemKEemKEemKEemCCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeMKEemKEemKE
emKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemKEemCCeMCCeMCCeMCCeMCCeMCCeMCC
eMCCeMKEemKEemKEemKEemKEemKEemKEemKEem?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=KEemKEemKE
emKEemKEemKEemKEemKEem?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?CdmGCdmGCdmGCdmGCdmGCdmGCdmGC
dmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GDd=GDd=GD
d=GDd=GDd=GDd=GDd=GDd=GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GC
d]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]GC
d]GCd]GCd]GCd]GCd]GCd]CBdMCBdMCBdMCBdMCBdMCBdMCBdMCBdMCCcmCCcmCCcmCCcmCCcmCCcmCC
cmCCcmSCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=OBcmOBcmOB
cmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcm;Bc;bj/YRFRgQdHV5MAEQB=EMA
;UUA;5Q=9eQ=9eU::EM8:5Q5:Ua5;f18=6A<>UU::UU;;UY<<5U<<UI<=5E==UE>>UM@?6AQAEmL@69N
AW5/EgmhIhInLHV0MX^2NI::OIF<PYRBQi^FSInITYnLU9nKUYjKUYfMTIfMTHb=PjZ[XYfPUjR/YZfa
Zj>WXZRYX;Nf/ZbZZFi[KCll?ZVWYZ^ZY[Jg[Zbc[Z^b[JZ`ZjV_ZZ^_ZZj_Zjn`[;2a[JnZYjfXYJbW
Y:ZUXZJQWYbGU8j9QXAoO6mZEFYUD6=NBEmJAEmJAF9MB6AOBVEPBeUK?UUJ@5UG?eUF@EaF@eiFAF1G
BF=HBUYG>eQE>EaH?eaH?e]G?f=OAe]F@Chi900402X[8DI3=3`g8Ti7;UeI?EE@=fMSBUmK@UYF?EQD
?5ME?E=B?Dm>>Te>>U1A?Ca5<D19=DA:=dA:=dY>>e1B?di@?DU9=diC?TeB?DaA?4]@>d]@>daA?4eB
?DiC?U=A>EID?5YH@5eK@eeK@eiLA65OAf9PB5iM@F1OAF9PB65PC5aLC5UHBUIEBeEDBU=H@eEIAUMJ
BUYMCV5SEfm`IWn0Mh^<Pi6DTZ:UXjnb/;2d[k6e[kJj];Vn]KNl/iZFPgUeHUeIAUMC@5QD@E=??4m;
>59>>de<<4e<<Te<<T]9<DQ6;TI3;TE1;TE1;T919D=29T919d0o9Cdk8c`i93dj9Cll9c/o73Dh64=5
9dE6;4Y9=8N6L[VfYj^XVJZ^Z:Z^Z:b^Z:b^Z:j^Z;2]Z;2]Z;6]Z:Z`ZjR^ZJV_ZZjd[jjd[jZ`ZjR^
ZJZ`Zk6aZk2`Z[2`Z[2`Z[2`Z[2`Z[2`Z[2`Z[JaZ;NbZKVdZkbg[[ji/<6l/l>n]LBo]/g9_/k:_m3<
`M;>`mC@aMGAa]GAa]GAa]SDbMSDbMSDbMSDbMSDbMSDbMSDbMSDbMOCb=OCb=OCb=OCb=OCb=OCb=OC
b=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=GAa]GAa]OC
b=SDbMSDbMSDbMOCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OCb=OC
b=OCb=WCa]WCa]WCa]WCa]WCa]WCa]WCa]WCa]SEamSEamSEamSEamSEamSEamSEamSEamSEamSEamSE
amSEamSEamSEamSEamSEam_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=[Dam[Dam[Dam[Dam[Dam[Dam[D
am[Dam_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=WFb=WFb=WF
b=WFb=WFb=WFb=WFb=WFb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=_Eb=cFbMcFbMcFbMcFbMcFbMcFbMcF
bMcFbMcHa]cHa]cHa]cHa]cHa]cHa]cHa]cHa]_Eb=_Eb=cFbMcFbMcFbMgGb]gGb]gGb]gGb]gGb]gG
b]gGb]gGb]gGb]gGb]gGb]cHa]cHa]cHa]cHa]cHa]cHa]cHa]cHa]cHa]cHa]cHa]cHa]cHa]cHa]cH
a]cHa]_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=WE`m[Fa=[F
a=_GaM_GaMcHa]gIamgIamWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE``00
e<k?e<k?e<k?eLo@eLo@e]3Ae]3Ae]3Ad/oAd/oAd/oAdm3Bdm3Be=7Ce=7Ce=7CeM7GeM7GeM7GeM7G
eM7GeM7GeM7GeM7Gdm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;De=7Ce=7CeM;DeM;De]?Ee]?Ee]?Ee]?E
dm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Dd]3Fd]3Fdm7Gdm7G
e=;He=;He=;He=;Hdm7Ge=;He=;He=;HeM?IeM?IeM?Ie]CJdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7G
dm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm7Ge=;He=;He=;HeM?IeM?IeM?Ie]CJe=?Ee=?Ee=?Ee=?E
e=?Ee=?Ee=?Ee=?Edm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm?Ce=CDe=CDe=CDeMGEeMGEeMGEe]KF
e]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDdm?Ce=CDe=CDe=CDeMGEeMGEeMGEe]KFe=CDe=CDe=CDe=CD
e=CDe=CDe=CDe=CDdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
e]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CDdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Ce=CDe=CDe=CDe=CD
e=CDe=CDe=CDe=CDe]CCe]CCe]CCe]CCe]CCe]CCe]CCe]CCfMCCfMCCfMCCfMCCfMCCfMCCfMCCfMCC
f=?Bf=?Bf=?Bf=?Bf=?Bf=?Bf=?Bf=?BfMCCfMCCfMCCfMCCfMCCfMCCfMCCfMCCem;Aem;Aem;Aem;A
em;Aem;Aem;Aem;Af=?Bf=?Bf=?Bf=?Bf=?Bf=?Bf=?Bf=?BeMC@eMC@eMC@eMC@eMC@eMC@eMC@eMC@
f=?@f=?@f=?@f=?@f=?@f=?@f=?@f=?@eM?BeM?BeM?BeM?BeM?BeM?BeM?BeM?Be=??e=??e=??e=??
e=??e=??e=??e=??eM3=eM3=eM3=e]7>e]7>em;?em;?em;?f=G=f=G=f=G=f=G=f=G=f=G=f=G=f=G=
e=G<e=G<e]C<e]C<emC<emC<fM?<fM?<fM?<fM?<fM?<fM?<fM?<fM?<fM?<fM?<f]7>f]GBd=;<dm[C
c=C:bL[0d<_2^[6WPWINMFUAI5Q0FT`eFDTbFTXcFdTbFTPaH4/_GD/^G4X]FDT/FDXZEdXZED/YED/Y
GDd`FD/^G4haHEDiIEPnI5TnIE]3JV18KFMDLV]JNGESPWe^QhAeRXUkS8YoS8b0Ti>7UYJ:VYV?W9^A
WYbDX9fHY:6LYjBPXJFJV9^BU9N>[JnYY:JP];Fa[:f[Z:VWZJ^U^kfg[k6[HfEOC4i8[:jXY:JPYJNQ
Y:RSYj^VZjnZ[[:]/;B_[k>^[K6/ZjnZ[k2//;6]/[>_/[>_/;6][:fYYjRTY:FQW9^AShn3OGe_KFeK
IFA?HV=9I6=7IFE7E5I0EEM1F5M2EeI1F5E0FeI1G5M2GUU4FUU5FeY6EUE1CD`hBdXfCD`hBDPd@3l[
7AP99b8C=30N?CTV@d0[BTP`E5<iG5]1G5/oEEHlE5@lDU<oCdloAdLi@T<iA4Dk>40e>T8g@4LjATXn
BDhoC4loC4loCDhnDe0dEUDkFEY0E5PoCE<lAe0kAe<mBeI2E5LnDeHmDeHlEULmFeXnGUi0Hf53IF=5
Fee7G5i8GF1:GEm;FUi;EE]8DUQ7D5I5AU90BeE4CUQ7D5Q7E5M7FEY:HF9BJ6QHK79QN7i]QhamTIF9
VibBXjBKZj^U[jjZZK2YPHYmFFE?D5a0E612Ef15EEi4EEa7Fe=2Ee4nDddjCdXeBTP`BDL_AdP^AdP^
BDHZAT<W@ShU?c/R?CTQ>cHQ=c8M=2hK>3@HAT4X=c<K:RHCPh1aWij@YjJL[:fSZ:^RZJbSZjfW[Zn[
[k2/[Zn][Jj/[Jf]ZjjUZjjUZjjUZjjUZjjUZjjUZjjUZjjU[:nV[:nV[:nV[:nV[:nV[:nV[:nV[:nV
ZK6WZZnVZZnV[[6X/KB[]KJ]]KJ]][B/]k^`^;ba^Kfb^knd_<2e_/:g_l>h`<BiaLVnaLVnal_0blc2
clk4dM36dm77e=;8eLo8eLo8e]78e];7emC6f=G6f=K4fMS4f]C9fM?8f=;5fMC5g=G6g=G4f]?2em6n
fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6f=;5f=;5f=;5fM?6fM?6f]C7f]C7f]C7fM?6fM?6fM?6fM?6
fM?6fM?6fM?6fM?6f]C7f]C7f]C7f]C7f]C7f]C7f]C7f]C7fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6
f=C2f=C2f=C2fMG3fMG3fMG3f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4fmO5fmO5fmO5fmO5
fmO5fmO5fmO5fmO5fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3gMK5gMK5gMK5gMK5gMK5gMK5gMK5gMK5
fmC3fmC3fmC3g=G4g=G4gMK5gMK5gMK5f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4fmO5fmO5fmO5fmO5
fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5g=S6g=S6g=S6g=S6g=S6g=S6g=S6g=S6
gMK5gMK5gMK5gMK5gMK5gMK5gMK5gMK5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5h=[7h=[7h=[7h=[7
h=[7h=[7h=[7h=[7g]S5g]S5g]S5g]S5g]S5g]S5g]S5g]S5g=G4g=G4g=G4g=G4g=G4g=G4g=G4g=G4
g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3fmG2fmG2fmG2fmG2
fmG2fmG2fmG2fmG2fmC3fmC3fmC3fmC3fmC3fmC3003Dc/oDc/oDc/oEcm3Ecm3Ecm3Fd=7Fd=7Bcm7B
cm7Bcm7Cd=;Cd=;DdM?DdM?DdM?EdMOEdMOEdMOEdMOEdMOEdMOEdMOEdMOCd]CCd]CCd]CCd]CCd]CC
d]CCd]CCd]CDdM?DdM?Ed]CEd]CEd]CFdmGFdmGFdmGCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CC
d]CCd]CCd]CCd]CCd]CCd]CCd]CBd=KBd=KCdMOCdMOCdMODd]SDd]SDd]SCdMOCdMODd]SDd]SDd]SE
dmWEdmWEdmWCdMOCdMOCdMOCdMOCdMOCdMOCdMOCdMOCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CCdMOC
dMODd]SDd]SDd]SEdmWEdmWEdmWDdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGCd]CCd]CCd]CCd]CCd]CC
d]CCd]CCd]CCdm?Cdm?De=CDe=CDe=CEeMGEeMGEeMGFe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CCdm?C
dm?De=CDe=CDe=CEeMGEeMGEeMGDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CCdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Fe=CFe=CFe=CFe=CFe=CFe=CFe=CFe=CCdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?De=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CFe=?Fe=?Fe=?Fe=?Fe=?F
e=?Fe=?Fe=?Ie=?Ie=?Ie=?Ie=?Ie=?Ie=?Ie=?Ie=?Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Ie=?I
e=?Ie=?Ie=?Ie=?Ie=?Ie=?Ie=?Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Hdm;Hdm;Hdm;Hdm;Hdm;H
dm;Hdm;Hdm;Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Ee=3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Hdm3Edm;E
dm;Edm;Edm;Edm;Edm;Edm;Edm;DdloDdloDdloDdloDdloDdloDdloDdloEd<gEd<gEd<gFdLkFdLkG
d/oGd/oGd/oHeLgHeLgHeLgHeLgHeLgHeLgHeLgHeLgDeLcDeLcFe<cFe<cGe<cGe<cIdlcIdlcIdlcI
dlcIdlcIdlcIdlcIdlcIdlcIdlcFcLWNf=?AclOEel_=d<6/[9Z;QG9PETAPECYICS=BAbaBAB]HBBmL
CC=OCSAMC39OCC1NC2mMBbiJBReGBRYHBb]HCBeICRiND3=MCc9ODcMXG41]HTM]Hd]aIdmgK5IkM6=m
NFN3Off9QWN?S7jBTH>CThNDU8RHVXjJVi6NWiFPXIRQXYVSXifVYJ6YZ:BUZ9nKWYFDUhjZ[:JLWIVX
ZJFNWifIVYRCUHnPXYbMWiUVJ69CEDnMWiVBU8jFV9:CUYBGVYROXZ2WZZR^/Jnb]K>d]kFe^;J`/Jnb
/k6c];:d]K>c];:a/[2_/:j][Zb_/:NZZj:RXINGUXR8R7IiN6AXIe9PGTIDEd5FF49HFTAJFDALFDAK
F4=MF4=MF4=LFdMNGDUKFTIDDcmCDSiHEd=GET9BDCe5@35:ACI@C3YACCYACSUACcMCDCUFEC]DEC]?
CcM>CCQ=CSY:Bc]4A3I0@CM3A3Xa=b`d>Rlj?S<n@SI3ASM7AcU8BCU8BCUACC]FDT1IETMHF4QDEDED
EDEEF4UIG4eKFd]KFd]MFdUPG4YRGT]WHTeYI4m/IE5PH4QPH4QMH4MLGTQHFTICF4=@E45<DSm8DCe9
Cca9Cca=DCiCED9IFDMOGD]QGdeDET=JG4UQHU9UJ5U]Kf=hNFn1QGZ8Rh:TXYZ<S81/K5YFFD1GFCaN
GD=LF41CCSUMET=JDcmED3]ACCE>BS9=BC1<Bc5<Bbm2@BLo?R@l>b4j>20i=R4g=1ld<1db;Q/a;A@h
=1`c<1]4@bn<S7bWYYRSXYRTXiVWZZ6Y[:>[[JN][jV^[j^^[jf][Zb/[J^[[ZF[[ZF[[ZF[[ZF[[ZF[
[ZF[[ZF[[ZF/[jJ/[jJ/[jJ/[jJ/[jJ/[jJ/[jJ/[jJX/:JY[ZFX[JB/[jJ_/ZVb/jZb/jZc/JV`]:Va
]JZa]JZc]jbd^:fe^Jjf^Znf^Zni_K:j_[>k_kBo`;K2`KO4`kW6a;[7aK_?bL;@b/?Ac<?Bc/?Cd<;D
dL;Edl7Edl7GdlSFd/OHd/GIdlKKe/OMe/GKe<?Id/7IdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKHd/GH
d/GHd/GIdlKIdlKIdlKJe<OJe<OIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKJe<OJe<OJe<OJe<OJe<OJ
e<OJe<OJe<OIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKHe<;He<;He<;IeL?IeL?IeL?Je/CJe/CJe/CJ
e/CJe/CJe/CJe/CJe/CJe/CJe/CKelGKelGKelGKelGKelGKelGKelGKelGIeL?IeL?IeL?IeL?IeL?I
eL?IeL?IeL?Me/GMe/GMe/GMe/GMe/GMe/GMe/GMe/GKe<?Ke<?Ke<?LeLCLeLCMe/GMe/GMe/GJe/CJ
e/CJe/CJe/CJe/CJe/CJe/CJe/CKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGK
elGKelGKelGLf<KLf<KLf<KLf<KLf<KLf<KLf<KLf<KMe/GMe/GMe/GMe/GMe/GMe/GMe/GMe/GKelGK
elGKelGKelGKelGKelGKelGKelGOfLKOfLKOfLKOfLKOfLKOfLKOfLKOfLKNf<GNf<GNf<GNf<GNf<GN
f<GNf<GNf<GLeLCLeLCLeLCLeLCLeLCLeLCLeLCLeLCLe/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?L
e/?Le/?Le/?Le/?Le/?Le/?Le/?KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;Ke<?Ke<?Ke<?Ke<?Ke<?K
e<<00=?=c]C>cmC>cmC>cmG?d=G?d=G?d=G?d=;?dM;?dM;?dM?@d]?@d]CAdmCAdmCAdmGAemGAemGA
emGAemGAemGAemGAemGAem?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=CAdmCAdmCAdmGBe=GBe=GBe=KC
eMKCeM?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=;@e];@e];@
e]?Aem?Aem?AemCBf=CBf=?Aem?Aem?AemCBf=CBf=GCfMGCfMGCfM?Aem?Aem?Aem?Aem?Aem?Aem?A
em?Aem?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Aem?Aem?AemCBf=CBf=GCfMGCfMGCfMCCeMCCeMCC
eMCCeMCCeMCCeMCCeMCCeM?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Be=?Cdm?Cdm?CdmCDe=CDe=GEeMGE
eMGEeMKDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=?Cdm?Cdm?CdmCDe=CDe=GEeMGEeMGEeMCDe=CDe=CD
e=CDe=CDe=CDe=CDe=CDe=?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?CdmKDe=KDe=KDe=KDe=KDe=KDe=KDe=KDe=?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?CdmCDe=CDe=CD
e=CDe=CDe=CDe=CDe=CDe=KDdmKDdmKDdmKDdmKDdmKDdmKDdmKDdmWDdmWDdmWDdmWDdmWDdmWDdmWD
dmWDdmSCd]SCd]SCd]SCd]SCd]SCd]SCd]SCd]WDdmWDdmWDdmWDdmWDdmWDdmWDdmWDdmOBdMOBdMOB
dMOBdMOBdMOBdMOBdMOBdMSCd]SCd]SCd]SCd]SCd]SCd]SCd]SCd]GDd=GDd=GDd=GDd=GDd=GDd=GD
d=GDd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=SCd=GCd]GCd]GCd]GCd]GCd]GCd]GCd]GCd]CCcmCCcmCC
cmCCcmCCcmCCcmCCcmCCcmG@cMG@cMG@cMKAc]KAc]OBcmOBcmOBcmSEcMSEcMSEcMSEcMSEcMSEcMSE
cMSEcMCEc=CEc=KDc=KDc=ODc=ODc=WCc=WCc=WCc=WCc=WCc=WCc=WCc=WCc=WCc=WCc=W=anGLdkbf
ZIVHQ8>1JEmK?U9:;4i595U?<EI<;UE;;EQ=;ee?<Ue?<U];;UM7:Ui<;ee;;UY:;EU9;5U;;UY?<EeB
=5iD=VIJ?VEI?FYOA7AYCWQ^EWQ`FGadGH5hI8J2L8V5Lhb9NY6>OiBCQINGRiZJSY^JT9fNU9nPUZ:S
VZ>TVjBTWZFTX:RWXjZYYJjaZ:BWWYfOVK2b[:2QWJZ[ZJ2QWi^KVi^LV9nPW:NXY8^<R7n0O:VZYYZK
UjBUXJ:UXjFXYZZ]Zk2c/KBg]KJi]kJi]kJi]kBe/kBe/kFf];Jg]KNh][Nh][Ri]kRi]k>d/[Ff/[Rh
/[Ne[Jj]XinMTXb;OH5nKfM[F6EWE5mQCUYJB5UGAEUGAEeIAemKBEIG@eYKAeYKAeEF@U=D@5IG@eQI
AEMHA5=>?eA?@5IB@5MC@EMC@5MD?eMD?eMD?e5A>Da;=TU:=TY:>4Q9>D54=D53=d96>cPk<SXm=3m0
=T53=dI6>TQ7>DU8>TY:>Ta5?55:@EE>AEA@AE9>@e9?@EEBA5QEAeMEBeMEBeUEBUYFBeiHBf9KC6AM
CVENCf9SBF5RB5iOAEYMA5II@eAG@E5F@E5F@EAIA59D@51B?UEF@UeNBVIUDFMVDVQTDF9QCF1NC5aL
BU]LC5UOCUYQDUeWEf5ZGGYgKgQdJFQSE5E@>e9<=F1E?f1C?E=5<UQC?UE@>e1<=4a8;dU5;4Q5:DQ5
:DQ6:3Xj8SPh83De7C@c7S@c7c<b7S0^72h/6S4_5b/X4c<b7VaZF9RHR:j]WjBTV:FTVZJZWjNZXJZ]
Y:b^Z:j_Zjj_Zjf^[:b]Zj^^YJ^^YJ^^YJ^^YJ^^YJ^^YJ^^YJ^^YJb_YZb_YZb_YZb_YZb_YZb_YZb_
YZb_YZN_YJR]Y:N/XjZ]Y:b_YZn`Yjn`Yjn]YJ^_Y:^_Y:b`YJb`YJfaYZfaYZfaYZjbYjncZ;2dZK2d
ZK>dZ[JeZkNf[;Vg[KVg[L6n]/;0]/?1]lG3^<O5^/W8^/[9^l_;^lg;`Lg;`=3<`M;?`MSCa=_DaM[C
`][B`MSBaMSBaMSBaMSBaMSBaMSBaMSBaMSBaMOAa=SBaMSBaMSBaMWCa]WCa]WCa]WCa]SBaMSBaMSB
aMSBaMSBaMSBaMSBaMSBaM[Dam[Dam[Dam[Dam[Dam[Dam[Dam[DamWCa]WCa]WCa]WCa]WCa]WCa]WC
a]WCa]SD`]SD`]SD`]WE`mWE`mWE`m[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=_GaM_GaM_G
aM_GaM_GaM_GaM_GaM_GaMWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mgFaMgFaMgFaMgFaMgFaMgFaMgF
aMgFaM_D`m_D`m_D`mcEa=cEa=gFaMgFaMgFaM[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=_GaM_GaM_G
aM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaMcHa]cHa]cHa]cHa]cHa]cHa]cH
a]cHa]gFaMgFaMgFaMgFaMgFaMgFaMgFaMgFaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaMgGa=gGa=gG
a=gGa=gGa=gGa=gGa=gGa=kHaMkHaMkHaMkHaMkHaMkHaMkHaMkHaMcEa=cEa=cEa=cEa=cEa=cEa=cE
a=cEa=cF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`m[D`M[D`M[D
`M[D`M[D`M[D`M[D`M[D`M[C`][C`][C`][C`][C`][C`P00dlg>dlg>dlg>e<k?e<k?eLo@eLo@eLo@
d/oAd/oAd/oAdm3Bdm3Be=7Ce=7Ce=7Ce=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3Fe=3Fd]7Cd]7Cd]7Cd]7C
d]7Cd]7Cd]7Cd]7Cdm3Bdm3Be=7Ce=7CeM;DeM;DeM;DeM;Dd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7C
d]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7CdLoEdLoEd]3Fd]3Fdm7Gdm7Gdm7Gdm7Gd]3Fdm7Gdm7Gdm7G
e=;He=;He=;HeM?Idm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;D
d]3Fdm7Gdm7Gdm7Ge=;He=;He=;HeM?Ie=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Edm;Ddm;Ddm;Ddm;D
dm;Ddm;Ddm;Ddm;Dd];Bdm?Cdm?Cdm?Ce=CDe=CDe=CDeMGEe]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CD
d];Bdm?Cdm?Cdm?Ce=CDe=CDe=CDeMGEe=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Ce]CDe]CDe]CDe]CDe]CDe]CDe]CDe]CD
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Ce=CDe=CDe=CDe=CDe=CDe=CDe=CDe=CDe]CCe]CCe]CCe]CC
e]CCe]CCe]CCe]CCfMCCfMCCfMCCfMCCfMCCfMCCfMCCfMCCem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;A
fMCCfMCCfMCCfMCCfMCCfMCCfMCCfMCCem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Aem;A
em;Aem;Aem;Aem;Ae=??e=??e=??e=??e=??e=??e=??e=??em;?em;?em;?em;?em;?em;?em;?em;?
e=;Ae=;Ae=;Ae=;Ae=;Ae=;Ae=;Ae=;Adm;>dm;>dm;>dm;>dm;>dm;>dm;>dm;>eM3=eM3=eM3=e]7>
e]7>em;?em;?em;?emC<emC<emC<emC<emC<emC<emC<emC<dmC;dmC;eM?;eM?;e]?;e]?;f=;;f=;;
f=;;f=;;f=;;f=;;f=;;f=;;f=;;f=;;elg3fM33TXYiGULnDd/]A3`GDTPPK64eH5LfGUDdGE@cGU<c
Ge8bFdh^ETLWDD8REdPXETHYEdLZEdT/FDdaGe<gI5TnJ5e2LVM<LVI>MF]COW=MPGUROgQTPW]XQGm/
RhIgRhQiShamTY63UYJ:VYZ>W9fCWYnEW:2EWZ6HX:>JXJ>MXJ:NXZ>OY:FSYZNU[;2ZYJVSX:BN][Ze
YjZX/kJd[:j^ZJ^[];Rc[K6/^knj][Ze/KF`_<2k[k>^_<2k^;Zj^K^k^kfm^kfm^kfm^K^k][Rh]KNg
][Rh][Rh]KNg]KNg][Rh^;Zj^[bl^kfm/[Be/kFf][Jf^KZh^kZf^[Nb];6/[jfUSI:3PHIgLGAUHf=E
FUY<FUU;G5]=H5e?EUI4FEU7Fe]9FEU7EEE3DU90DU90DE4oBdTgBdTgC4XhCddkDe4oEE=1EUE1EEA0
DeA0CDhjBTXhBT/kATTj@TDf@4@hA4Pl@D@k@TDlA4DlA4DkAdLkBDLlBTTkBTTkDDm4E597F5E7F5E6
EUA2E590EEA0EUE1EEM;EUQ<EUU:FEU;Fe];G5a:Gee;H5i<FEe4Ee]2E5M1CeDnC5<nC58oBeA0C5E1
BThkB4`iB4`iBdllD5A1EeU6FE]8F5Y7Gem?FU];EEQ8DEU8CEM7AE92@E50@U91A4m5BUA8C5=6BTdm
BTXhDThkF54nFU4mDTljCd`gBdTaB4@[A40W@SlS@ShR@ShQ=CLQ<cDO<34M;RlK;RhL;2`L:BTI9bLG
:R/G824=>SXXRXYjVIR:ZjZLYJFIZj^OY:RMYZZOZJbSZjjU[JnY[JjZ[JjZ[:fYZjjUZjjUZjjUZjjU
ZjjUZjjUZjjUZjjU[:nV[:nV[:nV[:nV[:nV[:nV[:nV[:nVZ;2VZ:fTYjbSZZfT[:nV[k2W[ZnV[ZbT
[;2U[;2U[;2U[;2U[;2U[;2U[;2U[;2U[K6V[[:W[[:W/;6W/[6W/k:X];:X];:X/k6W];:X][BZ^;J/
^kV__K^`_kfb`;jc_;fc_[fc`L6ebLFjdL^nem31fM32f<o1f=;5f=;5f=;5f=;5f=;5f=;5f=;5f=;5
em74em74em74f=;5f=;5fM?6fM?6fM?6f=;5f=;5f=;5f=;5f=;5f=;5f=;5f=;5fM?6fM?6fM?6fM?6
fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6fM?6f=C2f=C2f=C2fMG3fMG3fMG3f]K4f]K4
fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4fMG3fMG3fMG3fMG3
fMG3fMG3fMG3fMG3g=G4g=G4g=G4g=G4g=G4g=G4g=G4g=G4fmC3fmC3fmC3g=G4g=G4gMK5gMK5gMK5
f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5
fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5gMK5gMK5gMK5gMK5gMK5gMK5gMK5gMK5
fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3gMO4gMO4gMO4gMO4
gMO4gMO4gMO4gMO4g=G4g=G4g=G4g=G4g=G4g=G4g=G4g=G4fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2
fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]?2f]?2f]?2f]?2
f]?2f]?2003Bc<gCcLkCcLkCcLkDc/oDc/oDc/oEcm3Bcm7Bcm7Bcm7Cd=;Cd=;DdM?DdM?DdM?Dd=KD
d=KDd=KDd=KDd=KDd=KDd=KDd=KBdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?Cd=;Cd=;Cd=;DdM?DdM?D
dM?Ed]CEd]CBdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?AcmGA
cmGAcmGBd=KBd=KBd=KCdMOCdMOBd=KBd=KBd=KCdMOCdMODd]SDd]SDd]SCdMOCdMOCdMOCdMOCdMOC
dMOCdMOCdMOCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CBd=KBd=KBd=KCdMOCdMODd]SDd]SDd]SDdmGD
dmGDdmGDdmGDdmGDdmGDdmGDdmGCd]CCd]CCd]CCd]CCd]CCd]CCd]CCd]CBd];Bd];Bd];Cdm?Cdm?D
e=CDe=CDe=CEdm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Bd];Bd];Bd];Cdm?Cdm?De=CDe=CDe=CCdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Edm;Edm;Edm;Edm;Edm;Edm;Edm;Edm;Hdm;Hdm;Hdm;Hdm;Hdm;H
dm;Hdm;Hdm;Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Hdm;Gd]7G
d]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7DdloDdloDdloDdloDdloD
dloDdloDdloGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oDd]7Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7Cd/kC
d/kCd/kCd/kCd/kCd/kCd/kCd/kEd<gEd<gEd<gFdLkFdLkGd/oGd/oGd/oGe<cGe<cGe<cGe<cGe<cG
e<cGe<cGe<cCe<_Ce<_Edl_Edl_Fdl_Fdl_Hd/_Hd/_Hd/_Hd/_Hd/_Hd/_Hd/_Hd/_Hd/_Hd/_Ec<;1
^:Y_IE=?@b]WFSYWFSAQDbUPDbMGCReFCBaEC2]FBb]HBb]GBRYGB2QEARIA@R9@@b=CABQFBRiNDCMU
FD5ZH4Q_I4igK5IeKEIkLeb2NfN6P6f6P6f6PW2:QWB:QgR<RG^>SGnCTHJHV8bKW9:OX9NOXYVNXIRP
XiZRY9jSYInRXinSY::UYZBWYjNTZjBNY9nLXYfd^KNW[:Ze^[V`];F_/kBj_kf^/k6k`;jn`l70aL>g
_;Za][Bm`/2f^;Rg^KVi^k^k_Kfl_[jl_[jk_Kfj_;bh_Kbg_;^e^[Vd^KRd^KRf^kZh_Kbi_[fl_l>i
_<2e^KZf^;Vi^;Zj^[Zl^[Zk^KV//ZNOYIZ?ThQlP7E`LFMXIeePGeELFe5IFTYJFd]MGTiMGTiJFd]C
E4A?D41=CSiADCm?Cce=CC]>CSa?Ccm@D41?Ccm=CCeFETI>Ccm9BSY6BCY3ASLm@CDl@cI0AcXi?CLi
?CLi?SDk?SDo@3I1@cM6ASY7Ac]8CCQ9CSU;D3]9DCY8D3U7D3I7D3I7D3I2DT52DT15Dd55E3m8E419
ECm9ECm;ECi<ETE8E494CcloC3`mBS`kBCdjBchlCD11CD51Cd=2D4A1Cd<nC40nC411Cd=1DTE5D4Hm
Bd0lBSllC44jBd0bB3`dBcdhDD<YC48ZBD0eD4M1ETdlC44b?2li@C1=D417C3M8BSI5B392A2i0@2Pn
?B<m>B0l>1lb=20_<Ad[;AXY:QXW:1PT91HQ8A<N7Q8J6`/N7`m>CcnPX9:KVhfTY9RTXYN[ZIjSYi^U
ZIfWZj2Z[JB/[jJ][jV/[ZR/[JV[[ZF[[ZF[[ZF[[ZF[[ZF[[ZF[[ZF[[ZF/[jJ/[jJ/[jJ/[jJ/[jJ/
[jJ/[jJ/[jJY/JNZ[jJY[ZF[[ZF]/:N`/JR_/:N`[ZJ^/ZN^/ZN^/ZN]/JJ]/JJ]/JJ//:F//:F^/ZN_
/jR_/jRa/ZRc/ZRc/ZRd/ZRd/ZR[ZZ2/Zj6^[J>a/:Jd/jVg]Jfi]jnj^;2^/jZa]:^g^:k1_kC;akcE
cL3Id<?Id<;Hd/GHd/GHd/GHd/GHd/GHd/GHd/GHd/GFd<?GdLCGdLCGdLCHd/GHd/GHd/GIdlKHd/GH
d/GHd/GHd/GHd/GHd/GHd/GHd/GIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKI
dlKIdlKIdlKHe<;He<;He<;IeL?IeL?IeL?Je/CJe/CIeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?Je/CJ
e/CJe/CJe/CJe/CJe/CJe/CJe/CIeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?LeLCLeLCLeLCLeLCLeLCL
eLCLeLCLeLCKe<?Ke<?Ke<?LeLCLeLCMe/GMe/GMe/GJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CKelGK
elGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGKelGK
elGKelGKelGMe/GMe/GMe/GMe/GMe/GMe/GMe/GMe/GKelGKelGKelGKelGKelGKelGKelGKelGLe/?L
e/?Le/?Le/?Le/?Le/?Le/?Le/?MelCMelCMelCMelCMelCMelCMelCMelCLeLCLeLCLeLCLeLCLeLCL
eLCLeLCLeLCKeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;KeL;Je<7J
e<7Je<7Je<7Je<7Je<7Je<7Je<7Jdl;Jdl;Jdl;Jdl;Jdl;Jdl800=;<cM;<cM;<cM?=c]?=c]C>cmC>
cmC>cm;?dM;?dM;?dM?@d]?@d]CAdmCAdmCAdm??eM??eM??eM??eM??eM??eM??eM??eM7@d]7@d]7@
d]7@d]7@d]7@d]7@d]7@d];?dM?@d]?@d]?@d]CAdmCAdmCAdmCAdm7@d]7@d]7@d]7@d]7@d]7@d]7@
d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]3>e=7?eM7?eM7?eM;@e];@e];@e];@e];@e];@e];@
e];@e]?Aem?Aem?AemCBf=?Aem?Aem?Aem?Aem?Aem?Aem?Aem?Aem?Be=?Be=?Be=?Be=?Be=?Be=?B
e=?Be=;@e];@e];@e];@e]?Aem?Aem?AemCBf=CCeMCCeMCCeMCCeMCCeMCCeMCCeMCCeM?Be=?Be=?B
e=?Be=?Be=?Be=?Be=?Be=;Bd];Bd];Bd];Bd]?Cdm?Cdm?CdmCDe=GCdmGCdmGCdmGCdmGCdmGCdmGC
dmGCdm;Bd];Bd];Bd];Bd]?Cdm?Cdm?CdmCDe=?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?CdmGCdmGCdmGCdmGCdmGCdmGCdmGC
dmGCdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?CdmGCd]GCd]GC
d]GCd]GCd]GCd]GCd]GCd]SCd]SCd]SCd]SCd]SCd]SCd]SCd]SCd]KAd=KAd=KAd=KAd=KAd=KAd=KA
d=KAd=SCd]SCd]SCd]SCd]SCd]SCd]SCd]SCd]OBdMOBdMOBdMOBdMOBdMOBdMOBdMOBdMKAd=KAd=KA
d=KAd=KAd=KAd=KAd=KAd=?Bc]?Bc]?Bc]?Bc]?Bc]?Bc]?Bc]?Bc]KAc]KAc]KAc]KAc]KAc]KAc]KA
c]KAc]?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=;AcM;AcM;AcM;AcM;AcM;AcM;AcM;AcMG@cMG@cMG@
cMKAc]KAc]OBcmOBcmOBcmKCbmKCbmKCbmKCbmKCbmKCbmKCbmKCbm;Cb];Cb]CBb]CBb]GBb]GBb]OA
b]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]KDbKjhZg1VED/m9eE4:UM59U]::EY:9U=9:e98:U16
:4m49U539U949eE5:5M7:Ti18E5495A9:ea@=6AH@6YOBG5VDWEZEWA]FGE^FWaeHXJ0KH^7MH^6Mhb9
NY2=OX^:O8j=Oi>AQYRHS9^LTZ2QV:6TVj:UW:2TWZ:VX:BXXZFYY:FXYZFXYZRZZZZ/[:F[YZ6WXZ2U
XkNl^ZR][;Jj^k:f]k:f]kZo_Znd/kRm_;Rm_<76aK2e];Fj^KVn_KRj^kRj^kZl_K^m_[^m_[^m_[^m
_[^m_[Vm_[Rl_KJj^kFi^[Bh^KFi^[Jj^kNk_;W1`KVn_kNl_KRl_KRl_KVk_;Vh^[Je]kFl]Jnf[jN^
YinSWIBFT8:4OW1`JV9RG61QDE]LC5UJBUaMCEYKBeAEADi??da=?Di>?4i>?4e=>de=?Da;?De<?Ti<
@Dm=@U=CAD];?D95=T13=3Xo<3Dl;cHm<3]2=B`f<2`g;bhf;blh;S@l<S]1=T17>T=:?Ce9<cm:=T1<
>3i>?3e??S]A?cYA@SYA@S=AASE@ASIBACUCASUCACUC@cYA@SYA@T9FDCeCCSU?BSA;Abm7ABi6A2a6
ARe7Ac1:BSA>CSEADC9>CRY9B2I6ABU9B2e=C2m=CRM5ARA2@b=2@Adl>AHe<Q`l=bQ8@b9EDAa;B2A>
CC1BDR4l>@PL5``L4BDc9bhi:C0j:S<k:SDk:3@h9C4c7bh_6bd/5bX^6bHY6B<V5R0S51hP51/M4ALH
3Q@E2``A0RDZ6fU/GJV/WJJVV:FUVJVWW:VWW:6UVJ>WVjJZWZV]XZ^^YJb_YZb^Z:^]Yj^^YJ^^YJ^^
YJ^^YJ^^YJ^^YJ^^YJ^^YJb_YZb_YZb_YZb_YZb_YZb_YZb_YZb_YZZbZ:Z_YZV^YJf`YjnbZK:cZ[6b
ZK:`Z:faYZfaYZfaYZfaYZb`YJb`YJb`YJb`YJfaYZfaYZjbYk2aYk:aYk:aYk>aYk>aYjf]XJj]Xk2_
YK>aZKJd[;Re/;Zg/[^h]:feZjjf[;Ji/<;1]lg9_]O>a=_BaMgAaMOAa=OAa=OAa=OAa=OAa=OAa=OA
a=OAa=K@`mK@`mK@`mOAa=OAa=SBaMSBaMSBaMOAa=OAa=OAa=OAa=OAa=OAa=OAa=OAa=SBaMSBaMSB
aMSBaMSBaMSBaMSBaMSBaMWCa]WCa]WCa]WCa]WCa]WCa]WCa]WCa]SD`]SD`]SD`]WE`mWE`mWE`m[F
a=[Fa=SD`]SD`]SD`]SD`]SD`]SD`]SD`]SD`]WE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE`mWE
`mWE`mWE`mWE`mWE`mWE`m_D`m_D`m_D`m_D`m_D`m_D`m_D`m_D`m_D`m_D`m_D`mcEa=cEa=gFaMgF
aMgFaM[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_G
aM_GaM_GaM_GaM_GaM_GaM[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=[Fa=gFaMgFaMgFaMgFaMgFaMgFaMgF
aMgFaM_GaM_GaM_GaM_GaM_GaM_GaM_GaM_GaMcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF
`mcF`mcF`mcF`mcF`mcF`mcEa=cEa=cEa=cEa=cEa=cEa=cEa=cEa=[D`M[D`M[D`M[D`M[D`M[D`M[D
`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`MWC`=WC`=WC`=WC`=WC`=WC`=WC`=WC`=WB`MWB`MWB
`MWB`MWB`MWB`@00d/c=d/c=d/c=dlg>dlg>dlg>e<k?e<k?d/oAd/oAd/oAdm3Bdm3Be=7Ce=7Ce=7C
dloEdloEdloEdloEdloEdloEdloEdloEdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3Bd/oAd/oAdm3Bdm3B
dm3Be=7Ce=7Ce=7CdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3B
d<kDd<kDdLoEdLoEdLoEd]3Fd]3Fd]3FdLoEdLoEd]3Fd]3Fd]3Fdm7Gdm7Gdm7Gdm7Gdm7Gdm7Gdm7G
dm7Gdm7Gdm7Gdm7Gdm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;DdLoEdLoEd]3Fd]3Fd]3Fdm7Gdm7Gdm7G
e=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Ee=?Edm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;Ddm;DdM7AdM7Ad];Bd];B
d];Bdm?Cdm?Cdm?Ce=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;BdM7AdM7Ad];Bd];Bd];Bdm?Cdm?Cdm?C
d];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
dm?Cdm?Cdm?Cdm?Ce=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Bdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?C
d];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Be=;Ae=;Ae=;Ae=;Ae=;Ae=;Ae=;Ae=;Aem;Aem;Aem;Aem;A
em;Aem;Aem;Aem;Ae]7@e]7@e]7@e]7@e]7@e]7@e]7@e]7@em;Aem;Aem;Aem;Aem;Aem;Aem;Aem;A
em;Aem;Aem;Aem;Aem;Aem;Aem;Aem;Ae]7@e]7@e]7@e]7@e]7@e]7@e]7@e]7@dm;>dm;>dm;>dm;>
dm;>dm;>dm;>dm;>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>dm7@dm7@dm7@dm7@dm7@dm7@dm7@dm7@
d]7=d]7=d]7=d]7=d]7=d]7=d]7=d]7=eM3=eM3=eM3=e]7>e]7>em;?em;?em;?e]?;e]?;e]?;e]?;
e]?;e]?;e]?;e]?;d]?:d]?:e=;:e=;:eM;:eM;:em7:em7:em7:em7:em7:em7:em7:em7:em7:em7:
eMO;blVnVi:5MFEEFT<cBSDPEdD^EdL`D4DZCd@YCD8WC3lUCChTCSlUDT4WE4<YDdLUEDXZG54cHePm
JV18L6EALfUGMF]JMg5NN79OOgQWR8AbS8UjS8UkRhYlShj0Shj0TY25UiN;VY^AWj2GWj:IX::LWZ:L
XZJPYJVSYj^VZ:^YZ:^YZJ^[Zjf][[2aZ:nZY:^XXjZW^KnnZZn`][^l/[Nj/kRk]kfl];Zi^Knn/KNf
`<K5/KNf_/C3]kfl_Ko0_Ko0_Ko0_;jo^kfn^[bm^K^l^;Zk][^l][^l]KZk]KZk]KZk][^l][^l]kbm
/;^i/KVh/KVi]KZk]kbm^;bm^;Vm]KJj];^f/kZe/[Vd/KNb[K6/Wj>NSHj:OWmkLWEVI6MHF5]<EeY;
EeY;DEA5C4m0BTdn@dDaATPeB4XgAdPhATHhAdLkBdY0D4m5CTe3A4Dk?Clc>Cda=3/^<CP[<cd]>D<c
:3Pa9cL`9SD]:3D]:cT^<Shb=d<g?4Hj@4]1?4]3>da8>Di<=e1B<e5F;e1I;51H:4aF:DiF:TmG;51F
;DmE;4mC;DeB;4e@9dM<9TI;94A:845:7D597T5;7T9<7d9?4CY34Se65D195dE=64M?6DYB6DeD6dmF
6d]G6DUE7TaG8DaE5Ci71b`d1RX`4CDk4TY;4dI96dA=6c]62R0[00H<00L53QPB3b0E52DH6bTM8BhP
9BhQ9BXK8RDE7R4A7R@C6b0A5a`=5AT=51P=4QH;3Q482`h51`d2;38WKg=WSi65WIfAWIfAZZVKY:>E
X:FFXZNHYJVMZ:bPZjnT[:nVZjjUZjfWZjjUZjjUZjjUZjjUZjjUZjjUZjjUZjjU[:nV[:nV[:nV[:nV
[:nV[:nV[:nV[:nVZ;2VZJjUZJjU[:nV[k:Y/kB[/[>Z/k6Y[;2U[;2U[;2U[;2U[;2U[;2U[;2U[;2U
ZjnT[;2U[;2U[k2V/K2V/[6W/k6W/k6W[k6U/;:V/K:X/kB[][J`^;Nc^[Rg^kVh/;^c/k^d^Kje`lBk
cL_1elk4f]36g=34em74em74em74em74em74em74em74em74e]33e]33e]33em74em74em74f=;5f=;5
em74em74em74em74em74em74em74em74f=;5f=;5f=;5f=;5f=;5f=;5f=;5f=;5fM?6fM?6fM?6fM?6
fM?6fM?6fM?6fM?6f=C2f=C2f=C2fMG3fMG3fMG3f]K4f]K4f=C2f=C2f=C2f=C2f=C2f=C2f=C2f=C2
fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fMG3fmC3fmC3fmC3fmC3
fmC3fmC3fmC3fmC3fmC3fmC3fmC3g=G4g=G4gMK5gMK5gMK5f]K4f]K4f]K4f]K4f]K4f]K4f]K4f]K4
fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5f]K4f]K4f]K4f]K4
f]K4f]K4f]K4f]K4gMK5gMK5gMK5gMK5gMK5gMK5gMK5gMK5fmO5fmO5fmO5fmO5fmO5fmO5fmO5fmO5
gMO4gMO4gMO4gMO4gMO4gMO4gMO4gMO4g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=G4g=G4g=G4g=G4
g=G4g=G4g=G4g=G4f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1
fM?0fM?0fM?0fM?0fM?0fM?0fM?0fM?0fM;1fM;1fM;1fM;1fM;1fM;1003AblcBc<gBc<gBc<gCcLkC
cLkCcLkDc/oBcm7Bcm7Bcm7Cd=;Cd=;DdM?DdM?DdM?CcmGCcmGCcmGCcmGCcmGCcmGCcmGCcmGAd=;A
d=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Bcm7Bcm7Bcm7Cd=;Cd=;Cd=;DdM?DdM?Ad=;Ad=;Ad=;Ad=;Ad=;A
d=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;@c]C@c]C@c]CAcmGAcmGAcmGBd=KBd=KAcmGA
cmGAcmGBd=KBd=KCdMOCdMOCdMOCdMOCdMOCdMOCdMOCdMOCdMOCdMOCdMOCd]CCd]CCd]CCd]CCd]CC
d]CCd]CCd]CAcmGAcmGAcmGBd=KBd=KCdMOCdMOCdMODdmGDdmGDdmGDdmGDdmGDdmGDdmGDdmGCd]CC
d]CCd]CCd]CCd]CCd]CCd]CCd]CAdM7AdM7AdM7Bd];Bd];Cdm?Cdm?Cdm?Dd];Dd];Dd];Dd];Dd];D
d];Dd];Dd];AdM7AdM7AdM7Bd];Bd];Cdm?Cdm?Cdm?Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Cdm?C
dm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Dd];Dd];Dd];Dd];Dd];D
d];Dd];Dd];Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Cdm?Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Dd]7D
d]7Dd]7Dd]7Dd]7Dd]7Dd]7Dd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7FdM3FdM3FdM3FdM3FdM3F
dM3FdM3FdM3Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7Gd]7FdM3F
dM3FdM3FdM3FdM3FdM3FdM3FdM3Cd/kCd/kCd/kCd/kCd/kCd/kCd/kCd/kFdLkFdLkFdLkFdLkFdLkF
dLkFdLkFdLkCdM3CdM3CdM3CdM3CdM3CdM3CdM3CdM3BdLgBdLgBdLgBdLgBdLgBdLgBdLgBdLgEd<gE
d<gEd<gFdLkFdLkGd/oGd/oGd/oFdl_Fdl_Fdl_Fdl_Fdl_Fdl_Fdl_Fdl_Bdl[Bdl[Dd/[Dd/[Ed/[E
d/[GdL[GdL[GdL[GdL[GdL[GdL[GdL[GdL[GdL[GdL[8c/?CdlO?a[c;^JjXTXIoIe]SCSli9QLo<a]0
=1a2=Qi5=b19>B9=?BIC@BYFA2eGCB]KD31SF3YZGdA_I4idJEEeJeYfK5]nN6EnMfJ2OVb9QWN=RWb9
R7Z9Qgb:RWjAShBDU8RIVHfLWI>NXIRNXIRKWiVJWYRPYj2RZ:>UZjJVZjVVZjZW[:^Z[Zn]/K:U[:VQ
Z:FQZ:Fg_KbW[:fd^KZa][Vb]kZ_]KBb^;Nf_;^X[Zfk`L2_]KC2b<Na]kJd]KVd]KVe][Zg^;bh^Kfi
^[jj^knj^kne^[fe^[ff^kjf^kjg_;nh_L2h_L2i_/6b_KZ`^kR_]kJ^][Fa][Nc]kRb][Na];Rc_;V`
^KJ`]kBa^;Fc^;J`/k6VZJNOX9j=T85gNV]SIUMMH55KGTmEF4U@DdA?DT=9BcM<CS]>D3e9BSY3@cM1
@3I5A3Y:B419BT11@SPk?38g>blc>Rdb>B`d?RhkACDW?3@V>34R=2dQ<RTQ<RLT=2TX>B`/>RhR;C4P
;38J:c@D:cX>;3l9:d<1:4@09TH094009D409d00:4419cl29cd09C/08cT5:cL6:cT6;C/6;ch9<D<:
=DH==dX>>D`AA5@@A5@CBUTLEF@XHg8aKW`cLX0bLGlLEf/TGg8hL8=7NH/kJWPSCe`MA58VC5P4=S`@
?DPH?4`B;3d452D01a@8314D5QH05@/56Q4@8aXJ:QlQ;B4R:QlO9QTM8ADD6``A60T>5@P=50L=4`P<
4@P93PD62`812@0W;bANI5USIe]oPGF8R7bRXI>MVXbOY9FQYYNUZIfX[:2Z[Z>[[ZF[[ZF[[ZF[[ZF[
[ZF[[ZF[[ZF[[ZF[[ZF[[ZF[[ZF/[jJ/[jJ/[jJ/[jJ/[jJ/[jJ/[jJ/[jJW[jFX[JBW[:>/[jJ_/ZVc
]:^c]:^c/JV//:F//:F]/JJ]/JJ]/JJ^/ZN^/ZN^/ZN[[jB[[jB//:F_/:Ja/:Jb/JNd/ZRd/ZR_/JF`
/ZJb/jVc]:^f][2h]k>i]kJj^;Re`;Rg_kRj`[S4aKc<b/3Ec<;Fc<;Gbl7GdLCGdLCGdLCGdLCGdLCG
dLCGdLCGdLCEcl;Fd<?Fd<?Fd<?GdLCGdLCGdLCHd/GGdLCGdLCGdLCGdLCGdLCGdLCGdLCGdLCHd/GH
d/GHd/GHd/GHd/GHd/GHd/GHd/GIdlKIdlKIdlKIdlKIdlKIdlKIdlKIdlKHe<;He<;He<;IeL?IeL?I
eL?Je/CJe/CHe<;He<;He<;He<;He<;He<;He<;He<;IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?IeL?I
eL?IeL?IeL?IeL?IeL?IeL?IeL?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?Ke<?LeLCLeLCM
e/GMe/GMe/GJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CKelGKelGKelGKelGKelGKelGKelGKelGKelGK
elGKelGKelGKelGKelGKelGKelGJe/CJe/CJe/CJe/CJe/CJe/CJe/CJe/CMe/GMe/GMe/GMe/GMe/GM
e/GMe/GMe/GKelGKelGKelGKelGKelGKelGKelGKelGMelCMelCMelCMelCMelCMelCMelCMelCLe/?L
e/?Le/?Le/?Le/?Le/?Le/?Le/?LeLCLeLCLeLCLeLCLeLCLeLCLeLCLeLCJe<7Je<7Je<7Je<7Je<7J
e<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Idl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3Id/7I
d/7Id/7Id/7Id/7Id/400=C>cmC>cmC>cmC>cmC>cmC>cmC>cmC>cm;?dM;?dM?@d]?@d]?@d]CAdmCA
dmCAdm;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d];?dM;?dM?@
d]?@d]?@d]CAdmCAdmCAdm?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]CAdmCAdmCAdmCAdmCAdmCAdmCA
dmCAdm7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]3?dM3?dM3?dM7@d]7@d];Adm;Adm;Adm;Adm;Adm;A
dm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm;Adm7@d]7@d]7@d]7@d]7@d]7@d]7@
d]7@d]?AdM?AdMCBd]CBd]CBd]GCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmGC
dmGCdmGCdmGCdmGCdmGCdmGCdmCBd]CBd]?AdM?AdM;@d=;@d=7?cm?AdM?AdMCBd]CBd]CBd]GCdmGC
dmGCdmCBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]GCdmGCdmGCdmGCdmGCdmGCdmGCdmGCdmCBd]CBd]CB
d]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CB
d]CBd]?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=OBcmOBcmOB
cmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOBcmOB
cmOBcmOBcmKAc]KAc]G@cMG@cMKAc]KAc]OBcmKAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KA
c]KAc]KAc]KAc]KAc]KAc]G@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@
cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cM7@c=7@c=?@c=CAcMG@cMKAc]SAc]SAc]OAb]OAb]OA
b]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]OAb]K@bMK@bMK@bMK@bMK@bMK@bMK@
bMK@bMOAb]7;a<o9`]C>amOAb/[4_JfWX9F?R5YA?Di5<D4f8ST^6Sd_74@e8TPi9TTj9eY<=Ue@>V9E
?fIKAFQRBfm[DgMcFg]iHGEeIgUiJgmoLH>3MHJ6N8V9Nhn?PIBDQYJCQIFCR9NERYZISi^LTYnPUinR
VJ6SWJFSXjJTY:RVYZZXZ:f[Zjn][K6_[k:`/:fc[Z^`[ZZ_[Jba/;6f]K>g^;:f]k2c]k6f]K6f]K6f
]K6f]K:g][Bi^;Fj^KJk^[Bi^;Bi^;Bi^;Fj^KFj^KFj^KFj^KFj^KBi^;Bi^;Bi^;Bi^;Bi^;Bi^;Bi
^;Bi^;6f]K6f]K6f]K6f]K:g][>h]kFj^KJk^[>f^[>f^[>f^[:e^K:e^K:e^K:e^K:e^JBZWiFKT7f4
Mf=ZGE1GB4Q@?dUA@4aD@eAA@U1C@dE??cM4=S=0<SU3=ci1>3/l<c4o<c4k;c@i<3/m=c<i=24/:A8S
80`R804G8P8H8`@J9@@J9@DK9PLM:0/Q;0hT;`8U<P8X=0H[>@P_?@/b@@`dAP`gB0dgBQ52DQA7EaU=
GA]BHA]DHaYEI1YGIAaIIamFHb1GI25HIb5HIb9HJB5GJ25FJR1EJA5BHA=AHAIAHA]CI21HJB9MKB5O
KaiOKS]_O0HjAc1TLDEjQe25TT5fPdQoS3mfPca`McE/L@/j?QTf>`073P@42PXC5P0>304E6P<J700H
62I3@1di<`dR6PTF3PhG3@hE4P050P0200P?30H=2P02000200L>2``?02HY6Cdn;T11<DI6=UQHB6aY
FW=`HH64MHV<OIJIRZ>VUj^^WjjaXZf`XJ^^WjR/X:Z^XZ^_Y:Z]Y:V/XjV[YJb^Z:j_ZjZ/YZV[YJZ/
YZb^Z:f_ZJf_ZJb^Z:Z/YZZ^XZfaYK2dZ;6eZJncYjjbYZfaYJjbYZV/XjV/XjZ]Y:Z]Y:^^YJ^^YJb_
YZb_YZ^_Y:faYZncZ:ncZ:faYZb`YJfaYZjbYjf^ZZn`[;>e[k:d[[6dZkRl/HV=PZN[X:R^XkVk[l6n
[kZbXMkCaMG9_mG9`mc@c]O@_mO@_mO@_mO@_mSA`=SA`=SA`=WB`MSA`=SA`=SA`=SA`=SA`=SA`=SA
`=SA`=WB`MWB`MWB`MWB`MWB`MWB`MWB`MWB`MSA`=SA`=SA`=WB`MWB`MWB`M[C`][C`][C`][C`][C
`]WB`MSA`=SA`=O@_mO@_mWB`MWB`MWB`M[C`][C`][C`]_D`m_D`mWC`=WC`=WC`=WC`=WC`=WC`=WC
`=WC`=[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`][D`M[D`M[D
`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M_E`]_E`]cF`mcF`mcF`m_E`]_E`]_E`]_E`]_E`]_E`]_E
`]_E`]cF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`m_E`]_E`]cF
`mcF`mcF`mgGa=gGa=gGa=cF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF
`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`mcF`m_E`]_E`]_E
`]_E`]_E`]_E`]_E`]_E`][E`=[E`=[E`=[E`=[E`=[E`=[E`=[E`=WC`=WC`=[D`M_E`]_E`][D`MWC
`=WC`=[D`MWC`=SB_mSB_mSB_mSB_mWC`=[D`M_A_m_A_m_A_m_A_m_A_m_A_`00e<k?e<k?e<k?e<k?
e<k?e<k?e<k?e<k?d/oAd/oAd/oAdm3Bdm3Bdm3Be=7Ce=7Cd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oA
dm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bd/oAd/oAd/oAdm3Bdm3Bdm3Be=7Ce=7Cdm3Bdm3Bdm3Bdm3B
dm3Bdm3Bdm3Bdm3Be=7Ce=7Ce=7Ce=7Ce=7Ce=7Ce=7Ce=7CdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3B
d<oAd<oAd<oAdM3BdM3Bd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7Cd]7C
d]7Cd]7Cd]7Cd]7CdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3Bdm7Adm7Adm7Ae=;Be=;BeM?CeM?CeM?C
eM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?Ce=;Be=;Be=;Bdm7A
dm7Ad]3@d]3@d]3@dm7Adm7Adm7Ae=;Be=;BeM?CeM?CeM?Ce=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;B
eM?CeM?CeM?CeM?CeM?CeM?CeM?CeM?Ce=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;B
e=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Bdm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7A
dm7@dm7@dm7@dm7@dm7@dm7@dm7@dm7@em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?
em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?em;?e]7>e]7>eM3=eM3=e]7>e]7>em;?
e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>eM3=eM3=eM3=eM3=
eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=
dM3<dM3<dm3<e=7=eM3=eM3=f=7>f=7>em7:em7:em7:em7:em7:em7:em7:em7:em7:em7:em7:em7:
em7:em7:em7:em7:e]39e]39e]39e]39e]39e]39e]39e]39em7:e<k7d/c5e<k7f=;;f=;;dL_4blFn
blBa/JNEQge[I5Q6CT0^@cDS@30O?RhMETTcGE0jIU]5KVI?LVaELFeEKFUAJ6I>N7QZNGU[NWY/NWY/
NWY/OWi`QHEgRh]mUYJ8UYJ:UYJ:UIJ<U9R=UIR?UIZAUIVCXJ6QXZ:RY:BTYZJVZ:RXZj^[[Jf][Jf]
[;:]ZJj/YjbZZJj][K:a/;Be/;Be[k:f[K:a[kBc/[Nf];Vh][^j][^j]KZi];Vh];Vh];Vh];Vh];Vh
];Vh];Vh/kRg/kRg/;Fd/;Fd/;Fd/KJe/[Nf/kRg/kRg/kRg/KJe/KJe/;Fd/;Fd/;Fd/;Fd/KJe/[Nf
/kNh/kNh/kNh/kNh/kNh/kNh/kNh/kNh];RbZZjXVIjEQH^0LGM/GFAGC5=6@dXkBDLlBde1Adi1?TPk
>T@h?48g>S/a=C<Y;CLZ;cL/<3P^:c8]7BPV4R@S5C4b8d938TYF9TiJ:E5M:e=O:e=O:e=O;5AP;EEQ
9e5M:59O:E=P:5=R9eAR9e=T959T959T5DQH5d]K6TiN64mN54eL44]J3T]I3T]I3DMC3DMC3TMF3TMF
3TIG3TIG3DEH34AG75QX6e=T8UIW;Ema=FMi<fMh;6Ae:6Ad?71m44AA=FUf?gB1A7V6@7F2DXNDDXND
Ag^2?WAk64Q>4Rld00L>10@:51dP01DC014C018D014A:DA132<O014=00D200H100@300D400<20040
0PL62@h=10T80040720=;c<P?Cl/>C/X=cLU@40^BTPfBTPfC4m0E5M8HVEFLgIWQHQiTiJ7WJ2AXZFF
YZZNZJfQ[;2T[;2UZjjUZJbSZJ^UZJ^U/K>][k6[[JnY[:jX[:jX[:jXZjfWZZbVYjZQZZfT[[6X[k:Y
[[6X[[6X[k:Y/KB[ZjjUZjjUZjjUZjjUZjjU[:nV[:nV[:nVZjnT[K6V[k>X[[:W[K6V[;2U[;2U[[:W
ZJZV[JjZ];J`/K>]Z:^RXJFJGf=HL7AYL7MXO7m_QHA`S8Ebakf[d<FgeL[2fLo8e/nnem2oem2oem2o
f=70f=70f=70f=70em2oem2oem2oem2oem2oem2oem2oem2ofM;1fM;1fM;1fM;1fM;1fM;1fM;1fM;1
em2of=70f=70f=70fM;1fM;1fM;1f]?2f]?2f]?2fM;1fM;1f=70f=70em2oem2ofM;1fM;1fM;1fM;1
f]?2f]?2fmC3fmC3fM?0fM?0fM?0fM?0fM?0fM?0fM?0fM?0f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1
fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1fmG2
fmG2fmG2g=K3g=K3fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3
g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3fmG2fmG2fmG2g=K3g=K3g=K3gMO4gMO4g=K3g=K3g=K3g=K3
g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3
g=K3g=K3g=K3g=K3g=K3g=K3g=K3g=K3fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2f]G0f]G0f]G0f]G0
f]G0f]G0f]G0f]G0fM?0fM?0f]C1fmG2fmG2f]C1fM?0fM?0f]C1fM?0f=:of=:of=:of=:ofM?0f]C1
f]2nf]2nf]2nf]2nf]2nf]2n003CcLkCcLkCcLkCcLkCcLkCcLkCcLkCcLkBcm7Bcm7Bcm7Bcm7Cd=;C
d=;Cd=;DdM?Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Bcm7B
cm7Bcm7Bcm7Cd=;Cd=;Cd=;DdM?Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;DdM?DdM?DdM?DdM?DdM?D
dM?DdM?DdM?Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;@cm7@cm7@cm7Ad=;Ad=;BdM?BdM?BdM?BdM?B
dM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?BdM?Ad=;Ad=;Ad=;Ad=;Ad=;A
d=;Ad=;Ad=;CdM7CdM7CdM7CdM7Dd];Dd];Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?E
dm?Edm?Edm?Edm?Edm?Edm?Edm?Dd];Dd];Dd];CdM7CdM7Bd=3Bd=3Bd=3CdM7CdM7CdM7CdM7Dd];D
d];Edm?Edm?Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Edm?Edm?Edm?Edm?Edm?Edm?Edm?Edm?Dd];D
d];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];Dd];D
d];Dd];Dd];CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM3CdM3CdM3CdM3CdM3CdM3CdM3CdM3Gd/oG
d/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oGd/oG
d/oGd/oGd/oGd/oFdLkEd<gEd<gEd<gEd<gFdLkGd/oFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkFdLkF
dLkFdLkFdLkFdLkFdLkFdLkFdLkDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcD
clcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclc@cl_Ad<cCd<cCd<cEd<gEd<gGd<gGd<gFd<WF
d<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WF
d<WFd<WFd<WGdL[GdL[Fd<WCcLKAblCCcLKHd/_Mem3HdL3Hd;oCbk[:`:neZ9RBQGE]GTiDACE>@bm<
@Be;@RiDBcMRFdMbKEQoNVF6PFaaL69dLfEhMfUmO6j1P7:7QWR>SGnCTXB:SGj:S82:SX:<T8F=ThR>
UXbAVHnCVY>JWijJWijLXJ2OY:>QYZFSZ:NUZZVVZjZY[jZW[:ZTZJNTZJRW[:^Z[Zn//;6]/;BY[Zf/
/K2a][Fe^[Vg_;^f^kZd^KRc^;Nd^KRc^;Nc^;Nb]kJb]kJa][Fa][F`]KBZ[jj[/:n//K2]/[6^/k:_
];>`]KBa][F`]KB`]KB_];>^/k:]/[6^/k:^/k:_];>a]KJa]KJa]KJa]KJa]KJa]KJa]KJa]KJd]kF^
/JnSYj:GViJ4R89ZKfI;D4Lg?3<n?SQ1@ce1ASdlA3Xi@CHl@3Dj>Rhe<bP[<bPY<BLS;BLI9bD:8B<3
8bP9<cXD@TX0<Sh0=T80?4P2?TX1?DT0>dL0>TH0>TH4=T86>4@8>DL9?DX;?dl<@54;@E8;@E8ICf0M
Df@NEVLPF6TNFFTLF6PMFFTMFFTPH6/PH6/PGfdPGfdPGVhOGFdMFfdLFV`REVLA@eD??DlLAeXRCF0H
AUP?@E<BAULXGFX>@e0`IG8eJWLfJgPmLWm>Pi1BQiA?Q8i<PXTeIF/E<ST84AX:3A8O:bd36a/04a@0
4a<04a<oE5D661T851@730d<3Pl000020P810@400000000000010@40000V:QLb=R<k?BXg>BHf=R@j
>RPm>bTh=R@e=RHh>BTn?bm9BSYFEdMTIEE`LF5hNFV:Sh2AUXNJWi2RYYZVZYnY[J:/[jJ^/JR/[jJ[
[ZFY[:>XZj:WZZ6XZj:Z[JB[[ZF^/:Z_/J^`/Zb_/J^][jV[[JN/[ZR][jV]/:N]/:N]/:N]/:N/[jJ/
[jJ/[jJ/[jJ//:F^/ZN_/jR^/ZN//:F[[jB//:F^/ZN_/:bc];2h^[Bd][2Y[:>LX9E?DdQGFe1EGTYI
GTUMGDE/Idjk/icDb[SJdL?Gc/CFckkFckkFckkGd;oGd;oHdL3HdL3HdL3Gd;oGd;oGd;oGd;oGd;oG
d;oGd;oGd;oHdL3HdL3HdL3HdL3HdL3HdL3HdL3HdL3Gd;oGd;oHdL3HdL3HdL3Id/7Id/7Id/7Id/7I
d/7Id/7HdL3HdL3HdL3Gd;oGd;oHdL3HdL3Id/7Id/7Jdl;Jdl;Jdl;Jdl;Hd[oHd[oHd[oHd[oHd[oH
d[oHd[oHd[oIdl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Idl3I
dl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3Je<7Je<7Je<7KeL;KeL;KeL;KeL;Je<7Je<7Je<7Je<7Je<7J
e<7Je<7Je<7Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?KeL;K
eL;KeL;KeL;Le/?Le/?Le/?MelCLe/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?L
e/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Le/?Je<7J
e<7Je<7Je<7Je<7Je<7Je<7Je<7JeL3JeL3JeL3JeL3JeL3JeL3JeL3JeL3Hd[oIdl3Je<7Je<7Je<7J
e<7Idl3Hd[oIdl3Idl3Hd[oGdKkGdKkHd[oIdl3Idl3Jd;kJd;kJd;kJd;kJd;kJd;h00=?=c]?=c]?=
c]?=c]?=c]?=c]?=c]?=c]7>d=7>d=;?dM;?dM;?dM?@d]?@d]?@d];?dM;?dM;?dM;?dM;?dM;?dM;?
dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM7>d=7>d=;?dM;?dM;?dM?@d]?@d]?@d]?@d]?@d]?@
d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d]7@d]7@d]7@d]7@d]7@d]7@d]7@
d]7@d]3?dM3?dM3?dM7@d]7@d];Adm;Adm;Adm7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@
d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d];@d=;@d=?AdM?AdM?AdMCBd]CB
d]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]?AdM?AdM?A
dM?AdM?AdM?AdM?AdM?AdM;@d=;@d=?AdM?AdM?AdMCBd]CBd]CBd]?AdM?AdM?AdM?AdM?AdM?AdM?A
dM?AdMCBd]CBd]CBd]CBd]CBd]CBd]CBd]CBd]?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?A
dM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM;@d=;@d=;@d=;@d=;@d=;@d=;@
d=;@d=;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cmKAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KA
c]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]KAc]G@cMC?c=C?c=G@cMKA
c]KAc]G@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMC?c=C?c=C?
c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?
c=C?c=3?bm3?bm;?bm?@c=C?c=G@cMO@cMO@cMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@
bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bMK@bM7;a=G?b=OAb]G?b<o9`/c6_lg7
`=3:`lo:^m?>_m_DaN3GbMkEamG:_<Fj[;^^X9VAP8MoKVmWEUmGAUeFAF=LBfYSDVeVEG=bI7MfJ7el
KX:1LhF4MXF4MX>2M8>2M8J;O8N;OhR<P8R>PhZBQhjFS96JT9BLUI>LVIBMVYFNViRQWYZSX9bUXYjW
Y9nXYJJ/Yj>XYZ2UXinTXj6VYJBXZJR/[JZ]/JN/ZjV^[Jba/:nd/k:g][>h]k>h]k:g][:g][:g][6f
]K2e]:nd/jjc/Zjc/Zfb/JR][:R][:V^[JZ_[ZZ_[Z^`[j^`[jba/:jc/Zfb/Jba/:ba/:ba/:fb/Jjc
/Znd/jfb/Jfb/Jjc/Zjc/Zjc/Zjc/Znd/jnd/kVk_;>e]Zb^[ZJXZ9^NW8B8PfAXHdeAC3Tl>STl>SPl
=cDi<c@i<3Hi<3Lh;SHg;B@/9AXV818U8Q@];aLk@AA2C@XoC00jB@mBHA9EI1IIJ1MJJAIIJ1AGIQ=F
IA=FIB9JIB9LJ2EOJbIQL2UUMB]WMbYXNR]YNbEPL2MSLbYVMRaXN2aXN2aXN2aZNRe[NbQ]MbQ]MbQ/
NBQ/NBMZNBEXMb=UMb9TMQ];G@0]?`0L;`0V>@@/?`0U>00W>@<cAA=:E`U0CB]PKC=XMCM/NDEiQTMk
R4EiQTZ1RTf4SDQiPAPe?PdF7``>5Q`X;00D50LO7@8H5P0E4daKG@0520872P000`@01@L51@<10@L5
1@/92@80008000T71bDS8bX_6S4f8CPj9SPj9S`m:D11;Cln:STh93dn;S/l;3Tj:SPi:C/l;411<DI7
=dY;>eMKB5mRDVe`H7aoL8V;OiFGRj2QUjJWWJJZWZN[WjR/X:R/X:N[WjN[WjR/X:V]XJZ[Yjb]ZJb]
ZJ^/Z:Z[YjVZYZZ[Yjb]ZJnbZJnbZJjaZ:jaZ:f`Yjb_YZb_YZb_YZb`YJjbYjjbYjfaYZ^_Y:^_Y:fa
YZncZ;>g/[>g/[Bh/[2d[Z^`YjN]XUaREf1VFfA^Ef=YD5mQA6YVBK^dVMO?^=_D`M?<_MK?_]K?_]K?
_]K?_]O@_mO@_mSA`=SA`=O@_mO@_mO@_mO@_mO@_mO@_mO@_mO@_mSA`=SA`=SA`=SA`=SA`=SA`=SA
`=SA`=O@_mO@_mO@_mSA`=SA`=SA`=WB`MWB`MSA`=SA`=SA`=SA`=SA`=SA`=O@_mO@_mSA`=SA`=SA
`=WB`MWB`MWB`M[C`][C`]SB_mSB_mSB_mSB_mSB_mSB_mSB_mSB_mWC`=WC`=WC`=WC`=WC`=WC`=WC
`=WC`=[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`MWC`=WC`=WC`=WC`=WC`=WC`=WC`=WC`=WC`=WC`=WC
`=[D`M[D`M_E`]_E`]_E`][D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M_E`]_E`]_E`]_E`]_E`]_E`]_E
`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`][D`M[D`M_E`]_E`]_E`]cF`mcF`mcF`m_E`]_E`]_E
`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E
`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`]_E`][D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[E`=[E`=[E
`=[E`=[E`=[E`=[E`=[E`=SB_mSB_mWC`=[D`M[D`MWC`=SB_mSB_mWC`=SB_mOA_]OA_]OA_]OA_]SB
_mWC`=[@_][@_][@_][@_][@_][@_P00d/c=d/c=d/c=d/c=d/c=d/c=d/c=d/c=dLk@dLk@dLk@dLk@
d/oAd/oAdm3Bdm3Bd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oA
dLk@dLk@dLk@dLk@d/oAd/oAdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3B
dm3Bdm3Bdm3Bdm3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3Bd<oAd<oAd<oAdM3BdM3Bd]7Cd]7Cd]7C
dM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3B
dM3BdM3BdM3BdM3Bd]3@d]3@d]3@dm7Adm7Adm7Ae=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;B
e=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;Bdm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Ad]3@d]3@d]3@dm7A
dm7Adm7Ae=;Be=;Bdm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Ae=;Be=;Be=;Be=;Be=;Be=;Be=;Be=;B
dm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7A
dm7Adm7Adm7Adm7Ad]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3?d]3?d]3?d]3?d]3?d]3?d]3?d]3?
e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>e]7>
e]7>e]7>e]7>e]7>e]7>eM3=e<o<e<o<e<o<e<o<eM3=e]7>eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=
eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<
e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<clk:d<o;d/o;d/o;e<o<e<o<e/o<em3=
e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39e]39
e]39e]39e]39e]39clW2dL_4dlg6e]39em7:e]39eLo8dlg6f]O9eM;4d<ZmcLNjd/ZmfM33h=O:i=_>
em;3b/Ff^kBUZZ>DVY>4Qh1aLV]LI5e>IfAFJFIHKV]MMG9TO7U[PGi`QH9dQX=eS8n0S8j2RHf1RHf2
RHn4RY:8SIF;SiJ?SiVCT9ZDTYbFU9jHUj6KVJ>MVjFOW:JPXZRSX:FSWZ>QW:6PW:6PWj>TXjNXYZV]
YZ^ZYZ^ZYZ^ZYjb[ZJj][K:a/;Fd/[Nf/;Fd/;Fd[kBc[[>b[K:a[;6`Zk2_Zk2_ZJj]ZJj]Z:f/Z:f/
Yjb[YZ^ZYZ^ZYZ^ZZZn^ZZn^ZZn^ZZn^Zk2_[K:a[kBc[kBc[;6`[;6`[;6`[K:a[K:a[[>b[[>b[kBc
];Fi/;6e[k6b/;:bZjf]UYVGMGQfG61K=c`j=CXh=3Tg<SPc;cD`:S4/9C0X9C0X4B<T3bHX4S4d74=;
:EYT:fAc8V1`5EMY969d9F=e9VAf9F=e8f5c8f5c9F=e9fEg:FMb:FMb9fId9FId9FIe8F=e869d7F5d
;Feo;Vj0;Vj0;6an:VQj9fEg9VAf9fEg96Uc96Uc96Qe96Qe8fIe8FAc869d7f5c6TaN0C5302@g33A7
641C4ciA54AF7e5S6E=O4deI9ei[=FYg@GF2F8VGC7f;BWV7@gV4A7b7BGZ43B`e00LA008<3QXP00`>
220N0ALE0a<BDeiL1@X92`T9100020832P<01`002P<05a0=6Q<@50d:5a0=8a`I<3DP<SLR=CLS=SPT
>CXV>c`X>3LS<C0L>c/Y>SXX>3PV>3PV>CTW?3`Z?Sh/@40^<cDQ>C/W@T@aCDllFEY:IVIHLg=UNg]_
TIJ7UY^<WJ:CXZNHY:VJYZ^LZJjO[;6RXjFOYZRRZJ^UZZbVZZbVZjfW[JnY/;:/[k:Y[k:Y[[6X[[6X
[K2W[:nV[:nV[:nV[;2U[K6V[K6V[;2UZjnT[;2U[[:W/KFZ/;Ja[kF`[KB]Z:nXZ;2VYZjSEEeBDUY?
I6mEIVeBHfE7JFE8]JnBdLZae/nlc/NfeLjmeLjme/nne/nne/nnem2oem2oem2oe/nne/nne/nne/nn
e/nne/nne/nne/nnem2oem2oem2oem2oem2oem2oem2oem2oe/nne/nnem2oem2oem2of=70f=70f=70
em2oem2oem2oem2oem2oem2of=70f=70em2oem2of=70f=70fM;1fM;1fM;1fM;1em6nem6nem6nem6n
em6nem6nem6nem6nf=:of=:of=:of=:of=:of=:of=:of=:of]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1
f=:of=:of=:of=:of=:of=:of=:of=:of=:ofM?0fM?0fM?0f]C1f]C1f]C1fmG2f]C1f]C1f]C1f]C1
f]C1f]C1f]C1f]C1fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2
f]C1f]C1f]C1f]C1fmG2fmG2g=K3g=K3fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2
fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2fmG2
f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]G0f]G0f]G0f]G0f]G0f]G0f]G0f]G0em6nf=:ofM?0fM?0
fM?0fM?0f=:oem6nf=:of=:oem6ne]2me]2mem6nf=:of=:ofLnmfLnmfLnmfLnmfLnmfLnm003Bc<gB
c<gBc<gBc<gBc<gBc<gBc<gBc<g@cLo@cLoAc]3Ac]3Ac]3Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7B
cm7Bcm7Bcm7Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3@cLo@cLoAc]3Ac]3Ac]3Bcm7Bcm7Bcm7Cd=;C
d=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Ad=;Ad=;Ad=;Ad=;Ad=;A
d=;Ad=;Ad=;@cm7@cm7@cm7Ad=;Ad=;BdM?BdM?BdM?@cm7@cm7@cm7@cm7@cm7@cm7@cm7@cm7@cm7@
cm7@cm7@cm7@cm7@cm7@cm7@cm7Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;Ad=;AcloAcloBd=3Bd=3CdM7C
dM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7Bd=3B
d=3Bd=3CdM7CdM7Dd];Dd];Dd];AcloAcloBd=3Bd=3CdM7CdM7CdM7CdM7Bd=3Bd=3Bd=3Bd=3Bd=3B
d=3Bd=3Bd=3CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3B
d=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3AcloAcloAcloAcloAcloA
cloAcloAcloAclkAclkAclkAclkAclkAclkAclkAclkEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gE
d<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gDclcCc/_Cc/_D
clcEd<gEd<gDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcCc/_C
c/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_C
c/_Cc/_Cc/_?c/[?c/[Ac/[Bcl_Cc/_DclcFclcFclcEclSEclSEclSEclSEclSEclSEclSEclSEclSE
clSEclSEclSEclSEclSEclSEclSFd<WFd<WFd<WFd<WFd<WFd<WFd<WFd<WIdlcEclSAblCBc<GEclSH
d/_Hd/_GdL[Bd<GCdLKEdlSHe<WHd/OEclCBbKo@akg=b[c>bkg?c;kDc/7Dc;o;`kJn]JRdZij@RWf9
PgJ1NfimMfYmMfZ2O6n6P7>8PWF3PWB3PGJ2PWJ3PWR5QWb8Rh:=T8NAThf@UY6AUi:CVIBEViJGWIRJ
X9^KXIbLXYfNY9nNXj6MXZ2KX9nJWijKWj2OXjBRYJVVZjZTZJRSZ:NRYjJTZJRX[Jb]/[6`]KB]/[6]
/[6//K2//K2[/:nZ[jjZ[jjY[ZfZ[jjZ[jjY[ZfW[:^VZjZUZZVTZJRSZ:NX[JbX[JbW[:^X[JbY[ZfZ
[jj[/:n//K2[/:j//Jn//Jn]/[2^/k6^/k6_];:_];:_/K:_/K:b];Be]kN`/k6IWIQgNgILH5/f?3Ld
>SDd>SDd>cP[=S@L;2/A9bD;9R<7:S@E?4DOCEPPEF8NFFPSHG4YJG/^KX0^JGT_JWX^JGT]J7P[IWH/
IgL_JWXbKGdUI78TIG<UIW@TIgHTIWPQIWLOI7LOI7LUJG`VJWdWJghWJG`VIGTUI7PWI7PYIWXVJgDW
K7HWJgPWJgPVJGPUJ7LTIWPSIGLSFf`GCEhIBed]GFlhJ7XaHgD[HG8^IWL^JWHOFfLMEf<^Hg0mLGiN
Sie?OXaFPi57OX]8P8]9O8H>;ST000X00P/651X05QX05A815Q@I9RAoQH1RGeY/IUm[IUefL6EoNFj2
O761Ng24OW>CSH:EShA^J5dl=R/c>B8b>24c=R0f>B<j?2Hk?BLj>B@f=B0a<Qhc=20e=R8g>2@j>bLl
?BTn?b/o@2`f>B<g>R@h>RHh>RHj?2To@316AcM<CCeGGDaQIeI_MFAmPg:9SgjEVhZQYiJY[ijZ[Z>]
/JJ`]:V`]:V^/ZN//:F[[jB[[jB]/:N]/:N]/:N]/:N/[jJ/[jJ/[jJ/[jJZ[Z>[[jB//:F[[jB[[jB]
/JJ`]:Vd^:fa]k:b^;>a^;6]]:f[/jVPZ9e0B3d^=R]9DcaDFT5IFciQGD2_Z8g?ak3Id[oDcKkEc[gE
c[gEc[gEc[gFckkFckkGd;oGd;oFckkFckkFckkFckkFckkFckkFckkFckkGd;oGd;oGd;oGd;oGd;oG
d;oGd;oGd;oFckkFckkFckkGd;oGd;oGd;oHdL3HdL3FckkFckkFckkGd;oGd;oGd;oHdL3HdL3Gd;oG
d;oGd;oHdL3HdL3Id/7Id/7Id/7GdKkGdKkGdKkGdKkGdKkGdKkGdKkGdKkHd[oHd[oHd[oHd[oHd[oH
d[oHd[oHd[oIdl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3Hd[oHd[oHd[oHd[oHd[oHd[oHd[oHd[oHd[oH
d[oHd[oIdl3Idl3Je<7Je<7Je<7Idl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3Je<7Je<7Je<7Je<7Je<7J
e<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Idl3Idl3Je<7Je<7Je<7KeL;KeL;KeL;Je<7J
e<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7J
e<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Je<7Idl3Idl3Idl3Idl3Idl3Idl3Idl3Idl3JeL3J
eL3JeL3JeL3JeL3JeL3JeL3JeL3GdKkHd[oHd[oIdl3Idl3Hd[oHd[oGdKkHd[oGdKkFd;gFd;gFd;gF
d;gGdKkHd[oIckgIckgIckgIckgIckgIckd00=;<cM;<cM;<cM;<cM;<cM;<cM;<cM;<cM3=cm3=cm3=
cm7>d=7>d=7>d=;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM7>d=7>d=7>d=7>d=7>d=7>d=7>
d=7>d=3=cm3=cm3=cm7>d=7>d=7>d=;?dM;?dM?@d]?@d]?@d]?@d]?@d]?@d]?@d]?@d];?dM;?dM;?
dM;?dM;?dM;?dM;?dM;?dM7@d]7@d]7@d]7@d]7@d]7@d]7@d]7@d]3?dM3?dM3?dM7@d]7@d];Adm;A
dm;Adm3?dM3?dM3?dM3?dM3?dM3?dM3?dM3?dM3?dM3?dM3?dM3?dM3?dM3?dM3?dM3?dM7@d]7@d]7@
d]7@d]7@d]7@d]7@d]7@d]7?cm7?cm7?cm;@d=;@d=?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?A
dM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM;@d=;@d=;@d=?AdM?AdMCBd]CBd]CBd]7?cm7?cm7?
cm;@d=;@d=?AdM?AdM?AdM;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=?AdM?AdM?AdM?AdM?AdM?AdM?A
dM?AdM;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@
d=;@d=;@d=;@d=;@d=;@d=7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?c]7?c]7?c]7?c]7?c]7?c]7?
c]7?c]G@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@
cMG@cMG@cMG@cMG@cMG@cMG@cMC?c=?>bm?>bm?>bm?>bmC?c=G@cMC?c=C?c=C?c=C?c=C?c=C?c=C?
c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>
bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>blo>b/o>b]7>b];?bm?>bm?>bmK?
c=K?c=G?b=G?b=G?b=G?b=G?b=G?b=G?b=G?b=G?b=G?b=G?b=G?b=G?b=G?b=G?b=G?b=K@bMK@bMK@
bMK@bMK@bMK@bMK@bMK@bM_Ec]OAb]?=a]7;a=;<aM?=a]?=a];<aMKEbmCCbM3?aLk<`/o:`M;=a=SA
b=cEc<k>`/o=`/o=`];>`mK@aMW@a]cBb=cBb=cFbM3:_Kni[:nYW::LSiNAQ8j8NhV3MY2:OHn9OXf7
O8b7OXb:P92=QIBBRYNDSi>ESiBFT9FGTIRJU9ZLUYbNV9jPVYnQViZPVibQWifRX9bQX9VNWIVMWYbP
XInRYZFZZJBYZ:>XYj>XYjFZZJN/ZjZ_[Zba/:Z_[ZZ_[ZZ_[ZZ_[ZV^[JV^[JV^[JV^[JV^[JV^[JR]
[:R][:N/ZjJ[ZZJ[ZZFZZJN/ZjN/ZjFZZJBYZ:BYZ:>XYjBYZ:BYZ:N/ZZN/ZZR]ZjV^[:Z_[J^`[Z^`
[Zba[k>e]K2b/Zja[j^_ZZ:VXHfARg5eKeeRFCQ0=C0h;RXa:RL`;Ad/;Q4Z;PP]<@Tc>0m2EQ]CIR=N
LAYLKQAFJ1YKJRMSLbeXN2ETLRMVM2UXMRUXMRQWMBMVM2UXMRYYMb=RL29SLBAUM2EWNBEZNbIZOBI[
ORI[OaaTMQiVN29WNR=WNREWNRQWNb]ZOS1]PBATKbEUL2ETLRIULbESLbESLbARM2=QLbAWMRESLbaW
McQ`PCifQcMbPRe[NbIYN3YhPbIRKQI@G2MNJcM[N5Z9UdYgQEf:V4Z1STf7Te:6TRU9E0074`/?6P<@
60@O8`0=3@LL6SI1?ZjaZ<C1/lk7]/o:]M[F_];:^MG=_=;:^M38]mK>_LBlZh9jJC/c8SDk938h8C@g
8CLj93`n:3do:D0o:T0o:SHe8CLf8SPg8cTh93Xi9CXi9CXi9CXi9Cm2:Cm2:Ci0:S/m9cLh93Lg9CTi
9c/k:Ble8SLm:T98=DeC@5QNBfE[F7EkJ867M92EQYJKS9jSU:>XVJJ[W:J[W:N/WJR]WZ^^YJ^^YJ^^
YJ^^YJ^^YJb_YZb_YZb_YZV]XZZ^XjZ^XjZ^Xj^_Y:jbYk:fZkJj[k:i];>j]KBl]K6i/[6j/:>]XCY4
>20Z7SHo:TI<=E5A>EeH?jjVSm;8]]kEamS@`mC=_=C=_=G>_MG>_MK?_]K?_]K?_]K?_]G>_MG>_MG>
_MG>_MG>_MG>_MG>_MG>_MK?_]K?_]K?_]K?_]K?_]K?_]K?_]K?_]G>_MK?_]K?_]K?_]O@_mO@_mO@
_mSA`=G>_MG>_MK?_]K?_]O@_mO@_mSA`=SA`=O@_mO@_mO@_mO@_mSA`=SA`=SA`=WB`MK@_MK@_MK@
_MK@_MK@_MK@_MK@_MK@_MSB_mSB_mSB_mSB_mSB_mSB_mSB_mSB_mWC`=WC`=WC`=WC`=WC`=WC`=WC
`=WC`=SB_mSB_mSB_mSB_mSB_mSB_mSB_mSB_mSB_mSB_mSB_mWC`=WC`=WC`=[D`M[D`MWC`=WC`=WC
`=WC`=WC`=WC`=WC`=WC`=[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D
`M[D`MWC`=WC`=WC`=[D`M[D`M[D`M_E`]_E`][D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D
`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D`M[D
`M[D`MWC`=WC`=WC`=WC`=WC`=WC`=WC`=WC`=[E`=[E`=[E`=[E`=[E`=[E`=[E`=[E`=OA_]OA_]SB
_mWC`=WC`=SB_mOA_]OA_]OA_]OA_]K@_MG?_=G?_=K@_MOA_]OA_]S>_=S>_=S>_=S>_=S>_=S>_000
dL_<dL_<dL_<dL_<dL_<dL_<dL_<dL_<d<g?d<g?d<g?d<g?dLk@dLk@d/oAd/oAd/oAd/oAd/oAd/oA
d/oAd/oAd/oAd/oAdLk@dLk@dLk@dLk@dLk@dLk@dLk@dLk@d<g?d<g?d<g?d<g?dLk@dLk@d/oAd/oA
dm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bd/oAd/oAd/oAd/oAd/oAd/oAd/oAd/oAdM3BdM3BdM3BdM3B
dM3BdM3BdM3BdM3Bd<oAd<oAd<oAdM3BdM3Bd]7Cd]7Cd]7Cd<oAd<oAd<oAd<oAd<oAd<oAd<oAd<oA
d<oAd<oAd<oAd<oAd<oAd<oAd<oAd<oAdM3BdM3BdM3BdM3BdM3BdM3BdM3BdM3BdLo?dLo?dLo?d]3@
d]3@d]3@dm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7A
dLo?d]3@d]3@dm7Adm7Ae=;Be=;BeM?CdLo?dLo?dLo?d]3@d]3@d]3@dm7Adm7Ad]3@d]3@d]3@d]3@
d]3@d]3@d]3@d]3@dm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Ad]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@
d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@dLo?dLo?dLo?dLo?
dLo?dLo?dLo?dLo?dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=
eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=eM3=e<o<dlk;dlk;
dlk;dlk;e<o<eM3=e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<
dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;
dlk;dlk;dlk;dlk;c/g9clk:dLk:dLk:dlk;dlk;eLk;e/o<eLo8eLo8eLo8eLo8eLo8eLo8eLo8eLo8
eLo8eLo8eLo8eLo8eLo8eLo8eLo8eLo8e]39e]39e]39e]39e]39e]39e]39e]39cLO0dL_4eLo8f=;;
f=;;em7:e]39e]39blc3cLk5d]38d]38d/o7d/c5d<[3d/[3cLc2clk4dLo5d/g4dL[1d/W0dlS0eL[2
d<Zmd<ZmdL^neLo2em74eLo2c/Rkb<:e^k:U]jfS[ZFKYijEWiR?VYB=V9:;V9:=U9B>UIF?UiNAVIVC
W9bFWYjHX:2JXJ6KV9jIVj2NWJ:PW:6PVYnNVIfNVinPWZ6UXjRWY:VXYJZYYZ^ZYjb[Z:f/Z:f/Z:f/
Z:f/Z:f/Z:f/Z:f/ZJj]ZJj]ZJj]ZJj]Yjb[Yjb[Z:f/Z:f/Z:f/Z:f/Z:f/Z:f/Z:f/YZ^ZY:VXXZNV
WjBSWZ>RWJ:QWJ:QXJNRXJNRXZRSXjVTY:ZUYJ^VYZbWYZbWW9nMTiNBQXZ5NgmiL7A^HFIMD5I;A4Xo
>dDe;3DX72DK51lL3B0S2BT_3cY36DaF555[5eYa65ie5V1b7fEf:V]j;VUi;V9b6F5[7FE_8VYd96af
8f]e8FUc86Qb86Qb:VUg:VQh:6Uh9FMi96Ii86Ag7f9g765e86Yl8F]m8VYl8VMj7f=f869e8f9f9V=g
:VQc:fUd;6Ug;FYh;FUi;FUi;6Mj:fIi7VMe96Uh:fak<W20=gF5>7V8<gR7;GJ4?Wb7:VQc6E=O;VEb
>fmlFHRFAG:0H8^J@7Z6BhFAFHfI?f5^2ADQ5QXU00T@01XO010B3R<Q@da9^;N]hM[9em:icLV/d]2^
eLbhclJbdlZfg]G1dlZfXiZ6HUU5=RdI>d4X>3hU=c/R=SXQ=STP=3LN=SHN>3PP>CPT>CPT>3LS>CPT
>CPT>STU>STU>cXV=STO>3/R>SdT>cdW>S`V>S/W>c/Y?Cd[>3lZ>D0[>3lZ=3/V<CPS=SdX@4LbBU4l
EUa9HVQELgUVQH]hU9Z7X:JCZ:jK[K>PZJbSZJbSZZfTZZfTZjjUZjjU[:nV[:nVYj^PZJfRZJfRZZjS
ZjnT[[:W];R]^;ba[[F`[[F`[[J_[KF^/[^aZ[BXA4i2:S@X<c`XA4TdCTdhFeDn[ZFAdLNff]74dLRo
e<fle<fleLjmeLjmeLjme/nne/nne/nneLjmeLjmeLjmeLjmeLjmeLjmeLjmeLjme/nne/nne/nne/nn
e/nne/nne/nne/nneLjmeLjme/nne/nne/nnem2oem2oem2oeLjmeLjmeLjme/nnem2oem2of=70f=70
e/nnem2oem2oem2of=70f=70f=70f=70e]2me]2me]2me]2me]2me]2me]2me]2mem6nem6nem6nem6n
em6nem6nem6nem6nfM?0fM?0fM?0fM?0fM?0fM?0fM?0fM?0em6nem6nem6nem6nem6nem6nem6nem6n
em6nf=:of=:of=:ofM?0fM?0fM?0f]C1fM?0fM?0fM?0fM?0fM?0fM?0fM?0fM?0f]C1f]C1f]C1f]C1
f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1fM?0fM?0fM?0fM?0f]C1f]C1fmG2fmG2
f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1
f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1f]C1fM?0fM?0fM?0fM?0fM?0fM?0fM?0fM?0
f]G0f]G0f]G0f]G0f]G0f]G0f]G0f]G0e]2mem6nf=:of=:of=:of=:oem6ne]2mem6nem6ne]2meLnl
eLnle]2mem6nem6nf<jlf<jlf<jlf<jlf<jlf<jl003@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_?cLg?
cLg?cLg?cLg@c/k@c/kAcloAcloBd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3CcLkCcLkCcLkCcLkCcLkC
cLkCcLkCcLk@c/k@c/k@c/kAcloAcloAcloBd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3AcloA
cloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloBd=3Bd=3CdM7CdM7CdM7D
d];Dd];Dd];Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Cd=;Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Bcm7Ac]3A
c]3Ac]3Bcm7Bcm7Cd=;Cd=;Cd=;Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3B
d=3Bd=3Bd=3CdM3CdM3CdM3CdM3CdM3CdM3CdM3CdM3CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7CdM7C
dM7CdM7CdM7CdM7CdM7CdM7CdM7Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3CdM7CdM7CdM7CdM7CdM7C
dM7CdM7CdM7Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oB
d<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oBd<oEd<oEd<oEd<oEd<oEd<oE
d<oEd<oEd<oDclcDclcDclcDclcDclcDclcDclcDclcEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gEd<gE
d<gEd<gEd<gEd<gEd<gEd<gEd<gDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcD
clcDclcDclcCc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cd<SC
d<SCd<SCd<SCd<SCd<SCd<SCd<SBcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[Dc/ODc/ODc/OEclSEclSE
clSFd<WFd<WEclSEclSEclSEclSEclSEclSEclSEclSEd<OEd<OEd<OEd<OEd<OEd<OEd<OEd<OEd<OE
d<OEd<OEd<OEd<OEd<OEd<OEd<ODclKDclKDclKDclKDclKDclKDclKDclKDclKDclKDclKDclKDclKD
clKDclKDclKFdlC=b[cBcLCIdlcAc/K@cLGBdLO>cL?Dc/7CcL3CcL3CcL;Ec/GDcLCCblCAbL;EcKcC
bk[BbK_BbK_BbKc@a[c;`KO6_;:j]:Vj]:Vi/jRf/:Fc[J:`ZYn^Z9f]Yib[Yib[YibZYY^YYIZYYIZY
YIZZYY^ZYY^Z[:J`/Zbb]:j_/J^][jV[[JNVZ::OXI^OXYVi_;>SYYfKWYFe^:nJWIB8Rh:j_KBb]JbF
VI1kOWFUZ9nMX9NIW9>NXIRTYijh/Zfe[jZk]k:^ZZFXYJ2^[ZRYZJ>c/jfj/Z_0^;6b[:Fg/JZb[jNZ
Yinf/j^b/:R//:FDV8emPGJFVXi<DdHF7A0i@SFLYIR/Y9M7AS`240X071d4;CH>?U0KDFPJDF`QHG<Q
HG<RHW@TI7HUIGLWIgTXJ7XXJ7XWIgTYJG/[Jgd/K7h/K7hZJW`XJ7XVIWPXIg/WIWXVIGTVIGTVIGTX
Ig/ZJGd[JWhVJ7/VJ7/UIgXUIgXUIgXTIWTTIWTTIWT[IWT[IWT[IWT[IWT[IWT[IWT[IWT[IWT/JW`Z
J7X`JghkMHQ1Nhi0N8/lM8LmLXI1MXX`JWd<AUTkJ7e>KHAMO9=?O952P998QYPnNHUBQIEDOX/S@4h0
4ah54A/=5Ql06a/030YVIeg0`Zo5ckS6dk_;ckc@bK[Ea[gDb;k@ak[Ed<73`k5kOFTi@BXc?28d=B4d
=B4c=20c=20d=B4d=B4f=b<f=b<d=ahd=ahc=Qdc=Qdd=ahd=ahf>B0f>B0f=b<f=b<g>2@g>2@h>BDi
>RHi>RHi>RHh>BDh>BDg>2@g>2@g>2@g>2@h>BDi>RHn?BU1@2a7AS9AD3aNGDU`Ke^3PVj?SWZGVXZP
Xi>[[Yj_/Z>/[Z:XZYjWZ9jXZIn[[ZFXZj:WZJ>/[ZRe][:j^kVi^[Rf]kFb]:Ri^[2e^JjSYYfn`[b_
]Zm?EE0V;2La?RA>DcQ:ARYODCZ^WH[Hbkg>akk;b<?Dc[_Dc[_Dc[_Bc;WAbkSBc;WFd;gIdl3DcKkE
c[oFcl3Fcl3Fcl3Ec[oDcKkDcKkEbkWFc;[Hc[cIckgIckgIckgKdKoLd/3Hc[cHc[cHc[cHc[cHc[cH
c[cHc[cHc[cKd<;?a;KFbkgRelWLdL?HcKoMd/CMd/CIckgHc[cHc[cHc[cIckgKdKoMdl7OeL?IckgI
ckgIckgIckgIckgIckgIckgIckgLd/3KdKoKdKoJd;kJd;kIckgIckgHc[cKd<;Kd<;Jcl7Jcl7Ic/3H
cKoHcKoGc;kJcl7Jcl7Jcl7Jcl7Ic/3Ic/3Ic/3Ic/3Hc[cIckgIckgIckgJd;kJd;kJd;kKdKoJd;kJ
d;kJd;kJd;kKdKoKdKoKdKoLd/3Ld/3Ld/3Ld/3Ld/3Ld/3Ld/3Ld/3Ld/3KdKoKdKoKdKoLd/3Ld/3L
d/3Mdl7Mdl7Me<3Me<3Me<3Me<3Me<3Me<3Me<3Me<3Ld/3Ld/3Ld/3Ld/3Ld/3KdKoKdKoKdKoMe<3L
dkoKd[kKd[kKd[kKd[kLdkoMe<3Kd[kKd[kKd[kLdkoLdkoLdkoMe<3Me<3LdkoLdkoLdkoLdkoLdkoL
dkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoLdkoKd[kKd[kKd[kKd[kKd[kKd[kKd[kKd[kId;cI
d;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cGc[[Gc[[Hck_Hck_Id;cI
d;`00=3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:blo=cLo=cLo=cLo=cM3>c]3>c]7?cm7?cm;@d=;@d=;@
d=;@d=;@d=;@d=;@d=;@d=?=c]?=c]?=c]?=c]?=c]?=c]?=c]?=c]3>c]3>c]3>c]7?cm7?cm7?cm;@
d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?
cm7?cm7?cm7?cm7?cm7?cm;@d=;@d=;@d=?AdM?AdM?AdMCBd]CBd]?@d]?@d]?@d]?@d]?@d]?@d]?@
d]?@d];?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM7>d=7>d=7>d=;?dM;?dM;?dM?@d]?@d];@d=;@d=;@
d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=?Ad=?Ad=?Ad=?Ad=?Ad=?Ad=?A
d=?Ad=?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM;@d=;@d=;@
d=;@d=;@d=;@d=;@d=;@d=?AdM?AdM?AdM?AdM?AdM?AdM?AdM?AdM;@d=;@d=;@d=;@d=;@d=;@d=;@
d=;@d=;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@
cm;@cm;@cm;@cm;@cm;@cmG@cmG@cmG@cmG@cmG@cmG@cmG@cmG@cmC?c=C?c=C?c=C?c=C?c=C?c=C?
c=C?c=G@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMG@cMC?c=C?c=C?
c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=?>bm?>bm?>bm?>bm?>bm?>bm?>
bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?@b=?@b=?@b=?@b=?@b=?@b=?@b=?@b=7<bM7<bM7<
bM7<bM7<bM7<bM7<bM7<bM?=a]C>amC>amC>amG?b=G?b=G?b=K@bMG?b=G?b=G?b=G?b=G?b=G?b=G?
b=G?b=G@amG@amG@amG@amG@amG@amG@amG@amG@amG@amG@amG@amG@amG@amG@amG@am?>aM?>aM?>
aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aLo<_/O4]/S4^L[5_<G3^LW7_M7?
aM;@aM3>`lo=`/g;`Lg;`Lg:`/g9a<g9a<g9a=OB`mG?`]C>`M?=`];<`M7:`M38`Lo7`=;?am3=aLk;
`lg:`/g:`/k;`lg:`/g:`/G3^lC2^/?1^L2n][nm]Kfk/kbj/[bj/[2a[KRi]Ko0_;jo^kZk]kBe/JVZ
YYjOVhR:Q:6SWKBf/<G7`JZ/YTe?BC8d;WUkMLc>b:naZhZ<QYJHTVa^J6EWHI:DS/G7`LO2_lk;akbi
]L2o^kZi]J:SWibPVh>7PWeiM:>OV[6]Z;Vf/Kbi]<6n^LS5`;2`ZYfLTXN6O4e>A8J:Oh:8OFEZHFee
JfmgKEYPFb0[:0DM7A8g>aY8Db9FIbYSNBMPNB9RM2=SMB=SMBATMRIVN2MWNBMWNBQXNRIVN2MWNBYZ
O2][OB][OBYZO2QXNRMWNBQWNbQWNbMVNRIUNBMVNRQWNbYYOB]ZORIXNbIXNbIXNbEWNREWNREWNRAV
NBAVNBUWNBUWNBUWNBUWNBUWNBUWNBUWNBUWNBaZO2YXNS1[OSYeR45kST1hRcadQc]cQSYbQC=^PA1:
GDA_Q6^7WgjF[V:9We:7Vd^6VD=kS5B7UeV2TB];F0@J9@0A6PHB700<3`DD5UiRGKBfZ[W3/[>o[Jb_
X<[4^MW=`mC;_]K>`MKA`ZZZV5]MBBP`6Bde7S@e8C<d83<d83<d83<d83@e8CDf8SHg8c@f83<e7c<e
7c<e7c<e7c@f83Dg8CHh8SHg8cHg8cHg8cLh93Lh93Pi9CPi9CTj9SXk9cTj9SPi9CHg8cHg8cHg8cHg
8cHg8c/j9S/j9SXi9CPg8cXi9D0o:dQ7<di=>EaPCFM[F7QkJhJ9NY>FQj2RUZf_XkNh[[2dZJb`YJR[
XZRZY:b^Z;6b[[Ff/[Jg]KBh[K^n]Kc1^:V]YkJm]Z^b[E5HDaHO71d]5S]3;3`j8UE9<JFGPMc>_=O?
`]7=`/g7]<k8]M3:]m3:]lo9]]3:]m;<^MG?_=?<_MC=_]K?`=O@`MSA`]SA`]O@`MO@`M[@_]cB`=cB
`=W?_MC:^=;8]]C:^=O=^mC:^=C:^=C:^=C:^=G;^MG;^MG;^MG;^N7Fb=cA`moDa]cA`m?8^]O<_]_@
`]35]mW?_]O=_=K<^mC:^MC:^MC:^MG;^]G;^]oEa=kD`mgC`]_A`=[@_mS>_MO=_=K<^mO=^mS>_=W?
_M[@_]_A_mgC`MkD`]kD`]G;^]K<^mO=_=W?_][@_mcB`MgC`]kD`m[@_m[@_m[@_mW?_]W?_]W?_]W?
_]W?_]S>_=S>_=W?_MW?_MW?_M[@_][@_][@_]W?_M[@_][@_][@_]_A_m_A_m_A_m_A_mcB`=cB`=cB
`=cB`=cB`=cB`=cB`=cB`=[@_]_A_m_A_m_A_mcB`=cB`=cB`=gC`MgD`=gD`=gD`=gD`=gD`=gD`=gD
`=gD`=cB`=cB`=cB`=cB`=_A_m_A_m_A_m_A_mgD`=cC_m_B_]_B_]_B_]_B_]cC_mgD`=[A_M_B_]_B
_]_B_]cC_mcC_mcC_mgD`=cC_mcC_mcC_mcC_mcC_mcC_mcC_mcC_mcC_mcC_mcC_mcC_mcC_mcC_mcC
_mcC_m[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_MW@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@
_=W@_=W@_=W@_=W@_=W@_=O>^]O>^]S?^mS?^mS?^mW@_000d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;
clg=clg=clg=clg=d<k>d<k>dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dlg>dlg>dlg>dlg>
dlg>dlg>dlg>dlg>d<k>d<k>d<k>dLo?dLo?dLo?d]3@d]3@dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?
dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d]3@d]3@d]3@d]3@
dm7Adm7Adm7Ae=;Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3Bdm3BdLk@dLk@dLk@dLk@dLk@dLk@dLk@dLk@
d<g?dLk@dLk@dLk@d/oAd/oAd/oAd/oAdLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d]3@d]3@d]3@d]3@
d]3@d]3@d]3@d]3@dm7@dm7@dm7@dm7@dm7@dm7@dm7@dm7@dm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7A
dm7Adm7Adm7Adm7Adm7Adm7Adm7Adm7Ad]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@dm7Adm7Adm7Adm7A
dm7Adm7Adm7Adm7AdLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>
dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>e<o>e<o>e<o>e<o>
e<o>e<o>e<o>e<o>e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<
e<o<e<o<e<o<e<o<e<o<e<o<e<o<e<o<dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;
dlk;dlk;dlk;dlk;d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:
d/o7d/o7d/o7d/o7d/o7d/o7d/o7d/o7dLc9dLc9dLc9dLc9dLc9dLc9dLc9dLc9dlg6dlg6e<k7e<k7
e<k7eLo8eLo8eLo8e<k7e<k7e<k7e<k7e<k7e<k7e<k7e<k7e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6
e<o6e<o6e<o6e<o6e<o6e<o6e<o6e<o6dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5
dlk5dlk5dlk5dlk5dLg2eM;4f]O9f]O9emC6e]?5eM;4d/o1d]77d]77dLo7d<g8d<g8d<g9dLk:d/k=
cL_0cL_0c<[0b/NobLJnbLG0c<S3c/W6alBo`l2k_kbg_kbg`l2kalBob<G0alBo`<:l_l6k_/2j_Kni
^kfg^K^e^;Zd^;Zd_Kjla<G3bL[8alS6aLK4`L;0^KZh/;6_/K:^[JjZ][Nc^KZfQHJ2>3TeBDY6XjBP
NgahKFiZIfQTWj2LVY^GVibH/;6]bL[6_;Ziclg<YJJTZZf[T9>AEEYHDeQF9bh[>S/gTY>?`L:n_;fi
YjRT[JjZalS4_[nk_kfc]kB/FEM?IVQRIFUTIfeXX:NTTibI7CDk3R/b4cY28U=M8eYW961`:6Ei961f
9FEg9FEg9FEg9VIh9VIh9fMi9fMi9fMi9FEg9VIh:6Qj:VYl:f]m:VYl:FUk:6Qj:FQl:FQl:6Mk:6Mk
:6Mk:FQl:VUm:fYn9VQk9VQk9VQk9VQk9FMj9FMj9FMj96Ii:FMi:FMi:FMi:FMi:FMi:FMi:FMi:FMi
:FUk:VQj;feo>gJ9@7Z=?GN:?7B7?7B7<Fao=7:444YMA6f3S::kW:g7M92XG8FKBhFH@WZ;D8>CEH2?
;e9P1b<^01<M018M01<I320U9b`]CU9=BeI<AeE:Ada3WYRAd<Njbl>fdljoalBePX9`>cdY9BXE<3LR
<S@P<C<O<C<O<C<O<C<O<S@P<cDQ=3HR<cDO<S@N<S@N<S@N<S@N<cDO=3HP=CLQ=CHR=CHR=SLS=SLS
=SLS=cPT=cPT=cPT>S/W>CXV>3TU=SLS=3DQ=3DQ=3DQ=3DQ?SdY?SdY?3/W>CPT=cHR>3LS?3/W?chZ
=cTU?T0/BD/hEEI6HV=CLg=UQHEgTY:6UYZ>Wj>G[;2T]KV^^;^b]KR_/K>][[2ZZk2W[;BZ][ffYjjY
Z[B^[KJcHfi[5R4O5bPJ=40^>3TUCTH_WI5if/fggM6odLVhem6nf=:ofM?0em6ne<jkd/bidlfje<jk
blBcc<Fdc/Nfd<VhdLZid/^jd/^jd/^jb/>`clReeLjkem2me/nleLjkem2mf]?0fmC1f]?0f]?0f]?0
f]?0fM:ofM:ofM:obl>bclNfeLfld<Rgc<BcgMG4iMg<elnnfLk0fLk0fLk0fLk0fm32g=73g]?5gmC6
eLZle/^me/^me/^melbnelbnf<fof<fogM?1gM?1g=;0fm6of]2nfLnmfLnmf<jlfm70fm70fm70fm70
fm70fm70fm70fm70fLnnfLnnfLnnfLnnfLnnfLnnfLnnfLnnf<jlf<jlf<jlfLnmfLnmf]2nf]2nf]2n
fLnmfLnmfLnmf]2nf]2nfm6ofm6ofm6ofm6ofm6ofm6ofm6ofm6ofm6ofm6ofm6of]2nf]2nfm6ofm6o
fm6og=;0g=;0g=;0g=>og=>og=>og=>og=>og=>og=>og=>ofm6ofm6ofm6ofm6ofm6ofm6ofm6ofm6o
g=>og=>ofm:nf]6mf]6mfm:ng=>og=>of]6mf]6mfm:nfm:nfm:ng=>og=>og=>ofm:nfm:nfm:nfm:n
fm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nfm:nf]6mf]6mf]6mf]6mf]6mf]6mf]6mf]6m
fM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2leljjeljjeljjf<nk
f<nkf<nk003@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_?cLg?cLg?cLg?cLg@c/k@c/kAcloAcloAcloA
cloAcloAcloAcloAcloAcloAcloCcLkCcLkCcLkCcLkCcLkCcLkCcLkCcLk@c/k@c/k@c/kAcloAcloA
cloBd=3Bd=3AcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloA
cloAcloAcloAcloAcloAcloAcloAcloAcloBd=3Bd=3Bd=3CdM7CdM7CdM7Bcm7Bcm7Bcm7Bcm7Bcm7B
cm7Bcm7Bcm7Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3@cLo@cLo@cLoAc]3Ac]3Bcm7Bcm7Bcm7AcloA
cloAcloAcloAcloAcloAcloAcloBd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd<oBd<oBd<oBd<oBd<oB
d<oBd<oBd<oBd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3B
d=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3AcloAcloAcloAcloAcloA
cloAcloAcloAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkAclkA
clkAclkAclkAclkAclkAclkAclkDclkDclkDclkDclkDclkDclkDclkDclkDclcDclcDclcDclcDclcD
clcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcDclcCc/_C
c/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_BcL[BcL[BcL[BcL[BcL[B
cL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[BclOBclOBclOBclOBclOBclOBclOBclOAc<WA
c<WAc<WAc<WAc<WAc<WAc<WAc<WCcLKCcLKCcLKDc/ODc/ODc/OEclSEclSDc/ODc/ODc/ODc/ODc/OD
c/ODc/ODc/ODclKDclKDclKDclKDclKDclKDclKDclKDclKDclKDclKDclKDclKDclKDclKDclKCc/GC
c/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/GCc/G8a[c@c<75`[>b/9j^ZYN^
ZYRaZY^f[j2d]jjg^[6j_;Jl_[Rl_KVl_K^l_K^m_[bn_kK0`KS2`k[1`K^o_[Zo_[[2`;o5`l:o`;bj
^kNe][:e][:j^kNn_k^n_k^m_[Zm`Kbn`[fo`kjo`kk0a;o0a;no`kjo`kk0_[g3`L31_kjl^[Vl^[W1
_kk3`L30_[g4`ko2`Kg;b/K7a/:YZ:BDThnXYj?8al?Ee=2WYZ9/JfMoOWZ2PGfNWIVf]K6l^kNl_kg>
dLnf^KNc^;J@UiAKHUmGH5e0BDI0AT6CVIBj`;^]/Jb?ThjEUY:g^;Bi^[Ji]Zk5`k^NWIV]/[2`^;RC
Wj5iR8/hAT`<=dPD@U<ME6<PG6`KG6/LGW0RHW@QHG<WIgTWIgTWIgTWIgTXJ7XXJ7XXJ7XXJ7XUIGLV
IWPXJ7XYJG/ZJW`[JgdZJW`ZJW`ZJGdZJGdZJGdYJ7`ZJGdZJGdZJGd[JWhWJG`WJG`VJ7/VJ7/VJ7/U
IgXUIgXUIgXXJ7XXJ7XXJ7XXJ7XXJ7XXJ7XXJ7XXJ7XXJ7XXJ7X`KX0iMhToNXdlMXTjM8LkMHPYJG/c
LhD=AeXjHGNIZ/B/]M1nTZ]NOYE<Q9E4NX]=P91FPi4oJGHQA58I>DHR?ddYDU/lEElD7BH52a002PX5
510F71NIU97?b[_>bK[Bcl2^[YaMGd`_<Ah_<b0d>2D`<Ql`<Ql_<Ah_<Ah`<Qla<b0b=24b=24a<Qha
<Qh`<Ad`<Ada<Qhb<alc=20c=20d=B4d=B4e=R8e=R8e=R8e=R8e=R8e=R8g>2@g>2@e=R8d=B4c=20c
=20d=B4d=B4a<1`c<Qhe=20f=B4g=R8i>2@m?2Q0?b/i?2Hi?2Hi>bLi>bLk?BY2@c=<CCeCE4AQI5Ab
MFF;SWnOXY>Z[:2_/:Jb/jVe]Zb`^:j[/jVc^kBX/ZbT[ZR/]kAaO7T95Q@760lQ;B4W;A`l>BB4NV;3
^9g=`JW0/ifo^ZG0^jK0^jK0^jJo^ZG1_:O5`:_9a:o>bKC?b[GAc;OBcKSBcKSBcKSBcKSBcKSAb[KB
bkOEc[[HdKgId[kEc[[>ak?9`ZkBbkOAb[KAb[KAb[K@bKG@bKG@bKG@bKGLeL7Id[kMe/;Ke<3BbkOE
c[[Gd;c<aK7BakWBakWBakWCb;[DbK_Eb[cEb[cFbkgIc/3Ic/3Ic/3Ic/3Jcl7Jcl7Jcl7Jcl7Id;cH
ck_Gc[[FcKWDbkOCb[KBbKGAb;CJd;kJd;kIckgIckgHc[cGcK_GcK_Fc;[Hc[cHc[cHc[cHc[cIckgI
ckgIckgIckgGcK_Hc[cHc[cHc[cIckgIckgIckgJd;kIckgIckgIckgIckgJd;kJd;kKdKoKdKoKdKoK
dKoKdKoKdKoKdKoKdKoKdKoKdKoJd;kJd;kJd;kKdKoKdKoKdKoLd/3Ld/3Kd[kKd[kKd[kKd[kKd[kK
d[kKd[kKd[kJd;kJd;kJd;kKdKoKdKoKdKoKdKoKdKoLdkoKd[kJdKgJdKgJdKgJdKgKd[kLdkoJdKgJ
dKgJdKgKd[kKd[kKd[kLdkoLdkoKd[kKd[kKd[kKd[kKd[kKd[kKd[kKd[kKd[kKd[kKd[kKd[kKd[kK
d[kKd[kKd[kJdKgJdKgJdKgJdKgJdKgJdKgJdKgJdKgId;cId;cId;cId;cId;cId;cId;cId;cId;cI
d;cId;cId;cId;cId;cId;cId;cFcKWFcKWGc[[Gc[[Hck_Hck/00=3:bm3:bm3:bm3:bm3:bm3:bm3:
bm3:blo=cLo=cLo=cLo=cM3>c]3>c]7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm?=c]?=c]?=
c]?=c]?=c]?=c]?=c]?=c]3>c]3>c]3>c]7?cm7?cm7?cm;@d=;@d=7?cm7?cm7?cm7?cm7?cm7?cm7?
cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?
cm7?cm;@d=;@d=?AdM?AdM;?dM;?dM;?dM;?dM;?dM;?dM;?dM;?dM7>d=7>d=7>d=7>d=7>d=7>d=7>
d=7>d<o<c]3=cm3=cm3=cm7>d=7>d=7>d=;?dM7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm;@d=;@d=;@
d=;@d=;@d=;@d=;@d=;@d=;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@cm;@d=;@d=;@d=;@d=;@d=;@d=;@
d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@
d=;@d=;@d=;@d=;@d=;@d=7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?c]7?c]7?c]7?c]7?c]7?c]7?
c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]7?c]C?c]C?c]C?
c]C?c]C?c]C?c]C?c]C?c]C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?
c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=C?c=;=b];=b];=b];=b];=b];=b];=b];=b];=b];=b];=
b];=b];=b];=b];=b];=b]7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<
bM7<bM7>a]7>a]7>a]7>a]7>a]7>a]7>a]7>a]3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=;<aM;<aM?=
a]?=a]?=a]C>amC>amC>am?=a]?=a]?=a]?=a]?=a]?=a]?=a]?=a]?>aM?>aM?>aM?>aM?>aM?>aM?>
aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM?>aM;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=
a=;=a=;=a=;=a=;=a=;=a=7>a/c:_j2NS6i/E6EQB7E_F8^4LJJLRjFYWZb`YKFh[k^m]k^m]kZk]kVj
][Vj^;Rk/[Vl/k^n]K^m]kZk]kRi]KVj^;Vj^;fo^KZl][Ni/kNi/kZl][^m]kVk]KNi/kBh/[Fi/kJj
];Rl][Rl][Rl][Nk]KNk]L:o^lC1_L:o^kfj][fj]/?0_<K3_lG2_[fj]Kfj]LK3_/K3_[bi]<6n^L?0
^kBa[;6^ZKVf/J^XXknl]k>`ZlG2_Lc9a;jk]Zfa[:jb[KZn^Kk4_kJm^:F/Yi:LUXnITgn7P9ZRVi^R
VibPVYbPVZ:TW[:b[:FUWj>VWIFITi2IUWf;RW>6ReedO3MAGAljB0PoE1MBIQaKKaIKK1QNKb5VMbMZ
NB]/NbQXNRQXNRUYNbUYNbUYNbUYNbUYNbUYNbIVN2MWNBQXNRYZO2][OB][OBa/ORa/OR]ZOR]ZOR]Z
OR]ZOR]ZOR]ZORYYOBYYOBMYO2MYO2MYO2MYO2IXNbIXNbEWNREWNRQXNRQXNRQXNRQXNRQXNRQXNRQX
NRQXNREWNBIXNRm_PCYhRSajS3YeR3UdQcafRBQZO39dQPa7FRaCJIBU_jffdHZK]FB3VU>7V4f1TTn2
TUV:VUJ3TD5/Nd5ZNEEoS4YkQEinRbTiAP0:500@5P`N7bD];:RVYL_;^Lk>_<G5/h^=NT53<2d`83Dh
:2T/72d`82`_7b`_7b`_7b`_7bd`82ha8Blb8S0a7Bl`72l`72l`72l`730a7C4b7S8c7c@e8C@e8C<d
83<d83<d83<d83<d83<d83<d838c7c8c7c8c7c<d83@e8CDf8SHg8c8a7CDd83Lf8SLf8SHe8CHe8CLf
8SPg8c/n9CXm93Pk8SHh8SDf8SLh93/k:Chn;3Li9D53;di@?5]MBVY[Fgn0L9RHRZZZW:neZZR`YK:j
/;>l/ZRcZjbf/79nN0080P0400HD2A4I22DW4EmJ@IN>LjJKP9Z>MYB@N9FANINCNiZFOZ2LQ:VUSKB`
V;bhX:n[Tjn[Tjn[Tjn[TjjZTZfYTJbXT:^WSk^gWkFaVK>_UkfiXLk:/][F_]cH`=WE_M7=]M;>]]C@
^=KB^]SD_=[F_]cH`=gI`Lc8/;nkXlW5[McH`=OC^lo;/m;>]]C@^>3Fa=oE`mkD`]gC`M_A_mW?_MS>
_=O=^m_A_m_A_mW?_MO=^mG;^M?9]m;8]]77]MWA^]WA^][B^m_C_=cD_MkF_mkF_moG`=C:^=C:^=G;
^MK<^]S>_=W?_M[@_][@_]O=^mO=^mO=^mS>_=S>_=W?_MW?_MW?_MO=^mO=^mO=^mS>_=S>_=W?_MW?
_MW?_MS>_=S>_=W?_MW?_MW?_M[@_][@_][@_][@_][@_][@_][@_][@_][@_][@_][@_]W?_MW?_M[@
_][@_][@_]_A_m_A_m_A_m[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_MW?_MW?_MW?_M[@_]_A_m_A_m_A
_mcB`=_B_]_B_][A_MW@_=W@_=[A_M_B_]_B_]W@_=W@_=[A_M[A_M[A_M_B_]_B_]_B_][A_M[A_M[A
_M[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_M[A_MW@_=W@_=W@_=W@_=W@_=W@_=W@
_=W@_=S?^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mK=^MK=^MK=
^MO>^]O>^]O>^P00d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;clg=clg=clg=clg=d<k>d<k>dLo?dLo?
d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>dlg>dlg>dlg>dlg>dlg>dlg>dlg>dlg>d<k>d<k>d<k>dLo?
dLo?dLo?d]3@d]3@d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?
dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d<k>d<k>dLo?dLo?dLo?d]3@d]3@d]3@dLk@dLk@dLk@dLk@
dLk@dLk@dLk@dLk@d<g?d<g?d<g?d<g?d<g?d<g?d<g?d<g?clc>clc>clc>d<g?d<g?dLk@dLk@dLk@
d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@dLo>dLo>dLo>dLo>
dLo>dLo>dLo>dLo>dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?
d]3@d]3@d]3@d]3@d]3@d]3@d]3@d]3@dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d<k>d<k>d<k>d<k>
d<k>d<k>d<k>d<k>d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=
d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=dlk=dlk=dlk=dlk=dlk=dlk=dlk=dlk=e<o<e<o<e<o<e<o<
e<o<e<o<e<o<e<o<dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;
d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:dLc9dLc9dLc9dLc9
dLc9dLc9dLc9dLc9dLc9dLc9dLc9dLc9dLc9dLc9dLc9dLc9dLk6dLk6dLk6dLk6dLk6dLk6dLk6dLk6
d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d/c5d/c5d/c5dlg6dlg6dlg6e<k7e<k7dlg6dlg6dlg6dlg6
dlg6dlg6dlg6dlg6dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5dlk5
d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4d/g4e];=emG:XZ6<HV55
F5DfIf15OG9LVXilWinAZ:RJ/k>W^KR^^[V_^;J^^;J^^KJa`<:f_Knc^kbb^[^b^[^b^[Zd]kNa]KB`
/[6W];>Y]kJ/^[V_^KR^^;N]]KBZ/k:X[;2U[K6V[[:W[[:W[K6VZjnTZJfRYj^PWYfCXj:HYJBJXj:H
XZ6GXZ6GWYfCV9N=WinCT924SXj2T924R8QlR8QlT924TY:6OgmcShn3PH5eQhMkJVYNMgM[PH5eM7AX
PhAjLG9XOh=hRi66VZ2EUYjCLGU^Ig5UDUa?FVAGE5e@I6QLJfeQJ6QLLFmTJ6AIEVEM?dm8E6UV<Da@
9dQA7DAB43a=:5EZ3TUM85ea7f5d65i_8VQi9fak:6Uh;Val:FUk:FUk:FUk:VYl:VYl:f]m:f]m;6an
:VYl:VYl:VYl:f]m;6an;6an;Feo;Feo;6]o;6]o;Fb0;Fb0;Fb0;6]o:fYn:VUm:6Ym:6Ym9fUl9fUl
9fUl9VQk9VQk9VQk9fUk9fUk9fUk9fUk9fUk9fUk9fUk9fUk9FMi9fUk;W22>7R:>gV;=gF7>7>6?7N:
;6j0<7F64DmQ8DaQQIVbYK;<Ujg6KY2WFHbLEHRHCX6ADHBDCH2@=6Mg;f9bB7^;B7n6FGn;=4UH008?
00XB0QLI:SLeT9B?UiV5WZ2<S8ijF5Y7;BhN;C0P=3LX9RTJ:S0O:BlN:BlN:2hM:BlN:S0O:c4P;38Q
;blM;RhL;RhL;BdK;RhL;blM<30N<C4O<c@P<c@P<S<O<S<O<S<O<C8N<C8N<C8N<34M<34M<34M<34M
<S<O<c@P=CHR=SLS=cHR>CPT>cXV>cXV>CPT>3LS>CPT>STU<cLJ<cHL=3LM=CPO=STP>3XT>CXV>S/W
;c<J<cLN>3/U>SdW?T0/B4XgEeU6HfEBMGQXNh5`SI:3XZVLYJjQZk>XPXb05b0F3AP@4adA6R8A:RdG
ATL]J6A8LV]BK65;KFUAKFUAKFUAK6Q@Kf]CMW9JOg]SQH5YRXI]RXI]RXI]RHE/R8A[QX9YQ81WPgmV
CT`d@d4Y?3XRAD<[GE]3MgEMQXA/RXQ`UiEmVIMoW9Z2XIn7YZB<ZjVA[ZbD/:jFVIQnRHQ^W9^1_kjT
aLBZ`L2Vc<^afMRnb/:[bl>/c/J_dLVbe<bee/jgelnhf=2idLVbd/Zce<bee/jgfM6jfm>lgMFng]Jo
d/Zcd/Zcd/Zcdl^de<bee<beeLffeLffg]G1gMC0gMC0g=>ofm:nf]6mf]6mf]6me/fie/fie/fieljj
f<nkfM2lfM2lf]6melfkelfkelfkelfkf<jlf<jlf<jlfLnmf<jlf<jlf<jlf<jlfLnmfLnmf]2nf]2n
f]2nf]2nf]2nf]2nf]2nf]2nf]2nf]2nfLnmfLnmfLnmf]2nf]2nf]2nfm6ofm6ofM2lfM2lfM2lfM2l
fM2lfM2lfM2lfM2lf<jlf<jlfLnmfLnmf]2nfm6og=;0g=;0fm:nf]6mfM2lfM2lfM2lfM2lf]6mfm:n
fM2lfM2lfM2lf]6mf]6mf]6mfm:nfm:nf]6mf]6mf]6mf]6mf]6mf]6mf]6mf]6mf]6mf]6mf]6mf]6m
f]6mf]6mf]6mf]6mfM2lfM2lfM2lfM2lfM2lfM2lfM2lfM2lf<nkf<nkf<nkf<nkf<nkf<nkf<nkf<nk
f<nkf<nkf<nkf<nkf<nkf<nkf<nkf<nkeLbhe/fie/fie/fieljjeljj003@b/_@b/_@b/_@b/_@b/_@
b/_@b/_@b/_?cLg?cLg?cLg?cLg@c/k@c/kAcloAclo@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/kCcLkC
cLkCcLkCcLkCcLkCcLkCcLkCcLk@c/k@c/k@c/kAcloAcloAcloBd=3Bd=3@c/k@c/k@c/k@c/k@c/k@
c/k@c/k@c/kAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloAclo@c/k@
c/k@c/kAcloAcloAcloBd=3Bd=3Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3Ac]3@cLo@cLo@cLo@cLo@cLo@
cLo@cLo@cLo?c<k?c<k?c<k@cLo@cLo@cLoAc]3Ac]3@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/kBd=3B
d=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3AclkAclkAclkAclkAclkAclkAclkAclkAcloAcloAcloAcloAcloA
cloAcloAcloAcloAcloAcloAcloAcloAcloAcloAcloBd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3Bd=3AcloA
cloAcloAcloAcloAcloAcloAclo@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/g@c/g@c/g@c/g@c/g@
c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/gCc/gC
c/gCc/gCc/gCc/gCc/gCc/gCc/gDclcDclcDclcDclcDclcDclcDclcDclcCc/_Cc/_Cc/_Cc/_Cc/_C
c/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_BcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[BcL[B
cL[BcL[BcL[BcL[BcL[BcL[BcL[@blS@blS@blS@blS@blS@blS@blS@blS@blS@blS@blS@blS@blS@
blS@blS@blS@cLG@cLG@cLG@cLG@cLG@cLG@cLG@cLG?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/OAblCB
c<GBc<GBc<GCcLKCcLKCcLKDc/OBc<GBc<GBc<GBc<GBc<GBc<GBc<GBc<GBcLCBcLCBcLCBcLCBcLCB
cLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCBcLCAc<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?A
c<?Ac<?Ac<?Ac<?Ac<?Ac<?Ac<?1_[[CdLJWYY5ZJ4ULFSMOEcUQECeeIU=aLEmiNFN1PG64Q7B3PWB2
P7F5PgR8QW]^KemTI5IIFD]EEDUGEd]IF4iGEDeCDDUFEDMPGe5/JeebLF=aL69]K5i[JUa[JUaXJ5YY
JE]ZJUa[JeeZJUaXJ5YVIUQTI5IVIUI/K5a^KUi/K5a[Je][Je]VIUIPH51UIE=TI59/K5YfMVAcLf5T
I59QHDmZJUQ[JeUXJ5IFETA^KUaOGdeWIeE/K5YTI59^KUiSI5AJFd]YK5a^LF5HGTe5CC`e?B`nBCEF
Gd]MHe1WJeQRHU1KEdE/IEA[I5=@Jf4R@CXG>SH8<C@WF68/HW<[Igd[JH4OEfP_JWXWJ7LPHg8YKWdW
JWTRH70]JGTXJ7XYJG/ZJW`[Jgd/K7h]KGl^KX0^KX0]KGl]KGl]KGl/K7h/K7h]KGl^KX0^KX0/Jgl]
K80^KH4^KH4^KH4/Jgl[JWhYJ7`XJWdXJWdXJWdWJG`WJG`WJG`VJ7/VJ7/WJG/WJG/WJG/WJG/WJG/W
JG/WJG/WJG/RIgPUJW/_LH<gNH/iNH/fM8HfM8HlMhX_LH<^Lh@IEfTJAea[QIf?XkbF]LaXTjQHRIUG
RYY>PI5;Oi11MhPKDf@;@e@QG6a:RHeGQHeAJgT031/01a803@l_?SY^MFi?Ed1FGTM8CCP^<QlY;1`]
<24`<28b<RHX;AhX;AhX;AhW;1dX;AhY;QlZ;b0[<24];A/];A/];A//;1X];A/^;Q`_;ad`<1hb<alb
<alb<ala<Qha<Qh`<Ad`<Ad_<1``<Ad`<Ad_<1``<Ad`<Adb<alc=20d=B4Z:AD];1P_;QX`;a/`;a/a
<1`c<Qhe=20c=ALc=APb=1Lc=1Xd=A/e=Adf=B0e=1le>A`j?B=0@bU0@bXl?bHg>B<d=B4c=20l?RQ<
CCUDET9^L5ehO6UoQGAeNV/[<R<U:b0N9AHU:aP_=A`d>Ahl?B=5@2]2>bPn>R4n>R4m>B0j=Qdg<aXg
<aXi=A`k=ahi=QXi=QXi=QXi=QXh=ATg=1Pf<aLe<QI1@2Hh=ad];18X9`d/:a4b<ALh=adj>Alc<QPd
<aTg=Q`j>Alm?290?bE3@RQ4@bTo?R8a<1@k>Qi=C31<Bbm9B2aAD3AGESYaJdidKU5jM5N1Nej8PVF>
R6^ARfjCSG2OVGbRW7nWXHB]YhZd[Y6j]9No^Ic2_9o<aJc=aZg?b:oCc;?FckKId[WLeKcMe[gAb;CA
b;CBbKGBbKGBbKGCb[KCb[KCb[KEc;SEc;SFcKWGc[[Hck_Id;cId;cJdKgFc;[Fc;[GcK_GcK_GcK_H
c[cHc[cHc[cGcK_GcK_Hc[cHc[cIckgIckgIckgIckgIckgIckgIckgIckgIckgIckgIckgIckgHc[cI
ckgIckgIckgJd;kJd;kJd;kKdKoHck_Hck_Hck_Hck_Hck_Hck_Hck_Hck_GcK_GcK_Hc[cIckgJd;kK
dKoLd/3Ld/3JdKgJdKgId;cHck_Hck_Id;cJdKgJdKgHck_Id;cId;cId;cJdKgJdKgJdKgKd[kId;cI
d;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cId;cHck_Hck_Hck_Hck_Hck_H
ck_Hck_Hck_Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Gc[[Ec;SE
c;SFcKWFcKWFcKWGc[X00=3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:blo=cLo=cLo=cLo=cM3>c]3>c]7?
cm7?cm3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]?=c]?=c]?=c]?=c]?=c]?=c]?=c]?=c]3>c]3>c]3>
c]7?cm7?cm7?cm;@d=;@d=3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]7?cm7?cm7?cm7?cm7?cm7?cm7?
cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm3>c]3>c]3>c]3>c]7?cm7?cm;@d=;@d=7>d=7>d=7>
d=7>d=7>d=7>d=7>d=7>d=3=cm3=cm3=cm3=cm3=cm3=cm3=cm3=clk;cLo<c/o<c/o<c]3=cm3=cm3=
cm7>d=3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c];@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=7?c]7?c]7?
c]7?c]7?c]7?c]7?c]7?c]7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?
cm7?cm;@d=;@d=;@d=;@d=;@d=;@d=;@d=;@d=7?cm7?cm7?cm7?cm7?cm7?cm7?cm7?cm3>c]3>c]3>
c]3>c]3>c]3>c]3>c]3>c]3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>
cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cMC?c=C?c=C?
c=C?c=C?c=C?c=C?c=C?c=?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>bm?>
bm?>bm7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM7<bM3;b=3;b=3;
b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=3=aM3=aM3=aM3=aM3=aM3=aM3=
aM3=aLo:alo:alo:alo:alo:alo:alo:alo:am7;a=7;a=;<aM;<aM;<aM?=a]?=a]?=a];<aM;<aM;<
aM;<aM;<aM;<aM;<aM;<aM;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=a=;=
a=;=a=7<`m7<`m7<`m7<`m7<`m7<`m7<`m7<`m7<`m7<`m7<`m7<`m7<`m7<`m7<`m7<`l?0_=WGc:ZZ
TVIU@eMD;UA=;5=6;6EF@eAA?5UF@EiJAeiJB5]GAEaGB65LCFMQE5eMBdi>?3`l;3De9CTh:Sdk<3`j
;cPf:d<o;E9>?6APCVeYEfaXEVUUDfQTDVYVE69PCVARD6QVE6YXEV]YEf]YEfUWEFQVE6IVE6QXEVIV
E69RD69RD6MWEFUYEfMWEF5SCFU[EFEWDEmQBfAVD6EWDF=UCfQZE5eOBE=E?dI8<V]]EeMI@de?>EEG
@EiPBVITDWEcHEMGAFe]Ff5SD3a0;EQLBE1D@D===UMOB5ILAEiPBV1OBV5LAfYSCeeD@1@h;1e4?2MB
Cb=FFBeXLPa>H25WOQ=MMbUNJcI]O2YWMB5RL2i_ORMXMbAPL3I`PbQXNRUYNbYZO2][OBe]Obi^P2m_
PBm_PBm_PBm_PBi^P2e]Obe]Obe]Obi^P2i^P2e/P2i]PBm^PRm^PRi]PBe/P2]ZORUXO2QZOBQZOBQZ
OBQZOBMYO2MYO2IXNbIXNbEZNbEZNbEZNbEZNbEZNbEZNbEZNbEZNb9WN2EZNbmaPcMiRcUiRcIdQSId
QS]iRc1bQ2aaPQ]KKA=2EeMcRgZBZXf_aUR:WTn0T5R9VE>6UUB8VD^3U29LK`]6FB5OLCj1PU>3RG:=
Va@Y>0<L9P0B53A6?e=KDC@m8cLo:2P_6RHZ5c<f9R`_82PX73/k;bP]7RL/7BL/7BL/7BL/7BP]7RT^
7bX_82d]7B`/72`/72`/72`/72d]7Bh^7Rl_7c8c7c8c7c4b7S4b7S0a7Bl`72l`72l`738c7c4b7S0a
7Bl`72l`730a7C0a7C4b7S@c7cHe8CLf8SHe8CDd83@c7cHe8CPg8cLi6cDg6C<e63<e63Df73Hf7SLg
7cLg7cHj7CHj7CLk7SPk8CXm93e09d53;DA6<3hl94I6;SLg7cXl9SPj9S/m:D=7=1LK21DG2`X=01@I
128X3adT2A`O1RDT42XV52TU32dY434]538^5C4]530/4c0/4c0/4bh/3Rh/3Rl]3c0^430^430^42l]
3bh/3R@S2BPW3B`[4B`[4BTX3RDT2R@S2BDT2Rl^52l^52l^52h]4bh]4bd/4Rd/4R`[4Bl_4BTY2bh^
43<c5C0`4STi6dA49T518cLb4CTd4cdh5d4l6d<n7DE07dI184I184@o7TI184Q38T]69Di9:55<:e=>
;EA?;Ti7;U=<<eaE?6QQB7E^EH5jHHZ3JXn8KjJNQjVQR[2XTKR`VL2hXLW1Z/o7/=;:/mC<]MG=]]G=
]]K>]mS@^MWA^]WA^][B^mK<^]K<^]K<^]O=^mO=^mS>_=S>_=S>_=O=^mO=^mS>_=S>_=S>_=W?_MW?
_MW?_MW?_MW?_MW?_MW?_MW?_MW?_MW?_MW?_MS>_=S>_=W?_MW?_MW?_M[@_][@_][@_]S?^mS?^mS?
^mS?^mS?^mS?^mS?^mS?^mO=^mO=^mS>_=W?_M[@_]_A_mcB`=cB`=[A_M[A_MW@_=S?^mS?^mW@_=[A
_M[A_MS?^mS?^mW@_=W@_=W@_=[A_M[A_M[A_MW@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@_=W@
_=W@_=W@_=W@_=W@_=W@_=S?^mS?^mS?^mS?^mS?^mS?^mS?^mS?^mO>^]O>^]O>^]O>^]O>^]O>^]O>
^]O>^]O>^]O>^]O>^]O>^]O>^]O>^]O>^]O>^]G<^=G<^=G<^=K=^MK=^MK=^@00c/W8c/W8cl[9cl[9
cl[9d<_:d<_:d<_:d<[;dL_<dL_<dL_<d/c=d/c=d/c=dlg>e<k?e<k?e<k?e<k?e<k?e<k?e<k?e<k?
d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<[;dL_<dL_<dL_<d/c=d/c=d/c=dlg>dLo?dLo?dLo?dLo?
dLo?dLo?dLo?dLo?d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>clg=clg=clg=clg=d<k>d<k>dLo?dLo?
dLo?dLo?dLo?dLo?dLo?dLo?dLo?dLo?d<k>d<k>d<k>dLo?dLo?dLo?d]3@d]3@dLo?dLo?dLo?dLo?
dLo?dLo?dLo?dLo?d<k>d<k>d<k>dLo?dLo?dLo?d]3@d]3@dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>
e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>dlk=dlk=dlk=e<o>e<o>e<o>eM3?eM3?e<o>e<o>e<o>e<o>
e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>dLo>dLo>dLo>dLo>dLo>dLo>dLo>dLo>
e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>e<o>d<k=d<k=d<k=d<k=
d<k=d<k=d<k=d<k=d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<
dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;e=79e=79e=79e=79e=79e=79e=79e=79e<o<e<o<e<o<e<o<
e<o<e<o<e<o<e<o<dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;gM[Bd<g5c/_3dLk6c/_3d/o7emC<d/o7
d<g5d<g5d<g5d<g5d<g5d<g5d<g5d<g5d/o7d/o7d/o7d/o7d/o7d/o7d/o7d/o7eLk;e<g:e<g:dlc9
d/_8dL[7dL[7d<W6c/k2c/k2c/k2c/k2clo3clo3clo3clo3dL_4dL_4dL_4d<[3d<[3clW2clW2clW2
e/g4e/g4e/g4e/g4e/g4eLc3eLc3eLc3eMC0d];2clg5clk:cm3>cLk:b/_2a/Rld/_2e<g4eLk5eLk5
dlc3dL[1dL[1dL[1elW3e<S2dlO1dlO1dlW2eL_4eLg6elo8eLO8e/W7e/W7eL[6eL_4dl_4d/_2d/_2
cm37emG=dLo7dLk6cLO0e<k7h=SAaknhe=2nd/bi^K:NI5Y2FTdcGe4dGT`]E4<RHE4jHU8kH58kGe<k
GU@lGePoHUe4IF58IUaBD4@hACPXCD8^D4LcA3h[>3PX>c/]A4H`BTddFE/mHVE5HV=1FU/kF5LkGUY1
GEU1Hem6JFE<JfQ<JFM9J6I7JFQ6JfY8If1=If1=If1=If1<If1<J65=J69;J69;K6AGK6AGK6EFJfAE
JV=BJ65@IUm>IEm<GeY1D4XcDDdeH5e8GEY5ATDa@Cl]C4`jKVACIf5:HEm0Ff0iEelgD5PjC58oBdm4
BU`gBE4bDThfH5I5GUaBAEE>7TM20cdh3d]G5UAO7EeX7f5/7F9/76=]86Qb9Feg:VUg;6]i;Vek;Vek
;Vek;Vek<6mm<W5o9W2286Qj:722<WN:9fao8VIi:F]n:ff0;6j0;6j0;Fn1;W22;W22;g63<7:4<7:4
;762;G:3;W>4:g219fam9FYk9fam:Vn0<Fb0;6Um9FMj8fMj9FUl:F]n;V]o;fYn:VYl9fUk9fUk:6Yl
9fam9V]l8VQi7fEf:fYh;fil>7F3?7V7?7N6>W>2>gB3?GJ5>7N<;6Mj:f9a3D5><5m]@g62BWZ<Dh:H
DhZCEX^HDXBFDH>GCh6E>Van:5aY:em[DHRGCh2>E7j;:4QC01@K01PL?5=E73@d2A4:4Q`@7bTI9C0L
9c0K:2hK:c4P;S<T9BXK9R/L:2dN:BhO:c0Q:c0Q:c0Q:c0Q:bTG:bTG;2XH;2XH;2XH;B/I;B/I;B/I
:BhO;34R;C8S;C0Q;2`N:RXL;B`N;bhP:S0M:2hK9bdJ:2hK:BlL:S0M:BlL9bdJ;R`J;R`J;bdK<2hL
<BlM<S0N<c4O<c4O=SDP=3HP<S<O<30N<2hL=BlL>c@P@3PQ?3TT?3PU?3PU?3PU?STT@3/RAC`QAc`P
@SlSA40W@clV@CdU@SdX?cXU=2hK9R0=2aD53aL66Q/;9R8@;2DD;BLD;2TD;B`G<2`C<2`C<BdD<RhE
<RhE<blF<blF=30G>SHM=c<J=30G=30G=C4H=C4H=30G<blF<C0F<S0H<S0H<RlJ<BdJ;b/H;BTG:bLE
:B/E:R`F;2hH;S0J<38L<38L<38L<38L;RdC<c8H>3LM=C@J;bhD;RdC=3<I>cXP=cLI=SHH=CDG=3@F
<c<E=3@F=3@F=3@F=3DE=CHF=CHF=CHF=CHF=3DE<c@D<c@D<S@G;BlB;2h@<c@D>CLH>CPF?3XH@3hK
?cdK@ClMAD<QBTPVD4h/EE<aFELeFeTgL6]:Mg9APWeLRhIUThi]WIQgYj:1[ZV8^k>E][2Ca<:Td]6e
dM2fdlngfm:nfm2le<bef=2ig=BmgmO0gmO0g=Bmelnhe<beg=6kfLjhelbff<fgf/nigM:lgM:lg=6k
fLjhfLjhfLjjf<jlfLnne/foe<^nd/Vlh]Fog=6kelbfdl^dd/jfdm6ie=Ble]Jne/fie/fie/fieljj
eljjf<nkf<nkf<nkfLjhfLjhfLjhf/nifm2jfm2jg=6kg=6kf/nif/nif/nif/nif/nif/nif/nif/ni
f/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/nif/ni
f/nif/nif/nif/nifLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjh
f<fgf<fgf<fgf<fgf<fgf<fg003>bLS>bLS?b/W?b/W?b/W@bl[@bl[@bl[@b/_AblcAblcAblcBc<gB
c<gBc<gCcLkDc/oDc/oDc/oDc/oDc/oDc/oDc/oDc/o@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/k@b/_A
blcAblcAblcBc<gBc<gBc<gCcLkAcloAcloAcloAcloAcloAcloAcloAclo@c/k@c/k@c/k@c/k@c/k@
c/k@c/k@c/k?cLg?cLg?cLg?cLg@c/k@c/kAcloAcloAcloAcloAcloAcloAcloAcloAcloAclo@c/k@
c/k@c/k@c/kAcloAcloBd=3Bd=3AcloAcloAcloAcloAcloAcloAcloAclo@c/k@c/k@c/k@c/kAcloA
cloBd=3Bd=3AclkAclkAclkAclkAclkAclkAclkAclkDclkDclkDclkDclkDclkDclkDclkDclkCc/gC
c/gCc/gCc/gDclkDclkEd<oEd<oDclkDclkDclkDclkDclkDclkDclkDclkDclkDclkDclkDclkDclkD
clkDclkDclkAclkAclkAclkAclkAclkAclkAclkAclkDclkDclkDclkDclkDclkDclkDclkDclkDclkD
clkDclkDclkDclkDclkDclkDclk@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/gBcLcBcLcBcLcBcLcBcLcB
cLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcCc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_Cc/_DdLWD
dLWDdLWDdLWDdLWDdLWDdLWDdLWDclcDclcDclcDclcDclcDclcDclcDclcCc/_Cc/_Cc/_Cc/_Cc/_C
c/_Cc/_Cc/_Cd<SAc/KAc/KCd<SCd<SAc/K@cLG?c<C@cLG@cLG@cLG@cLG@cLG@cLG@cLG@cLGAc/KA
c/KAc/KAc/KAc/KAc/KAc/KAc/K?b<G@bLK@bLK@bLKAb/OAb/OBblSBblS>c<C?cLG?cLG@c/KAclOA
clOBd<SBd<SBc/WAcLSAcLSAcLSAcLSAcLSAcLSAcLSAblCAblCAblCAblCBc<GBc<GBc<GBc<G:b[[9
b;[8aKg9a/;=b/KAcLSAclG?c/3:b;g<b[o=bl3>c<7>c<7>c<7>c<7?cL;Bc/?CclCDd<GEdLKFd/OC
dLKCdLKBd<G:a;o9aL3:a/7;b<3>c<;Ad<KDe<SFe/Zo_K?CdLO>c<;5`;OGd<OGd<O<`k[JdLS?bkW>
akJf[i]OEd1CB2eHBRiLC2mIBRY@@R]CABiFBS9FC3AFCcIGD3MHDcYKESeNE4=NDT1OE41NDcmBBcQ;
B3UHFTi/LFQXJF1HFTi<CS]>D3YGEcmMFd=PFdIQFdQDD3eGDd1KEdALFDAKF4=GECeEDc]DDSYNFDAN
FT9NFT9NFT9NFT9NFT5NFT5NFT5IEcmJF41LFT9NG4AOGTAOGTAOGTAOGTAVIDUIF3aGESaMGDEHFd99
BcE6BC=@DSiACSmACceCDSiCECmBE3i>DC]<CSY<CSY6B2YCDSQPFTMGE4Hk@C`R>3HMA4HUF5/QEFDS
FVTWGVdVGfhSGVdSH6hUI78YJ7H_IgPaJGXcJg`cJg`cJg`cJg`eKGhgKh0bLHH]K84cLXLiMH/fL8Hd
KX@iLXPhLHLcKX8cKX8cKX8dKh<eL8@fLHDfLHDgLXHcL8@eLXHeLXHcL8@_K80]JWh^JglaKX8bKH4/
JglUJG`TJG`UJWdWJgh[JWh]J7`/LH8YKWlWK7dXKGh/LH8[LH8VK7dQIgPOHW4VIgH`LH0jN8PkNHTi
MHDdL80bKGd]L8LWIWX]J7PAAU<_H6hmKWi5Mh]@PIM?Qi9BRII>Q9EBQiaISJA?Q9U5Nha=Q9=2Ohe7
OXeLRII8K7HcD5LgD5ABJF/A:BT=50lF7aDP:A`T;QdU;QXV;1/W:alY;B8W;1dW;1dX;AhY;QlY;QlY
;QlX;AhX;Ah[;AX[;AX[;AX[;AX[;AX[;AX[;AX[;AXU:Q/X;AhZ;b0/;b0/;1h/;1h_;R0b<B<[<AhZ
<1dX;Q/X;Q/Z<1d[<AhZ<1dY;a`];a`];a`^<1d^<1d_<Ah_<Ah`<Ql`<Qla<adb=1hc=20c=20c<Qde
<Qdi=Adk=alg=1lh=B0i>2<k>RDk>RDm>b<m>B4l>1li=alj>20j>20h=B0i=B8h=24_:aTS7`d:50<B
60LN7P`Z9Q@a:QLa;1Lb;APb;aXi=QXj=a/k>1`n>am1?R94@BE6@bM8ABU3@2A1?R8o?20o?211?R93
@2A3@2A2?b=3@RQ2@BM0?RHo?2Lm>RDl>2Dk=b@k=bDj>B@j>B@j>B@j>B@i>2<i>2<i>2<i>2<h=adl
>b4n?B<l>b4h=adh=adk>R10?bDn?B4m?20l>alk>Qhj>Adk>Qhk>Qhl>alm?Alm?Aln?R0n?R0n?R0m
?All?1hl?1hd>1/`<QD^<1<d=1Hh=QLe<a@f=18h=Q@d<a4e=18f=A<h=aDj>ALl>aTn?A/o?Q`h=aDk
>QPn?A/o?Q`n?A/o?Qa2@Am5A296@RI1?R97B2i?DSU@DSaPGd]hLF1nMVFRWHRZYI2g/Yg2_JS:aK3?
b[GCc[WFdKcAbK;Fc[OLe;gMeKkKdkcGckSEcKKDc;GRf<3Pe[kNdkgLdKgJd;kIckkIc/3HcKoBaJoF
bK?JckWPeKoPf<7KeKkEdKW@c;CGc[[Gc[[Gc[[Gc[[Hck_Hck_Id;cId;cJckWJckWJckWJckWJckWK
d;[Kd;[Kd;[JckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJ
ckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWJckWIc[SIc[SIc[SIc[SIc[SI
c[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SHcKOHcKOHcKOHcKOHcKOHcKL00<k9b<k9b<o:
bLo:bLo:bM3;b]3;b]3;b]3:bm7;c=7;c=7;c=;<cM;<cM;<cM?=c]?=c]?=c]?=c]?=c]?=c]?=c]?=
c]?=c/o=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cM3:bm7;c=7;c=7;c=;<cM;<cM;<cM?=c]3>c]3>c]3>
c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c/o=cLo=cLo=cLo=cM3>c]3>c]7?
cm7?cm3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c/o=cLo=cM3>c]3>c]7?cm7?cm7?cm7?cm3>c]3>c]3>
c]3>c]3>c]3>c]3>c]3>c/o=cLo=cM3>c]3>c]7?cm7?cm7?cm7?cm3>cM3>cM3>cM3>cM3>cM3>cM3>
cM3>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM;=c=;=c=?>cM?>cMC?c]C?c]C?c]C?c]?>cM?>cM?>
cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM3>cM3>cM3>cM3>cM3>cM3>cM3>
cM3>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM?>cM3>cM3>cM3>
cM3>cM3>cM3>cM3>cM3>cM;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=
c=;=c=;=b];=b];=b];=b];=b];=b];=b];=b]?@b=?@b=?@b=?@b=?@b=?@b=?@b=?@b=?>bm?>bm?>
bm?>bm?>bm?>bm?>bm?>bm;=b];=b];=b];=b];=b];=b];=b];=b/g:`]?@b=3=aLg:`]?@b=3=aL_8
`=3=aM3=aM3=aM3=aM3=aM3=aM3=aM3=aM3=aM7>a]7>a]7>a]7>a]7>a]7>a]7>a]7>a]7;a]7;a]7;
a];<am;<am;<am?=b=?=b<c8`lc8`lc8`lg9a<g9a<g9a<g9a<g9a<[7`l[7`l[7`l[7`l_8a<_8a<c9
aLc9aLk:aLk:aLk:aLk:aLk:aLo;a/o;a/o;a]CBam?>aM3:`m;9aMC<aMS?a]WAa=WB`M3Ca<oB`loB
`lkA`/g@`Lg@`Lc?`<_>_lW9]l[:^<g=^lk>_<k>_<c<^/[:^<S8]];Cb]3Ab<g>a<W:`<O9_LK9^/O:
^lO:^mgJc<O4]][Dalc6^L6i[<g4]lNn/MW@`mWE`mC@_[fgY6ELB598<515:UA8;5Q:;Ti1:e95;eE:
=5M<=UE==UA<=E5;=59<=EE9<EeA>F=G?eYB>e1<>E9FBVMaJgZ8QUIJGdQ=CSm3?D=7>d]<?4e:>dU3
=TQ0<dQ5=TY7>4e:>e5>@59?@E1=?d]8>TM4=TE5;DM7;dY:<Ti>=U=C>eMG?eYJ@UaLA5YNAE]OAUeQ
B5mSBV5UC69VCF9VCF9VCF1PCUUKB5=E@TiA@DQ=?T=8>D99?4E<?d18?TE9A4Q7BDM3BDQ3A4]9?e9A
?5UJ>VII@dm9=SHi:R8c:QTe=Aa2AbUEHSMVM3MYNcMYNcIZNcIZNcE[O3A/OCI^OcM_P3M/P3U^PS]`
Q3]`Q3U^PSU^PS]`Q3ebQSE^Q3I_QCM]Q3E[PSQ/Pce_QSa^QCQXP3I]PSI]PSM^PcQ_Q3Q_Q3U`QCYa
QSYaQSM`QCQaQSQaQSI_Q3A]PS9[P39[P3=/PC5^PR]]P2I[ORA/ORE]ObM/ObU[OR]XO2U_P2E[O29X
NBE[O2Y`PB]aPRM]OR9XNBE[O2U^ObicQ3QjS4:2U4F5UdB2U3mmSbidS2U/PBe[O@]4DbAHIC1SLca^
P4YmTE28Te29V4V1U4R1Ue6:Xdf7WDF2UTj<WT:9UdR9Uf6FXf:<V6f<UG2:T6QoP@LL7Q8H5aPO6QlW
7B4Z7B4X6B0T620T6B8U72@Y6R@Y6R@Y6R@Y6R@Y6R<X6B8W624V5b@Z6B@Z6B@Z6B@Z6B@Z6B@Z6B<Y
62<Y620U5R8W62DZ6bP[72XZ72/[7Bl^834`8RX`7bP^7BH/6bH/6bP^7BT_7RP^7BL]72P^6bP^6bP^
6bP^6bP^6bP^6bP^6bP^6b//62h_6c4c7C@d73<c6blb6Blb6C0c6S4d6c@g7SLj8CXm93/m9cPj9S<h
8c0d8CLi8cPj93Hg8c<d83<c8C<c8b/[6b8R4PTD01DK22@U4C8/6CL`73Tc73Te7CLe7D4m8D4m8D<o
8dI29T]7:e1<<5EA=EQD>5aH?5UE>EIB=UEA=EIB=UIB=UA@=5=?<e5@=U5@=U1?=E1>=U5>>E9?>UA@
?EEA?UE@>eA?>U=>>E9=>55<=e5<=e5<=e9=>4e;<de;<da:<T]9<D]9<D]9<Da:<Ta:<Te<<Te<<T]:
<4Y9;dY9;dY9;d]:<4]:<4e<<4i=<Dm><Tm><Tm><Tm><Ti=<De<<4E8;T13:D52:4E7:TQ8:TI49T=1
8TE3944o840n7clm7Shl7C`j6c/i6SXh6CTg638e5C<f5S<f5S4d52ha4Bd`42d`42ha4CPf7R`_5RD[
51HL2@<900P;01PF2a`E31dK2Bd[6D=1;eQFA6UWEGUgIHV7MIBBP;6[U;^eW/O1Z/c6[l_5[/c6[m7;
]=OA^]G</MG;/mG;/mG:]=K;]MO<^=S=^MW=^ngObNSJa>3C_MW<]]C9/mC9/mG=]]S@^MO>^]O>^]S?
^mS?^mW@_=W@_=W@_=W@_=[?^M[?^M[?^M[?^M[?^MW>^=W>^=W>^=[?^M[?^M[?^M[?^M[?^M[?^M[?
^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?^M[?
^M[?^M[?^M[?^M[?^M[?^MW>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>^=W>
^=W>^=S=]mS=]mS=]mS=]mS=]mS=]`00c/W8c/W8cl[9cl[9cl[9d<_:d<_:d<_:d<[;dL_<dL_<dL_<
d/c=d/c=d/c=dlg>dlg>dlg>dlg>dlg>dlg>dlg>dlg>dlg>clg=clg=clg=clg=clg=clg=clg=clg=
d<[;dL_<dL_<dL_<d/c=d/c=d/c=dlg>d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>
d<k>d<k>d<k>d<k>clg=clg=clg=clg=d<k>d<k>dLo?dLo?d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>
clg=clg=clg=d<k>d<k>d<k>dLo?dLo?d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>clg=clg=clg=d<k>
d<k>d<k>dLo?dLo?d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=dlk=dlk=dlk=dlk=dlk=dlk=dlk=dlk=
d/g<d/g<d/g<dlk=dlk=dlk=e<o>e<o>dlk=dlk=dlk=dlk=dlk=dlk=dlk=dlk=dlk=dlk=dlk=dlk=
dlk=dlk=dlk=dlk=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=dlk=dlk=dlk=dlk=dlk=dlk=dlk=dlk=
dlk=dlk=dlk=dlk=dlk=dlk=dlk=dlk=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d/g<d/g<d/g<d/g<
d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:
dm38dm38dm38dm38dm38dm38dm38dm38dlk;dlk;dlk;dlk;dlk;dlk;dlk;dlk;d/g:d/g:d/g:d/g:
d/g:d/g:d/g:d/g:cL[2eM;:c<W1a/>kdLk6dm38cL[2dm38d<g5d<g5d<g5d<g5d<g5d<g5d<g5d<g5
d<g5d<g5d<g5d<g5d<g5d<g5d<g5d<g5d/c7d/c7dL_6dL_6d<[5clW4clW4c/S3dlk;d/g:d/g:dLc9
d<_8cl[7cl[7cl[7b/W5bl[6bl[6bl[6c<_7c<_7c<_7cLc8blS3blS3blS3blS3blS3blS3blS3blS3
cL[2c/S1d<Jod<FmdlNmdLRkd<Vjd<Vhd<foclbnc/^mclbnd<fod<foclbnc/^md<jld<jldLnme=2n
e=2neLjme<fle<flblVoblVoc<[0cl_0d<fodlg0e<o0e<o0cLVgLViL[ZZH^K:QQgm^^k>Ri=[9g=;1
c/Vjal>a]:fLIEm<ETlkDTXcDdTaED/cEDdfEdlhFE4jF50iE4`eDDTbCTPaCTPaET/]E4T[CT<WAd4Z
BDXjCEA?AUEH>diF6bH^82/_;3@c=3`b<cL[;blQ<BhP>38W=SLW=SHX>CT[@40dAD@jAT@l@3dh>cPc
>Ch_>d0a?T<d@THjATXnBTi3CE56Ce=8C5=@CEAACEAACE=BC59ABe1ABTm@BDi?>C]6>C]6=3E3:B`j
92Th9b/m9Rdn92Xm6bXc7RPj7Aln6a@i81Lb=2dbC4PeFe/gI5]>>Shc4BTQ2C@a6U9G:fMc<6Ym;VAk
;fMj;fMj;FMj<6Ym=6j1=W23=Fn2<fj1;fUl<F]n<ff0<Vao<F]n<F]n<ff0=6j1>767?GJ<>6j5<FMn
>Ff4?727>6Z1<fEl>766>766>G:7>W>8>W>8>gB9?7F:?7F:>GB8>WF9>WF9>GB8=g:6=G24=6n3=6n3
<6f1:Vao9V]n9Feo9fn1:Vn2:ff0;V]o96Yk96Yk9F]l9fam:Fio;6j0;6j0;6j09V]n8fMj86Ag9FMj
<gF8@h:FBXNKAhBH@XVT>7bC=WB644MF9EUU<V=a?FinBg^=EhfHEhjMCHFHBX:KDHbVCHZTA8NNBHbQ
?8VI?HBBCHNCF8F@O9fVRjF[O92E4bHY5a`M6b4P82LP82PM82HK82@I828L824M8BHG8BHG8RLH8RLH
8RLH8BHG8BHG82DF8BTH8BTH8BTH8BTH82PG82PG82PG82PG8RLH8bPI9BXK:2/L;2`N;BdO<2lQ<S4S
:c4P:2hM9B/J9B/J9bdL:BlN:BlN:2hM9c0L9c0L9RlK9RlK9RlK9RlK9RlK9RlK:b/I;BhJ<S8J<S8J
;c8I;38K:C8M:3<O<3HO<cLN=3PO=CPO=3LQ;SDP:38Q9BlR<cPS=3TT<3DP:blL:B`L:B`L92LH71l@
31D0724<;RdH>C@O?cLP@S/R@3/R?S/O@3`O@CdP@CdP@clRAd<VC4P[D4`_DdlbHEe0Ge/nGUXmH5`o
I613If=6J6A7J6A7IF96IV=7If=:J6A;J6A<If9=IV5<IEm<If1<If1<IEi:IEi:IEi:IUm;If1<J65=
IF=;HEm7GUa4GUa4H5i6HEm7H5i6GE]3HEm7H5i6Gee5GUa4GUa4GUa4GUa4Gee5GUm5Gf16H657H657
HF98H657H657Gf16F5]5EEPoEUU0GUm5H695GUe1GU`nGedoFeXnFUTmFEPlEUDiE5<gDE0dCdhbCTda
AT/^Ad`_Ad`_AT/^ADX]A4T/A4T/ADX]>C`V=S/V<S/W7bXJ0P`0008010<010000P@01PP04A<75QP<
5QP<61X>7b4E9bTM;R/F>SLRCT/fHf1;NWMRU95l[JZE_[^Ve<nfeM2ge/nfeLjeelfefLjhgM:lh=Fo
dL>]eLNafLbfg<nig]6kgm:lh=>mhMBnf<nkf<nkf<nkf<nkfM2lfM2lf]6mf]6mfm2jfm2jf/nif/ni
fLjhf<fgf<fgf<fgfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjh
fLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhfLjhf<fgf<fgf<fgf<fg
f<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgelbfelbfelbfelbfelbfelbf003>bLS>
bLS?b/W?b/W?b/W@bl[@bl[@bl[@b/_AblcAblcAblcBc<gBc<gBc<gCcLkBc<gBc<gBc<gBc<gBc<gB
c<gBc<gBc<g>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c@b/_AblcAblcAblcBc<gBc<gBc<gCcLk?cLg?
cLg?cLg?cLg?cLg?cLg?cLg?cLg@c/k@c/k@c/k@c/k@c/k@c/k@c/k@c/k?cLg?cLg?cLg?cLg@c/k@
c/kAcloAclo?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg>c<c>c<c?cLg?cLg@c/k@c/k@c/k@c/k?cLg?
cLg?cLg?cLg?cLg?cLg?cLg?cLg>c<c>c<c?cLg?cLg@c/k@c/k@c/k@c/k?cLc?cLc?cLc?cLc?cLc?
cLc?cLc?cLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcAc<_Ac<_BcLcBcLcCc/gCc/gCc/gCc/gBcLcB
cLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLc?cLc?cLc?cLc?cLc?cLc?
cLc?cLc?cLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLc@c/g@
c/g@c/g@c/g@c/g@c/g@c/g@c/gBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcB
cLcBcLcBcLcAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WBclOBclOBclOBclOBclOBclOBclOBclOBcL[B
cL[BcL[BcL[BcL[BcL[BcL[BcL[Ac<WAc<WAc<WAc<WAc<WAc<WAc<WAc<W=b/;Cd<S@cLG<bL7BclOG
e<cCd<S@cLG?c<C?c<C?c<C?c<C?c<C?c<C?c<C?c<C?c<C?c<C?c<C?c<C?c<C?c<C?c<C?c<C?bL;?
bL;?bL;>b<7>b<7>b<7>b<7>b<7=al;=al;=al;>b<?>b<?>b<?>b<?>b<?<bLC;b<?;b<?;b<?:al;:
al;:al;:al;@c/C?cL??cL??cL?>c<;>c<;>c<;=bl7>bL3Dbl;Hc<;Lc/;Lcl7Hcl;Cd<;AdL?@bL3?
b;o?b;oAb/7DcLCDcLCAb/7>akkBcl7@cKo@b[g@b;_Ab;_EbKgGbkoKcL7=aKk@a[o@akk@aKg?`kW<
_[;7^Jg5]JVETh4a;ae[IeEkMfEBBcZ9PG2^YYFSVhZWY9FRWHjIUH=RGTaXHTmVH4eQFTMPFDI=AS9=
AS9<AC59@Ri5?RY4?BU8?b]:@BeGC2i>@bM3?2=2?R]6BD0kAdTK;CP03b402a<34QD@7A/M:R8V<2@/
<RLg>S54AC`mACXlA3Xl@ca0AD=3B4M1A4Pj?D8d=She>dHd>TDb>4D`=D@]<T4[;d4Y;D0X;3lJ8DPJ
8DPJ84TI7dPH7TTF6dPD64PC5dL<2TD?44X>3TX724@41d@92d/734/11TD03CH02cl00T8003X:0C<U
83E4A3QCF3P]=S<W?SXSCdhVIVLXLGTTKgdUJWhXIWh[K7//KG`_L7lcM8<fMhHhMXHfM8@cLH4dLX8f
M8@hMXHhMXHgMHDgMHDhMXHjN8PgLXE0NhhgLH@aJghoMhY0MHTfJgliK80kMXHlMhLlMhLmN8PnNHTo
NXXoNXY0Nh/lN8PlN8PkMhLkMhLkMhLiMHDfLX8eLH4aK80^JglYJghXKH0[L8<`LXDcL8@eL8@YKWl]
LX<aLhDaLH<]KGl]JgdbKH0fLH@bLX@^KX0ZJ7XZJ7XiM8M:Q9M=QiY9PI@bMHhXIg`XH748>THTDUX^
FF8aFFDcGFXZFF4^GVXYFF/WFg8cJXDbKhT[Jh<[KX<VLh<VK7dbJgY3KgahV:>?ZK2;WZDdAd`F6a`H
7QdK8Q/K8aPL8QLM8AHM7aTN7a/L8A8M8Q<N8a@P9AHQ9QLQ9QLQ9QLQ9QLQ:1TQ:1TQ:1TQ:1TQ:1TQ
:1TQ:1TQ:1TV:a`V:a`V:a`Y;1d/;1h^;R0_;R0_;R0Y;QlV:a`S:1TR9aPT:AXV:a`V:a`V:a`U;QXU
;QXU;QXU;QXU;QXT;ATT;ATT;AT/;Q/];QX_;aL^;QH[;ALV;QdS<BDS<b`V<1lX;Q/Y;A@X:a4V:A0P
9a8M9aHJ9aTS:A8U:a@S:1<N8`hN8PlO8Q8L7`lG6PXB6P<S:A0f=Qho>R53?257@2E6@RE2?R55?b94
?R54?R53?B14?R56@2=8@RE9@bI=AbY>B2]BC2mIDcISGD1/ITUaJdicKE1eLEAgLeMjMUYlMeilMUmh
LU]dKEUaJUIdKEUdKEUcK5QbJeMbJeMbJeMbJeMbJeMfLeiaKUU]JUE]JUEaKUUbKeY`KEQ/JEAaKUU`
KEQ_K5M^JeI]JUE^JeI^JeI^JeIZKEA[KUE/KeI]L5M]L5M]L5M]L5M]L5MWJEESIE5TIe5ZK5I^KUIZ
Je5YJ4iZJDe/Je5/Je5[JU1ZJDmXIdeWITaVID]VID]LHdQJHDIHGdAFGD9CFSmAF3e?ES]=E3U5BSE2
BcM6DT0gA3HD7aL01`@10`<2004930<?4PTC5Pd>4@P41`000`000`05200B4P8B4P8D50@I6@TQ8A4Z
:QXa<B4e=BEKFTEcLUfHUWji]Ig<aZoBb[?>aZo<`Z[Ic[SJckWIc[SGc;KGb[CHbkGLckWPdkgGc[[G
c[[Hck_Hck_Hck_Id;cId;cId;cJckWJckWJckWIc[SIc[SHcKOHcKOGc;KIc[SIc[SIc[SIc[SIc[SI
c[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SIc[SI
c[SIc[SIc[SIc[SIc[SIc[SIc[SHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOH
cKOHcKOHcKOGc;KGc;KGc;KGc;KGc;KGc;H00<k9b<k9b<o:bLo:bLo:bM3;b]3;b]3;b]3:bm7;c=7;
c=7;c=;<cM;<cM;<cM?=c];<cM;<cM;<cM;<cM;<cM;<cM;<cM;<cLk<c<k<c<k<c<k<c<k<c<k<c<k<
c<k<c=3:bm7;c=7;c=7;c=;<cM;<cM;<cM?=c/o=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cM3>c]3>c]3>
c]3>c]3>c]3>c]3>c]3>c/o=cLo=cLo=cLo=cM3>c]3>c]7?cm7?clo=cLo=cLo=cLo=cLo=cLo=cLo=
cLo=cLk<c<k<c<k<c<o=cLo=cM3>c]3>c]3>c/o=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLk<c<k<c<k<
c<o=cLo=cM3>c]3>c]3>c/o=c<o=c<o=c<o=c<o=c<o=c<o=c<o=c=;=c=;=c=;=c=;=c=;=c=;=c=;=
c=;=c=7<bm7<bm7<bm;=c=;=c=?>cM?>cM?>cM;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=
c=;=c=;=c=;=c=;=c=;=c<o=c<o=c<o=c<o=c<o=c<o=c<o=c<o=c=;=c=;=c=;=c=;=c=;=c=;=c=;=
c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=3>cM3>cM3>cM3>cM3>cM3>cM3>cM3>cM;=c=;=c=;=
c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=7<bM7<bM7<bM7<bM7<bM7<bM7<
bM7<bM;?am;?am;?am;?am;?am;?am;?am;?am;=b];=b];=b];=b];=b];=b];=b];=b]7<bM7<bM7<
bM7<bM7<bM7<bM7<bM7<bLc9`Lk;`mODc=?@b<C1^Lc9`MGBb/W6_/o<a<o<a<o<a<o<a<o<a<o<a<o<
a<o<a<k;`lk;`lk;`lk;`lk;`lk;`lk;`lk;`m3;`]7<`m7<`m;=a=?>aM?>aMC?a]C?a]39`=39`=7:
`M;;`];;`]?<`mC=a=C=a=7=`]3<`Lo;`<g9_/c8_L[6^lW5^/S4^Lc6^L_5^<[4]lW3]/S2]LK0/lFo
//Fo//W1]<_2]<k1/Lfo[LBjZKRgZJng[:^h/:jb[:^_ZJR/YZJZY:>WXIfQVi:FT8Z>R6adKFYaJVM[
IFEWHFIVH6UVHFeYI79/Ig]hM7]hM7]gLWUcKWM]IW1UGF]NEVIIDEaLCSDe9cln<3hm;dA1<eE?@T]5
>5YDAd]8>DM4=DY7>2DR4c@a8S8_82PU5RHS538^6c<_73@^6c<]6S@]6SH_73dc8D4g9Cde7Sdf8T<l
:dU7?4I;BSDoBAHZ?00G<@0350044PLB6R4]<cQ3Ad1:DCi5CSY0Bc]5CcU2CcLoD3@kCc0dD2X]C2@V
BAlPAQ<KBQ8IBQ0GB0hDB@/@A`P<APH:A@D8A@04E003EP03F004F`04G@03H002G`01H000HP82IP<5
J@04JP44K087KP45KP02J`06F@09H@04G`00D0D4A1`N@30g>SQ2<Ahl@BI<D31RJ35_MbU[MR1TLBQV
N3I_Q3=aO3EcOSQdP3YfPSafPSYdP3]bOcU`OCmcOd5ePD=gPdAhQ4AhQ4AhQ4IjQTUmRC]_O4IjQci_
OD1_OE1oSDUfQ3]XMT]fQDmmR51nRE1nRE5oRU:0Re>1S5>1S5B2SE21Rdn0RTioRDn0RTn0RTioRDYk
QDMhPSU^Pc=/PBi[Oba[Obm^PSAaQCUbQcebQbm_PC9bQ3EcQCE_PS5YO31UNCEXO3]]PD1gQTAhR4=g
Qd=fQT]nSUJ7Ue5oT4=aPQmJKQeCI2YJIQU0B3ULH45PHcIDFC5?E4AWJd]_MdA[NT=^Pe20V567WTF1
Ud:1UBmdQc1`PSa`PE1iR8FR/96Z]8nUZdiQJ0hD4`hE40lG3@lH2a4H2A<G2a<G31@G3Q8G21<H2ADJ
2aLL3APM3QTN3aTN3aTN3a/P4A/P4A`Q4Q`Q4QdR4adR4ahS51hS520U5QhS51dR4b0S52@T5R@T5R@S
5B<R51hS51XO41LL3AHK31LL3AXO41/P4A/P4A`R3a`R3a`R3adS41dS41dS41dS41dS42@V4RDW4BLU
3BHS3R0Q4AXQ71HT:Q<W<QTX81`V6AlT3b0Q1b4P11hQ21/Q3QTS4adP1R8U2b<V3B4T2b8T3RHW4bHW
4b8S3aLP1Bdb5cln94Dn8dLo8Ta49d]69dA18TY59TY59TU49DU49DQ394M28dI18TI18TI18TI18TM2
8da7:59=;UQC=5]F=eaG>6AP@fUUB75]DGYfFX5lHhAnIhAnIhAnIh9mJ89mJ89mJ89mJ85lIgmjIGeh
HgagHWmkJ7]gI7QdHGQdHG]gI7eiIW]gI7QdHGahIW]gIGYfI7UeHgUeHgUeHgUeHgYfI7EgHGEgHGMi
HgQjI7UkIGUkIGUkIGUkIGMkJ79fHg9dH7IhI7MiHgAdG75aFGAbFWEeGGEeGGEeGGEeGGEeGGEeGGEe
GGEeGG=gGW1dFfibFFibFFibFFibFFa`EfY^EG1fGfA]F6A`GUAQDb@_9`040@000@800`0100010042
00830@4200830@P91`h?3@83008300H7014B21`M4b4R61lP5Q`M4a/Q41/Q3R0T4B`^6TI5<FaYE9JA
O;2/U<C0Z<_7[mC>]mSB^m[B^mS@^M_@^]cA^mK=^MK=^MK=^MO>^]O>^]S?^mS?^mS?^mW>^=W>^=W>
^=W>^=S=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=
]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mO<]]O<]]O<
]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]K;]MK;]MK;]MK;]MK;]MK;]@00
c/W8c/W8cl[9cl[9cl[9d<_:d<_:d<_:d<[;dL_<dL_<dL_<d/c=d/c=d/c=dlg>d/c=d/c=d/c=d/c=
d/c=d/c=d/c=d/c=cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;d<[;dL_<dL_<dL_<d/c=d/c=d/c=dlg>
clg=clg=clg=clg=clg=clg=clg=clg=d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>clg=clg=clg=clg=
d<k>d<k>dLo?dLo?clg=clg=clg=clg=clg=clg=clg=clg=c/c<c/c<c/c<c/c<clg=clg=clg=d<k>
clg=clg=clg=clg=clg=clg=clg=clg=c/c<c/c<c/c<c/c<clg=clg=clg=d<k>clg<clg<clg<clg<
clg<clg<clg<clg<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<dLc;dLc;dLc;dLc;d/g<d/g<d/g<dlk=
d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<clg<clg<clg<clg<
clg<clg<clg<clg<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<
d<k=d<k=d<k=d<k=d<k=d<k=d<k=d<k=d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<d/g<
d/g<d/g<d/g<d/g<d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d/o7d/o7d/o7d/o7d/o7d/o7d/o7d/o7
d/g:d/g:d/g:d/g:d/g:d/g:d/g:d/g:d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<g5b<Fme]?;aL:j
UiB<YjBLclc4bLJnc/_3c/_3c/_3c/_3c/_3c/_3c/_3c/_3cL[2cL[2cL[2cL[2cL[2cL[2cL[2cL[2
d<_2d<_2cl[1c/W0c<NnblJmb/FlbLBkc/RkcLNjblFhb<:eaKnb`[b_`;Z]_kV/^kBS^[>R]k2O]:fL
/JZI[ZNFZjBCZZ>BVY>0VI9oUi1mUHikThaiTHYgShQeSXMdRH9_Rh1/R7]UPWEOMFmLIfiQGg5ZGGEc
GWUeFgIbFGA`Eg9^E6m[BfIR?EQD<Te932//2RPY1R8S0a`N0aPJ0QDH1QDH1aHI0A8?0A8?1Q<A2QDB
41LB51XE61`F6adG7B4F8BDJ5a/@71dC>3L]=cH/;2XP?cdc=34R=34R@Ch`8b8D=3<U;bhP9R@I:2HK
9bHB:RTE;b/H<R`I=BhK=c0M?C<Q@3HT;R/M<BdR>SP^ATE1?d=8:SA572]56Be<0P8V0@<U3Q4`8bU6
<SYH;cQJ8bUB6Ai;3aQ441Q73aI82`m91PQ90P59001:001<001B001D001G001K005N005S005U009X
00Qg00Yj0@]m0`b11@f61Pf81`f<1`f<0`Z50`Z510b7212<216@112>10n?1Q6A009n00N000Ie005P
1@iB72QB;Ca<;d52>Um]>f9`@FQfAVekA6]iA6]jCGB3FH2?AgAoBWN2CGN3CWJ2CWB0CgF1EGR5FWf:
Ggb5HWn8I86:IX><IX><IhB=JXN@K8VBKXfFN9NPL8fFMI2JQJ2ZL8VCGgR2O9:MRIbTRYfURYfURijV
S9nWSJ2XSJ2XSJ2XRZ6YRJ2XR9nWRJ2XRj:ZRJ2XQ9^SP9NO@gB:?Fn5=Fb1<FYo<V^0>6n4?W26@767
=6n2<Vao<f]n>6]o?Fn3AG:7B7>8B767BGF2Cg^8Dgf:CgV6EWf;GX>AEGZ8B6]i?6an@6ekEW^3AfAX
IgmmKX5nI7IeHG=bH7EfI7f1G7J2EGJ6H8NMH8nTE8VMChNJC8NKCX>HFHBGKi6QVKC2U:ZeSZ>[GWAj
5ahI5AhD51d@4ad<51d95Q`;5QX>5QX?4aP951T:5AX;5Q/<5a`=5a`=5a`=5Q/<6QX>6a/?71`@7AdA
7QhB7alC820D8B4E7B8C6Ql@6Ah?71l@8B4C8R8D8R4C81lA6QhB5a/?4QH:4AD94aL;5QX>5a/?61`@
7Al<7Al<7Al<7R0=7b4>7b4>828?828?7R@=8RD<9bD=9b<@8B0F61hU3adc2aln5RPY72PR9BPH;BT@
<B/><2`@;b`G;2hK;Bd?<c<E=SHH=3<G=3<I=cHL=S@L<S0H7RH8=3PKAD@XAd4TAclQC4@VC4LVAd8Q
Bd<UC4@VCTHXCdLYCdLYCTHXC4@VBT8TD4PZCTHXBd<UBT8TBd<UC4@VBd<UBT8TCTTZDT`_FU@gHea1
KFI;MFiENg=LOgMPOGaWOgiYPh9]QhIaR8MbR8MbQXE`QHA_QX9_Q81]Pgm/Pgm/Q81]QX9_QX9_QX9_
Qh9cQX5bQH1aQ7m`Q7m`Q7m`QH1aQH1aP89^PH=_PXA`Q8IbQHMcQHMcQHMcQHMcQhYjPHAdOX9_PhEb
Q8EaPH=]PH1[Ph9]Q8=^Q8=^Q8=^Ph9]Ph9]PX5/PX5/PX5/NWaVN7YTN7YTNgeWOh5[PXA^PXA^P89/
MgaQIg1FK7QRJ7=S=Sle0PL500013PP=1P<51`@61`@61@840P010P010P0110431@P62Pd;41<A51LE
4QDC30l=1@P60@@200D01Q<56R@G9bhO:BlN9bTF8b@@8R4=@4<ZGV58S8ad];:JblN_d<bdd<Zcd<Ra
eLbheLbheLbheLbhe/fie/fie/fieljjelbff<fgf<fgf<fgf<fgf<fgfLjhfLjhf<fgf<fgf<fgf<fg
f<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fg
f<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgelbfelbfelbfelbfelbfelbfelbfelbfelbfelbfelbfelbf
elbfelbfelbfelbfe/^ee/^ee/^ee/^ee/^ee/^e003>bLS>bLS?b/W?b/W?b/W@bl[@bl[@bl[@b/_A
blcAblcAblcBc<gBc<gBc<gCcLkAblcAblcAblcAblcAblcAblcAblcAblc=bl_=bl_=bl_=bl_=bl_=
bl_=bl_=bl_@b/_AblcAblcAblcBc<gBc<gBc<gCcLk>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c@c/k@
c/k@c/k@c/k@c/k@c/k@c/k@c/k?cLg?cLg?cLg?cLg@c/k@c/kAcloAclo>c<c>c<c>c<c>c<c>c<c>
c<c>c<c>c<c=bl_>c<c>c<c>c<c?cLg?cLg?cLg?cLg>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c=bl_>
c<c>c<c>c<c?cLg?cLg?cLg?cLg>c<_>c<_>c<_>c<_>c<_>c<_>c<_>c<_Ac<_Ac<_Ac<_Ac<_Ac<_A
c<_Ac<_Ac<_@bl[Ac<_Ac<_Ac<_BcLcBcLcBcLcBcLcAc<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_A
c<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_>c<_>c<_>c<_>c<_>c<_>c<_>c<_>c<_Ac<_Ac<_Ac<_Ac<_Ac<_A
c<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_@c/g@c/g@c/g@c/g@c/g@c/g@c/g@c/gBcLcB
cLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLcBcLc@blS@blS@blS@blS@blS@
blS@blS@blSAc/KAc/KAc/KAc/KAc/KAc/KAc/KAc/KAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<W@blS@
blS@blS@blS@blS@blS@blS@blSHeLg4`KW>bl>]ZZ9YIUj3P7S9a[k>bl?>bl?>bl?>bl?>bl?>bl?>
bl?>bl?>bl?=b/;=b/;=b/;=b/;=b/;=b/;=b/;=b/;9a;_7`[W4_kJo^[6j]Jbe/:Nb[JB`Zj:OVhVL
V8JFTX2?RgV6PW1nNVQiMF=eLEm`Ie=_IU9[HTiWGTYSFTIOET9KDSiJDCeKD3YJCcUHCCMEBSABAc5@
ABm>@be=@Ra@BC1BARi@@bU<@2Q4@2doBCdmEU8nH60^H5`_HEdcIF4kKFU1LflnL6`eIf<[GETbIfX`
IFP_Gf<ZFEdXDULWCE8TB4hTAT`N@3lI>cXB<Bh;:2D781`56aH56A@761@?5`d:4PP730<?50/<3`H>
3`HN7aHD5@`J5`PO70dc<R@N7@la;b@];B4[:alc<RP^;a/b<ali>2@n>RM1>bQ2>bQ4>RQ7>bU1?STe
<Rde<Rhj>C/`<S`G83@;6CH@84@D344A2d0@3Cl<3Cl41S`00C`014D7354014/21e852EP51Uh40f45
0FP:16l?27L227<327D427P527/61gl82H<928H928H03XP03hX248h44I<64IL649T749d749d64iD0
3Hl039064iL559T03iL049P75il94:<>5J0=5I0>6G/R<7Q8F8IQMHiWO8/nIWQEMXUaRI^1T:=jQYQ^
OHebPi1mT9enVjB1WZN3WZR3W:J3VJB<WZVGZKBR/[jZ/;^//[f_]L2a]l:b^<>d^/Fg_LRi_lZf`LVn
bM6d_LJj`lc8cmRX[KJDVJ:f^lC8aLk8aLk9a/o9a/o:am3;b=7<bM;<bM;=c=G;b]?;b]?<bmC>cMK=
c=G7a/o2`LY<N8m5M8XkKH<eJWleJWljK88oKXA2KXDlM8LgK80eJ7a1L8EEP9EPRImTRImOQ9Y[SiUb
UZ1bUIm[SYQaTIakVjIkVJA`SYU;MXEAMh=VQ8UBJ6I/OGUdP7YeOgUjQ7i]NgUcPXAWO8AQO8Y^Sj9b
W:mXV:YSUjQCQiiCPYQMQIQhUZVP^/RCZKF@YJe/PXP]=BhZ=2PX<R8U<1`V;aXX;Q/W;A`V:a`R9aPR
9aPS:1TS:1TS:1TR9aPQ9QLP9AHS7a@T81DU8AHW8aPX91TZ9Q/[9a`/:1dU:Q/R9aPQ9QLU:1T[:ad]
;Al];1hZ:A/T:1`P91PL81@J7Q8L81@O8aLQ9ATQ9ATY9aDZ:1H[:AL/:QP]:aT^;1X^;1X_;A/V;1</
;aHd<QXf<R0`;BTS:CHH9DDA94lJ;C@S;blb=2Po>B97?Am8?B55?RE1?RTm?1Y3@R15@bA1?b0n?1hn
>alk>1`f<aLR:P`h?1m:B2Y8@bA8?R1>ABA>AbI7@b15?Qe8@B1<ABA?B2MABRU@BBQ>AbI<ABA@BBQ>
AbI<ABA=ARE@BBQBBbYBBbYBBbY<AbQ;ARM:A2M;ABQ>AbaCC3=HDCQKDcaZK5I_LE]gNF=oPF^5Qg68
RWB8RWB7RG><R7F<R7F<R7F<R7F<R7F=RGJ?RgR@S7V@Rgb@Rgb>RGZ=R7V=R7V=R7V>RGZ>RGZ:S7V;
SGZ=Sgb>T7f?TGj@TWn@TWn@TWn8SGj4QgN2QGF8RWN;SGZ;S7R>SGRAT7^>Sg^>Sg^=SWZ;S7R9RWJ8
RGF6Qg>6Qg>;RWJ9R7B7QW:9R7B<RgN>SGV<RgN9R7B=TWEmQ6V6T7V8TX5>ET/93@P200490`P200<2
00<200<200<300@60PL91@X:1P/61`/<3A4A4QH?41@82@d310P51PX82@d030<03`@34@H43P823008
3P0B5@DL7P/K8@PO9@`Z;QDi?2=DE3akNF6VXX[2_ZKDbkODbkODbkODbkOEc;SEc;SEc;SFcKWFbkGG
c;KGc;KHcKOHcKOIc[SIc[SJckWHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOH
cKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOGc;KG
c;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KGc;KFbkGFbkGFbkGFbkGFbkGF
bkD00<o:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo9b/o9b]3:bm3:bm7;c=7;c=7;c=7;c=;<cM;<cM;<
cM;<cM;<cM;<cM;<cM;<cM3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3;b]3;b]3;b]3;b]3;b]3;b]3;
b]3;b/o:bLo:bM3;b]3;b]7<bm7<bm7<bm7<bm3>c]3>c]3>c]3>c]3>c]3>c]3>c]3>c/o=cLo=cLo=
cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=
cLo=cLg;blg;blg;blg;blg;blg;blg;blg;blo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cM;=c=;=c=;=
c=;=c=;=c=;=c=;=c=;=c=3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b];=c=;=c=;=c=;=c=;=c=;=c=;=
c=;=c=;=c=7<blo:bM3;b]7<bm;=c=3;b/k9b=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=
c=;=c=;=c=;=c=;=c=;=c=7<bm7<bm7<bm7<bm;=c=;=c=;=c=?>cLo:bLo:bM3;b]3;b]7<bm7<bm7<
bm7<bm;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=;=c=3;b=3;b=3;
b=3;b=3;b=3;b=3;b=3;b=;=b];=b];=b];=b];=b];=b];=b];=b];<aM;<aM;<aM;<aM;<aM;<aM;<
aM;<aM_>c=W=bmG<bM39a/c7a<c9aLg<b<o>b/c6`Lo9a=7;a];<am;<am3:aM3:aM3:aLo=`m?@b=3=
aKFa[7ehMHN2OlG0_lW4`l[5`/[5`/_7`/k;`m3>a=3>`lc;_LW9^M;;_<o8^L_4]LFn[kffYk:[W:JO
T9jGR9F:M8f2K85fH7Q]Eg9WDFiSCFUNB6EJA5iC?EeB?5aA>eY?>EM<=UE:=5=8<U=8<U12<512<4m1
;dm1;di0;Tdo;Ddo;D`n;4Hj<4Dk:TDj94Hn8DPn84Ll84Hh8D<e7dDd8DXh8D`k84Dj7c@i92I1>25@
E25MJAABGAQFHAiLIamNK21OKB1NKQiOKQmPKbQSLRMQKBANJRQOK2mSKcAVLS=VL3AUKbmVMB]RLBaS
L2mVLbaRKB9IHR5HHBQOJ2Q?GRA;FQm5DAPoB1Dk@1Dk?AHl?1Tn?1Th=aLc<aD`;1T`:b0e;2Pj;BXk
;B`l:cY7<C0j;RXb:bhg:S4k934h7C@d93dd<2lcBa0C<PP8=Q8BCPd>DPD7CP89CP8:C@02C002DP02
F`00HP00J000K0<3K`D5L@09M`07M`06N005N`06P008QP09R@0;S@0;T`0<U08=U`4;V00:U`09U`0:
V08;V`0>Y00?Y@4BZ04EZP8FZ`0FZ`0EZP0EZP@CY@<DY@@EYP0EYP0GY`0HZ00HZ00IZ@@FZ@0H/P0G
/0hVZ4A@Z:Z[ekZkbKg1`WalP[>c^Kbl`/C4b[^k`HB4R[Ng_LC4b/;5b/;5b/;5b/?6blC7c<C7c<G8
cLG8cLO7cLO7cLS8c/W9cl[:d<_;dLc<d/c<d/kBel[>dlG9c]KIhLg?fKZlaYZLYlW;e]7<cM3>c]7>
d=;>dmC@e]GAemKAf]CAf];@cmKDdmKCcm7>b]KBcMcHdm7=b<6k]6V;V4maOU=fPdiaOTM]NE1hQ4ad
P4ifPT9aNE9mQU=gOff9T8FJXWnBVH>FWH>GW8FGV8JHVHJHVHFGV8RJVhNIVWf?T763Q764PFf1O6en
NW:0NWR5OGf8P7f6O7^3NH>8Ogf5OWf<R7B<S8n//H6OZX6M[WnJ[W>KYgNJYg^GXYBZ]Kk?f9BTZhZJ
X8JGVTE>A2T`8c8d8CPf7SXf7D8n9C@b6S0_6SDb7CHc7SPe83Tf8CXg8SXg8SXg8SXg8SXh83Xh83Xh
83Xh83Xh83Xh83Xh83Xh83dl83hm8C`k7cXi7Cdl845093dl83He6Blc6Rlc6S4d6c8e73De7CPf7STg
7cTg7cPg6cPg6cPg6cTh73Th73Th73Th73Th73Th8c`j740m5d8o6CXl9RXc=QDWAPPODB4c?S8i<T@n
8DU06d8m73lk8TDn9Da094I08d<m840j7D0j7D<m84<m840j7Cdg6SDh63i18DI79dA59DE394U69d]8
:Da7:4e8:Da7:4]69dY59TU49DU49DU49DY59Ta49Ta49Te59de59di6:4i6:4m7:Dm7:E59:e59:e18
:Tm7:E18:U59:e=;;EE=;di:;E5=<5MC=UiJ?FQTAgEaE89nHH^7JYJ@OIVBPIbEQ9fFQi^DQIZBQIZB
QI^BR9FEQIFEQIFDQY>AQY:@QI:@QYBBR9NDS9JHQIBFPi:DPIBEQIRHRYVIRiRHS9FERH^:O92?PIJE
QiNFR9BCQI6@PY6@PY>BQ9:EQY6DQI2CQ92CQ92CQ92CQ96DQI:EQY>CPI>CPI>CPI>CPI>CPI>CPI>C
PI>CPIBCOY>EPHnEQ82:NW1iK`480@<610800001000100040P01000100871@0200lF4a4E5P/?40dA
4Q<G60dA4P041@0310T=3P0710071007100710081@081@091P091PT>30`A3a<J4aXR61hW6R8/6bhi
9C]7<F]cEIJNOl35YLW:Z<6oWLFmWmG:[^;E^m_E^<S2YMcE^]gF^m7:/M[B^mK>]lo7/=_@]M[?]=W>
/mS=/]S=/]S=/]W>/mW>/mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=]mS=
]mS=]mW>/mW>/mW>/mW>/mW>/mW>/mW>/mW>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>/mO>
/mO>/mO>/mO>/mO>/mO>/mK;]MK;]MK;]MK;]MK;]MK;]@00cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9
clW:clW:d<[;d<[;dL_<dL_<dL_<dL_<dL_<dL_<dL_<dL_<dL_<dL_<dL_<dL_<d<[;d<[;d<[;d<[;
d<[;d<[;d<[;d<[;d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:cl[9cl[9d<_:d<_:dLc;dLc;dLc;dLc;
d<k>d<k>d<k>d<k>d<k>d<k>d<k>d<k>c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<
c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;
c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;d<_:d<_:d<_:d<_:
d<_:d<_:d<_:d<_:dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;d<_:cl[9cl[9dLc;d/g<dLc;cl[9
dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;d<_:dLc;dLc;dLc;
d/g<d/g<d/g<d/g<cl[9cl[9d<_:d<_:dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;
dLc;dLc;dLc;dLc;dLc;dLc;dLc;dLc;d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8dLc9dLc9dLc9dLc9
dLc9dLc9dLc9dLc9d/c5d/c5d/c5d/c5d/c5d/c5d/c5d/c5dlO5e<S6e<_8d/_8d<_8clc8clc8c/g9
cl_6c/[5cLW4c<S3blO2c<S3c/[5cl_6b<Jl`l6ge=79f=G=SXZ5I5mLXIbId<_8elo8d/[3bL:i`;Z_
][2SZZFFX9^<VIF3Q7YYP7IUNW1OM6YIKfEDJEm>HUQ7GUA3IEY6GeA0FDhjEDXfE4TeE4TeDTLcD4Da
CD8^C44]Bd0/BSl[BChZB3dYAc`XAc`XBS`ZBS`ZBC/YB3XXAcTWAcTWAcTWAcTWAST[@cLU@3DO?CHK
@3TN@S/RA3XXA3XYA3HZASLW@cDS>C8O:S<V73/h5d]B5EIU65UW65UW65UW6EYX65]Z65]Z5UUX5EQW
7Ue[75]Y6eUT7EUU8eeY9f5]:F5/:61[:VEe9f9a9f9a:fMc;VQd;FQb;FQa<FYc<VIc<fAb<F=_<V=[
=FEY>6U[?Fe^?g1^>V5Z>UiX>5aR?5aQ?eiO@EeM?eYF?UMC=Di4<4E3;D15<TA3=DTl=DHh>DA2@4A?
;cEN41A71`U930iL1PMM009J00EJ00QJ00]Q00YV0@U^0PMd0`Ii1@In1`R02@Z210n810n80Pn90Pj<
0PnA0a2D1Q:H1a>K0PnK0a2L1A6O112N0`jN0PbO10jQ1Q2S01:Y0AB[0aJ]0aR_0a^a0a^a0AZ`01V_
0aBZ0aBZ0aN/0QR]0QZ_0Qb`0afa0Qjb1Qba0Afh01Zc4B^]BeR^/[CM`<;=`/O5Q8B:^k_1`l?9b/[@
`L77Rh^A_ko5b/[@b<_@b<_@b<_@bLcAbLcAbLcAbLcAbLcAbl_Abl_Ac<cBcLgCc/kDcloEd=3Fd=3F
b/k?bLc@`lK:dMCIblgE`<;:X:6[blcFeMWNeMSPe=OOdmGMd]CLdM;Ld]7Kd]7Kbm?Jc]KMc=CKbLoF
cmGJe]cQcmGJ`LG:M9>LFGR1GWn8GH69FGf5G869DWMoD7MoCgb0Egn4D71fJh>9RYfRRi^QSYnRRibO
TInNTZ2OTZ2OT9jMTInNT9jMQiFDNhV8Q9FBPY2>OXb8PHb9Qi6;SIF>SiJ?T9B>Si:9S9><RINCNXj?
UZjdT:ZfU:fmSjNiQJReQZJaSJNcYKO2`m;KXk2hXk6gUZJ/BeA:;SDX=SPU>CTQ?CTPAD4X>CLO=SDP
>CHQ>SLR>cPS?3TT?CXU?3TT?3TT?3TT>cTQ>cTQ>cTQ>cTQ>cTQ>cTQ>cTQ>cTQ?chR@3lS?SdQ?3/O
?chR@d8V@3lS>3LK<CDL<CDL<cHM=3LN=cLO>SPP>SPP>cTQ?chR?chR?SdQ?3/O>cXN>STM>CPL>3LK
>CPS?C/M@3dG@ChH>C/U:C8e52I51ai@8C<n<CPaA3hQB3lJ@SdL?c/RAChUC40TAT0S@cdP@C/N@C/N
@cdP@cdP@C/N?SPK<SDE?ChNA4DUAD<TAD<TBDHWCTTZCTTZCDPYCDPYBdHWBTDVBTDVBTDVBTDVBdHW
CDDWCTHXCTHXCTHXCTHXCTHXCdLYCdLYD4PZCdLYCTHXCTHXCTHXCdLYDDT[DTX/Cd/^D4`_D4`_D4`_
DDd`EE4dFeLjGe/nJfM?LVeHO7MRQh5^TH]hVY>2Xib=ZJ:CT91nTi>3UiN7VIR:VYR=ViV>WI^AWYbB
Vib<WYn?XjBDZJVKZj^OYJFIViZ@TY67RXUkSXeoTY63UIB6UYF7UiJ8V9N9VIR:UYV:UYV:UIR9U9N8
U9N8UIR9UYV:UYV:VYZ8VYZ8VYZ8VYZ8VYZ8VYZ8VYZ8VYZ8VIR4V9Z6UI^:Qi23MWme1@/610L50P00
004000801@X8004000<10@P500802a8?00810`P72@h=2a0?3Q<B4AHE4QLF4AHE1Pl<1@h;10d:0P/8
0@X700T600P500P52`l@20d<2@h<3aH?4AT?41T<4ad=5b4@:34L=d4ZBU0gEEPnIfI:OGUMSHMZTh]^
^K:A]k2?b/:TcLFXe<b_hmZofM2eeL^ce<V^e<V^e<V^e<V^eLZ_e/^`f<fbf<fbf<fgf<fgf<fgf<fg
f<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgf<fgfLjcfLjcfLjcfLjcfLjcfLjcfLjcfLjc
eljceljceljceljceljceljceljceljceljceljceljceljceljceljceljceljce/^ee/^ee/^ee/^e
e/^ee/^e003?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?bL[?bL[@b/_@b/_AblcAblcAblcAblcAblcA
blcAblcAblcAblcAblcAblcAblc@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@bl[@bl[@bl[@bl[@bl[@
bl[@bl[@bl[?b/W?b/W@bl[@bl[Ac<_Ac<_Ac<_Ac<_?cLg?cLg?cLg?cLg?cLg?cLg?cLg?cLg>c<c>
c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c>
c<c>c<c>c<c=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<cAc<_A
c<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[Ac<_Ac<_Ac<_Ac<_Ac<_A
c<_Ac<_Ac<_@bl[?b/W>bLS?b/WBcLcCc/gBcLcAc<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_A
c<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_@bl[@bl[@bl[Ac<_Ac<_BcLcBcLcBcLc?b/W?b/W@bl[@bl[Ac<_A
c<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_Ac<_@blS@
blS@blS@blS@blS@blS@blS@blSAc<WAc<WAc<WAc<WAc<WAc<WAc<WAc<WBc<GBc<GBc<GBc<GBc<GB
c<GBc<GBc<GCb/KEc<SFcLWFd<_Ccl[Bc/W?c<O=b/GCdLWCdLWBd<SAclO>c<C<b/;9ako7aKgKelc:
a[_Cc/GHdlZ5OgPm=c9VH5^IThjCQg^<P7B2MfUgK5i]He9SFDMJD3iDBSQSED9ND3eGBCIBA35A@c1A
@c1@@Rm?@Bi5>RI3>2A1=R91=R94>BE5>RI5>RI5>RI3>2A3>2A3>2A3>2A3>2A2=b=2=b=2=b=7>BM5
=bE4=RA2=292=293=B=4=RA5=bE4=RA0=B4l<alj<alj=24g<R<c;RD_:bH_8b4[81`T71DM7ALE9R<@
=3X;A5<:Cf8EFfPAEf@?EF8BF6DHGV/KHFhJH6dGGFXIH6XHGfTIGVPMGfXQHfhUIG0UIG0VI6lSI7<S
I7<SHW0SHW0ZJ7<aKWPaKWP^JG<cKGTcKGTcKWPfL7HiLGHkM7HnMWLoN7M3KX53Kh15L7m:LGm<LWi:
KgM4J6i1HfToHF4mG6E0FfU4H6M4Hf15HUm8H6a=H7/X<WP;5F<32VL:3gH127L017<02WH03GD35Wl3
58<34HT33hd43I853Y@749H84IL54ID449H449P349X54Yh54j455J@65JL24j845J@65jP65ZT45:L4
4jT65J/75Jd04j/05Jd06;026[817;<07;<06k806k836k447;847K<47kD68KL69;T89[/99k`;9;X1
8[l07[PD<K9BH[Fl_^K9c=78cLB;Ri72`/S9bLo?cmG7alfCTiW6a/c?cmG=d=G=d=G=d=G=d=G=d=G<
cmC<cmC<cmC@d=K@d=KAdMOBd]SBd]SCdmWDe=[De=[@d];CeMG;cLkBe=G?d=C<c=:][K?@cmS6d=[7
d=W:dM[<dM[>dMW@d][Bd]SBd]S;en7<f>;8e=k1cMO3cmW8e=k0c=Jc_lUkUI]/RHi^Ri1IMgaELgQX
R8eJOH56JFeLPXILOh9>JFe[OX6DXJ>KYjVOZj^IYJFNZJJPZjRQ[:VPZjRS[Z^S[Z^LYjBBWIZFY:>B
WYj>VIN@V9NHWI^OXijTYJ6TYJ6PX9ZQYJ2HXj5nT96L[kJQ]l>Z_/nS]<NH^<>H];nX_<NgaM78d]bd
_LK1c=B]^<1AG58b>bhi?BXn?RHo?RA6AB/l?2@m?bTo?BDo?BE0?RI0?RI0?RHo?BDn?2@m>b<l>R8l
>R8l>R8l>R8l>R8l>R8l>R8l>R92@BM2@BM0?bDn?B=1@2I5A2Y2@BLj>Ald>1ld>1lf>B0g>R4i>B4l
>R8m>b<m>b=0?bE0?bDo?R@n?B<l>b4k>R0j>Alj>Alj>B@n?1i1?QQ2?aTi>bDY<SDD9TD67DlQ<cha
>354?R58?aY2?A`o>b94?BA<@2A6@2=4?R52?1m2?1m3?B13?B11>aho>A`a<Q8k?1a5@bA5@bA6@bA<
AbQ?BR]?BR]>BBY=B2U<AbQ;ARM;ARM;ARM;ARM<AbQ?AbU?AbU?AbU?AbU?AbU>ARQ>ARQ>ARQ?AbU?
AbU>ARQ=ABM<A2I=ABM=ABM>ARQ=AbY>B2]?BBa>B2]<ARU=AbY@BReBC2m@C31EDCEMFCeVHDQ`JU=j
M5f3O6R:PfnIV8BMW8RPWXbQWhfOW8fLVH^KV8ZJUhVUYIFSXYBQX9:QWiBRX9JSXINRWiNPWIFMW8jL
VhfMW8jOWY2RXI>SXYBQX9:PWi6MX96LWi2KWXnKWXnKWXnKWXnLWi2MX96QXI6QXI6QXI6QXI6QXI6Q
XI6QXI6QXI6PWh^OXHjLXY6@VHaoR7h93`X51`L200000@000`4730X00`422@H330T00P033P/00`0;
3`X?4`h93@P<40/G6aHD61<72`H01P<01P<01P<01`@01`@22@H32PL42`P11PT00@@00P<73P/A61<C
6a@B6a4C7A4E8ADB710=5PTC6@PW:AE0@2QBDCMKF3a:A1mIDbiZI45`JTNCS6^^YXR_YhW:`ZC=`ZO=
`ZO>`jS?a:W@aJ[Cb:gEbZoFbk3HcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOHcKOH
cKOHcKOHcKOHcK;HcK;HcK;HcK;HcK;HcK;HcK;HcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;FcK;F
cK;FcK;FcK;FcK;FcK;FcK;FcK;Eb[CEb[CEb[CEb[CEb[CEb[@00<k9b<k9b<k9b<k9b<k9b<k9b<k9
b<k9b<o9b/o9b]3:bm3:bm7;c=7;c=7;c=7;c=7;c=7;c=7;c=7;c=7;c=7;c=7;c=7;c=3:bm3:bm3:
bm3:bm3:bm3:bm3:bm3:bm3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b/o:bLo:bM3;b]3;b]7<bm7<bm7<
bm7<blo=cLo=cLo=cLo=cLo=cLo=cLo=cLo=cLk<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<
c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c<g;blg;blg;blg;blg;blg;blg;
blg;blk<c<k<c<k<c<k<c<k<c<k<c<k<c<k<c=7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm3;b]3;b]3;
b]3;b]3;b]3;b]3;b]3;b]7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<blo:bLk9b<g8alo:bM;=c=?>cM?>
cM;=c=7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm3;b]3;b]3;
b]3;b]7<bm7<bm;=c=;=c<o:bLo:bM3;b]3;b]7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<
bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm7<bm3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b=7<bM7<bM7<
bM7<bM7<bM7<bM7<bM7<bM;<aM;<aM;<aM;<aM;<aM;<aM;<aM;<aMG?b]C>bM;<am;<am;<alo;a/k:
aLc8`lG5^LS8_<g=`M;Ba]?Cam3@a<[:_/G5^LFm/;F]X::JSIB;PEmFCCH]94To>598@EU;>EE7=E12
<4`n:d`n:d`n:d/m:TTk:5I8<U94;Tdo:D/m9d`n:4i0:Tm1:dm1:dLk:DHj:4Hj:4Hj:4Hj:4Hj:4Hj
:4Di9d@h9T@h9T@h9T<g9D<g9D8f948f948f94Di9d<g9D4e8d0d8T0d8T4e8d<g9D@h9T4f8She8C/c
8SLa92h/8R<R7QHF5P`=4@h94PX630D420H<4@TN9Phe@`m9G0mCJQEIIQ5EHPmCH1EGHQeOJR=TKB5R
JaaMIQaOJ1ePJB1SK29TKb9TKb9RKAiMJa]JJ21QL2=TLRASLB9PJbERK35YM39[M2mVKcMZM3MZM3]/
M3i]MD1`MT5`M49bM4AaM4aaOdicPE=fPeQkQEQlQ5QiPUIfO5=cNE]jNemkPVAlR6R0QVF2Of5oP69l
SF=iW1HXS@8BO@0=Q@PBU@8=T`0<TPDEU`LIUPHLV@@IVP8DW@4AX08@Y0@BZ0@BZ0@BYP0@W`0?X@4@
XP8BY@4BZ0<DZ`8D[@<E[P0GZ@8IZ`@J[`@I/0<H[`8G[`@I/@HJ]@0I/`0K]00N]`0P^@4Q^P0Q^P0R
^P0Q^@@S^P<T^P@U^`HW_@LX_PPY_`P[`@P[`@PY_`0V`P0Q^QDf]EQX^l36jLg@e<gAaXj>U<K6c<c<
d]3@e/S8cYNGWLW9cm3@e/kAe/kAe/kAe/g@eLc?e<c?e<_>dl_>dm?CfMCDf]CDf]GEfmGEfmKFg=KF
g=KFg=SIemgMgM;Bd]CCeM7@d]?Be[Bb^=;@e/gFf]3Ffm;Gf]CHfMWIfMcJfMoKf^3Kf=KKf]SMg=KK
f]?Gf=?HfMCIg<_BeKo6bHBJWhNMXX2FVdaUJDAOHgF@U6b9SDAQIFR<S6Z8REebLgb9Rj>][J^c/[:h
]jZb/JJ]ZZZa[Zfd/Jnf/k>j]kNn^k>j]j^b[in[[IbUZ9^RYIjSY:BYZ:f][K2^[Jn][;2]ZK:e/jJ^
[H6@Tif_]Zk0bk_:fZjlcZS3cJJlakW9eL?=elO@f[W2c=;KiKK0bUMRF3Ho<Sa0;D13:T509TI5:clo
9d=5;d90:4=1:D=1:D90:490:40n9Slm9Chl93hl93hl93hl93hl93hl93hl93hl93hl94919d919d0o
9Cln94919dI5:d919cXi7cLk8SLk8STl8cTl8c`l93hl93lm9Clm9C/j83/j83`k8C`k8Cdl8Shm8chm
8cln93`k9Slm7d8o6D=06SXl9RXc=QDWAPLND20b?C4h<D<m84Po6T4l6chj8D@m94/o8dDo8T@n8D<m
848l7d8l7d4k7T0j7D0j7C8c4chl7DI49DQ59TY59Te8:E59:e18:Te8:De8:Da7:4]69d]69d]69da7
:4e8:E59:e59:e18:U18:Tm7:Di6:4i6:4i6:4m7:Dm7:Di6:4e59de59da49Ta49Ta49Ta7:4m::e9=
;U=>;e=>;eA?<5IA<UQC=4i<:Tm=:e1=;U1=;U5=<5=?<eMC=e]G>f]WCg9^EWehHhV4KiB>NinHQjRQ
T:jWV:VYVJJUUj>RU:6OU:6OUJBRV:JSVjRUWJFTUZ:QTj6PTZ>RU:RWVJZYVjRWVJBSUJ6TUJ6TUJ2S
U9nRTinRTj2SU:6TUJ6TUJJVUZJVUZJVUZJVUZJVUZJVUZJVUZJVUZFSTJBVTj:WV9VQUXF=QP/@3P@6
1P800@01000100871@040@XC418M6P0<20@B3QDM4aTQ5aPP5Q<K4ADM4aLO5@lG3@<;0@891P891P48
1@0710481@<:1`D<2@H=2PdC60H<4@<:3@L?3`XB4@PA3PD>2`@>20HD4PLD4PPC40H=20D;010D0BHY
43Xl7c`f3DQ26DHo63hg45YB;FAK>G5XA[V`S];7[=;7[=;7[=?8[MG:[mO</MW>/m[?]=O<]]O<]]O<
]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]O<]]S=/]S=/]S=/]S=/]S=/]S=/]S=
/]S=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]K=/]G:]=G:]=G:
]=G:]=G:]=G:]000c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8clW:clW:d<[;d<[;dL_<dL_<dL_<dL_<
d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<_:d<_:d<_:d<_:
d<_:d<_:d<_:d<_:cl[9cl[9d<_:d<_:dLc;dLc;dLc;dLc;c/c<c/c<c/c<c/c<c/c<c/c<c/c<c/c<
cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;
cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;
d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:
d<_:d<_:d<_:d<_:cl[9c/W8cLS7cl[9d/g<dlk=dlk=d/g<d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:
d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:cl[9cl[9d<_:d<_:d<_:dLc;dLc;dLc;cl[9cl[9d<_:d<_:
dLc;dLc;dLc;dLc;d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:
d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8dL_4dL_4dL_4dL_4
dL_4dL_4dL_4dL_4dLk6c/_3blS0c/S1dL_4dlg6dlg6d/c5clk0bLRj_[f_/k:TYjJHVIR:S8]mPh9d
LFUHK6=EETdoCdHiA3/^@CL]Cd@l@SL_EdHaDd8]CchYCSdZD3l/DT4^E4<`E4<`BS`VBC/UAcTSAcTS
BC/UBS`VB3XTAcTSB3`ZB3`ZB3`ZASXXACTW@cLU@cLU@cLUA3PV@cLU@SHT@CDS@3@R?c<Q?S8P?S8P
@CLU@CLU?cDS?cDS?cDS@3HT@CLU@SPV?SPU=c<Q;RXO924L6ATI30lC0PD=00080`@B000>000;00TF
21d/43A454IH5DiS659N6UEO85QS:5mX;VA[<FE[;V=V;F1S;FAW<6M/<fY_<fU`;FA]8eUT6TmL54UF
8EaV:F5/<6Ia=6Ma>V]cAG=kC7QoCGV0G7V0Ggb3I827JXB:KhV?M8fAMXnCN8jCNXnAO96COY>DPIFF
PYNEQINFQINFQYRGOY>;Q9BCRYJHS9NDQiR=PYJANHjMLhJW1b2H016?01:K1QR[0A:X01>V1AbX1QjV
0b2W01ZV01FW01:Z01>_01B`01B`01>^01>Z0AB[0AJ^0aR`0QRc0QZd0a^e11^g01V]01^_0Abb0Abb
01^b0A^e0Qbf11jh02Bj02Fk0bRn0b_00Rc10Rc10Bc102_002Zm02Zm02Zm02Zm0BVm0RZn0RZn0RZn
12fo02[102Fi4cVeF6^l`/S[d=7Ecm36Ti>Ibl_AcloEd=3FbLW?Vi^QcLgCdM7Gcm;Gcm;Gc]7Fc]7F
cM3EcM3Ec<oDc<oDe=CJeMGKeMGKeMGKeMGKe]KLe]KLe]KLdmGEfM_Kd=;Cd]CEc/oCdM7G/k>id]7J
fM[Hf=WGfMOFf]OCf]GBf]C?fm;>fm;>elk4fM?8g=G<g=K?gMWDg=WDeM;>b/W5VZfbUZZ_T:BYI7Yo
H7IkRJ:VPijRIH24OIbMQ:2QO92AVJFW_<72_<70_/?2^[nn/KJd][^i^Kjl^[nm_/?1`LK4_lC2^Kjl
Y[:hYK2dYk2d[KBg][Vm^kfn^k^k^;Rh^KZh_L;1[[RhQYFHXK>j]<G>`m3N]L;@/<[A[lC<_m3Iam7K
am3J^<3=cmSU/[k:EfEJ=T0c>d4^@D@[?d0V@T<Y?3lVADPb@d8X@d8X@d8X@d8X@T4W@3lU?SdS?C`R
?S`T?S`T?S`T?S`T?S`T?S`T?S`T?S`T@3hV@ClW?cdU?C/S@3hVA48Z@3hV>CLO>CdT>CdT>SdT>SdT
?CdU?cdU?cdU?cdU>cTQ>cTQ?3XR?C/S?S`T?cdU?cdU@3hV?3/V?cdO@d0JA44K>cdW:c@g5RQ721mA
838m<3L`@cdPAchI@C`K?SXQ@c`SBclS@cdP@cdP@cdP@S`O@3XM?cTL?cTL@3XM=cDF@T0QBTLXBTLX
BdHWCdLYCdLYD4HXC4LXC4LXBdHWBdHWBdHWBdHWC4LXCDPYD4PZD4PZD4PZCdLYCTHXCTHXCDDWCDDW
CdLYCdLYCdLYCdLYCTHXCDDWC4@VC4@VDDXYDd`[EDh]E4d/DDXYCdPWCdPWCdPWCd/XD4`YD4`YCdXY
CDPYCTTZDD/^E4haBTHZCd/_Ee8iH5]2JfE>N75MQGiZSXMcTi5oW9Z8ZJJG/k2Q][>U/jnT[JVNZJBK
XJ2BWij@Wij@Xj:DZ:NIZZVKZ:NIY:>EY:NHY:NHXjJGXZFFXZFFXjJGY:NHY:NHZ:NIZ:NIZ:NIZ:NI
Z:NIZ:NIZ:NIZ:NIZZRFYZNGYJVMWJFKRI2;2a0?0P@50P030040004000<100H362<P:cTe4b@P4B8N
9S4W7bXP7RTO9c8X:C@Z8RdS72LM72LM5B0M4ahK3aXG2aHC21<@1a8?1Q4>1a8?00/?00P:00L900T;
00T900H600T70@h<008100@60@`@1`hA0PL50@D041D09RXACdTNEU0UCDLN@S/DCdPQ@SXEF50[a[fK
f/ndf/ndf/ndf/ndfm2eg=6fgM:gg]>helbfelbfelbfelbfelbfelbfelbfelbfelbfelbfelbfelbf
elbfelbfelbfelbff<fbf<fbf<fbf<fbf<fbf<fbf<fbf<fbe/fbe/fbe/fbe/fbe/fbe/fbe/fbe/fb
e/fbe/fbe/fbe/fbe/fbe/fbe/fbe/fbe<Vce<Vce<Vce<Vce<Vce<Vc003=b<O=b<O=b<O=b<O=b<O=
b<O=b<O=b<O?bL[?bL[@b/_@b/_AblcAblcAblcAblc@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@
b/_@b/_@b/_@b/_@b/_@b/_@b/_@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[?b/W?b/W@bl[@bl[Ac<_A
c<_Ac<_Ac<_>c<c>c<c>c<c>c<c>c<c>c<c>c<c>c<c=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=
bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=
bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_=bl_@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@
bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[?b/W>bLS?b/WBcLcC
c/gBcLcAc<_@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[?b/W?
b/W?b/W?b/W@bl[@bl[Ac<_Ac<_?b/W?b/W@bl[@bl[Ac<_Ac<_Ac<_Ac<_@bl[@bl[@bl[@bl[@bl[@
bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@blS@blS@blS@blS@blS@blS@blS@blS@blS@
blS@blS@blS@blS@blS@blS@blSAblCAblCAblCAblCAblCAblCAblCAblC?c/C>cL?@c/CCdLOGd/WF
clK?b;o8`KRaZY^QVX^9PW=cK5eRFdaFCd1=ASM7@356?2Y;@Bm1=bI<@S5<@C=2=RY>@SI?@cUA@2]=
?2M9>2=8=bA9=bI;>BQ;>2U;>2U:?2U9>bQ:?2U<?R]>@2e=?ba:?2U7>BI2=BE3=RI3=RI1=2@o<R8o
<R91=2A3=RI5>2Q5>2Q4=bM3=RI1=2A0<b<o<R8n<B4m<b4n=28n=28o=B<o=B<o=B<o=B<o=B<d=2HX
:AlG61@:2`l210`10`h11A001Q422QL11a@01A802AL452@98S89;3X7<3l@>D8QBe8iHFI;LGEEN7]I
Ng]NOWeQPWiRPX5UQ8EVQhYSPhQINh5=KWM1I6hlGV/cGfHgHFQ4JVmGNGmYQhabSiAnUi^6W:6<V9Z=
VI^AVYfDWJ2GWZ6KX:>KX:>LWj>QYj:RZ:>SZJBRZ:>PYZ6QYj:SZJBV[:NIXiJPY9jUY:2VYI^RYiRH
Y9j8UjMjQjd18J805Yd06JT27K<05J`05ZX28:d28ZT49Zl07j/05j/05:h05k806K@06K<06:l05Zh0
5jl06[407;<17[D07kH07kH08;H07Zh08K408[D08KH08KH08KL28kT49;d0:KX0:[/0;Kh0;l00<L40
<L40<<00<<00<;d0<;d0;k`0;[`0;K/0;K/0;;X0;;X0<k/0</40;[dF?kUHKKk2ank@cmSAd<bHV9kA
dMOCdmWBd]S=cM>PX:KBd]SCdmWAe=WAe=WAe=WAe=WAe=W@dmS@dmS@dmSEeM_EeM_EeM_EeM_EeM_E
eM_EeM_EeM_@eMSEf]g@e=WGfn3@dm_=cmV`/[cFf>?FeMOFeMOFeMOGe][GeM_HeMkHeMkHeMkJemWK
emcJfMgHen3Be=k;cm[0a]>g_/f/_/FHZk:M/;N@YZb<XZRI/KNAZk6<YZb:Z:fG/[JEZ:fa_<3>dmK8
blo8c<g3alS5b/_:cm3<dM;9c/o9c/o:cm37c<g2alR/^L6/^L6`_<:g`LS1alc5b/g3a/Zo`lBk`;nn
a/J`_Kn<WJ2W^l2gb];3dmnha]:bc=:abLnnd=O5dM_:e^:^^/JgamBS]<5FI5Tb?c4h@Be1AB`m@2Hm
@2Hh?2=2B353@RQ4@bU4@bU3@RQ2@BM1@2Ho?R@n?B<n?2@n?2@n?2@n?2@n?2@n?2@n?2@n?2@o?BE0
?RHn?2@l>R8o?BE3@BTo?BDg=Adi?B@i?B@j?B@j?B@l?2@n?2@n?2@n?2@n?2@n?2@n?2@m>b<m>b<l
>R8l>R8l>R8h=b8l>Qa0?AM2?aTj?2HZ<cHF:4L87e4P<Sd`=c13?B17?QU0>aXn>R53?2=:?R90>Qe2
?1m2?1m1>ahn>1/m=aXm=aXo>A`h=AI3@25;B2U<AbQ=ABM>ARQ@ARQ=@bE:ABI:ABI9A2E9A2E:ABI:
ABI<AbQ<AbQ>ARQ>ARQ>ARQ>ARQ=ABM=ABM=ABM=ABM=ABM>ARQ>ARQ?AbU?AbU>ARQ=ABM<A2I=A2=?
AREAB2M@AbI>ABA=A2==A2=>ABA;AbA=BBI>BRM?BRU>BBY@BbaCCC1ECc9GDS=FDC9CCC1?BBa=AR]?
B2mDCCAHD3USHDU^JeIoO6N?RgRLV8JUXHn[YYN_ZY^/Zif/Zif][9j^[In_[Z2/ZifXYiVTXiFVZIZV
ZIZUZ9VTYiRTYiRUZ9VVZIZVZIZZZI^ZZI^ZZI^ZZI^ZZI^ZZI^ZZI^ZZI^]ZY^WYiVVZYjPZ9j;TXd:
3`h10PH200<20`400@0010802@HR<2`lCDTX?3LR>3<]?CHS<b`S<b`^?SL_?cPT=2dR<R/Y>C8N;BTK
:RHH9b<D8alC8QhC8QhD8alE920651<34A034A044Q434A0030/03@`44Q402`L00`8010P73A@:3A46
1`<=3@0I6`Lk<`]1>A51>191>19>AB0o=A=GCB_6_9[DbJkCb:gCb:gCb:gDbJkEbZoFbk3Gc;7FbkGF
bkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGFbkGGc;7Gc;7Gc;7Gc;7Gc;7G
c;7Gc;7Gc;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7Ec;7DbK?D
bK?DbK?DbK?DbK?DbK<00<g8alg8alg8alg8alg8alg8alg8alg8alo9b/o9b]3:bm3:bm7;c=7;c=7;
c=7;c<o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b]3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3;b]3;b]3;
b]3;b]3;b]3;b]3;b]3;b/o:bLo:bM3;b]3;b]7<bm7<bm7<bm7<blg;blg;blg;blg;blg;blg;blg;
blg;blc:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/c:
b/c:b/c:b/c:b/c:b/c:b/g;blg;blg;blg;blg;blg;blg;blg;blc:b/c:b/c:b/c:b/c:b/c:b/c:
b/c:b/o:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bM3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b/o:bLo:bLo:
bLo:bLo:bLo:bLo:bLo:bM7<bm3;b/o:bLo:bM7<bm;=c=7<blo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:
bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLk9b<k9b<o:bLo:bM3;b]3;b]3;b]3;b/o:bLo:bM3;
b]3;b]7<bm7<bm7<bm7<blo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:
bLo:bM3;b=3;b=3;b=3;b=3;b=3;b=3;b=3;b<o:alo:alo:alo:alo:alo:alo:alo:am3:`m3:`m3:
`m3:`m3:`m3:`m3:`m3:`l_<`]3?aM?Bb=GCbLk9`;ZcZYnFSHZ1N61C@eM:>T/n;TLj:TXm;E13<e=6
=UA7=dXo:eQ=>E14<UI:>595=D4d9TPk;D`n<Tdo:DXk:4Pi9TPh9dXj:T`k;Tdk<4`j;d0f9Cle940f
9D8h9d@j:D@j:D8h9d0f9D4d948e9D8e9D0c8cd`83ha8D<f9TLj:TDh:4Dh:4@g9d@g9d@g9d<f9T<f
9T<f9STb7cXc83df8clh9Clh9Chg93df8c`e8QdV71@K60P=40023@003@0240<74PH;500;4`084P08
4P085@8;604?6`0B6P0C6`4I7b<i?TiSIFUmOWB5PWR8PHBARHjKTi>JUIJMVYNOWYFOWhnJWXZEWHNC
WHNCWEQcMdiWJeU^L7Z;SYJSYIfWYj>XZJZ_[ZJ/YjJ/YjN[YZJZYJNXYZRVYJNUY:NUY:f/Z:n][;2^
[Jf^[:Z[ZJVYZJ^[Zjj^[ZN^Yjf^[;6[[;6]Z;6bZ:J`/96N^7Z8^00YY`0OX`0P[00Q]00HZ`0NZPX]
/`db/PL]/`4V/00O[@0K/00O]@4R]`4S]P0Q/@0L/@0N/`0P]@8S^04V^08W^@0W^@0W^@0V/`0X]@0Z
^@0Z^@0Y^`4Y_@<[_`D]`@0^^P0`_00b_P0f`@0g`P0g`P0f`@0f`@0h`00h`00h`00h`00g`04g`0<g
`0<g`00j^00j`P0g`QY8_UYa`L?7l=G@gmOBe9^KXMCDf]GEfm?CfLk>e:>SZMGEfmCDf];Ef];Ef];E
f];Ef]?Ffm?Ffm?Ffm?FfmKFg=GEfmGEfmGEfmGEfmGEfmGEfmGEflkFgM3Gh<gDgMOMj<[@gK_1cYnT
/lgBhM7FiLkEi/cCil[Aj/C?jl?>k/3<l;g:l;G9l[;5l:W0kJ>kjIVdiXn/ghJTfh:Qf:>e`9JZ]Inc
_XbR[H>IY9:[]HfV/8BOZGbLXXZV[HfPZ:ji`LgCf/_>e/_?e<K:cl[@elkDfm3FgL_Af<W?e/W?e/K<
dl77cZBg_jBe_ZJf_Jfj`[K2b;g6b[g3b;_2aK:l_;C0`:Vk_8fRY:S1aKC:d;oBf[O7djc;cZo:c[?9
ckc=e/_Kiij__9Z]^XnT/e=SF34n<3Q1;D57;Se09S/n93Di8457<4A39dA39dE4:4E4:4A39d=29T50
940o8cdk8cdk8cdk8cdk8cdk8cdk8cdk8cdk8cll9d0m:3hk9S`i93ll9d=0:cll9cPe83Pl8cPl8cTl
8cPk8SXj8S`j8S`j8S`j8STf8CTf8CTf8CPe83Pe83Pe83Ld7cLd7c<b7CLe5c/h4Sdj53Hh8RL`<a<U
A0HMCala?2lf;d8l7dHm640k6Sdi84<l8dXn8Shh6d0j7D4k7Sli73`f6CXd5c`f6Chh6c<`4Chk74U4
9Da49T]39Dm59di49Te294Q394Q394Q394Q394Q394U49D]69d]69d]39Da49Ta49Ta49Ta49Ta49Te5
9de59dY294]39Da49Te59di6:4e59da49T]39DY17da38Dm695179E179E589U=::5I=:da594i79U19
:4m7:De5:4a49da3:4e4:De69De69Di79Ti6:4i6:E59;5M><e]B=dM6:TY9;E1?<eQG?F=QBG=aFHF2
KI6>NIBCQIZIRj:QTjRWVJZYVjZYVjVXVZVXVZR[W:R[W:NZVjJYVZJYVZNZVjR[W:R[W:f[X:f[X:f[
X:f[X:f[X:f[X:f[X:f[X;2]WjVYVjN[X:6XXHbCT0X>3`421P8010<100830@@91`4:1b0^:Sa@Bbi4
?bi5@2a1?R]0?Ba1?Re2?ba1?RTn>b]0?Bi3@2To>RHl=b4g<Qdc;QX`:aX`:a/a;1`b;C11?BTj=R@e
<B<d<1d^:Q4R7`@E4P0@3@`M4P090`000`022P411`8000T801dM2dY16dY16dPo6TDk6EQ>;5U>;VUN
?[FZS<ZoY<ZoY<_0YLc1Y/g2Ylo4ZM76Zm;7[=K;]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MK;]MK;
]MK;]MK;]MK;]MK;]MK;]MO</MO</MO</MO</MO</MO</MO</MO</MG</MG</MG</MG</MG</MG</MG<
/MG</MG</MG</MG</MG</MG</MG</MG</MG</MC9/mC9/mC9/mC9/mC9/mC9/`00cLS7cLS7cLS7cLS7
cLS7cLS7cLS7cLS7clW:clW:d<[;d<[;dL_<dL_<dL_<dL_<clW:clW:clW:clW:clW:clW:clW:clW:
d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:cl[9cl[9d<_:d<_:
dLc;dLc;dLc;dLc;cL_;cL_;cL_;cL_;cL_;cL_;cL_;cL_;c<[:c<[:c<[:c<[:c<[:c<[:c<[:c<[:
c<[:c<[:c<[:c<[:c<[:c<[:c<[:c<[:c<[:c<[:c<[:c<[:c<[:c<[:c<[:c<[:cL_;cL_;cL_;cL_;
cL_;cL_;cL_;cL_;c<[:c<[:c<[:c<[:c<[:c<[:c<[:c<[:cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9
d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9d/g<dLc;cl[9d<_:
dLc;d/g<d<_:c/W8cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9
c/W8c/W8cl[9cl[9cl[9d<_:d<_:d<_:cl[9cl[9d<_:d<_:dLc;dLc;dLc;dLc;cl[9cl[9cl[9cl[9
cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9d<_8d<_8d<_8d<_8d<_8d<_8d<_8d<_8
cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7d<[3d<[3d<[3d<[3d<[3d<[3d<[3d<[3aLJlbL[0clk4blVo
][6XSXMnGUE<?S<[GThmFDThDd<bDd<bEDDdEDDdD40_Bc/Z@S@QGDllCT0]ACLUBS/[C3d]Dd<fB3P[
CCl/BS`YB3XXB3TYBCT/BSX^BCP_B3H_@3TZ?SLX?CHW?cPY@S//A3d^A3d^@c`]@cHXA3LY@cHX?c8T
?2lQ?C0R@SDWAcX/?S4S?c8T?c8T@3<U@3<U@C@V@C@V@SDW>C8O?3DR?cPU@S/X@c`Y@CXW?SLT?CHS
21HB1A4A0`XC0@HE0`DG0`HE10HA0PD=00P>00X@0@XC10XE10/D10/D10dA0PdA00P<9C4cF69RMGai
MgigN7]bPXAhShn3WiR?Xi^DYInJYZ6PZ:>U[:R^/k2i^;O1NXV;Hg5`IW1`SiFD[k6a/jn^[ZJV/jZW
[;BY[;BY[KF[/;F/]KR_]kVc_;bf_Kfg/[6c][Fi^[Vm^;Vm][Jl/[Fj];Jn][S0[kBe/k>i]K6g]k:c
]kZh[kW3U:C8Nh_60RjY02>T02F]02Bb01f[0bN`5Cbl74Fo3CFf1Rbb02B^02:b0bFh1bZj1RZh12Rd
1RRk22Zm22fo2c302S;12CC12CC123?002bf02jh0c6k0c2m0bnn132o1S;323C50c_21Cg41co624;9
1dC:1dC:14?90d;8047504750T;614;61d;72T?834C934C9046h04?40D367dk2GG?5a<Ocem7Tg=CK
Vi^Qe=CJe=CJdM7Gc<cBXj>Ye=CJdm?Id=?Hd=?HdMCIdMCId]GJdmKKdmKKdmKKe]KLe]KLe]KLe]KL
e]KLeMGKeMGKeMGKbM?Mb=;LaLkKcmSU^lCBXZZkQ8bM]kkA]/7O/;gMYKGJVZ_FRZ3@OYK<M8o8KX[6
CWS3B7:m?ffk>fZk=FNj;fBk;fBn;fK1Rij]VJbkVZnnIW^:EFakP9ZXP9ZXH7^9Hh>>LHfHM8RCVjNa
`lWDalcEbLkGa<[A^<7:_/O@`<WB_<G>^L;;^/?<^<7:];g6UjbdU:VaUJR`VJ^bY;:h[;Rn[[Vm[KRl
ZKFeYkJhWkBeRJ:TYl;6[lO=^LkF]<O?YlK7Z/O;ZL77]LS@bmgXTjJcPIRWOYRVDf=H<3d_>D8^@TP_
?T4W>ChS=3PO@DL`AD@XAD@XATDYATDYAD@XA4<W@d8V@T4U?3XR?3XR?3XR?3XR?3XR?3XR?3XR?3XR
@3dX@3dX?S/V?3TT?c`W@d0[@3dX>3DP=c/R=c/R>3/R=cXQ>CTQ>cTQ>cTQ>cTQ;R/F;R/F;b`G<BhI
<RlJ=34L=C8M=C8M;RdH<S0B=c@>>SLA<cDO92d`4B=211]=7c4l;cH_@S`OASdH@3/J?CTP@S/RBShR
?3HI?cTL@3XM?cTL>cDH>C<F>S@G?CLJ;R/<?3LHAD0QBD4SBd4SCT@VCd@VCD8TAd8SAd8SAd8SAd8S
Ad8SBD@UBTDVBdHWBD4SBT8TBT8TBd<UBd<UC4@VC4@VCDDWAclQB40RBT8TC4@VC4@VC4@VBd<UBT8T
DTTWDdXXDdXXDDPVCTDSCTDSD4LUDTTWBd@SCTHXD4PZD4P[CTHYC4<XBd4YBd4YDTTWDdXXE4/ZDdXY
DDLYDDHZDTL[E4T]C4d]Ce0`DU8dDE4cCdhbCdhbDU4gEE@jDe94HF1BMGAVR8MiUYF7X9nAZZVK/:nQ
ZZfNZJbMZ:^LZ:^LZ:^LZ:^LZJbMZZfN/:jS/:jS/:jS/:jS/:jS/:jS/:jS/:jS/ZnQZZZNZ:bQXjZS
SIBA2`l@0P<70`050P000P<11P/900P562LS=4Q3:d8m<4Y49Shl<d]9=dm=<4Q6<4Q6?EECA5aJ@EUG
BF=M@UaF>59<;DM18S`f6cD_5c4[5BlY93L^83<Z93H_=4Ho@E=<@55==DI2;Chj72hM2a/@10`<1PP@
0P08100181dEB4DgAc/GASXH@cLE@cHFJE`lRgePWHmccl6Uc<6VcL:Wc/>Xd<FZdlR]e/^`f<fbf/nd
e/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^ee/^eelbaelbaelbaelba
elbaelbaelbaelbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLbaeLba
dlRbdlRbdlRbdlRbdlRbdlRb003@b<S@b<S@b<S@b<S@b<S@b<S@b<S@b<S>bLS>bLS?b/W?b/W@bl[@
bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[?b/W?
b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W@bl[@bl[@bl[@bl[@bl[@
bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@
b/_@b/_@b/_@b/_@b/_@b/_@b/_<b/W<b/W<b/W<b/W<b/W<b/W<b/W<b/W<b/[<b/[<b/[<b/[<b/[<
b/[<b/[<b/[?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/W?b/O?
b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O>bLK>bLK?b/O?b/O@blS@
blS@blS@blS?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O>bLK>bLK?b/O?b/O@blS@blS@blS@blS?b/O?
b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?b/O?
b/O?b/O?b/O>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bl?>bl?>bl?>bl?>bl?>bl?>bl?>bl?Ac<?@
bl;@bl;Ac<?BcLCBcLC?b/7=b;o@aL7Jd<WRelni/:=^HeE9?beBAc=FBcE>@C5>@C5>@C5>@C5>@C5=
@31=@31=@31;?Ri:?Be:?Be9?2a9?2a:?Be:?Be;?Ri7>RY8>b]9?2a8>b]6>BU6>BU8>b]:?Be8>b]8
>b]8>b]7>RY6>BU6>BU5>2Q5>2Q1>BQ0>2M2>2M2>2M4=bM8>BU:>b];?2a7>Be6>2a5=b]5=b]5=b]5
=b]6>2a7>Be1>B`h;b90=BM3>2Y8?SA`JV<X9RDB51D91a<41Q4831L22aD000T00Pd92aH91a<33AL3
3AL231H12aD12aD231H33AL33AL3418c?SaRJF9cMFUfMFMmNVanO75jN6j4PgF7QGZ=Rh2EThVNW9:V
Xi^]ZZ:`[:NZYj:YYZ:WYZ:YZZR][jna][Fc^;Vd^KZl^[Vn_;bm^k^k^;Zn^[o3_lC3_lFn^/2l_<:n
_/Bo_lFo_lFm_L>m_L>n_/C0`<Jh_/^e^<32a<G4a/Jf_<6b`/nO^=9dTk@0<k`0;kd0:l81:l@2;<46
=;hFA/@UEld2?[T0?;L0>[D0>;<0>;<0>K@0>kH1?KP0?K`0?K`0?[d0?[d0?[d0?[d0?kh0?kh0?/d0
?/d0?l`0?lT0?lP0@<H0@<@0@<@0Al`0B<d0BLd2B/h7Blh;C<d<B/`>B/`3BL`3B/X6BlX6C<P8C<L:
CLL:C/D:C/D;DK`<CL0FC<4dEkUOJjfk_Mo=d^7>fn>d[ZO2a<c:dNG3bN3Fe^JJVZK9dnFfan7Df^G<
d>?9b^K;cnO:dN;3b=fo`NC3`?:``^N^_nJZ_>FT]n:M/]nG[]bCZ]Z?ZMQiU=A`R]1UQ<mIO]0oKL4W
GK8UHK<aL<4?Fk/=F;`;Dkh;D/4;Dl<;Dl<7D/05D;`0Cl`0CL`0C</0CL`3D</8ELX>FlT@G/Q_U;J4
Wk>EZ:ejTI=HO8AVTj5_WZaCPXYNQX]^U9UJNX25WjJU][nja<j_/kjf^<>e_Kfc_Kfc_Kfc_Kfd_[jc
_Kf_^k^]^KV?Yjf8XJF:WZ>BYJRN[JnQ[JnPZZZOYjNJYjVJYZRKY:ROYZnX];j_`ljXa]6N`LjJ]<:F
/KnN_<NO_LRge=fL/[fCXjnAWJV2OX=/KF]GFU58D3lmAc0f?bDh?RE1ABa0@bXm@2Lj?B@j?B@k?RDk
?RDj?B@i?2<l>bLk>RHj>BDi>2@i>2@k>RHl>bLm?2Pj>B@j>B@j>B@j>B@j>B@i>2<i>2<i>2<k>RDk
>RDk>RDj>B@i>2<i>2<h=b8h=b8a;aL`;QH`;QHb<1Pe<a/g=Adg=Adf=1`e=R8Z9aPW8A@_;A/e>bXY
=cHA8d804DTH9C<^;b]1>1e1>1<k=QDh=a/l>1]0=aHl>Q`i=aTe<aDd<ADe<APf<QTf<QXe<ATf<QDm
=aY2?1m8@2=:?b=:?b=<@2A=@BE8@298@298@298@298@298@298@298@298@2=9@BA:@RE;@bI;@bI:
@RE9@BA8@2=5@R=5@R=8@bA8@bA;@bE>A2I>A2I?ABM<A2M;@bI:@RE:@RE:@RE:@RE;@bI<A2M7AB=7
AB=8ARA8ARA8ARA8ARA9AbE9AbE9A2=:ABA:ABA:ABA:ABA:ABA:ABA:ABA:B2Y;BB]=Bbe>C2i?CBm>
C2i=Bbe<BRaGDc1@BbY7ABM6AB]<CCUOHU9nPWJHWY>b/Z:a/J6_[Z2^[In]Zj2]Zj6]Zj6]Zj6XZj:/
[jJa]:^a]:^^/JR/[jJ]/:N`/jZ_/ZVZ[:J/[JVVYZJ8Qh/200P;1a<000P42@X63Ph02PX030/K:bY2
EeEAIfE5GE]:Gf1;H65<HF9>HfA@IFIBIfQCJ6UDJFY<I5a?IemBJV9DK6ADK6ABJV9@J61>IUiJJF5=
G5@jBD4_?CLc@CdkBDDe@T0W=38U<C4L:2PK9bLJ9RH<61P<61PkAdMfPX8l=ahn>1]<AR=?B24n=@m7
>aUC@RNkYY3HbZkFbZkFbJoEbZoFb[;FbkGGc;KFc[OGbk?Gbk?Gbk?Gbk?Gbk?Gbk?Gbk?Gbk?Gc;7G
c;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Gc;7Fbk3Fbk3Gc;7HcK;HcK;G
c;7Fbk3Fbk3Dbk3Dbk3Dbk3Dbk3Dbk3Dbk3Dbk3Dbk3CbZoCbZoCbZoCbZoDbk3Dbk000=38b=38b=38
b=38b=38b=38b=38b=38b<k9b<k9b<o:bLo:bLo:bM3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;
b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b/o:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:
bLo:bLo:bLo:bLo:bLo:bM3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;b]3;
b]3;b]3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:bm3:blc:bLc:bLc:
bLc:bLc:bLc:bLc:bLc:bLc:b/c:b/c:b/c:b/c:b/c:b/c:b/c:b/o:bLo:bLo:bLo:bLo:bLo:bLo:
bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:
alo:alo:alo:alo:alo:alk9a/k9a/o:alo:alo:am3;b=3;b=3;b<o:alo:alo:alo:alo:alo:alo:
alo:alk9a/k9a/o:alo:alo:am3;b=3;b=3;b<o:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:
alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alo:alk9a/k9a/k9a/k9a/k9a/k9a/k9
a/k9a/k;`lk;`lk;`lk;`lk;`lk;`lk;`lk;`m3;`/o:`Lk9`<o:`M3;`]7<`lo:`Lg8_lg2_]cBbkZ_
YgA[GTi3=DHl:TXo:e97<D/n;T/n;T`o;d`o;d`o;d`o;d`o;d`o;d/n;T/n;TXm;DXm;DXm;DXm;D/n
;T/n;TPk:dTl;4Xm;DTl;4Lj:THi:DPk:dXm;DPk:dPk:dLj:TLj:THi:DHi:DDh:4Dh:44i:48j:DHl
:dLm;4Xm;D/l;4Xk:dTj:T@f:T@f:T<e:D8d:48d:4<e:D@f:T@f:T8f:SX]7dPk:d4f:69ICe9>BB4S
8`/@4`d?6P@84`<<5P<=5`053`094`/?6PH84`@>60<=5`<=5`8<5P8<5P<=5`<=5`@>60DB53Q3@F]b
JgeoLgmnL8J3MHV7O8N5NhN6N8V7O8b:Oi2>Q9BBR9NDS9ZGSibHTj:OVZJSWZ^ZY[Be/kbo_Ko4`l35
a;o4aKfo_l73a<32`kfn`[fn`/;2b<C4b/;1b/C4b/G5blG5bl?3bL30a[jna;jna<30a[c5ck[0alK8
bLS8b;^n`kW2d:Ridh6H^0e1/``l/P`j]a0j^a@m^a]8^baKa3a^cQDja1@i`a8g`A0e_a4f`18g`A@i
`aHka@dm`@dm`@hn`Plo`a10a151aA92aQ=3aa0o/a50]1=2]AE5]AQ9]a]<^1a=^Ae?^AYA]1aC]R5F
]bQJ^RmL_CAP_cMQ`CUR_c1K/SAM/SQQ]SmW^TE]_dac`U5gaEAjb6N6aFf=e7FDghfQhZ>/g/cEnjZl
iIZgi7n7[9n^ghjShHjPhHJBc7:0]HVOfFj>cd]oc4QicdEdd45bb3ea_SM]^SIW`cMScREI_BEI_R9H
_AmF_QeF_a]E_aYC`1QC`1ELa0eB_`a?`Q1Bb@]<aP54_P=7_PmDb@Q5a@I2a0Doa`DmbPHnc@@nc@<n
bP4la`11`010`@11`P15a0A:a@aBaa5Ib1ANb7FObGJD[gZ?Ug67S6J5SVB<V5n8TDieMdecN5UmPfZ:
T8ZV[J6h`;31bZFd_Jfi`jZi_:Ne^j:b^:>c^ZBc_:6a_Ib/^9NW]8VV[hNT[HRRZ8bRYi>VZIVYZ9VV
Y9NRWfj1Q7B4RWb9THFDWIFW/YfgaIRib8fd`YJnd8Vd`hJa`8>]^ZC:eYNf_i6W/XRKXj^Z[9^LVXJ;
PWElKFE[F51E@3/o;34c83do:Cdo:Cm1:d53;D=5;d53;C`n:3Pj93Th93Pg8cLf8SHe8CHe8CLf8STh
93Xi9Cdl9cdl9c`k9S/j9CXi93Th8cPg8SPg8SPg8SPg8SPg8SLf8CLf8CHe83He83Dd7c@b6S<a6C8`
63<a6CDc6cHd73Dc6c<a6C0a7AdJ2a4<01LE0b8X5Al]:a0P?@4BBQPU<bh_:d4h7D4h4c/f5CPg6c`h
6d0g5S`j73Tg6CHd5SDb5SHb6CLc6SHb6SDa6C@`4cTe640j7DHn8DHn8DPm8DTn8T/o8dQ08TQ08TQ0
8TQ08TQ08TQ08TQ08TQ08TQ08dQ08dU194U194U194U194Q08dQ08dE28dE28dM28dI18TQ08TY08TY0
8TY08TU194U194Q08dLo8TLo8TQ08dU194U194M28dM28dQ394Q394Q394Q394Q394Q394M28dM28dQ3
94Q394Q394Q394Q394U49DM59dQ6:4Y8:T]9:da:;4]9:dY8:TU7:D<n7DM49EEC=FITC7AeHH:5MIJJ
SZV]XZZZW:^[WJj^X[6aYK:aYk>bZ;:`Z;:`Z:R/XJZ^Xjb`YJb`YJ^_Y:Z^Xj^_Y:b`YJBWWZJYX:j`
ZZRYYHJ6QPD41PX93@000`020003008:0`TF3RTh<55TFf1eK5M_IEa]JEa]JEa]JE]/J5]/J5]/J5]/
J5]/J65eJF9fJUmcIeAXG4EICC]?@cU=@C]?@d=?@f=_Hh:>PXRCRG^6OVUdK5]UGe9LEU5JEdeFDdiG
E4mHED9;B3Q1?TYCD6QaKTm8=48n8T8m7T@l5cT`2TXn6UU::/6_T]g?/m_?/m_?/m[?]=W=]MO=]MK;
]MC<]MO</MO</MO</MO</MO</MO</MO</MO</MO</MO</MO</MO</MO</MO</MO</MO</MO</MO</MO<
/MO</MO</MO</MO</MO</MK;/=K;/=O</MS=/]S=/]O</MK;/=K;/=?:[m?:[m?:[m?:[m?:[m?:[m?:
[m?:[m;9[]?:[m?:[m?:[mC;/=C;/000d<S8d<S8d<S8d<S8d<S8d<S8d<S8d<S8c/W8c/W8c/W8cl[9
cl[9cl[9d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:
cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9d<_:d<_:d<_:d<_:
d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<_:d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;
d<[;d<[;d<[;d<[;d<[;d<[;d<[;d<[;c<[9c<[9c<[9c<[9c<[9c<[9c<[9c<[9c<[:c<[:c<[:c<[:
c<[:c<[:c<[:c<[:cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9
cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7c/W6c/W6c/W6cl[7
cl[7cl[7d<_8d<_8cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7c/W6c/W6c/W6cl[7cl[7cl[7d<_8d<_8
cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7cl[7
cl[7cl[7cl[7cl[7c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/W6c/_3c/_3c/_3c/_3c/_3c/_3c/_3c/_3
d<_2c/W0c<NncLRocl[1d<_2d<_2cl[1dLO0dl[1RX1f>c8U?C8TC48aBSh/D4DaB3/[B3/[BC`/BSd]
BSd]Bch^Bch^C3l_Bch^Bch^Bch^Bch^Bch^Bch^Bch^Bch^B3/[BSd]Bch^BSd]B3/[B3/[BC`/Bch^
B3/[B3/[B3/[AcXZAcXZASTYASTYASTY?3@S?cLVAC/ZBCl^C3l_CSl_Bc`/BS/[A3LYA3LY@cHX@SDW
@SDW@cHXA3LYA3LYAcHY@S8RD40`C3laRh9h=SH`728Q0PdA318M00XD0@dG0A8K00dF0`lI1a4K0@LB
1@lI10hH10hH0`dG0`dG10hH10hH1@lI1Q<E?DQ6M7YeR8UoRHMlSh^0U9:8U9:8Ti:4Ti66Ti66Ti67
Ti67U969U969U92;SX^6TXn:V9RBY:>O[Zn]][Vg^kfm_Kno_l?4`lO8`lK:_L35^Kc1_Ko7`/C<`lC>
a<G9a/O;alS<b<W=alS<alS<bL[>blc@`/_D`/S=blg>c/c<alG;alSF_<;IWj[6<E^X;UJX;eBY<EF]
=ER^?F6_Bg:gFX?2@eG0@UBo@E>n@5:m@E>n@eG0AEO2AUS3AEnmAEnmAf6oB6;0BVC2BfG3CFO5CFO5
I7[2IWc4J7k6K8;9KhK:Lh[>MXk@MhoAQ9oBRJ7ESZGGTjSKVJgMX;3OXk7QY;?Q^lGW_LKW_lSYa<cZ
alo]c=;_dMGbd]KbdLKFe]CXbloWbLoV^/?NWJgK>EVT4d:T4Bb3?f756T:b94Vk2BVD9dN[:4ni33^^
04_914oD0D_C04G404Nj04no04[503o703c903g:03k<03o=03o?043@047C047C04G503fo03_204?;
0TK?1DK;3D[:5e;@1T7613k60c_80c[;1C_>1Sg>13c;0S[70Sg20Cc10C_203k20T7114O11dfn2E6m
AGFY:e5d5Bhn7C<i;4Q?8T=<5C@e6C<]9DI?:4UBIhJ?MiJOQZ>/SJRbPijXS:F_VK:lUJfiT:ZhSZRi
SjNmRjBnQ9njOiVgJHfMM9NUNIVTN9FLNiBFQIZHR9VEQIF>DfecG7IlJX69NI6MRjJdUKK5TKS7Qk;3
Jj6hFI2UCX>GCH2@Qk?0U[W3UK2jQY^SX:FTWZ>QVj2GVYjBUib=T9:6OWmeK6eTC4`j@T8`=SHT;BdK
:b/I;blM=CDS>CTW=C@P=C@P=3<O<c8N<c8N=3<O=C@P=C@P?3/V?3/V>STT>CPS=cHQ=C@O=3<N=3<N
=3<N=3<N=3<N=3<N<c8M<c8M<c8M<c8M=cDM=C<K=38J=38J=C<K=C<K<c4I<S0H=cHQ8Qh<50d05aH2
92XG8Rl]4R8o11=;6BHd;c0/@CPM@CPC>SDD>3LK?3PK?cHE?3XL>CLI=cDG=S<G=c<J=c<J=S8J=C4I
<RhA=c<F?3PK@C/NA3`OA3`OAc`PAc`PAShPAShPAShPAShPAShPAShPAShPAShPB40SAclRAclRAShQ
AShQAclRAclRB40SA44RA44RAD0QA3lPACdOAS`NAS`NAC/MAclRAShQACdPACdPACdPACdPAShQAclR
AclQAclQAclQAclQAclQAclQAclQAclQA3lPAD0QAD0QAD0QAT4RAT4RAT4RAd8SA48TAD<UAT@VAdDW
AdDWAdDWAT@VAT@VE54bIV=4QH9VXJ69[ZnK[ZnOZjjO[;2TZ:ZNZJ^OZJ^OZZ^QZjbSZjbSZj^UZj^U
/KFY/;BX[k>W/;BX/kN[]KV]][Z^]KV]^knd^Kfb^;^bYJRONGac10L01@P000<04A@57R4B9b`M;SDV
@4/kFFIFHG5PFf]JHFYMH6ULGfQKGFIIFfAGFF9EEf1CEUmBE5e@EUmBDea?Ae13>D8e<c`_>44d?dPk
BU91MGe/XjZK/[VZZK2SX:JKY:ZO[;:W];V`/[N^/[N^/[N^[K:YXZNNWJ:IWJ:IQh1_LV]GIf15G5Dd
BT8MDdPRF4XV]jV5d/BWd/NYe<R/e/^`elbaeL^ceL^cd/Zce/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`
e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`e/^`eLZ_e/^`elbaelba
elbaelbae/^`eLZ_dlZ_dlZ_dlZ_dlZ_dlZ_dlZ_dlZ_dlZ_d/V^d/V^d/V^dlZ_dlZ_e<^`003?alO?
alO?alO?alO?alO?alO?alO?alO=b<O=b<O>bLS>bLS?b/W?b/W?b/W?b/W@bl[@bl[@bl[@bl[@bl[@
bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>
bLS>bLS>bLS>bLS>bLS>bLS>bLS@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@bl[@
bl[@bl[@bl[@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_@b/_;bLS;
bLS;bLS;bLS;bLS;bLS;bLS;bLS;bLW;bLW;bLW;bLW;bLW;bLW;bLW;bLW>bLS>bLS>bLS>bLS>bLS>
bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>
bLK>bLK>bLK>bLK>bLK>bLK>bLK=b<G=b<G>bLK>bLK?b/O?b/O?b/O?b/O>bLK>bLK>bLK>bLK>bLK>
bLK>bLK>bLK=b<G=b<G>bLK>bLK?b/O?b/O?b/O?b/O>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>
bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK>bLK=b<G=b<G=b<G=b<G=b<G=
b<G=b<G=b<G=b/;=b/;=b/;=b/;=b/;=b/;=b/;=b/;Ac<?>bL3<akk=b;o?b/7@bl;@bl;@bl;Dbl:W
WYAOED/e;1m2=bU@ASE>@C5:?Ra8>b]8>b]9?2a:?Be;?Ri<?bm<?bm=@31;?Ri<?bm<?bm=@31=@31<
?bm<?bm;?Ri9?2a;?Ri<?bm<?bm:?Be9?2a:?Be;?Ri8>b]8>b]8>b]8>b]8>b]8>b]8>b]8>b/h<1lj
<R51=bI5>bY:?Be=?Ri=?Ri=?Ri8>be7>Ra7>Ra6>B]6>B]7>Ra7>Ra8>be=>2UB?Bi@?ReSETJYXiPa
<RhH8R803Q@53aT02Q@45Ah97RH15Qh04AX441X02A<641X53aT43QP43QP43QP43QP53aT641X64QI0
BTYjP7^>ShJ=Rh2BSX>GUH^IUXjHUhVHUX^HUX^HUXbGUH^GU8bGU8bGThjDUHbBThZBTXbGUi6SXYj`
[Zfj^kW0`<2k`<72alS2alZk_lBf^[nk_/K2aLg6b=;5a/[7b<c8bLg9b/k8bLg8bLg:blo<cM6ob/k4
blk:c<g=b/c<b<g?bmK9amZk_=6O]MjN/MjM[]nQ/>6Q/N2R/]f[^n2daNJ``=f``=f``=f``=fa`Mjc
`n2da>6fa^>gb=fhbMjhbMjib]njbn2kc>6lcN:mc^>na>6oaN;0a^?1anC3bNK5c>O6cNS6cNS<dnC?
dnGAe^GEf>OHfNOIfNGKfNGKfNGJe]_IeM[Ke]SIe=KId]GJdMCId=?Id=?Zd]C_hN?KemKDfMO9dmfD
Zm/JAJH0;[D3;YdTEm<2><4=@LX09jLQCLXMD<l4@LL0?KT7ALL7ALT3@[X>DkXRI/TNGl/:B;h>Bl/>
Bl/<Bl/<B/`<B/`<B/`<B/`:Bl`<C<P9Al<:AL<ABLHGC<DHC/0RE/4]H<P0AkT0AKT0@[/0@;d0@[l1
A;l0@kX0@kP4>lH2>/L2>/L0>lL0?/H1A<<3B<43C<19Ok`YDgh1734462<S>T8T?48I;R`Y>BhWA4dM
>T=aT9UbTiajWZIoXj]dVJ5iWZIcUJEdUJQbU:]]T:YXRjaTR:aTR;1VRKAEQ9U[UZUfX:edV:1cTYEm
UI=nUHekSXE:JW1AL7UGMh9NP8eVRiU[TJ=TSZ5JQIPYFgLGBV@?@EPIBE][U:>D]<6O]L2;VjNCWYbH
XYbJXYRJWY>MWYBOX9NHUi>:RhV1PG5aLF5JFTY4A3@g=bLa<B4a<B4a<B4d<ald<alc<Qhc<Qhb<Adb
<Adb<Adc<Qhf=B0f=B0e=1ld<ahc<Qdb<A`a<1/a<1/c<Qdc<Qdc<Qdc<Qdc<Qdb<A`b<A`b<A`h=Qhf
=1`d<QXe<a/f=1`f=1`e<a/c<ATl>bHa;A//9A@b;Q/f>bHX=S8C8Cd14DHI9S@_<2a1>1e1>1<j=A@h
=a/k=aXo=QDk>A/i=aTg=ALf<aLg<aXh=1/f<QXd<1Pa;a4e<aDk=aXo>ai1>ai3>ai4?1m7?214?1i4
?1i4?1i4?1i4?1i4?1i4?1i4?1i7?b96?R54?1m3>ai3>ai4?1m6?R57?b91?Qm1?Qm3?Qm2?Ai4?1i5
>ae5>ae5>ae5?B14?1m4?1m3>ai3>ai4?1m4?1m5?B18?B57?217?217?217?216>am6>am6>am2?1m2
?1m3?B13?B14?R55?b95?b95?b92@292@293@B=3@B=4@RA4@RA4@RA4@R@l>Qa9AbUPGd=kNf>=SWZG
VHJQXY:XZib_/jN^/ZJ//:B[[jBZ[JBZ[JB[[JN[[JNe^:V`/jBY[9fWZY^WZY^WZY^SYYNPXiBGVHfA
ThN>TH:2QGI^LF4[;Qhm@Bi4B3E@CcYGFD=MGdUKGTQLHT]QJE9PJU=JI4eTIU1TIU1SIDmQHdePHTaO
HD]NH4YMGdUPH4iSHe5UIE=SHe5QHDmTI59]KE]fMVAjO6J3QFn;S7R<S7Z:RWR<S7bCTh>IV8ZKVXbJ
VH^GUXRDThFFUHNHUhVBTH>9R7ZGT86<QGB9PfalMUUOESEGCRQEBb>cYgo1/iK3^9[9_Z3>`jOBajcC
bZoDb[;Bbk;FbjoFbjoFbjoFbjoFbjoFbjoFbjoFbjoFbk3Fbk3Fbk3Fbk3Fbk3Fbk3Fbk3Fbk3Fbk3F
bk3Fbk3Fbk3Fbk3Fbk3Fbk3Fbk3EbZoEbZoFbk3Gc;7Gc;7Fbk3EbZoEbZoCbZoCbZoCbZoCbZoCbZoC
bZoCbZoCbZoBbJkBbJkBbJkBbJkCbZoCbZl00<o7alo7alo7alo7alo7alo7alo7alo7alg8alg8alg8
alk9b<k9b<k9b<o:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:
bLo:bLk9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<o:bLo:bLo:
bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo:bLo9b/o9b/o9b/o9b/o9b/o9b/o9
b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/o9b/_9b<_9b<_9b<_9b<_9b<_9b<_9b<_9b<_9bL_9bL_9
bL_9bL_9bL_9bL_9bL_9bLk9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9
b<k9b<k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/g8aLg8aLg8
aLk9a/k9a/k9a/o:alo:alk9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/g8aLg8aLg8aLk9a/k9a/k9a/o:
alo:alk9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9a/k9
a/k9a/k9a/k9a/k9a/k9a/g8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg:`/g:`/g:`/g:`/g:`/g:`/g:
`/g:`]7<`lo:`Lk9`<k9`=3;`]7<`m3;`/o:`L_2^6INDCXa94Po<TDj;4@i:e13=DDh:4Xm;DXm;D/n
;T`o;de0<4i1<Di1<Dm2<T`o;d`o;di1<Di1<Di1<Di1<D`o;d`o;dTl;4`o;di1<Di1<De0<4/n;T/n
;T`o;dXm;DXm;DXm;DXm;DXm;DXm;DXm;DXm;D0h9d0h9d<i:4@j:DLj:T/l;4dn;Tho;dXm;DTl;4Tl
;4Pk:dPk:dTl;4Tl;4Xm;Ddi:5]7=THd8gMZFZVSV3Tj=Q<L7`0;4`0:500=5PhQ:AL/=0PM9@0B6P8A
6P4=5`H@6PD?6@@>60@>60@>60@>60D?6@H@6PLC6D5:CGYoOHj?QXf;PI:=Q9JCRiRDSiFDQYBBQiBB
QiBBR9>AQi>@R9:?Qi:>RIFFS96BRHf>QHf=QiJCSj2MVJVUY:jZZJ^`[k>h]kJj^k:f]k6d^;Vl`L?6
blW<dL[<cL_=c/c>cl[<cLO9b/G7b<K8bLO9b[o8blG=cLK:blO6b<c8cLk9d/[6d/W3e<S8f/O5f<S6
f/g7g/k6gLW3e/_3e<o8eLWDb/WDb/[Ebl[Ebl_Fc<gHc/kIcloJd<gCc/gCc/gCc/cBcLcBcLcBcLcB
cLcBcM7If=7If=;Jf];Jf];Jf];Jf]?Kfm?KfmGDf=GDf=KEfMSEemOEeMKDe=OCd]KBdMKJfmKJfmSJ
fmWJg]_Jg]kJgmkJgn7Kh=G;g=[Hi<_@dM7Hdm3LhZFmjbeI_PM4d0TlZPi7`P0i_`0f_@0b/0/m]@Y3
_P0k_0@j]Pe2`A13`Q98^bQTa49necU`dA]?^PQ6_0Q6_0M5^`M4^PM4^0I3]`E2]PE2]QHnaQ<ma@lo
```n`0Dn^@A4]0iC^QURa014_011_00o_@0m`00n_`10_`0o^P0n]@0ia04iaP8ja`8mb@A0b0M6aPM:
a0Q=`SI[ZRU@O@LO=`0B7Ad_>RHi@B8b<C4i<R]3CaD_>eijQEAdOeUmQeZ1RTYeOTehPDifR5EmT5N0
Ue5lUdQcU4EbV4ejYEJ5/CecRU:5VEn=WUZ2SU9bMe1ZJTeRGdUKE2Y<DRa=ERQ<ERA:ER99Eam7FALo
DPdeB0HXA@0L=P0I<@LZ?UenSXZS/iRY]XFBX9NZYij/YZ6ZX:6RV9nNU:2NUYjMVIJIUjJVUYnOSi:B
PX20L6YZFU5A@CXj:R`/73Dd83Dd83Dd83Dd83@c7c<b7S<b7S8a7C8a738a73<b7C<b7C<b7C<b7C@c
7S@c7S@c7S@c7S@c7S@c7S@c7S@c7S@c7SDd7cLe7CDc6c@b6SDc6cLe7CPf7SLe7CHd73Xh83Tc83`d
8d4l9cXl:2@_;0hM=`<AAAXW=C0a;D8i7T4h4cXe53Lf6S/g6She53Tg6CPf63Hd5SHc5cLc6SLc6SDa
6C<_5bl_4CDc5CXh6Slk7T4k7T4k7T@l7dDm84<k7D<k7D<k7D<k7D<k7D<k7D<k7D<k7D@l7d<k7T4i
740h6d0h6d4i74<k7T@l7chk73hk740k744l7D<k7DHl7THl7THl7T@l7d<k7T<k7T8j7D8j7D<k7T<k
7T@l7d@l7d@l7d<k7T<k7T8j7D8j7D4i744i73li740j7D4k7T4k7T8l7d<m84@n8D@n8D0n840n840n
840n844o8D4o8D908T908S/j7S8a5B//4Rl_5cXi94U:=V9RD7EeIHb?Oi>FQifPTJNYWJf_Xjj_YJ^/
XjVZXI^LS9BEQHZ;Nh>4M7ioKgYkJg=dI6i_Gfa]GF=TE65SD69TDFIXE51B?VQ[EGAgHFi_EG9cFGIg
GGAeFfmbF6mbF71eFW5fFgMcFWMcFWQdFgUeG7YfGG]gGWahGgahGh=mJX9lJH9lJHAnJhR2Khb6Lhj8
MHj8MHN5KH5oIgejIGmlIh=oK89nK7eiIgQdHX9nJhB0KH5mJWahIH1lJHN3L8N3L81lJG5]FgIbH8J0
KGigGUQ@<di58e188;N^PlRkVlVnW/k3YM77ZMC9[M?:[m?:[m7:[mG:[]G:[]G:[]G:[]G:[]G:[]G:
[]G:[]G:[mG:[mG:[mG:[mG:[mG:[mG:[mG:[mG:[mG:[mG:[mG:[mG:[mG:[mG:[mG:[mC9[]G:[mK;
/=K;/=K;/=K;/=G:[mC9[];9[];9[];9[];9[];9[];9[];9[];9[]78[M78[M;9[];9[];9[]?:[`00
c/K6c/K6c/K6c/K6c/K6c/K6c/K6c/K6c<O6cLS7cLS7cLS7c/W8c/W8c/W8c/W8cl[9cl[9cl[9cl[9
cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7
cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9cl[9
cl[9cl[9cl[9cl[9clW:clW:clW:clW:clW:clW:clW:clW:clW:clW:clW:clW:clW:clW:clW:clW:
b/S7b/S7b/S7b/S7b/S7b/S7b/S7b/S7b/S8b/S8b/S8b/S8b/S8b/S8b/S8b/S8cLS7cLS7cLS7cLS7
cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5
cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5c<O4cLS5cLS5cLS5c/W6c/W6c/W6c/W6cLS5cLS5cLS5cLS5
cLS5cLS5cLS5cLS5c<O4cLS5cLS5cLS5c/W6c/W6c/W6c/W6cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5
cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5c<O4c<O4c<O4c<O4
c<O4c<O4c<O4c<O4c<W1c<W1c<W1c<W1c<W1c<W1c<W1c<W1d<_2cl[1c/W0cl[1d<_2d<_2cLRoblJm
[ZJI?cLZ;B@GE4/nA3T[?S<UETTkC3laC3l_CD0`CD0`CT4aCT4aCd8bCd8bD4<cC3l_CD0`Cd8bD4<c
D4<cCd8bCD0`C3l_BSd]CD0`D4<cD4<cCd8bCD0`C3l_CD0`C3l_C3l_C3l_C3l_CD0`CD0`CD0`CD0`
CDDdBd<bBd4`BCl^BC`/Bc`/C3d]CCh^BSh/BCd[BCd[B3`ZB3`ZBCd[BCd[BSh/B3TVEdPe?RlLMFQH
SHAj>CLf4ADJ00LA00TC00`F4R</734i2QlW00lH0`lI1a4K1@lI10hH10hH0`dG0`dG10hH10hH1@lI
1a<I?TM:MGYhRHV3RHMmShV2Ti28Thn:TY63TY25T8j3Shf3SH^1S8V1RhR0RXJ1QHIlQ8EkQ8ElQhEm
S8R3SXV6T8V6ShR5SHn9UINAVY^GVY^IWYnMZJVY/[:b][Fg^[bl_Kno`L?3a<K6a/S8bL_;cLo?d=;B
aL_:cM?BbLg>a<S9c<gAbLW?aLG;c/gFe/kEe<cCf<gEh=;Mh=?KgLkFflcDg/gFd/oHdm3Idm3Ie=7J
eM;KeM;Ke]?Le]?Lf=7Pf=7Pem3Oem3Oe/oNeLkMe<gLe<gLbmC:c=G;c=C=cMG>c]G@cmKAd=ODdMSE
f=OKfMSLf]WMfm[Lfm_Kfm_Kf]_If]_Ic]SOc]SOc]OPdMORdmORe=OUe]OUemSVbm7^cmS/am3Id=KE
bmCHZ;gS;e^d03Jf54^d146e14G50Cjl5Tc13D:a4Dfo2Dg403g:03oC0D3A1dS=7VCF=W[U:FSK2TG3
04?804?804?804?704?604?604C404C40C?=0cKB03[C03O=03S403o205;;0f?E14;@0ck@0c_@1C[A
23_A23_=2C_92C[42Snh2Cjg23^g23Vc1CN]1CNW1CRP13RL5dIn7CeV5BPm3Q`X62Tf83=2830g8bd]
32@`01<O6cM25S@o5SU35ci71c0i2SDn2S=24CU;4ciA33]A13E?1SYH54YY8UQi7ea`:F=f<VEe;EMT
7ci742H[1aPK1Q<E0QlT0b<X02@Z02</02@`0BHd024a01T/3B0e01L[01/_3R`mEG>4KhbKMi2PJh:A
PY^GPiB@R967Si65T8n1RXYnQ8QmQ8V0OWi/NWYXM7ARJf]IGUi<Cdlm?cl]=CDS=cHR=cHR=cHR=cHR
=SDQ=C@P=3<O<c8N=3<N=C@O=C@O=SDP=cHQ>3LR>CPS>CPS=C@O=SDP=SDP=SDP=cHQ=cHQ=cHQ=cHQ
=cDM=S@L=C<K=S@L>3HN>CLO>CLO=cDM>SHM>S<O?cDS?SXR<cHP82XT4b0j3Q]?6bPf<34]@STN@CPC
>SDD=cHJ>SHI?SDD=cDG=S@F=C<E=C8F=S8I=C4H<blG<2`D;Rh@<S8D>SPJ?C/M?c/N@C/N@C/N@S`O
@CTK@CTK@CTK@CTK@CTK@CTK@CTK@CTK@CTL@3PK@3PK?cLJ?cLJ@3PK@3PK@CTL>cPI>cPI?STJ?cXK
@SXLAC/MAC/MAS`N@SXM@SXM@CTL@3PK@3PK@CTL@SXM@SXM?CTM?CTM?3PL>cLK>SHJ>SHJ>CDI>CDI
?3DJ?3DJ?CHK?SLL?cPM@3TN@CXO@S/P?S`N?C/M?C/M?C/M?C/M?S`N?cdO@3hPADH/>c`R<C4I:b/C
9bHA9B@@:BPD<BlM?ChZCDhjIfQDOWi/SHemShmoRXUkQHAfLG=PKg5NJfeJJF]HJF]HJ6YGIVQEI6IC
L7=MIfUEIVQDIVQDJF]GHF=?IFMCJF]GM7=NM7=NMgIQNGQSN7MRMgIQO7]VPh9]Og]SP7aTPWiVQ81X
Qh=[RHE]RhM_S8Q`RXAaQX1]Q7i[QX1]RXAaRhEbQX1]PG]XQ89ZQ89ZR8E`ShagTHejSXYhSXYhTHek
OWYWPWi[Pgm/PGeZP7aYPGeZOg]XNgMTMGAOOGYURhEbO7EQCdP_@cTKASdH[JEmfln]fLj^f/n_fLna
fLnaeLf`dlZ_clR]eL^]eL^]eL^]eL^]eL^]eL^]eL^]eL^]eLZ_eLZ_eLZ_eLZ_eLZ_eLZ_eLZ_eLZ_
eLZ_eLZ_eLZ_eLZ_eLZ_eLZ_eLZ_eLZ_e<V^e<V^eLZ_e/^`e/^`eLZ_e<V^e<V^d/V^d/V^d/V^d/V^
d/V^d/V^d/V^d/V^dLR]dLR]dLR]dLR]d/V^d/V^003>a/K>a/K>a/K>a/K>a/K>a/K>a/K>a/K<alK<
alK=b<O=b<O=b<O>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>
bLS>bLS>bLS=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O>bLS>
bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>b<W>b<W>b<W>b<W>b<W>
b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W:b<O:b<O:b<O:b<O:b<O:b<O:b<O:b<O:b<S:
b<S:b<S:b<S:b<S:b<S:b<S:b<S=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=
b<O=b<O=b<O=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G<alC<
alC=b<G=b<G=b<G>bLK>bLK>bLK=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G<alC<alC=b<G=b<G=b<G>
bLK>bLK>bLK=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G=
b<G=b<G=b<G=b<G=b<G=b<G=b<G<alC<alC<alC<alC<alC<alC<alC<alC<bL7<bL7<bL7<bL7<bL7<
bL7<bL7<bL7=b;o=b;o=b;o?b/7?b/7=b;o8`k[4_kIgL64l=BHi<29@AcU6>Ri7>bmHBSi>@3A>@C5>
@C5>@C5>@C5>@C5?@S9?@S9?@S9<?bm>@C5@@c=AA3AAA3A@@c=>@C5<?bm;?Ri>@C5AA3ABACE@@c=>
@C5=@31=@31=@31>@C5>@C5?@S9?@S9@@c=@@c=@@c=<A3=<A3=>A3==@c9>@C5?@31>?bm=?Ri<@2i<
@2i;?be:?Ra:?Ra;?be<@2i<@2i5?BI?A2i4>BEPETEVGE@Z9B@B4AX311812Q@01a49624D9Bh65b00
2A812aD53QP43QP33AL33AL231H231H33AL33AL43QP131@d?D5XKFamOGN0OGF9Pgb=RHB<QhB<Rgf<
RWn;RGj:R7j9Qgf7Q7b6Pg^6PWf1QGV2PgV2PgV7QGf;R82>R8>?QX>=Q85mOG62PGN4PgV3PGV7QGf?
S8NCT8bBSh^BU9BGVIVNX:2UYjN[[Jfb];Bi^k^n`<2g_;[4bLRna<>h`<33b/foa/Vk`l?=d]?=cM?:
b]3:bloAd=CDd=GAcM?CbmGEcMO?bmk?bmk@c=o@c=o@c=o@c=o@c=o?bmkEd^;Ed^;Ed^;DdN7DdN7D
dN7Cd>3Cd>3BeM?Ce]CDe]KEemOFf=WGf=cHf=kHf=kGeM_He]cGf=cHf]_IfmcIfm_Gg=_Gg=[Cf]gC
f]gDf=gCe]kCeMgEe=kDd]kDd]k<dN3?dmkCe=SPgMWIf=c4eOIFP/l<Ck`4?Zl0=;00?lH0>[l>Al8;
@K@8AK/3A/<0=/H0=/d0=<`0>/D9C/LFG<h?CLT0<kX0>lT0>lT0?<L0?<H0?L@0?<80?L40?L40><80
?<H0?LL0>/80>K/0?[P5BKX;D;d:>K8:=[4:<k4<<[0><Zh@<ZX@<JH?;j07=8/7<HX7;8H59h438GP1
7fh06fD06f006DT04S@752@94Ql03Ql04BH352L13a/04R4052<041h06BL07B/2934072T6:CHB>4@@
=dD;=d@8=dD7>TX@AULMF6PYIGDJFfXIEV@MDEhMAe@>;3L03AP00@/11Pl03Q005AT06b007R@08b/7
9c@;93@87bl<72P462<692l?=D50KGQ4M81;O8Y;O8YYQX=FK6M>FDmGFT]IEdE9BSHk@BhjAC54AS0n
@2Xg>B<c=Ald=R0g>B<i>bDk?BLg=R8h=b<h=b<h=b<g=R8f=B4d<alb<Adh=b8h=b8h=b8h=b8i>2<i
>2<i>2<i>2<f=B0f=B0g=R4g=R4h=b8h=b8i>2<i>2<j>20h=Qhg=Adg=Adi=ali=alg=Adf=1`j=Qdi
<Qhl<R0m=b0c=QdQ;2@F8SX@7TlK:3Ha<Ri2>Ai1>1<j=A@g=QXj=QTm=1<e<aDd<Q@c<A<d<ADe<APd
<1La;AD^:Q8Z;0h`<18f=QPk>A/l>Q`m>A`o>Aa0>Qdo=aTo=aTo=aTo=aTo=aTo=aTo=aTo=aTn=QTn
=QTo=aXo=aXo=aXo=aXn=QTn=QTj=aPj=aPl=aPm>1To=aU1=aU1=aU1=aU0>1/o=aXn=QTn=QTn=QTn
=QTo=aY0>1/e=1Pe=1Pd<aLc<QHb<ADa<1@a<1@`;a<g<1Dg<1Dh<AHi<QLk=1Tl=AXm=Q/n=a`j>1Xj
>1Xi=aTh=QPi=aTj>1Xk>A/l>Q`T9`hS9PdV:A0`;aXc<Qda<1/`;a/b<Ad^;A<j>Am>C3AQGdM]JUEa
KEY^JUM[IeAUIU9XJEE/KEU^Ke]_L5aaLUidMF5fMf=]L5I[KUEaLeebLemdM69iNFUeM6IhMfUhN6Id
M69eMF=kNfUmNfUiMfElNVR4PW1mO6QmO6QoOVZ0Of^2PFf3PVj4Pfn5Q728QWB7QG>6Q7:7QG>9QgF9
QgF8QWB6Q7:DTGb@SGR=RGJ;QgB3OfekMfEnNFZ6PG:7Pg26PVn8Q76<R7F;QgB7Pg23Ofb4P6f>T7>:
Rg6@SGR5OV]NED5?AR]9?b6VWGSCajGAajGBajOBbJSCbJ_BbZgCbjkAbjkDbZcDbZcDbZcDbZcDbZcD
bZcDbZcDbZcDbJkDbJkDbJkDbJkDbJkDbJkDbJkDbJkDbJkDbJkDbJkDbJkDbJkDbJkDbJkDbJkCb:gD
bJkEbZoEbZoEbZoEbZoDbJkCb:gAb:gAb:gAb:gAb:gAb:gAb:gAb:gAb:g@ajc@ajcAb:gAb:gBbJkB
bJh00<k6a/k6a/k6a/k6a/k6a/k6a/k6a/k6a/c7a/c7a/c7a/g8alg8alg8alk9b<k9b<k9b<k9b<k9
b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<g8alg8alg8alg8alg8alg8alg8
alg8alg8alg8alg8alg8alg8alg8alg8alg8alk9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9
b<k9b<k9b<k9b<k9b<k9b<k8bLk8bLk8bLk8bLk8bLk8bLk8bLk8bLk8bLk8bLk8bLk8bLk8bLk8bLk8
bLk8bL[8al[8al[8al[8al[8al[8al[8al[8al[8b<[8b<[8b<[8b<[8b<[8b<[8b<[8b<g8alg8alg8
alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8aLg8aLg8aLg8aLg8aLg8aLg8
aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLc7a<c7a<c7a<g8aLg8aLg8aLk9a/k9a/g8aLg8aLg8
aLg8aLg8aLg8aLg8aLg8aLc7a<c7a<c7a<g8aLg8aLg8aLk9a/k9a/g8aLg8aLg8aLg8aLg8aLg8aLg8
aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLc7a<c7a<c7
a<c7a<c7a<c7a<c7a<c7a<c9`Lc9`Lc9`Lc9`Lc9`Lc9`Lc9`Lc9`L[5_<[5_<c7_/k9`<k9`<[5_<Bo
][nj/D0i:48k;4Dl;T<j;4Lk;e14>553=d@e;4i1<Di1<Di1<Di1<Di1<Di1<De0<4e0<4`o;di1<E13
<e95=E95=E13<di1<D`o;d/n;Ti1<E95=E=6=U54=4m2<Ti1<Di1<Dm2<Tm2<Tm2<U13<e54=554=595
=E95=D8j:DDm;4Y0;di4<e54=593<e11<Dho;e14<U14<Tm3<Di2<4i2<4m3<E14<U14<TM3:TM1:Tm7
<4m5=4i3>a`D5ALB6`P550<950002@094`PG800=5P0230053`064@<=5`<=5`8<5P4;5@4;5@8<5P<=
5`<=5`0432Xc=eaQH75`K7QeKH=mMXN3OXF0OH1oLH1nLh5oM85oMH:0MX9oMh9oMh=oNWAhK79dJ6i_
IG1_IGMaJWmfLXAkMhUmNh>0LXB1Lh9oLGijKgmjLH9mM81jLgYdKG9dM7IhN7YlO7j0P863PhB6QXV;
Rhb>SYfPWZba[jR^[JB^[[6m_Jjj^Zbi]l?>c<SFg<;@e/7=dL;>d/C?dl?=e<K<el[@gLkAeLkAeLoB
e/oBe/oBe/kAeLg@e<g@e<[Ebl_Fc<_Fc<_Fc<cGcLgHc/gHc/gHc]SDfMSDf]SDf]SCg=SAg]SAh=S@
hMS@hMSDfMWEf]OFf]SGfMKHf=GGemCGeM7Fe=OHcmSHd]_He=cHemoIf^;Ig>?IgnKJh>3Lem[Ed^3E
dNWId]W>d<cHm62?d`]C^0E3_`10bP16f@0nc`8l``Y1`00h^P0h_`@o_@Hn``Ll`P/o^a=;]QeC^1Y;
^A8l]`hi^10i^10h]Q0f/Q4f[Q4eZa4cZQ4dZ@8lW0@kW0LhW0TbU@l_T1D_RAP]PQD[N@0YK@0UK00P
JP0OJ@0OJ08OI04MG@0KE`0BD@0CDP0BDP0ADP4@CPD@B@PB@PTB?P0KAP0:9@/D8A<L9P0;7P09904G
<0@E:P0<6`PO;P044`0J:0DP;PdZ>0PX=AhnBa4d?PT]=`0X<@0Z<P8f?A17CQ]GGB5OI@i?G@E3CPLk
B10gA@LR<0055@003P`<708D5@@L70@P8@0O900O9@4L9P4D8@0;6`0?4P0?4`0S9`Hf?2YUKR=VKbec
P3UoS5akNSU@BbPc:CPk:dE4;c/n9C8k8CI3:CPk8SLj8CHi83Hi83Pk8SLj8CDh7c8e73Lf8SPg8cTh
93Th93Lf8SDd83<b7S8a7CTh8cPg8SPg8SPg8SLf8CHe83He83He83He83He83He83Lf8CPg8SPg8STh
8cTh8cdk8c/i8CTg7cPf7SPf7SPf7SDc6c<a6CLd63D^6ST`73dg83Hi828]9A0L=0@B@a`Y=c4b;T<j
7d4h4cXe53Lf6STe63dd4c<a4c8`4S8`4S<`53@`5c<_5S0/52dY4BPZ32`^43@d5SLg6CXh6S/g6S/g
6Shh6clg6Clg6Clg6Clg6Clg6Clg6Clg6Clg6C`d5cde63hf6Clg6Slg6Shf6Cde63`d5cXg63Xg63/f
5c/f5c`d5Sdc5Cdc5C`b53de63de63`d5c/c5S/c5S`d5cde63de62ha5bha5bd`5R`_5B/^52X]4bT/
4RP[4C</4c</4c@]53H_5SL`5cTb6CXc6SXc6SPf63Le5cHd5SDc5CDc5CLe5cTg6CXh6Si1:38e72LZ
4BPW4Rd/5cLf8DQ5<5IC?VMSAVUUB6]WBfiZCW5/DgA^EgMaFWQbFg5cGGEgHGQjI7MiHg9dGVi`FVi`
FVmaFg=gFW=fG7UlHgEfHW1`H7YhKGAbJ7aiLGUiKGAdJ7IfJX1nLh5oM7ijKh1lLHR4NH62LX62LX62
LX62LX62LX62LX:3Lh:3Lh22Kh:4LH:4LH63L7j0KGj0KH63L8F7M8V8M8>2KX>2KXV7MH^8NHJ3M8B1
LhN4MXJ4LWilJWekJHB2L8R6M8F3LHJ4LX^9Mgb0GGIhFWmmIHAnJg9XEVaQBeiC=jnVQKV]RkV_SKfc
TL:iV<RnX<g5Ym?;[]C>/MC;Z]C;Z]C;Z]C;Z]C;Z]C;Z]C;Z]C;Z]C9[]C9[]C9[]C9[]C9[]C9[]C9
[]C9[]C9[]C9[]C9[]C9[]C9[]C9[]C9[]C9[]?8[MC9[]G:[mG:[mG:[mG:[mC9[]?8[M78[M78[M78
[M78[M78[M78[M78[M78[M37[=37[=78[M78[M78[M;9[P00clS5clS5clS5clS5clS5clS5clS5clS5
c/S3c/S3c/O4clS5clO7d<S9d<S9d<S9cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7
cLS7cLS7cLS7cLS7c<O6c<O6c<O6cLS7cLS7c/W8c/W8c/W8cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7
cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7c<O6c<O6c<O6cLS7cLS7c/W8c/W8c/W8c/W8c/W8c/W8c/W8
c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8c/W8
c/S9c/S9c/S9c/S9c/S9c/S9c/S9c/S9c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c/O4c/O4c/O4c/O4
c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4
cLS5cLS5cLS5cLS5cLS5cLS5cLS5cLS5c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c/O4c/O4c/O4c/O4
c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4
c/S1c/S1c/S1c/S1c/S1c/S1c/S1c/S1c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4clW2clW2clW2clW2
clW2clW2clW2clW2c<_1b<Nmd<k4blVnc/^mclVlfMC5LFaM<2HDA3XXBT0^B3h/CD<aC48`BT0^DDLe
CT@bCD<aCD<aC48`C48`CT@bD4HdDTPfCclhCD0hCD4gCD4gBd8eC4<eC4DdC4DdB3h/BCl]BT0^C48`
CT@bD4HdDDLeDTPfDdLeDdLeE4PfE4PfDdLeDTHdDDDcD4@bEDLeEDLeE4HdE4HdDdDcDT@bDD<aDD<a
CT@bCdDcDDLeDTPfDdTgDTPfDDLeD4HdCCliBd8eBd@cBTTe@d<c;bhZ4a0I000=0`<E0@@C0@@C00HA
00TB00T@00L=00@80``I0P/H0P/H0@XG00TF00TF00PE00LD1`hG4ATPC59GM7UjIfaZKG5/P8=jMGQ_
OGabOGabOWecOGabO7]aNWU_NGQ^MgI/KgIa<STd82HQ<CLbLgMbMWMcNW]gKg1/O7QVNgIWMgAUM7AT
LGAULGIWLgM[LgY]LFmWLW1XM79ZMG=[MG=[M79ZLg5YLW1XL7EdKG9aKW=bLgUhNGmnP8R7SYJEVj>R
]kfl^Kjm_<70`lG5b<[:clo?dm7Adm7Ad=;Cc/oCc<gAc<cBcLcEc/gFcLcFc<_EdmGEdmGFdmGFdM;F
cloEdM7Ge=?LemKOg=gQf=WMe=GIdM;FdM;Fd]?Gd]?Gd]?Gc=?FcmCGd]GIemWJfm[Lg]_Mg]WJg=OH
fmcJf]_IfmcJg=gKf]_Ie]OEe]OEf=WGc<cHe]KLgM[LdM?Dc]KSbmglTZgP?enP4d>/3d2V2cfQ2CbL
2CfK2CjH23jE1cjC2SjH33jH2SZB2SV?3C^?4Cf@3CR90bio5R^04BMi3BAd2R5_2B5]1b1Z0Q]S01MO
2QUR21MP1aIK1AEH1QED21IA2AMA2AQ@0QE20QE20QE20QE20QE20QE20QE20QE211@n0a<m0a@k0Q<j
0A<h01<f018e014b01Da0A<`01</014X018T018Q0A8O0A<N018O0QPT01LS01DQ1b<^63I16CU43C0j
22Dc1R<a0R@a1R/i33E443e;3Sa=2CY:2SI=039324A@02de32D_0@LD000>000?00HH0a<P11XU01TO
01HL11HQ1PlM00@G00<@1QhZ020Z:5US3dAA4DUJAGbAB7bCBgf3>UQI=C/`?cXU@D<U?D<T>SlT?SdX
=S`S<cTP<cLN=3LN=STP>SXR>c/S?3XR=3DQ=3DQ=CHR=CHR=CHR=3DQ<c@P<c@P=SDP=cHQ>3LR>3LR
>3LR>3LR=cHQ=SDP<S4L<c8M=C@O=SDP=cHQ=cHQ=SDP=C@O=C@O=C@O=C@O=C@O=C@O=3<N<S4L<S4L
>2lQ>c<L?3LH>CPF;cDN7R`Z3B8h0Qa19B<i:B/[<CHK=cXC?3PE>S<H=c4D<c0A=3DE<c@D<S<C<C4C
;bhB;RdA;B`B;2/A<C0F=C4H=c@H>3@H>S@G>cHG@3PJ@SXL?cDG?S@F?S@F?C<E?C<E?38D?38D?38D
?SLF?SLF?cLI@3PJ@3PK?3<H=bhC<RP@;BT<=C4D?3HI?CDH?3@G@3DI?c@H?30D=34B=C8C=c@E>3DF
>3DF=S<D=34B<c0A?C@I=B/C;RPA;bTF8b0A4Q8441476AdB;BXE;BXE;R/F<BhI=34L=C8M=34L<BhI
=C@H=C@H=3<G<S4E;bhB;RdA<2lC<c8F<c<K>c/SB4P`EEDmGUi6I6A<JVYBKFeEKfmGKViFKViFKViF
KViFKfmGL71HLG5ILW1NLW1NLg5OMG=QMWARMgESNGMUNGMUNGMUNGMUNWQVNgUWO7YXO7YXOG]YOG]Y
OG]YOWaZOge[P7i/PX1^Ph5_Q89`QH=aPh5_Q89`Q89`Q89`QH=aQH=aQH=aQH=aQXQeQHMdQXIdQXId
R8IdRhMeS8QfSHUgSH]iSH]iS8YhRhUgRHMeR8IdQhEcQhEcSHIcSHIcSHIcSXMdShQeTHYgTX]hThai
R8Q`QXA/Q81WNgIMOgQMDd/^A3TM/JF9d/N[d/N[dlR/dlR/e<V]e<V]e<V]e<V]dlR/dlR/dlR/dlR/
dlR/dlR/dlR/dlR/d/N[d/N[dlR/dlR/e<V]e<V]e<V]e<V]dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/
dlR/dlR/dlR/dlR/dlR/dlR/dlR/dlR/d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[
d/N[d/N[003?b<G?b<G?b<G?b<G?b<G?b<G?b<G?b<G>b<?>b<?>alC?b<G?alO@b<W@b<W@b<W=b<O=
b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O<alK<alK<alK=b<O=b<O>
bLS>bLS>bLS=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O<alK<
alK<alK=b<O=b<O>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>
bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>bLS>b<W>b<W>b<W>b<W>b<W>b<W>b<W>b<W<alC<
alC<alC<alC<alC<alC<alC<alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>
alC>alC>alC<alC<alC<alC<alC<alC<alC<alC<alC=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G<alC<
alC<alC<alC<alC<alC<alC<alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>
alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>b<7>b<7>b<7>b<7>b<7>b<7>b<7>b<7>alC>
alC>alC>alC>alC>alC>alC>alC?bL;?bL;?bL;?bL;?bL;?bL;?bL;?bL;<bl79b;k>c<;9akc9a[S<
a[Ve/:5OFT]@ASELDT5ICciAAcIDBSUBB3M<@S5?ACADBSUDBSUDBSUEBcYEBcYDBSU@ASE=@c9GBCeG
BCeFBC]BAcU@ACM=@SA:@2m9?biAAcEAAcE@ASA@ASA@ASA@ASA@ASA?AC=DB3IDB3IEBCMEBCMEBCMD
B3ICAcEBASAHBSQHBSQHBSQGBCMFB3IEAcEEAcEDASACAcECAcEDB3IDB3ICAcECAcEBASAAAC=@@CQ?
@SA<AC5=B3=5@c4d<BTL5Q/80@h721H311800@`000/00`h01Q402A<02A<02AL02AL02AL02AL02AL1
2QP22aT331X00``22Q4g?D9SJ6]QIVEZKVUhNWAYJfE]KfU_LF]bM6icMFmaLfe^L6YYJfEVJ690BdTJ
8R4C6aXR:2MEFUUIGUeVJ6QRI6A^K6A/KFA[JfEWJF=SIf5OIUmLHeiKHUeTJ6=RIV5PI5mMHEaJGUUI
GEQIGEQIGEQEFU]=DU=:Ce1AEUMFGUiCFe]=EEE9DE5[L6j3R8JGVYRJWI^RXj6a[jjf];>a[jk7alO9
b<[;b/c>cM7Ad=CEdmWHeMkJen3:c/o<d=7>d]?>dMG=d=G<cmC=cmO?dMW2aLW7b/k?d]KGf]kKg^;J
gN7Ef=cAe=SKhNKHg^?FfmkDem_DeMWGe][If=[LfM_GfmcBe]O>d]??dmCCemSFf]_Hg=gIgMkFf^GK
g^?MgMg?dM6oalj/_==_R;0S@7<06FH066@05f806f@08VL09f`0:Vd1:fh4:g04:fl3:FX39VP6:FT:
:fX69F8075T16UX05eD0558055005Tl05Dd04dT044H054d04T/04TH04D@04D004Sl14Sd253d353l3
53l353l353l353l353l353l353l45C`45C`35CX253T25CP153D04c@04c@35C825C0052d04bP14RD0
4b824b0251l041d25B815b<05R858B`A;cX>;ST192h27RT07B/08Bh6:CL9<T4<=dH7=DH2<d<;=dh0
<444@D/0;SH;92h00A010A<421/85RP35R<06B<072416b456B@44Al00QD821P:5B<03a/TCUXBB5<?
C5XcLH4`KX1BPHE5Geln@SLo?2Ln@2<f?R0f>R4k>RDe>b@c>B8b=Alb=Ale=b4j>B@j>B@j>B@e=R8e
=R8f=b<f=b<e=R8d=B4c=20b<ale=Ade=Adf=Qhg=alg=alf=Qhe=Ade=Ade=Ade=Ade=Ade=Adf=Qhg
=alg=alh>20e=Ade=Ade=Ade=Add=1`b<QXa<AT`<1Ph<Qli=1/k>ALj>AL_=1lP;2`A8S`674DP8CHV
:2P^<aPd=a0g=A<g<1Db;Q8a;Pl`<A4_<10^;Q0];@l/:`lZ:@lY:0hY9`lX9Ph/:a4d<1Lg=1Ph=1Li
<aHh<a@i=1Dj<Q@j<Q@j<Q@j<Q@j<Q@j<Q@j<Q@j<Q@f<A8e<14f<1<g<A@g<1Dd;A@^9`hZ8`XY9PXb
;Q8f<QHg<1Dh;a@j<AHk<1Dh;A8a;Pla;Plb;a0b;a0c<14d<A8e<Q<f<a@e;AH/9PlZ9A0W9A<L6`d9
2`052@0<4@P`;AP_;1L^:aH/:A@[:1<[:1</:A@/:A@T8`LY:0``;a<g=QXo?R97ARY?CS9DDcMIF4=N
GDQTHdiXIe9YJ5=ZJEAZJEA[JUEcLUebLEaaL5]aL5]`KeYaL5]aL5]bLEadLV1dLV1eLf5gMF=hMVAi
MfEjN6IkNFMlNVQlNVQmNfUnO6YoOF]oOF^0OVb0OVanO6YoOF^0OVb1Off2P6j4PW25Pg65Pg64PW24
PW25Pg65Pg65Pg66Q7:6Q7:6Q7:6R7F6R7F7QgF6QWB9QgF<R7J=RGN>RWR=RgV=RgV<RWR<RWR;RGN:
R7J9QgF9QgF@RWN?RGJ?RGJ>R7F?RGJ?RGJ@RWNARgR?SgN2P6R4P6N1O6=aJTlk<aHk<1B/X8CBaj_B
aj_Cb:cCb:cCb:cDbJgDbJgDbJgCb:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cBaj_Baj_Cb:cCb:cCb:cD
bJgDbJgDbJgCb:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cCb:cBaj_B
aj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_Baj/00<o8aLo8aLo8aLo8aLo8aLo8aLo8
aLo8aLk8`lk8`lk7a<o8aLo7am38bM38bM38bLg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8
alg8alg8alg8alg8alg8alc7a/c7a/c7a/g8alg8alk9b<k9b<k9b<g8alg8alg8alg8alg8alg8alg8
alg8alg8alg8alg8alg8alg8alg8alg8alg8alc7a/c7a/c7a/g8alg8alk9b<k9b<k9b<k9b<k9b<k9
b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9b<k9
b<k9b<k8bLk8bLk8bLk8bLk8bLk8bLk8bLk8bLc7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<k7a<k7a<k7
a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<c7a<c7a<c7a<c7a<c7a<c7a<c7
a<c7a<g8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLc7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<k7a<k7a<k7
a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7
a<k7a<k8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<o9`/o9`/o9
`/o9`/o9`/o9`/o9`/o9`/[9_lW8_/c:`<[8_LW6^<c6^H^6Me9=?V=JC6UPDV5HBU]BA69IBf9IBeU@
@UQ?@D]2=4U0<TPo<D]2=4m6>558>Tm6>4a3=DPm:D]0;4m3<EA8=UQ;>eU<?5U<?UU<?UI<>UE;>EE;
>EA:>5A:>5=9=e98=U98=UE9=eI:>5M;>EQ<>UQ<>UQ<>UM;>EI:>5]=>eY<>UY<>UU;>EQ:>5Q:>5M9
=eM9=em??Ui>?Ee=?5a<>e];>U];>U];>U];>UY9?5M9=eE:=5E>=E5:=TDl<S8X:28H7P@42P<32@84
30<53`D650<65@0250004@065`055P045@03500350055P065`486@L<5@H;52ha>EAIG5]OH6=XIfY]
JeQLEeYNGe]OH5]OH5UMGU9FEdU=CSm3A3Tm?Q@O8`HA5@LB5PTB5R4W;24W;2lc>2lc>3Di?SHj?cHj
?c<i?Rlh?2Xc=b@_<b4/<1/R9AdT9ahU:1lV:AdT9aPO8Q@K7Q4H6a`T91<K6`dE5A0H618J6Q4I6A4I
6A8J6S/o>V=WHX62OWn0O860O96>RYFBSX^8Q9jMVJBRXJ^YZ;6_[kFb];^h^/:n`lS4bL?8bLO<cLcA
d/kCe/kBelgAe/g@f<g@f=CHgM?Gg=7Ef]3DfLkBelkBelgAe/gAe/;;clK?dlgCf<oEf];Ffm7DfM7D
fM7DfM?HfloDel[?d/_@dm3Ef=;Gf/oDel[?d[c5c[Fl_jba[i^OVGj6QF=_Nc52G00=<0D==@4;<`0;
<`0==`0B?@0G@@4JAP0KA`@MA`HNB0@MA@@K@@LNA0/QA@HL@00C>00C>`0B>P0B=`0C=`0E>@0F>00E
=`0E=00H?@0F?00F>P0E>00F=00F<P4F<@4G<08E>`8E>`8E>`8E>`8E>`8E>`8E>`8E>`@F>`@G>P<F
>@8E=P8E=P4E=00E<@0E<@<G<08F;`8D:`0C:04C90<C8`<D8@@D8@0?704D8@0F8P0F8P@N:PTW<P8R
;@0E800G8P0H8`0L:@8U<PH]>`Ha@08_?@0/>P/fB`0]?@0kA@8a>@lX<P003``=8AXO=1L[?0<K9`0F
800M8P0K804G8P0A7P014aD=7PlB8@0C8SYQKcU]NC=^N3mkQcafPTafMDAKEd11=chj9cPk8Blh7C4g
83/j9S4i8S0f7bdc72lb73<e7cDg8CLf8CLf8C@f8S@f8S@f8S<e8C8d834c7bla7Bh`734d6S8e6c<f
73<f73<f73<f738e6c4d6S<f73<f738e6c8e6c8e6c<f73@g7CDh7S<f73<f738e6c8e6c0c6Bha5b`_
5B/^52h^5S0_4c<b434b4RT]6Q`U:0dL=P@F?alQ<b<X9RX`5c8c4C@`4c<]5S4/4bl]3Rd]3bd]3b`[
3b/Z3RXY3bTW3bPV3RLT3b4P2bLW3c8`63Lf73Tf6SPd63Da53@`4cL`5CL`5CPa5SPa5SPa5SPa5STb
5cTb5c@`4c<_4c@`53@_5SD`5c8/5BdV4RTR3RTX3S4`5SLc6SDa63D`5cTb6CPa63D^5C4^4Rl/42dZ
3R/X32XW2b/X32`Y3B`Y3B`X5BDT42<S4B<S5ATK3`T=0PD:0@XA2R@Q32HS3RLT3bDR3B@Q32HS3R`Y
534^6C/j84509TU8;U5@=UUH?V1OAFMVC6a[DFMVDFYYE6i]F71_FW1_FW1_FW9aG7AcGWMfHGIeH7Ed
GgAcGWAcGWAcGWEdGgEdGgQfI7QfI7UgIGYhIW]iIgekJGekJGilJX1nK81nK85oKH5oKH:0KX>1Kh>1
KhB2L81nK81nK85oKH:0KX>1KhB2L8F3LHJ4LXF3LHJ4LXJ4LXJ4LXN5LhN5LhN5LhR6M8R:MhN9MXR8
MXN7MHZ8MXf9Mhj:N8n;NHf;NHf;NHf;NHf;NHf;NHf;NHf;NHf;NIB>Ni>=NY6;N92:Mhn9MXj8MHj8
MHj8MHR8L7mmIHN3JXJ1J7YcF6=K?W1UBKN[Sm;7Zm;7Zm;7Zm?8[=?8[=?8[=C9[MC9[M?8[=?8[=?8
[=?8[=?8[=?8[=?8[=?8[=;7Zm;7Zm;7Zm?8[=?8[=?8[=C9[MC9[M?8[=?8[=?8[=?8[=?8[=?8[=?8
[=?8[=?8[=?8[=?8[=?8[=?8[=?8[=?8[=?8[=;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7Zm;7
Zm;7Zm;7Zm;7Z`00c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/S3c/S3c/O4clS5clO7d<S9d<S9d<S9
cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7c<O6c<O6c<O6cLS7
cLS7c/W8c/W8c/W8cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7
c<O6c<O6c<O6cLS7cLS7c/W8c/W8c/W8cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7
cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7
c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4
c/O4c/O4c/O4c/O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4
c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4
c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/S1c/S1c/S1c/S1c/S1c/S1c/S1c/S1
c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/S1c/S1c/S1c/S1c/S1c/S1c/S1c/S1alJlbLRnb/Rnc/c1
cLZlblFhKFQIDdhoI5a?KVIIK6AGL6QKPGU/Q7a_NG5TM6aOLFULJ61CGUI9FE54FE54FE54Edm2E4`o
Fe<lGEDnH5E1HEI2Ge=1GTloFd/nFDTlED/iED/iET`jEddkEddkF4hlF4hlFDlmF4`jFDdkFThlFdlm
G50nG50nFdlmFdlmGDlmG4hlG4hlFddkFT`jFT`jFD/iFD/iHU91HE50GdlnGThmGThmGdlnH50oHE50
GddlFddgFddfFdlgFTliDdPjAc`d?S4_6aTH4a<C2PT;0P4:000:000>000B000C1@LI0`DG0@<E004C
000B000B008D0@<E004;00073Q4I9bXb:bhc;S4e;S8c8BDV82H]82H]7bD/6b4X51XQ318I10XA00D<
00P@00`D0`hF00@=00<<00<<0PTB10TB0@PI0@TJ0P/I0P/I0@XH00TF00PD00HB1a4H1Q0G10hE0`dD
0P`C0P`C0P`C0`dD0`/;10`<2A4A3ADE3Q<D41DF7B4R:bl`<C@[Ce99JFYQJFYQJFMOL6eULg1XL6YS
K6YRM79ZOW]fPWmjQ85mR8B3T8b;Ui>BWjJSYJ^Z[K>b]KZk^l33`LK9a/[?b/kCalc?alc?alc?a/_>
alc?b/oBcmCGd]OJdMSKdMSKdMSKcmGJc]CIcM?Jd=?Kd]GMeMkReMkRdM[Nb]?G`lc@^L;6ZK:fW:FY
PXjBLGajIViWF61EA4a2=3`k82/c1A8R3``K30/K20XL1P/P1Q4W21D_1QLb1ALd11Pa1QXc1QXc11Pa
21Xa31he21Xa0A<Z01@`01@`01@_0AHa0QLb0aPc11Td11Td0QTi0QXh0ATg0QPd0aPc0aTb1AX`1AX`
0A@g0A@g0A@g0A@g0A@g0A@g0A@g0A@g11Df0a@e0aDd0Q@a0Q@a0A@_0A@_0AD^0aD/0QDZ01<X0A8U
0Q8S0Q8R0a<P0a<P010M0Q<P01<P01@P0A/W1R8]01dX018M01LQ01PS01/V024^0bTe0bdj0Bhl02`j
239502`i03Dn1SDm4R`h008C6Qha<CM>7CM701`W01LP01`Q01@I01@N0aTU00dN00PE00lL01dZA6ik
C7V6?VQd>5eU>EUO<eMA=DM0>SX^>cLT=3LQ;3HO<cPS?C/Y;C@O:c8M:RlJ:RlJ;S0L<C8N<S<O<S<O
<S@Q<S@Q<S@Q<C<P<38O;S0M;2hK:bdJ<C@J<SDK<cHL<cHL<cHL<cHL<SDK<C@J;c8H<3<I<C@J<SDK
<SDK<C@J<3<I<3<I<SDK<SDK<C@J<3<I;S4G;2lE:RdC:B`B:2dB:bd?;Rl?;Bd?:2TI6b4V3QTd1QHk
724`8BPS:BlF;S4A<RhE<R/G;b/C;R`>:R`?:R/A:BX@:2P@9bL?9RD@9RDA9B@@7b0<9BHB;BlI=3@L
=cDM=SDK=S8I=C8F=C4I=30H=30H=30H<blG<blG<RhF<RhF;bhD;RdC;R`D;b`G;b`G;BTF:BDB9B4?
8bD?:R`F;bhI;B`G;R/F<RdH<B`G;bPD:2P@9bL?9RH>9BD=92@<92@<9BD=9BD=9bLG8R<C820B71l@
4AD91@/00PX02A476aP38b0;:bPC<2dH<c0K>CHQA44/C4TdG5e3H657IFI<J6U?JFY@JV]AJfaBKFiD
J6MCJVUEKFaHKfiJL6mKLW5MMWEQNGQTMWEQMWEQMWEQMWEQMgIRN7MSNWUUNWUUO7YXOG]YOG]YOWaZ
Oge[P7i/PGm]PGm]PX1^PX1^PX1^Ph5_Q89`QH=aQH=aQXAbPX1^PX1^Ph5_Q89`QH=aQH=aQXAbQXAb
QhEcQhEcR8IdR8IdR8IdRHMeRHMeRHMeRH]hR8YgRHUgRHUgRhUgSXYhSh]iT8ajSH]iSH]iSXajSXaj
ShekShekT8ilT8ilU91nTXilT8ajSXYhS8QfRXIdRXIdRXIdPh=[RHM_Sh]bQh9YShQ]/:R;`kRLa;RL
dLJZdLJZd/N[d/N[dlR/dlR/dlR/dlR/d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[dLJZdLJZd/N[d/N[
dlR/dlR/dlR/dlR/d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[d/N[
dLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZ003>alC>alC>alC>alC>alC>
alC>alC>alC>b<?>b<?>alC?b<G?alO@b<W@b<W@b<W=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=
b<O=b<O=b<O=b<O=b<O=b<O=b<O<alK<alK<alK=b<O=b<O>bLS>bLS>bLS=b<O=b<O=b<O=b<O=b<O=
b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O<alK<alK<alK=b<O=b<O>bLS>bLS>bLS=b<O=
b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=
b<O=b<O=b<O=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G<alC<alC<alC<alC<alC<alC<alC<alC>alC>
alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC<alC<alC<alC<alC<alC<
alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC<alC>alC>
alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>
alC>alC>alC>b<7>b<7>b<7>b<7>b<7>b<7>b<7>b<7>alC>alC>alC>alC>alC>alC>alC>alC>b<7>
b<7>b<7>b<7>b<7>b<7>b<7>b<79b;k:bKo:b;k@c/?<bK^j]:MMF4UIE4EVHUMfLVMnNVn9QGZLV8fN
VXn@S869QGZASH:9QGYnNVmeLFI/J5eSGeAIEDYCCdAGDSeFD3eGD3eFCcaFC3]FBCUFAcMEACQGCC]H
CSaHCSaICceICceJD3iKDCmKDCmLD3iLD3iNDT1ODd5ODd5PE49ODd5ODd5RE49QDd5QDd5PDT1ODCmN
D3iND3iND3iPD3mOCciNCSeMCCaNCSeOCciQDD1SDd9KC3UJC3IIBcEJCCMLCS]IC3aEAc]A@SU:B3hh
=BdM6QH50P@200H000P5010:1AX411@30a<10A40010001010A420Q830a<000P000L000P51Q0110`0
0PX010T00PL000X000X000/00@`00@`00Pd00`h00`h000X021@021D0114000/01A801Q<21A<00aL0
0aD00A@00Q<00a4011401Q<021800`L00PH00`L01PX22`l84AD?61`C720R:bPQ:2DS:RLZ;bd^<Bl_
<2hc<C0g=C@];b<d=2Pn?S98AS]=BCi<B3eCCD9JE4U;BSaBDD=JF4eLFU1JF4iJEdmOG5AUHEaKHU]P
If1XKfQaMg9kP7j6RhVAUYFHWIbVZjZ_];>k`;o0aLBm`/6d^KR[/:nUZZV[/ZnQYjJCVIR9SXn7S8n<
TYNEVj:KXJR4SI26Si9oR8]_N7]OJ6]AFUe0BD`b>chU<2hF81XC7A4E70d<4`H<4@P>4a483A0300@0
00<000L00`h02QP242<352T252/042D052T05RX052X05R`36S0162h04bT042/04B`14Rd14Bh14Bh1
4Bh24Rl34c004C@04c<04S<04S<04S424C4143014Bh0530053005300530053005300530053024Rl2
4bh24bh14R`14R`14bX152T04bP052H14RD04B80424042003al3420341h34b014Ah041d04al26RH7
8Bd37bX062<47BL172H072D07bT09301:cL4<3d6<d07;d40;c/0<CX6=CdB;3P0010P9CXe?5DF<d80
62<062816b403A<47BLR>THR>DT==3`>?4@@@Ti8NXI8LWhgDEPY;c@h<cDO?C0Y=b/d<bDi=B<b=b8[
=R8a=b@i>BT[=1lX<A`W;QTY;QT/<A``<Qh`<Qha<Qh_<R8_<R8_<R8^<B4]<20[;QhY;1`X:a/_<aX_
<aX`=1/`=1/`=1/`=1/_<aX_<aXZ;QD]<APa=A`c=ahc=ah`=1//<1LZ;QD^<QT^<QT]<AP/<1LZ;QDX
;1<V:Q4T:0lW<1H[<1D^<1<^;aDZ:Q`P9BPF7c<>6c/H7RTL8ahQ:A8V:PdZ9a8[91<Z9A0X:0XS9PdS
9PdR9@`R90hQ8PhP8@dP80hP80hI7@XN80dS9A4W:1@X:Q@[:a<^;1@`;QH[:QH[:QHZ:ADX9a<W9Q8U
910T8`lT8`lO8@/M7PXM7PXM7@/N7P`M7@dI60XF5@LE6@HK7``P8PlM7``L70XP7P`Q7`dN70XJ6`LK
70PL7@TN7`/O80`O80`O80`O80`I70`G6PXE60T@5@H;4048300<4`HD6`h`;APk>2=8AC1@CCQDDCaI
ET5QGTUXIE1PHdYSITeWJU5ZKEAZKEAZKEA[KUE/KeIdLemdLemdLembLEe`Ke]`Ke]bLEedLemeM61e
M61fMF5gMV9iN6AlNfMnOFV0Of^0OVb1Off1Off2P6j2P6j3PFn4PW24PW22P6j2P6j3PFn4PW24PW25
Pg66Q7:6Q7:4PW24PW24PW25Pg66Q7:6Q7:7QG>7QG>9QgF9QgF:R7J:R7J:R7J;RGN;RGN;RGN:S7V:
S7V:RWR:RWR=RgV@S7ZASG^ASG^>S7Z>S7Z>S7Z?SG^@SWbASgfASgfASgfBSGjAS7f?RW^=R7V;QWN:
QGJ:QGJ:QGJ=SGFCTGV?Rg:4OfJ=QV^k/iKKd;C;_j?AaZ[AaZ[AaZ[Baj_Baj_Baj_Cb:cCb:cBaj_B
aj_Baj_Baj_Baj_Baj_Baj_Baj_AaZ[AaZ[AaZ[Baj_Baj_Baj_Cb:cCb:cBaj_Baj_Baj_Baj_Baj_B
aj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_Baj_AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[A
aZ[AaZ[AaZ[AaZ[AaZX00<g6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lk8`lk8`lk7a<o8aLo7am38bM38
bM38bLg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alc7a/c7a/c7
a/g8alg8alk9b<k9b<k9b<g8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8alg8
alg8alc7a/c7a/c7a/g8alg8alk9b<k9b<k9b<c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7
a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a/c7a<c7a<c7a<c7a<c7a<c7a<c7
a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7
a<k7a<k7a<k7a<k7a<k7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<_6`l_6`l_6`l_6`l_6`l_6`l_6
`l_6`lc7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7
a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8
`Lk8`Lk7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<c;`L[9_lW7
_M3>`lG2]9ZDQeaGB69MCW9_IhJ3Ni2=QIJCRj6NUYfJTY2=QHf:PXJ3NhZ7Ohn<Q96>QXf:PXF2NW]h
L7EbJV5QEEiNDUYHCEUCAUQA@UQ@?e]A@5iA@EiD@UiD@UeC@EaB@5aB@5]A?e]A?eY@?V1D@V5E@f9F
A6=GAF=GAF=GAF9FA65E@fMIAfMIAfIHAVIHAVEGAFAFA6=E@f=E@f1D@V1D@V1D@V1D@V1D@V5E@f9F
A69FA5i@?Ee??5U>>UY>?5a??ee@@5a?@EY<@5QCA4a9>c`g;RXV8AdG61<=4PT43@D02P001`001`00
200020002@002P002P002PT74`L54@D54@D54@023@002@0130D950454045404540864@@84`L;5PX>
6@`@6`002`064`013P4750002`H95`<44PH75@0550044`0340023@0530@83@L<3`T>4@lD4b<X9d56
AEiSHVicLVmdLfQ]K65VIFebJDiCBS4d:b//8cDb:S/e;STa:S<[93`l;30`82d]7CPe9S`g:3Ha8S/d
9DHo<3Hd8S/i9clm:d0m;Sdj;3`i:cdi;Slk<3Lj:cPk;3Tk;cXl<3/l<Sm0=dA5?4U:@DU9@dm?BEEE
CeIFD51@BTY:A4I6@4E5?blb:Bha:3<e;ci2?DmDDemSI6EZKFI[KV1VIF=YJ5eSHU=IF4iDDdiDDdI<
BcY0?aPN6@hF31@K3QLN3a0E1PhB1`lA2`T:20`>3PL<2`@930083`0;4`0=6@0=7@0=7@0=8P0B9`0F
:P0E:`0G;`4K<`0I<`0E;`4>:0<?:`@@;0<>;04<:P0;:`8=;@<=;`0>;`0?<00?<04@<@4@<@8><04=
;`<=;`0C;00C;00C;00C;00C;00C;00C;00C;00@:P0@:P0A:00B9`0B9`0C9@0C9@0C900B8@0B8@0@
800?7`0>7P4>7P8?7`8?7`DB800@7@0?704D8@LM:@TS;`LS;P<O:PLQ:0@P9`0M9P0N9`0R;04Y=@La
?@Xf@`L^?@@d@00`=`<c>@lY=@003R0V?BXcCP/X=`0B7@0I8`DK8@0>5B@h@e]aOF1gQdElOd1jP31]
Md^5TDUcOd1DFBlZ:dLd;a`d8RPb8SHa8SLb8bhd8bPd8RXb8C4`8RTb7RL`72@]6BH/6BX^6b``7Bla
7Rla7RX`7bX`7bX`7bX`7bT_7RL]72H/6bD[6RPZ5bT[62X/6BX/6BX/6BX/6BT[62PZ5bLY5RX/6Bh`
7C0b7c0b7bd_72PZ5bDW52LY5RLY5RHX5BHX5B@V4b8T4B0R3alQ3QdX524X4bDX3bLV4B@S5AdO7a@L
:@dK;PhH7a4L51PP2AdP1b0L2R0J3B0L2AhP0Q/M1a/M1a/L21XK1aXJ21TI2ATI2ATI2@hD0a0F1A@G
1aDI1QLI1AXK1ahP2R@S3QdN3QdN3Q`M3AXK2aPI2ALH21HG1aDF1Q<G118F0a4D114D1A8E1Q4C1`lA
1@`=0`/B0a4H2ADJ2a8G218E1QHF21LG2ADD1QHG1aDF1Q<D114B0Pl@00h?00`=00`=00lA01<E0QPJ
1ahP3BDW52la7SXn:dE9=U5>>EUF@F9OBVQUD6UVDFUVDF]XDfaYE6AWCVMZDFU/DfY]E6Y]E6Y]E6]^
EFe`Eg9`GW=aGgAbH79`GW5_GG1^G79`GWEcHGMeHgMeHgQfI7YhIWajJ7mmJh5oKH>1Kh>1KhB2L8B2
L8B2L8F3LHF3LHF3LHJ4LX:0KX>1Kh>1KhB2L8F3LHJ4LXJ4LXJ4LXJ4LXJ4LXJ4LXN5LhN5LhN5LhR6
M8R6M8^9Mh^9Mh^9Mhb:N8b:N8f;NHf;NHf;NHb>Nh^=NXb<NXb<NXj<NY6=Ni:>O9>?OHj<NXj<NXn=
Nhn=Ni2>O96?OI6?OI6?OHj;O8f:Nhb9NX^8NH^8NH^8NHb9NXb9NXf=MH^9LH5mI8F0Ih9kH9>;K/Jk
WmW=/M35ZM76Z]76Z]76Z];7Zm;7Zm;7Zm;7Zm76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]35ZM76Z]76
Z]76Z];7Zm;7Zm;7Zm;7Zm76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76Z]76
Z]76Z]35ZM35ZM35ZM35ZM35ZM35ZM35ZM35ZM35ZM35ZM35ZM35ZM35ZM35Z@00cLK3cLK3cLK3cLK3
cLK3cLK3cLK3cLK3c/S3c/S3c/O4clS5clO7d<S9d<S9d<S9cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7
cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7c<O6c<O6c<O6cLS7cLS7c/W8c/W8c/W8cLS7cLS7cLS7cLS7
cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7cLS7c<O6c<O6c<O6cLS7cLS7c/W8c/W8c/W8
c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6
c<O6c<O6c<O6c<O6c<S3c<S3c<S3c<S3c<S3c<S3c<S3c<S3c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4
c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c<O4c<O4c<O4c<O4
c<O4c<O4c<O4c<O4blK3blK3blK3blK3blK3blK3blK3blK3c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4
c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4
c/O4c/O4c/O4c/O4c/S1c/S1c/S1c/S1c/S1c/S1c/S1c/S1c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4
cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0bl[0alJlalFkc/c1`;f_OGMZK6MHM6mPPWmjUiB?WY^FVIJA
VYNBU96<Shb7UI:=U96<ViRCXIjIXYnJViRCU96<Shb7SX^6PHJ5NgemKg1/IF=KG5Y?G5M8GEM4GeQ4
HEM5H5I4H5I4H5I4H5I4H5I4GeE3GeE3I5Q6IEU7IEU7IUY8IEU7IEU7I5Q6HeM5IeU7IeU7IUQ6IUQ6
IEM5I5I4I5I4HeE3GEM4GEM4GEM4GEM4G5I3FUA1FE=0F58oFE8oEdlnEd`nEDXlEDTmE4PlETPlEDPj
Ad4^BD8aBTDfBT@i@3/b;RXU6aHC3PT81@H:1PL;1`P<1`P<1PL;0`@800450003100<1@4=0009000;
004?000:000:0PPE0@<>008=004<000;000;000:0009000900D@0`LB00081`TD00081@DA000920HB
0PD=0`L<1PT=2`d>414?5QDA6AXA7A/C8R4G>cX`GeiDP7meShj4RhZ0O7]aL6mUOX5aH65A@40`=c8S
?CHWACX/B3/]BSX]A48`?C/Y>3HT>CDS>c@S>C8Q>S8Q?CDT=C8M>3DP>cPS?SXW?c/Y?SXX?CPY?CPY
@d8]@d8]@T4]?chZ>cTW>3DV>3DV>CHW=S<U=c@V=S<U=34S=C8T?S/]C4TkEeA6AD8cBDPjG5Y?OGab
X:2J][Nc^K^k]KNgX:JQXZRSX:JQX:JQZ[2[/KNbXZRSRi6<E5E;Ce55DEI7CU=4@THj?d<h?cli<c8^
9b/U8RHP6R0K51TG3aDD2Q8B1@hA0P/>00`I0Q8R1QHV11HW0aLY1Q/`1A`b0QT_0A4R0a8U1A@W118X
0@lV00dW0PhZ1A4]018X01<Y0A<Z11@[11@[1Q<]114[1A0[01<X01<X01<X01<X01<X01<X01<X01<X
0A8W0A8W0A8W0A8U0A<T0A<T0QDT0QDT018O0A8O014N010M0PlO0PlO1@lP1@lP0a0N00dK010M1APU
3B<_3RHb2B<_120[1ahV11hU0AhU01hW024[0RTb1Blk23E012Tg2CY4030g138i4R`h00<E:Bi79C1<
228b00lK1QPS1aLN0a0HAUAPT:6^TjNhMInTHI:J>WEo?g^7@GEl@f9S8c0X=SDW83@M:BlL<R/L;bTL
92/L82dO92/L:2LI82/G7BPD7BHB7BHB8BLD9BTF9RXG:2XG8BHG8BHG8BHG8BHG8BHG82DF7b@E7R<D
71hB7AlC7R0D7R0D7R0D7R0D7AlC71hB828F828F8B<G8B<G828F7b4E7R0D7AlC71hB71hB71hB71hB
6adA6A/?61X>5aT=41d?51/<6A/871X86QT;4aLB31DI1a<M21<G31L=41T45AP261D76Q@961H461X0
5AL35AL35AL45AL45AH651@651@651@620l02Q423Q<43Q@341@151H35aT56a`84QD64A@54A@54A@5
4A@541<441<441<43A@531<42Q422a8531872a462@h51``31a033AH93QL:31<631043a<74A<73a45
4aH74A@53A0130l03A014QD65aX;6Qd>:2TE<C<M>cdW@dD_CTdhFEU1I6A<K6aDIV=>JFIAK6UDKV]F
KfaGKFYEJfQCJVMBKW5KKg9LL7=MKW5KJfiHJVeGK6mIKW5KJVQFKF]IL6iLLg5OM79PMWARNGMUO7YX
OG]YOG]YOG]YOWaZOge[PGm]Ph5_Q89`QH=aQH=aQH=aQXAbQXAbQXAbQXAbQXAbQ89`Q89`QH=aQH=a
QXAbQhEcR8IdR8IdQhEcQhEcQhEcR8IdR8IdR8IdR8IdR8IdS8YhS8YhSH]iSH]iSXajSXajSXajSXaj
SHmlS8ikSHekSHekShekTXilThmmU91nShekShekShekShekShekT8ilT8ilT8ilSHYlS8UkSHYlSHYl
ShanT8eoTXn1Ti22RHUaT8ifQH5XU8mfUXmdU8a_`[NKgM6ed<FYd<FYdLJZdLJZdLJZd/N[d/N[d/N[
dLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZd<FYd<FYdLJZdLJZdLJZd/N[d/N[d/N[dLJZdLJZdLJZdLJZ
dLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZdLJZd<FYd<FYd<FYd<FYd<FYd<FYd<FYd<FY
d<FYd<FYd<FYd<FYd<FYd<FY003=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?>b<?>b<?>alC?b<G?alO@
b<W@b<W@b<W=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O<alK<
alK<alK=b<O=b<O>bLS>bLS>bLS=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=b<O=
b<O=b<O=b<O<alK<alK<alK=b<O=b<O>bLS>bLS>bLS<alK<alK<alK<alK<alK<alK<alK<alK<alK<
alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<alK<b<?<b<?<b<?<b<?<b<?<
b<?<b<?<b<?<alC<alC<alC<alC<alC<alC<alC<alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>
alC>alC>alC>alC>alC>alC>alC<alC<alC<alC<alC<alC<alC<alC<alC;a/?;a/?;a/?;a/?;a/?;
a/?;a/?;a/?<alC<alC<alC<alC<alC<alC<alC<alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>
alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>alC>b<7>b<7>b<7>b<7>b<7>
b<7>b<7>b<7>alC>alC>alC>alC>alC>alC>alC>alC=al3=al3=al3=al3=al3=al3=al3=al38akg3
`[S5`kW>c<6o_:i`JUeoNV^7PW>BShZWY9nYYZ6NViJIUY6GU8nKV9>ZYj:b[jZ_[:NSX9^=RXEcL6]Q
GUUKF5=LFEA1ATln@TLi?Chk?3Q2@cU@D41OGTYYIU5NE49OED=PETARF4ITFTQVG4YWGD]XGTaWFdUW
FdUWFdUWFdUWFdUUFDMTF4ISEdETETATETASED=RE49QDd5QDd5PDT1PDT1EDCiEDCiEDCiCCcaACCY=
BCI:AS=8A35@BCQ>AcQ:@SE8?SA5>c55>Bm3=b]2=RY3?2Q2>bQ0>RM1>RTo>B`k=b`g<RTa;bDP7b4P
7b4O7R0M71hH5aTA418:2@/61@L300/50@d000X000`721H111<000h321L10P`20`d51Q0721872186
1a441@l20`d31@l210h000L<3AL000P=2A@70`hG4ah?4A8E5ADL7A/V9R0`;R@g=2Hl=bPm>BLi=2Dk
=RLm>2To>R]1?2e1?2e1?2e1?2dd=B4h=b<o>bQ6?ba3>BM0<R11<B18=RD];1Pf=B4j=R<f<1dh<Qm2
>bQ5?R]2>2I9ABe:ARi=BC5CCSUHDSmJE45HDD1FCciDD3MIECaOFd9TH4QVHDaXHdiZI55[IE9XHE1W
H4mRFdYGD3m:@c93?2]3?2]6?bi5?b`i=B8e<R=5A3IVIE^2PWb>Sh^?T8j>THR>THR<ShJ?TXVIW9>F
VI1bMFa9C4=2?c4l>bdm?Blf>BX/<2@b=B`i>3@^;2//;R8W:AdQ8aLL7Q8I6Q0F5`dC50/A4PT01Pd3
31D74QX54Ad54R075RH862T35BH04AL04a/15B004b0041l03b0042<24bH04A`04Qd0520152445B83
4b<24B4142004bD04bD04bD04bD04bD04bD04bD04bD24bP24bH24bH252D25B@35RD35R<35R<251l2
51l14Ql14Ah342034206424642403A/031X14Ah<7BXA9c<@:3@78Bd272P26R016b817B@07bP08b/0
9c01:cL5;c/1934<>d<0<CH5<cXH<Sh43B4d>e@Z=E4:8c<04Ad75b<74QX741UGHfnZ^/NZ_<fQ^<21
Y:i;O8Y4OXY9PhU:NGHH>BXM<Q`R<QXW;1L[91DU7a8L8aHJ9aTO9QTS8AHH8Q4E7`hD70/D70/I7`hM
810M810M810G70dG70dH7@hH7@hH7@hG70dF6``F6``D5@`E5PdF5`hF5`hF5`hF5`hE5PdD5@`J6a8H
6A0E5PdB4`XB4`XC50/E5PdG60lE5PdE5PdF5`hF5`hE5PdD5@`C50/B4`X;610@60dE60TI5PLG5PPB
5@`<51<74aL64aD95``?60<D5P8G4`PI4PTG5@<G6@0E5`<E5`@E5`@E5PHE5@LE5@LE5@TE5@T:4@@=
50L@5`PC60TD5`LE6@HH6PLJ70P;3`<<40@<40@=4@D>4PH?4`L@50PA5@T:4@883`873P473@883@@8
3@@72`D52@<02P0640@840D32`032@0830493@872`0:3P8:3P8;3`<B5PXO8aLa=BU3Ac]>DTIIFD5P
H4QVITiXIdeVID]UI4YWI4QWI4Q_K5M^JeI^JeI_K5MbKeYdLEacL5]bKeY]L5Y^LE]^LE]]L5Y/KeU]
L5Y`LeecMV1bKf1eLV=hMFIjMfQjMfQjMfQlNFYmNV^3P762Og22Og21OVn1OVn2Og23P763P766Q7:6
Q7:6Q7:6Q7:6Q7:7QG>7QG>7QG>5Pg65Pg66Q7:7QG>8QWB8QWB9QgF9QgF8QWB8QWB8QWB8QWB8QWB9
QgF9QgF9QgF=RgV=RgV>S7Z>S7Z>S7Z?SG^?SG^?SG^=Sgb=Sgb=SG^=SG^@SWbBSWbDT7jDT7j?SG^?
SG^?SG^?SG^?SG^?SG^?SG^?SG^:RG^:RG^;RWb=S7j@Sh6CTXBEU8JGUXR@T7R[ZI6MVH2YY8^i/YNj
/YGAaZ[=`JG@aJW@aJW@aJWAaZ[AaZ[AaZ[Baj_Baj_AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[@aJW@
aJW@aJWAaZ[AaZ[AaZ[Baj_Baj_AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[AaZ[A
aZ[AaZ[AaZ[@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJW@aJT00<g6`lg6`lg6
`lg6`lg6`lg6`lg6`lg6`lk7a<k7a<o8aLo8aLo8aM39a]39a]39a/o8aLo8aLo8aLo8aLo8aLo8aLo8
aLo8aLk7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<_6`l_6`l_6
`lc7a<c7a<g8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLg8aLc7a<c7a<c7a<c7a<c7a<c7a<c7
a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a<c7a/c7a/c7
a/c7a/c7a/c7a/c7a/c7a/k9a/g8aLg8aLc7a<c7a<_6`l_6`l[5`/g6`lg6`lg6`lg6`lg6`lg6`lg6
`lg6`lW3_<_5_/k8`Lo9`/o9`/o9`]3:`m3:`lc6_m;<aM;<aL_5_/W3_<g7`<o9`/_5_/g7`<g7`<g7
`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7
`<g7`<k8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lk8`Lg7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7
`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7`<g7
`<g7`<[5_<[5_<[5_<[5_<[5_<[5_<[5_<[5_=79_<g5^=3:_lg7_:NRVG]hL7ejLYVGSjj[Yk6^ZZn/
Z:FRWZ2MVJJSWjn/Z;Fb[[nn^[Bd[YjRUh65NV5THTA4D34/AbHOA1PGB@01:Q8D<W=hQiNKX:j`/:VY
ZK^i^IbMViVGUXF4P6MTGe9@ATm=@UMCB5YGBEeA?ee@@5e@@5a?@E]>@5U;?eQ9@5M8?d]3=TY1=dU0
=TLn=DHm=4@j<d<i<T8g<cHc:cHc:cDb:S@a:C8_9c4^9S0]9C0]9BHX8RDW8B@V82<U7b4S7AlQ6ahP
6QdO6AlQ6alQ6b0Q61lP5b0O5B4O5B0N4b0N4b<O52LS62DR6R8O6R0N7A/J70l@50442@023@023@02
3@003000308030@030@0300130023@023@023@433P823P823P<33`X70Pd;0a<@21XH3RDP5blY7SD_
93Pb9Cle93le940f9D0f9Cle93hd8cdc8S`b8D4g9D4g9D4g9D0f93le8cdc8C/a7cX`7S`f8c`f8c`f
8c`f8c`f8c`f8c`f8c`f8cdg93dg93dg93dg93dg93dg93dg93dg940k8THo9Ti7;UU?=eeA>EU==Ea>
=f5C?6MI@fYLAV]NB6]PBVUQBVUSC6]WCfaZDW5XE6mVDVaSCfYQCFIMBEmF@UI=>E17<d@o:T0k9SD`
6b8N2aDC0AXH1R/[6cdm;Clo<Chn<3`l;SPh:S<c9B`/7RLW6B@T5QlK42<Q5QdO4aTM4A/M4ATG31lI
3S8X7RHN7R4J5a`I4AhN4R@T5RHX72DV7B0R71XJ6QDG60hA5@L=508;5@@=6`@A8@HB90XE8`<>700:
600<6P0>7P0<700<700?7`0=7`0>804A8P<C908D9@4E9P4E9P0D9@4D8`4D8`4D8`0C8P0C8P0C8P0C
8P0C8P<E9P8D9@0B8`0A8P0@8@0?800?800?808@8P4?8@0>800>7P0?700?700?6`0@70D?6@4=5`0?
60@G7`LN9PPR:@8O9P0J8@0E6`0F700I7`0M8`0Q:@0V;@0Y<P0/=0Pe@P8i@P0b>`/j@S18E0/A7QHH
8bT_>PhO:0@E7P0:4@DG7PTI7eARJ<kHgkc5bHN[]E>3Sd21T35iRSilS4M_Nal]<aPC5A<H2A<H2A@I
2QDJ2aLL3AHK31<H2A0E1Q@H3A<G31<G318F2a8F2a4E2Q4E2Q4E2QXJ31DE1a@D1QTI2aTI2a<C1A<C
1APH2P`=2@h?2a4B3Q@E4ADF4QDF4Q@E4A<D40X;2@l@3Q<D41<E3`lB2@hB1a<G2aPM3Q@H3A8F2a<D
2Q@E2aPG3AXH3QTG3ALE2a<F1Q<F1Q@G1aDH21HI2ADH21DH21@G1a/K2a`L31dM3AdM3AdM3A/K2aTI
2APH21lO3b0P424Q4B4Q4B4Q4AlO3adM3A/K2aPH21@D11DE1ATI2APH1Q@D0QPI1B0Q3ALH3Q<D2Ph?
1@d>10h?1A0A1`l@1Ph?1@`A0PP<00D900H900X<1P/<20T:20H61PD=0`L<0`L=0PL;00T<00`?01<E
0QLI1S8c6CXk8DM8;U=D>U]L@V1QAfAUBfIWCF5SAF9TAVAVBFIXBfMXCVQXD6QXD6QXD6a[Efe/F6i]
FFm^FVm^FVi]FFi]FFe/F71_Fg5`G79aGG5`G71_Fg9aGGEdH7QgHgYgJ7YgJ7YgJ7YgJ7]hJGejJgml
KH1mKX:1KH60K81oJgmnJWmnJX1oJh60K8:1KH>1KhB2L8N5LhZ8MXV7MHF3LHF3LHN5LhF5MhJ6N8N8
N8N8N8N8N8N9MXJ8MHJ8MHR:MXJ8M8:4LI6AOh61Ki2>O8^9MhR6M8f;NHb:N8^9Mh^9Mhf;NHn=Nhn=
Nhn=NiBAPY:?P9:?P9BAPYNDQINDQI:?P8f:Ni2>PhZ8OHF3N8F3N8Z8OHj<PHj<PHf;P969PXn:QiJF
UZNZ[[Nk`<35b<S<cM7Cdl2m]L[7/[bhULW0W]S9[m2oZ]?7Zm;:YM?9Zm?9Zm;8Z]77ZM77ZM36Z=36
Z<o5Ym77ZM77ZM77ZM77ZM77ZM77ZM77ZM77ZM77ZM77ZM77ZM77ZM77ZM77ZM77ZM77ZM;7ZM;7ZM;7
ZM;7ZM;7ZM;7ZM;7ZM;7ZM76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76
Z=76Z=76Z]76Z]35ZM35ZM35ZM35Z@00cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3c/O4c/O4c/O4clS5
clS5clS5d<W6d<W6clS5clS5clS5clS5clS5clS5clS5clS5c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4
c/O4c/O4c/O4c/O4c/O4c/O4c/O4c/O4blK3blK3blK3c<O4c<O4c<O4cLS5cLS5cLS5cLS5cLS5cLS5
cLS5cLS5cLS5cLS5c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4
c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O6c<O6c<O6c<O6c<O6c<O6c<O6c<O6cLS5cLS5cLS5c<O4
blK3blK3blK3b/G2cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3dL_4clW2c<JobL>la/2ial6jbL>lblFn
c/S1dL_4d<[3c<JoclW2eLo8eLo8clW2cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0
cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0c/S1c/S1c/S1c/S1c/S1c/S1c/S1c/S1
cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0
cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0blJmblJmblJmblJmblJmblJmblJmblJm
cLFhc<JidL_0al>hYZ6HQX=kRhV1YZ>N/[2_][Bc]K>b[J^ZZZRW/Jn^^[Rg_kfl/k6a]kRd^Kbc[;6X
SY6?HV=]=cE;7QTh008Z008T;318UI^V_/;7d]CEa<C4a/G7dM;@b<W7/[6]Ti>=NgUaJVQNF5I<BdTn
@cX]@cX]@ST/@CL]@3D]?S<[?30Z>blY<B`S<B/T<2XS;bTT;BHS;2DR:b<S:b<S9B@P92<O92<O8b8N
8R4M8B0L8B0L81lK7QlK7QlK7AhJ71dI6Q/G6AXF61TE61TE71dK71dK6a`H7A`H7Q/F7A/C7Q/C7Q/C
7QX?7adC81dE7AXF6aTH61LI3PlC10@:00@=00@=00@=008<008<004;004;0@0:00D<00H=0@L>10L?
1PTA20XB2`XC30/D9b@O:BLO;BXR<2hT=2lV=S0U=S0U=BlR?cDT?cDT?cDT?S@S?S@S?C<R?38Q?38Q
>S0N>S0N>c4O>c4O>c4O>c4O>S0N>BlM?3HS?3HS?3HS?3HS?3HS?3HS?3HS?3HS?3HS?3HS?3HS?3HS
?3HS?3HS?3HS?3HS?3LN?STPASlVD4H^DdTaETXbG50hIEM0J5Q1J5Y3JUa5JUi6J5i6If17J6=:JfI=
LV]BKVM>JfA;J658If17IEi5HU]2GePoH5Y3G5M2DdhiAD4^>CLU>cTWADDeD510>SX/>CT[=cLY=SHX
=CDW=CDW=SHX=SHX<S0U:R`P9RXN82LJ7B4E:b/OBDDjIEaBN75^NWA_OWabR8MiTY:4VI^?WIjEWYjH
TiBB[[6_V9fLB4e@210G00TA00`F000<0``I00/G0PhJ1A8P11@Q00lO010P0a<S00hP00hP0Q0R0Q8S
0A<T0Q@U01<T01<T0Q8R0Q8R0Q8R0Q8R0Q8R0Q8R0Q8R0Q8R11@U0a<T0Q8S010Q00lP00lP00lP00lP
0@lQ0@lQ00hP00hN00lL00lL00lK00lK1@lI0@dG00lH0aHN21dU1b4X0QhU01TP11`R11`R0QlT0B4W
02D]02Xa0B`e0Blg02`g02li02hg2SQ0;TMA10XG1PPC4QPS11HM21XQ01<J1QTP2b4WHgUn/LG:VJfb
GhJ?AWR4>7V8<7R9?h2?BGJ1;41551PI6Q`@5QP<4A<73Q043Q044A<75AL;5aT=4AD:4AD:4aL<51P=
5QX?61`A6AdB6AdB4aD93a453a4551H:51H:418641865AL;3a0<3Pl;2``81`P40`@0004000400040
0@801PL32``82`d720/22@d23A454QH:5AT>4aL<4aL<5QL=6QT?71/A71X@6aT?20/02`h041<35QT9
71l?8B@D92LG9BPH>CTY?Sh^AdLgDU92GEe=IVIFK6aLKfmOO7a/PX9bR8QhQHEeLg=SEeM7>3PX9BDE
;RhL:2PF9bLE:2PF8b@@6AX64a@051D130l03Q4241<441<43a833Q423a8341<44aL;3Q862@d11@T0
10P010L00`H00`H000@01PX051H:8RDF<34Q?Cd[B4TeCe0lFEY0GUm5HfA:IVM=IVM=I6E;HfA:HfA:
J6Y<JF]>Jfe@K6eCKFiDKViFKVeHKFaGJFQDJFQDJVUEJfYFJfYFK6]GK6]GK6]GL6mKLW5MM7=OMGAP
MGAPMgIRNWUUOGaXO7YXO7YXO7YXO7YXOG]YOge[P7i/PGm]OGaXO7]WO7]WO7]WOGaXOgiZPH1/PX5]
PGm]Oge[Oge[PGm]Q89`QXAbQXAbQXAbQXIdQhMeR8QfRHUgRXYhRX]gRhahRhahR8YdRH]eQXMcS8ei
RHQdShekRhUgRhUgSXajSH]iS8YhSH]iShekT8ilTHmmTHmmShj0SHanRhYlRXUkRXUkRXUkR8MiQhIh
Q8AhQhMkRXYnS8b0Rh]oR8QlQXIjQHEiPGiiYJBPb<c=dmWNb=7E`/_?dmSIi>[Y`l2hemBoc/ZWd/VW
fLZ`ckjYd<BXbl>Nd/RZd/RZd/RZdLNYdLNYd<JXd<JXclFWdLNYdLNYdLNYdLNYdLNYdLNYdLNYdLNY
dLNYdLNYdLNYdLNYdLNYdLNYdLNYdLNYd/NYd/NYd/NYd/NYd/NYd/NYd/NYd/NYdLJXdLJXdLJXdLJX
dLJXdLJXdLJXdLJXdLJXdLJXdLJXdLJXdLJXdLJXdLJXdLJXd<FYd<FYd<FYd<FYd<FYd<FY003<aL;<
aL;<aL;<aL;<aL;<aL;<aL;<aL;>alC>alC>alC>alC?b<G?b<G?b<G@bLK?b<G?b<G?b<G?b<G?b<G?
b<G?b<G?b<G=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?:aL;;
a/?;a/?;a/?<alC<alC<alC<alC=b<G=b<G=b<G=b<G=b<G=b<G=b<G=b<G;a/?;a/?;a/?;a/?;a/?;
a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/?;a/G;
a/G;a/G;a/G;a/G;a/G;a/G;a/G<alC<alC<alC<alC;a/?;a/?;a/?:aL;<aL;<aL;<aL;<aL;<aL;<
aL;<aL;<aL;=al3<a[o;aKk;aKk;aKk=al3>b<7?bL;>b<7>b<7;aKk9`kc;aKk>b<7<a[o5_kS<a[o<
a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<
a[o<a[o<a[o=al3=al3=al3=al3=al3=al3=al3=al3<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<
a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<a[o<
a[o<a[o<a[o<akk<akk<akk<akk<akk<akk<akk<akk6`;G>b;g>b[nm^:nOW9B?SHFKV9>`[JRc]KJh
^[^g^KZ`/[>^/;6d][Nk_Kjn`<6m^l6m_;ji_;Zc]k:X[J^LX:FATZ2:RIelPYUWKX5XL7fCVJ2LXJBY
[Jj[[Jjb/KFc]KFd][Jd]K>^[jfTXin>RhIYIV5;B4<^:RD^:RD]:B@/9b@Z9B@X8b8V824T7QlM6aXM
6aXM6a/L6QXL6A/K61XK5a`K5a`G61`G61`G61`G61`G61`G61`G61`G61`F5QHF5QHF5QHE5ADE5ADD
51@D51@D51@E5QXE5QXG5QPH5ALH5QHJ5QDJ5QDJ5A8H5@dK610J5a8H5A4F51@F5ALB4AD<2`l43QD4
3QD53A@431<42Q4521041`l41`l53@d83@h:3a0=4A8?4a@C5AHF5ALG5QPT8A`W9Ad^:b<c<BLh<bXj
=2Ti<bPh<RDj<R4i<B0h<1lg;ahg;ahg;ahg;ahg;ahe:aTf;1Xh;Q`j<1hk<Alk<Alk<Alk<Alk=B8k
=B8k=B8k=B8k=B8k=B8k=B8k=B8k=B8k=B8k=B8k=B8k=B8k=B8k=B8k=B8j=1dh<Q/j=1e1>B96>bE9
?RQBABmLCcUSE3YUESaWF3iWFT1VFd1XGD9ZHDI]I4U`JTe/ITUWHDAUGd9WHDAYHdI[IDQ/ITUVH4UT
GTMNFDAGDSe?BcQ<BSQ>C3YACceMGDeHF4Q?Ccm6ASHo?blj>RXh>2Ph>2Ph>b`[<24b>BX_>BTL8a@W
:Q]8AcUGDDAfKFUlMfj9QWREUHFQXY:/[:2c]:Zi^K>h^k:`/Zb//:^RZJIgOghf@4095AL02Ph00``0
10`021833a/241`031X031`24B413Al23R013b414B824R<04R<04R<04B814B414B414B414B414B41
4B414B414B434b@24R<14B8042403b003b003b003b013b413b403R003al041d03a`03a/03a/23QP1
3AL03aP351d66b<67BD272<061l57bD382D38BH292X29bl1:c82;CH2<3P9;c/2<cd0=3/E@4TiCeX7
3AP000/02A803A@;7B@76R4061h58RMVQX]`UIUMPhM@NhADR9@mOXddNX/mOXe5MX0dDED65QDH60`I
6@dK6`lK6`lJ6PhH60`F5PXD50PC5``C5``C5``C5``B5P/B5P/A5@XA5@XO8ADK7A4J710L7Q8J710F
60`E5`/G6@d41P0210000P000P000P031@0620882P@00@000@082P@>40XB5@`H714P91TV:QlP9Q/R
:1dZ;R<g>2i3A3Y?CTAFED]IEde`LfAcMVMiO6f0PgB7RW^>TH:BUHJDUhRIVH^IVH^KVhfLW8jMWHnM
WHnMWHnLW8jGUhVMWHnSXiFVYYRRXYBFUXR8R7YoOg5<CSXm?b/^<1`W:ADU9a<V:1@Z;1P_<AdH6`/L
7`lN8A4J7@dA50@<3`0;3P0=40021P031`042@062`0:400B60LL8PlR:1Dg>2Po@31;CCYGEdEQH4aW
IU5]JUE`KEQUJ4mWJU5YK5=YK5=XJe9VJE1VJE1WJU5VJTeWJU1XJe5YK5=ZKEAZK5IYJUIYJUIaLUi`
LEeaLUiaLUibLemdMF5eMV9fMf=/KEU_L5acM61eMV9fMf=gN6AiNVIkO6QjO6IiNfEiNfEiNfEiNfEk
OFMlOVQmOfV1PVj0PFf0PFf0PFf1PVj2Pfn3Q724QG69RGN5QG>1PFn0P6j3Pg66QWB5QG>3Pg6;RWF;
RWF;RWF<RgJ<RgJ<RgJ=S7N=S7N<S7BATGV?SWV:RGBCTWj>S7Z;RGN@SGj<S7b<S7b;Rg^;Rg^;Rg^<
S7b=SGf>SWj;S8::Rh6:Rh68RGn7R7j9RX2=SXB@THN1Q7^8Rh:?TXVAU8^=T8N;SXF<ShJ>THR5RHBJ
XIja^[fnb]37eM_<f=k0c<jb_;bQWYK:ak;=bJK>aJ?B`jW?_ZWEbJg>aZ7Bb:[AajWAajWAajW@aZS@
aZS@aZS@aZSAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWAajWBajWB
ajWBajWBajWBajWBajWBajWBajW@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@
aJO@aJO@aJO?a:S?a:S?a:S?a:S?a:S?a:P00<c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/g6`lg6`lk7
a<k7a<k7a<o8aLo8aLo8aLk7a<k7a<k7a<k7a<k7a<k7a<k7a<k7a<g6`lg6`lg6`lg6`lg6`lg6`lg6
`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`l[5`/[5`/[5`/_6`l_6`lc7a<c7a<c7a<c7a<c7a<c7
a<c7a<c7a<c7a<c7a<c7a<_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6
`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6aL_6aL_6aL_6aL_6aL_6aL_6aL_6aL_6`l_6`l_6
`l_6`l_6`l_6`l_6`l_6`lc5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/K0^LS2^lc6_m3:`m?=a];<aLk8
`L_5_]3:`m7;a=;<aM7;a=7;a=7;a=7;a<o9`/c6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6
_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lg7`<g7`<g7`<g7`<g7`<g7`<g7
`<g7`<c6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6
_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_lc7_/c7_/c7_/c7_/c7_/c7_/c7
_/c7_/S2]m3<`L_6_Jn/Y9JDS9BAS:2PVZb[Yk:e^KJi_KBg^jf`]:Z]/Jja]K6d^;6d^;Nc_[Jf_;Jh
^KJk^KFk^[>h^jfc^ZZ^^J>/]IJPYiZSYjbb]jZ_/Znb]Zf`]:VY[j>WZ:2TYIbPXIRJVXn?SgMgMeID
E3`j>R8R8R8Q8b8Q8b0O8ahL8Q`J81XG81PE7Q0C5a0C5a0C610C610B6Q4B714B714B70h@6Ph@6Ph@
6PlA6`lA6`lA6a0B710B710B4a0B4a0B4a0B4a0B4a4C514C514C50l>60l>5`l>5a4?5A@@5A@@5AHA
4aHA4aDB3APE4APE4A<A41@B4QPE5aPD6A@@5@hJ7PdI7@dH70dF6P`E6@dC60/A5PdA5PhD3`lE410F
4A@H4aLH51TJ5Q`K5adL61@A31LE3AhK4bDS6B`W7S<]8SD_93H`8cD]73@/6c<[6S8Z6C8Z6C<[6S@/
6c@/6cP^73T_7C/a7cdc8Chd8Shd8Shd8Shd8SXd8CXd8CXd8CXd8CXd8CXd8CXd8CXd8CXd8CXd8CXd
8CXd8CXd8CXd8CXd8CXd8CXe83D`6cD^6SL`73T`73X_6chc7dLi9UQ9;e]<<Ui?=EmB>69E>fII?faO
AG5TBV]VAfQSA6AO@6AO@6IQ@VUTAF]VAf]VAfENAF1J@eeG@5UD?eQC?UEA?U5??Dm=>dY:>TQ8>4I6
=T=3<d51<D10<410<451<C]0<B<Z6b/e9B/f9PhH21HK33<c9C8_8CH`9Cli;4Q5=U5??EEE@eaLCVIU
Ffm/Ih^?PiRLT9nUVZBYX:J]YY>JUEIPFQPQ7PL@50093@042`073`0:500:5P0:600=7@0=7@4>7P8?
7`4@804A8@4A8@0A800A804@804@804@804@804@808A8@8A8@8A8@<B8P8A8@4@800?7`0>7P0>7P0>
7P0?7`0>800>804?8@4@800@7@0?700?6`0>6P4=5`4=5`0?604B6`@G7`@I8@<H800F7P4K8@0L8@0N
8`0Q9`0T;04X<08[=0@]=Q@d?`/f?`@e?A]2BSmDG0/A700330094P0>5@XL8`@J800D6`0K8E=mQ2YL
HRYQITelQ6:HXd5oSc9gR3ajRTAgPCmRI@4L6ALF31TH3Q/J41/J41TH3QLF31HE2aHE2a0F2a4G314G
318H3A<I3Q@J3a@J3aDK40`@1@`@1@dA1Q0D2A4E2Q8F2a<G31DI3Q@F41HH4QXL5R0R72LY8bla:cHh
<SXl=UAFD5YLEV5SGFQ[HVe`IgAgKW]nMH64NiBJSiBJSiBJSiZNTj2QUjBUVjNVW:JUViVLSI^NSifP
TJ2SU::UUZ>VUjBWV:BWV:NWVJJVV:JVV:FUUjBTUZ>SUJ:RU:6QTj6QTinOTIbLSYZJS9^KSIjNT::R
U:FUUi>GOWj1Jf9UCdY==cTk9b/]6B4S41XL2A/P2aTN2A<H0``A00L<00H;00P=00/@00T=0A0E1QXP
3b@Z5bhe83a4;D]D>UEN@eiOBf9TCVUXDfYYE6UVDFMRCFAPB6ANAfEWDFIXDVQZE6QZE6QZE6Y/EVe_
FG1bG6Y]E6]^EFa_EVe_FFe^FVa]FFa/FV][FF][FFYZF6YZF6][FFa/FVi^G75aGg9bH6m_GG9bH7If
I7UiIgUiIgUiIgYjJ7]kJG]mIgYlIWYlIWYlIWYlIW]mIganJ7eoJHJ6M8F5LhB4LXB4LX>3LH>3LH:2
L8:2L8B4LXJ6M8F5Lh>3LHB4LXN7MHV9MhN7MHn>M8j<M8f;Lhb:LX^8Lh^8Lh^7M8^7M8Z:LY2@N8j=
N8B3Khn?OHJ6MXB4MX^;OHJ6NXJ6NXN7NhJ6NXJ6NXN7NhV9OH^;Og]oNH24OXB8PXN;QHR<QXb@RYBH
TYZNV;6e/;>g/[Bh/kBh/kFi];Zn^L75`<O;a/cGe<oKfk[9c8ZLXfEfOe][LU]WKEEPI7mlM;VfXLW5
X/RoWLbmXlnnZMW=/M79Y=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36
Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=36Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=76Z=35Ym35Ym35
Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ylk3Ylk3Ylo4Z<o4Z<o4Z<o4Z000
blC1blC1blC1blC1blC1blC1blC1blC1cLK3cLK3cLK3cLK3c/O4c/O4clS5clS5c/O4c/O4c/O4c/O4
c/O4c/O4c/O4c/O4cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3
bLC1b/G2b/G2b/G2blK3blK3blK3c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4c<O4blK3blK3blK3blK3
blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3blK3
blK5blK5blK5blK5blK5blK5blK5blK5b/G2b/G2b/G2b/G2blK3blK3blK3blK3blC1blC1blC1blC1
blC1blC1blC1blC1c<JoblFnblFncLO0c/S1cLO0b<:ka;jga;jgb<:kcLO0c/S1c<Job/BmcLO0d/c5
blFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFn
blFnblFnblFnblFncLO0cLO0cLO0cLO0cLO0cLO0cLO0cLO0blFnblFnblFnblFnblFnblFnblFnblFn
blFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFnblFn
blFnblFnblFnblFnc<Nnc<Nnc<Nnc<Nnc<Nnc<Nnc<Nnc<NncLRodlk5aL:jYZ>KTXn:UYFAXJ2LXZ>O
[:nc/;>g/;>gZjjbZJb`[:nc[K2dZjjbZJRbYjJ_YJR/Yj^/ZJj_Z:nbYjfbXZZaZK>cXZb/Zk:eZJnd
WZBYTIFJR8bAMWYoF5mRC55D>Ci1:Rda7R4U5aLM4a4G4@lE41<H41<H3a4I3PlI3@hH2`/G20PD1`LE
1@P@1@P@1@LA1PPB1PPC1PLE1`PF1`LG0@@B0@@B0PDC0`HD0`HD10LE1@PF1@PF2P`D2P`D2P`D2`dE
2`dE2`dE2`dE30hF1`LC20PD2PTC2`XD3@XC40`B4@dC4@dB3`d<4Q0?4Q0@3`d=3``>5a8D6A@F618G
3QXL3QXL3aPK3QLJ3aHI41DH3a@G3a@G4AD?4AD?51H@51H@5aLA6QLB6QLB6QLB6aPC6aTA71TA7A/A
8QdD9b4F:bDJ;BLJ<R/J<R/J<R/J<R/J<b`K=2dL=BhM=BhM?C<Q?C<Q?S@R?cDS?cDS?S@R?S@R?C<Q
>S@Q>S@Q>S@Q>S@Q>S@Q>S@Q>S@Q>S@Q>38O>38O>38O>38O>38O>38O>38O>38O=c<Q=BhM<b`K=blN
>2hM=2XI=BPH>2/KA3PPAc/SBclWD48[EDL`G4hgI5HoJUa5I5m0I5m0HehoIF11If93If93IF11Heho
D4T`C4D/BD8YAd4ZAd8]B4<^AD4^@cl/B4HdBTPfCD/iCT`jCT`jC4XhB4HdAT@bADPh8RPG82PG7bTH
3AD482<C@40`@3//<BXK=RlN>CDR=SDP=3<O=3@T?3X`@d4i>3//A4TjCE55DeM;IfiQQH^0SYJ;R925
8b/Z4ATI00P;00D<00TB0P/H0``J10dK00/I0@`J00dK0PlM010M010M010M010M00hN00hN00lO00lO
0A0P0A0P0Q4Q0Q4Q0A4N010M00lL00hK00hK00hK00lL010M00dO00hP0@lQ0A0P0A4N010M00hJ00dI
0@dG00dF00hG0A0I0Q<L0a@M0QDM0A@L01DK01HL01XO01`S0B0Y12D^1RTc22/e3BDa0bL_02@[3S@i
=DQ@1`hG00L>1a<I1QXO1APO0ALM01DL01dU?fif1D196EYR<fYaDHbF?7Z:>GN9AWj?DX2;CG=e534^
51P=4aL<41@93A4631054AD:6QhC8BDJ3aL<4QX?5alD7RHK9BdR;3@Y<SX_=CdbD5A9E5Q=FUiCH6AI
J6aQLGEZMWY_N7aaQHQoR8^2S8n6TIB;UIR?VIbCVYfDVijEXJBKXZFLXjJMXjJMXjJMXjFOY:JPYZRR
WJFJVj>HW::GVj6FWZ:GX:6GWYnEW9fCYJNKYJNKYJNKY:JJXjFIXZBHX::FWj6EVYb@VYb@VYb@VYb@
VYb@VifAVifAW9jBXjFIY:JJY:JJXZBHWj6EVYb@UIN;TYB8Y:ZCWZB=U9V4QX]fLgMTFEa<>Sd^8bHG
82D@5AX52@h01@X031405a`782D@8bPC?D8c@dPiC591DUQ5EEe6FV=9HFY?IW1BG5m6Gf99I6=>IVE@
JFIAJfIAKFQCKfQEKW1MKW1MK6iKJVaIIfUFJ6YGJfeJKW1ML7=MLGANLWAPLWAPLWAQLW=SLG9RLG9R
JfaLJfaLK6eMKFiNKVmOL75QLG9RLW=SM7EUMgQXNW][Nga/NW][NGYZNGYZNGYZO7mYNgiXNgiXNgiX
O7mYOH1ZOh9/Oh9/O7e]OGi^OGi^OGi^OGi^OGi^OGi^OGi^MGMTOX1]PhEbOh5^OGm/PH=`Q8IcPhEb
QXM]QXM]QHE]QHA_QXEaQhEcR8IdRHIgQHE]R8YdQhQdQ8EePhIgPHEjOhAkQXZ4O8=lOhIoPhZ3QHb5
Qhj7Ri:;T9N@UIbEZK6`[kNf^<2o_LG4`<S7a<c;bM7@c]KEd=SGc=CCbM7@bm?Bd=SGeMgLf>3OfN7P
cmgK^/c=TJBYIgb4I7J1P96JWJZbYJnfP7ee`;fXd/j[clJTc[nUckjYe/Z^c<BOclFWclFWclFWd<JX
d<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JXd<JX
dLJXdLJXdLJXdLJXdLJXdLJXdLJXdLJXd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FW
d<FWd<FWd<FWd<FWcL:VcL:Vc/>Wc/>WclBXclBX003;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7<aL;<
aL;=a/?=a/?=a/?>alC>alC>alC=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?<aL;<aL;<aL;<aL;<aL;<
aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;9a<79a<79a<7:aL;:aL;;a/?;a/?;a/?;a/?;
a/?;a/?;a/?;a/?;a/?;a/?;a/?:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:
aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aL;:aLC:aLC:aLC:aLC:aLC:aLC:aLC:aLC9a<79
a<7:aL;:aL;:aL;;a/?;a/?;a/?;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7@b/?;aKk7`K[7`K[<a[oA
blCBc<GAblC;aKk<a[o>b<7@b/?<a[o6`;W6`;W9`kc;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;
aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk<a[o<a[o<a[o<a[o<a[o<
a[o<a[o<a[o;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;
aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk;aKk:aKc:aKc:aKc:aKc:aKc:
aKc:aKc:aKc;bKo:akni]ZjNViJAT8bJVIFOX9jMWYbTYZNYZjb/[ZnZ[:f/[Zna/kBa/kB^/;6g^[jb
]KV]/;BZ[k:Y/;>Y[kBS[;2OZ:bKXj9oQhMaMga@EEhk@4TV:c@Y;c@N9BPF7b<A6Qh?5AX=4aX=3aT<
3ALA4AdJ62@41`l41Q041Q041Q431A010Q0000l000h00P`00P`10`d10`h10Q010Q010A410A4000l0
010001010A410A420Q820Q830a<41@l41@l41@l51Q051Q051Q051Q051Q0210l30`l41@l71Q081a0<
2Q0>2Q0?2a071PP;2P`<2`d:1`T;1PP@2`dE3Q4E3Q4841094A4;414;414<414>414?4A8?4A8A4`dA
4`dC4`dE4PdF4`hG4`hG4`hI4`hN6aHL6Q8K610K6@lN6A0T7Q<Y8aP/9QT_:aTa;A/c;ade<Alg<b4h
=28h=28h=28m<b4m<b4m<b4m<b4m<b4k<Alj<1hi;adi<b0i<b0i<b0i<b0i<b0i<b0i<b0i<b0g<Ahg
<Ahg<Ahg<Ahg<Ahg<Ahg<Ahg<Ahd;b0`:a`c;1dh<B8k<R@i;R0f:adf:ad`:AHc;1Th;Q`k<Am2=RA;
?B]CAC=IBcUIDcIJE3MMEcYRG3mUGd9TGT5PFSeLESULDcQJDCIFCcIECSEECcQFDCaGDSeEDCi?BcQB
CS]GDd1IED9FDSm?BcQ6@Rm0?2U2@S8/;Ad]<20d>RT`<b<k>b];ASM6?Blo>RE1?2M2?RHk>B4a<1/^
;1X_;B8d<BTl?S8W:AdR91P^<2@[;B4O8AD_<BE?DDD/<bhI81d630/01PT020l11a801a@01aH021H0
2AL02aT03A/13Q`041d041d041d03Ad03Ad03Ad13Qh23al34203420342013Q`13Q`03A/031X031X0
3A/13Q`13Q`03Al03R013b424B424Ql041d03QX03AT03AH03AH03QL03aP141T141T24AX24AX04AP0
4QT05A/05al56bH782X98bl;9C4251l05b0061d7:Bl`@TT63QD53A@@7R@:8bL05Q/261h06B<9:C@n
K7L=BU@KH6XSIFY0PHY7Pi=7Oi9=OHmBN8A7IVTS>cT`>2hj@SQ8D4IAFDmEGE=FGUAGGeEIHEM^MV]a
NFifOW=mQGZ4S86;ThR@V8fCVi27S8><THR?U8^AUXfGW9>OY9^SZ9nRYijNXYNPY9VSYibVZYnWZj2V
ZYnTZ9fSYibMXIJLX9FKWiBJWIBIViFHVYBGV9BGV9BCWI6CVi2DW96JX9FOYIZUZIjXZInWZ9jLWI>L
WI>MWYBNWiFNWiFNWiFMWYBMWYBVZYnTZ9fQYIZNXYNLX9FJWY>IWI:HW96IWI:KWiBMXIJOXiROXiRN
XYNKWiBIWI::TGb@UX>FW8^JWi2KWi>HW96;SXEnP7YPHe=AE4A1A3@m@317BSYDEdMLGdmMH51RJ5MU
JeYWKEYWKEYUK5MQJ5=OIe1NITmRIDmTIe5VJE=XJEEZJ5I/JUQbKEieL65ZJe]ZJe]XJEUVIeMTIEEU
IUIYJUY/KEe[KEU/KUY]Kea^Kem_L61_Kf5^KV1^KV9aLV9bLf=dMFEfMfMgN6QgN6QgN6QgN6QeMVIg
N6QiNVYiNVYgN6QfMfMfMfMgN6QjO6UjO6UjO6UkOFYlOV]nP6f0PVn1Pg1mOVinOfn0PG62Pg>4QGF5
QWJ5QWJ5QWJ4QW><SW^:S7UoPFiiNfQjO6UjO6UdMV=kOfIkOfIkOVQmOfb0PG64Q7J8R7b:RGn3QgB4
R7F1QWNBV8egOgR;U96;UYB?VIV5TI6;UiNBWYjHY:BLZ:RS[jn/^;Rc_knb_L6g`/Jlal_1c=33c];4
cm?5d=C5d=C?f=_<eMS;e=O=e]W@fMc>em[6cm:ob<^odM:U^;^8Vj>3UZ>R/l2oc=Znb=:[/[^4PGVo
_:OAcJ[@ajGA`ZS?_ZWEbJg;`ik>a:K>a:K?aJO?aJO?aJO@aZS@aZS@aZS?aJO?aJO?aJO?aJO?aJO?
aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO?aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO@aJO?a:K?
a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K<`JG<`JG=`ZK>`jO>`jO?
a:P00<_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`Lc5`/c5`/c5`/g6`lg6`lg6`lk7a<k7a<g6`lg6`lg6
`lg6`lg6`lg6`lg6`lg6`lc5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5
`/c5`/W4`LW4`LW4`L[5`/[5`/[5`/_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l_6`l[5`/[5`/[5
`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5`/[5
`/[5`/[5a<[5a<[5a<[5a<[5a<[5a<[5a<[5a<S3`<W4`LW4`LW4`L[5`/_6`l_6`l_6`l_4`L_4`L_4
`L_4`L_4`L_4`L_4`L_4`Lc6_lW3_<O1^/[4_Lk8`Lo9`/_5_/K0^L_5_/Fo^<Fo^<o9`]K@bMC>am7;
a=3:`l_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5
_/_5_/_5_/_5_/_5_/_5_/c6_lc6_lc6_lc6_lc6_lc6_lc6_lc6_l_5_/_5_/_5_/_5_/_5_/_5_/_5
_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5_/_5
_/_5_/_5_/_5_/_5_/_5_/W4^lW4^lW4^lW4^lW4^lW4^lW4^lW4^kjk/kFbZZ:OVY2@RY6@S9^LVYnP
WYRKVInMW:BRXJNUY:RVYJ^YZ;2^[Jn][:ZXYinTXYnTXifRXiRNXhbBVG9jPEEMI3i8Cb@Y;14E6Q/M
:10C8A@G9@<74PhD6@H=400:3P083`D=50/B6`/?6P<44P0030003@H840H74@L84PL74`L75@H650@3
4`@34`@63P@63P@53`@440@440@44P@44P@34`82408240<34@<34@<34@@44P@44P@44P013`013`01
3`013`013`013`013`013`012`02308430<53@L73@X93@/:3P`;3`<420P93@`;3`T52PT41Ph72Q8;
3Q@;3PH;2PL<2`X<30h>3Pl?3a<A4A@B4QLB4a@C3aDD41LD41TD4AXE4QdF4ahG520G51/H4a/I4A`I
4AdK4B8M52PR5b`V6bhX6b/W5BhZ63<_7CLc8CXf93/g9CXf93Te8c/a7c/a7c`b83`b83`b83/a7cX`
7ST_7CPb7cPb7cPb7cPb7cPb7cPb7cPb7cPb7cH`7CH`7CH`7CH`7CH`7CH`7CH`7CH`7C0]7bhX6bhX
6cH^8CXb9CP_8SP/83T]8B/X6R`Y6bhX6blW6S4X6cL[7cda9D@f:TM09dU2:Di7;UE>=E]D>eeF?E]D
>eUB>D<j7d<j7d<j7d0i83hh8Chh8Clj9D0k9RPT4C0/6C`h9DI2;da8=De9=TY6<dM3<3di9c/i9d=3
<Di@?E1@?T]7=D<k:T0c8cli8T4l8d0m8C/h730^5RHT4R8N4ahK4a4B22LX7R`^8R4Q5B@T63@d:2h^
81HF21dU6aDL5@dB40T>3`<93P022`003@024@054P07500:5P4=6@4?6`0@704A7@4A7@0;6`0<700<
700=7@4>7P8?7`<@80<@800>6P0>6P0=6@0=6@0=6@0>6P0>6P4?6`0<7P0>804?8@8A8@8B7`0@7@0>
6P0<600<5@0=5P0=5P0=5P0<5P4=5`8>60<?6@0>5@0>5@0@5`4@6@8B7PDE8@LH9@PI9P@@700I800O
9A8b=cI9CPP@5`@?4`lP8`DR9P0F6P<I7`8F8ALd@TI`OB=MJA1AGbM`M3EjPd^7Ud1bQS5FJRY5DaX`
=A`^;Ca:?diLDFIdJGZ8OH>AQXJDRHRFRhVGS8^ERHbFRXjHS96KSiBNTYNQUIVSUiZTV9fRVJ6VWJ:W
WYjSVYjSVZ>XWj>XWinTVi^OU9bPUIfQUYnSV:2TVJ6UVZ6UVZ:VVj>WVj:VVZ>WW:BWWZNYXjRYYJVZ
YZVZZ:B^XZ6[WinWW9fUVYjTVInSV9^OU9VMTYnPUZ2QUj6RV::SVJ>TVZ>TVZ:SVJ:SVI6ERY:FRi:F
RiBHSINKT9^OU9nSV:6UVZ>WW:6UVYbPUIRLTIJJSiJJSiRLTIVMTYZPSi^PTIRLT9>FSIJHTZ6RX:NW
YjNVZ9jQTYBGR8V<OHF8NHR;O8f@PHjAPXf@PGZ0KGUoK7QnJgUoKWUoKWQmKWEjJg=hJGImJ7ImJ7Mk
J7AgIg9bI71^Hg1^Hg5_IG1cI75dIG9eIW5dIG5dIG=fIgQkK7]nKg5eHW9fHgAgIgEhJGIiJWMiKGMi
KGMhKW9eIWAgJ7MjJgYmKWYmKWUlKGMjJgEhJGf0LGj1LWn2Lgj1LWf0LGf0LGn2Lh:5MX:4N8:4N8>5
NHB6NXJ8O8V;Oh^=PHb>PXjAPXnBPi2CQ9:EQY:EQY6DQI2CQ8nBPhnCP8fAOX:6LgEiIWEiIWj2Kgb0
KG5eHWMoJ7MnJGIlJGMlKGYnLWj1N863OHB5PG^2LgEnLGIoMIjZY6QeLiBSYIRX[YFW[XfPZ9>V[Y^^
]Ynb^Z:e_JRk`k74c;W<e;g:d[c9dK_8d;c9dKk;dkk;dkg:d[c9dLC@e<??dl??dl7=dKg9cKO3ak2l
`:^g^h2?TXjNY9f_^Z6a`IZY^IFO/9RNZibPZhF2N[NdWlG1W/g4X]?4Z]70ZmG9[Lk6XLg3YLk4Y/k4
Y/o5Ylo5Ym36Z=36Z=36Z<o5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5Ylo5
Ylo5Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ylo4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4
Y/o4Y/o4Y/o4Y/o4Y/o4Y/_0Y<c1YLc1YLg2Y/k3Ylo4Z000b/?0b/?0b/?0b/?0b/?0b/?0b/?0b/?0
c<G2c<G2c<G2c<G2cLK3cLK3c/O4c/O4cLK3cLK3cLK3cLK3cLK3cLK3cLK3cLK3c<G2c<G2c<G2c<G2
c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2b<?0bLC1bLC1bLC1b/G2b/G2b/G2blK3
blK3blK3blK3blK3blK3blK3blK3blK3b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2
b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G2b/G4b/G4b/G4b/G4b/G4b/G4b/G4b/G4
b<?0b<?0bLC1bLC1b/G2b/G2blK3blK3b/?0b/?0b/?0b/?0b/?0b/?0b/?0b/?0b/BmblFncLO0clW2
blFn_KN`ZJ>LVI><TH^4R89kS8IoYInH`;ZcblFnblFnbL>lb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bm
b/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmc<Joc<Joc<Joc<Jo
c<Joc<Joc<Joc<Job/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bm
b/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb/Bmb<>jb<>jb<>jb<>j
b<>jb<>jb<>jb<>j[Z^SWifESX^6QXF1SHj:VY^IVijLUiVIVYNCWibHXYnKXYnKYJ:NZ:FQYJ:NWibH
FV5JBE1=<cPi82H[5AdT4QTR3AHO2a@M6alT0`D?3`lO1`TK418T008=31DI1a4A2aDL0@/B00H?0PPC
1`XH1PTH2`/M4A4S2@/C2@/C2P/E2`/G2`/G2PXH2PXH2@PH1`H?1`H?1`H?1`H@1P@@1P@@1P<B1@8A
0`0?0`0?0`0?0`0?0`0?0`0?0`0?0`0?0@4A000@000@000@000?000?000?000?0049004900<80PD:
1PL;20X;2`X<2`X<0`H;2PX@3PdA2`L<2`H83`P;50/>50/>30d;3@h<4@l>518A61@C71LF7APG7QTH
6QHE6aLF71PG7aXI8a/K9AdM:AlO:AlO924L9B<K9R<K9bDK:B@K:bDJ:bDJ:R@G9B4?:BDC;b/I=C4O
>CDS>CDS>3@R=S8P>c4O>c4O?38P?C<Q?C<Q?C<Q?38P>c4O>38O>38O>38O>38O>38O>38O>38O>38O
=BlL=BlL=BlL=BlL=BlL=BlL=BlL=BlL<BhP:RLI:R@G;bTL=BdP=2/N<bXM=RXN;RdS;B`R;2XP:RDL
:R<J;B@K<BHN=bXR>2lK>S4M?cHRAchZD4LcETdiEdhjEdhjFDhbFU4fG5<hFE8iETlfDT`eDTdhDdhi
>cLT@CdZBDDbD4`iDdllDDdjC4PeB4@aACd/C4DdC4PfCT`jEE4oCDDdBC`/DT8bAd8YBDDYBDLYAT<W
>cTQ;B/I8QhC71H?9BHM824H9B@J;B`R:BTM7adB928G=3<U4QP=5AXA61hI61dL3A4F00@=000>00DD
00@A00DB00PE00`H00hJ0Q0L0A4M0A4M00XK00XK0@/L0P`M0`dN10hO1@lP1@lP0PhJ0@dI0@dI00`H
00`H0@dI0PhJ0`lK00`N00dO0@lQ0a8R0Q8O010M00hJ00`H00`E00dF00dF00dF00/E00/E0`dG1@lI
00XB00XB00XB00TC00/G00`H0PdK0`hL2A<M2B0X22X`7ce2?TiD1PhE00P<1QLJ01hO01@H0QPN010K
7SQ6BG1o<VIf03U9975d8f]c?WV99E9W12<h00hM00064alO11D<2a`C5RLN8C8Y;d0g@eA;FV]RJW]b
QHn3QY24RI>7S9J:T9Z>U9jBUZ2DV::FTIRAUijGVJ2IUYfFVJ2IXJRQXZVRWZFNXJFJWj>HWZ:GWJ6F
WJ6FWj>HXJFJXjNLX:FFWj>GWZ:GWZ6HWj6KX:6MWj2NWIjLTifATYb@TifAUinDWJ>HX:JKXZJKXJFJ
Y:FKY:FKY:FKXjBJXJ:HWj2FW9fCVibBXJFJWj>HWJ6FVinDVinDVinDW:2EWJ6FV9bAVinDWj>HXjNL
Y:RMXZJKWj>HWJ6FUYZ>VinCVYfDTYB>TI:@VYVKWijRWifSWIjDWIjDW9fCW9fCW9fCVibBVY^AVIZ@
W:>>V9n:UI^8Uif<VinCWj>HWj:IWJ2GTij:Uj2<VZ:AW:6BW9jBVY^AW9ZBW9ZBUYV:UYV:UIR9TiJ7
T9>4Si:3TIB5TiJ7SI20SY61T9>3TYF6TiF9U9J:U9F;U9F;Si:3TYF6UYV:VIb=VIb=UiZ;TiJ7T9>4
Si:3T9>4TIB5T9>4T9>4TIB5UIR9VIb=UYN=UYN=UiR>VIZ@VibBWYnEXJ:HXjBJX:>DX:>DWj:CWZ6B
Vij?UiZ;TiJ7TIB5OH5^MWYWJ6aIHfMDM7QURhmlSY9oPHEbNXEaNHA`MX1`M7e`M7abMWagN7ekNGim
JG=WH6]QHFeWW:ZXE6=VTJ>ZV:ZeTZFbRIn[SZB`U:ZfUJ^gUJ^gUjfiW[C0YK_7]LC=/;o8Z[W2Z[W2
[Kc5[kk7[[g6[;_4YK>iY;:hXJneVJN]T9jTS9ZPSifSTj6WZ[VlXK6hVj^gVZViUj>eUIf^W9n^YJFc
THj6^kRSaL6NclJTelR^d;nZdlN[bl>NcL>UcL>Uc/BVc/BVclFWd<JXd<JXd<JXclFWclFWclFWclFW
clFWclFWclFWclFWclFWclFWclFWclFWclFWclFWclFWclFWd<FWd<FWd<FWd<FWd<FWd<FWd<FWd<FW
clBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVclBVbl2Tbl2Tc<6UcL:V
c/>WclBX003=aKk=aKk=aKk=aKk=aKk=aKk=aKk=aKk;a<7;a<7;a<7;a<7<aL;<aL;=a/?=a/?=a/?=
a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?=a/?<aL;<aL;<aL;<aL;<aL;<
aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;9a/;8aL77a<37a<37a<37a<38aL78aL7>alC?
b<G>alC=a/?;a<7;a<7=a/??b<G=b/;;b<39a[k9a[k:ako:ako8aKg6`k_:aLK9a<G9a<G9a<G8`lC8
`lC8`lC7`/?:_l7<`L?=`/C?a<K?a<K>`lG=`/C<`L?2_k_3`;c4`Kg4`Kg6`ko6`ko7a<38aL75^k_9
_ko<`/;=`l?=`l?<`/;=`l?>a<C<akjo^[7Ac<>l]jk7`[W9a;]iM6]PFe9TGEATGE@o>2n;Q7_HdLS3
_;?5_[G8`KS;a<7:`l3:`l39`[o:`l3;a<7<aL;<aL;>aKc?a[g?a[g?a[g?a[g>aKc=a;_=a;_5`;O5
`;O6`KS7`[W7`[W8`k[9a;_9a;_;a[g;a[g:aKc:aKc9a;_9a;_8`k[8`k[;a;_;a;_:`k[:`k[9`[W8
`KS8`KS8`KS>a;g>a;g>a;g>a;g?aKk?aKk?aKk?aKk9`;K;`[S=a;[?a[c@akg@akg@akg?a[c=a[g<
aKc<aKc;a;_;a;_<aKc=a[g=a[gAb;o?a[g<`k[7_[Fo]Zff[JB^YIbYX9NWWhjYX9:/Y9NcZZ2j/jZn
^;70^[G1^[O6^[Rn]Zo9`kS3_kBi/jc@bl[7`<N7OX/P7bPN72PK62PF52LC4R8>41X<4A@;4A0321L3
21L321L621X92A/:2Q`;2Ad<2Qh831L831L831L831L831L831L831L831L<3AL<3AL=3QP=3QP=3QP>
3aT>3aT>3aTB4ADB4ADB4ADB4ADB4ADB4ADC4QHC4QHA3aDA3aDC3aDC3aDE3QDF3QDG3aHG3aH>1`h?
20l>1`h>1`h=1Pd;10/90PT80@P31P/71`d:2`l@410G5A@I61@K61<J610N6APN6APN6APM61LM61LL
5aHL5aHL5aHV7QLV7QLU7AHU7AHU7AHT71DT71DT71DY8ahV81/R71LT6aLW71PX7ATY7ATY7ATW81LW
81LW81LW81LX8APY8QT[91//9A`V7aHW81LX8APZ8aX]9Qd`:B0c;2<d;B@m<b4l<R0k<Alj<1hi;adi
;adi;adj<1hc;Qlc;Qld;b0d;b0e<24e<24f<B8f<B8g<b4e<Alc;Ql`:a`_:A`^:1d_:Ah_:1lZ:Q`Z
:A/Y:1X/:A/`:Qd_:A`_9aX]9AP[:Q`/:ad^;Al_;R0^;Al[:Q`X9aTV9ALX91TY9QP[:1Tb;Q/i=Ae0
?2=6@RE:ARU?AC=AAcEFBcMJCc]NDC]PDS]PDS]PDS]CCSEECSEFCcIHCSIJCSIICCEIBcAIBcACBcAB
BS=ABC9@B35?Ac1?Ac1?Ac1?Ac17@Re6@Ba4?bY1?2Ln>B@k=R4i=1lh<ahg<b0g<b0g<b0c<Al`<20]
;AdZ:Q`Y:A/V:B0P8aXK7ALI6QHH6ADC518>3`d;2`/000@00`P6210<3QH=3QP<31P821@51A402a<1
31@331H43AL73AX83A`931/931/;4A`83QT331H331H53aT54A/441X23QP03QX23QX33a/53aT63aP5
3QL63QD63QD441H23Q@23Q@33aD441H54AL54AL441H31Q@11A0010/01@T01@T010/000X000X000/2
4a`?7RL^>d=MIVl020l83Q<00`P=41l73Qd041d57b/N@T`^GFDNE5/2?48bBU0X?T@H:c896B023AD0
21452Q<731D43Ph641074A474A4641074A4:51@=5aLQ:2//=3@oAdMEGEa[MFmoRX:>VI6GXYRDX9BH
Y9RIY9bGXI^IXJ2NYJRMXjRIWjJLXJBLXJBMXJ:MXZ6OXZ2QXYjQXifQY9^LXIRLXIRLXIRLXIRLXIRL
XIRLXIRLXIRMXYVIWYFEVY6FVi:IWYFMXYVMXYVLXIRNXYNNXYNOXiROXiRPY9VQYIZQYIZQYIZMXIJL
X9FJWY>HW96HW96IWI:JWY>KWiBLY9VPYY^QYibRYY^OXiROX9JOX9JQX9JKWINIViFFV9:EUi6EUi6H
VYBKWINMWiVIWI:JWY>JWY>KWiBKWiBLX9FLX9FMXIJUYj6NX9ZGVI>HVYBNX9ZRY9jPXYbLWYRGWiRG
WiRHX9VHX9VIXIZJXY^JXY^JXY^KXibJXY^JXY^JXY^JXY^KXibMYIjMYIjIX9VIX9VJXIZJXIZKXY^L
XibLXibLXibAVI:EWIJIXYRNYYbQYibPYiZNXYJLX9BMXIFNXYJOXiNPY9RQYIVRYYZSYi^SYi^UZ9VQ
Y9FMX96IW8fGVX^EV8VBUHJ@ThB:RG^9R7Z7QWR5Q7J3PWB0Og5oOW1nOFn2QGIoPW=kOVmlOg1oPW>2
QGJ2QGJ0PgAhPW67U8I6Ed`jD4/gCTYFKFUNM6m@I5m2Cde?G5YQK6V>VIM]NG^:VZ5mSY^?XkB4VJR;
X:n>XK26VJR4UJ:8VJJ:W:N9VJF9VjJ:W:N<WZV=WjZ?XJb?XJb?XJb?XJb8Xjf;Y[2<Yk6<Y[:AZkVF
/;jF[knAZ[Z=Y/2?Y/29WkR0TjQmS9n3Sj6;UJJ?V:ImPX2j]JK@`ZKB`j?>aJ[6`ZW@bJS?`9W@aJO@
aJO@aJO@aJO@aJO@aJO@aJO@aJO?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?
a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K?
a:K?a:K?a:K?a:K?a:K?a:K?a:K>`jG>`jG>`jG>`jG>`jG>`jD00<c4_Lc4_Lc4_Lc4_Lc4_Lc4_Lc4
_Lc4_L_4`L_4`L_4`L_4`Lc5`/c5`/g6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6`lg6
`lg6`lg6`lg6`lg6`lg6`lc5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5`/c5
`/c5`/k;alg:a/c9aL[7`lW6`/S5`LO4`<O4`<Bo_<G0_LK1_/K1_/K1_/K1_/S3`<W4`M3:`lk8`Lc6
_lc6_lg7`<g7`<_5_/W3_<G2_/G2_/K3_lO4`<S5`LW6`/W6`/[7`l[1_/_2_lc3`<g4`Lg4`Lg4`Lg4
`Lc3`<c6`Lc6`L_5`<_5`<_5`<[4_l[4_l[4_l_2_/k5`M37`m37`lo6`/k5`Lo6`]37`m;;`/W2^McE
c<_4^m?<`l[3^W=/He9;@UaCBUmFCD0g;XV0MmW@am;9`=O>aMO>aLS0^LS0^LNo^<No^<No^<S0^LW1
^/W1^/[1^<[1^<_2^Lc3^/_2^L_2^L[1^<W0]lo8_lo8_lo8_lo8_lo8_lo8_lk7_/k7_]39`=39`=39
`=7:`M7:`M7:`M;;`];;`/[3^/_4^lg6_Lk7_/o8_lo8_lo8_lk7_/o6_Lo6_Lo6_Lk5_<k5_<k5_<k5
_<k5_=?:`=?:`=?:`=?:`=78_/o6_<g4^/_2^<c5_<_4^l_4^l[3^/W2^LW2^LW2^LW2^M37_]37_]37
_/o6_Lc3^/W0]lJm]<Bk//W1/<Ro/LNo//Ro]LW2^LO1_<Fn^l6l^LFk^kje//O1^/>n]K2]YKNc/ZNQ
YVaWL0lA6@l@6Pd=6``:7@X86`H75@D840@930044`044`0550845PD55`D55`H45`L560D950D950D9
50D950D950D950D950D950d>60h?6@h?6@h?6@l@6Pl@6Pl@6Q0A6a4@518A5A8A5A8A5A<B5Q@C5a@C
5a@C5aHE6ALF6QPG6a/G71hH7AlI7R4J7b8K81/G71/G71/G71/G71XF6aTE6QLC61HB5a0?4a8A4aLE
5A/I624N6R<P62<Q5b<Q5b@N6B@N6B@N6B<M62<M628L5b8L5b8L5bTS62PR5bPR5bPR5bLQ5RLQ5RLQ
5RHP5B@Q6B@N5b8L5B<K52LM5RLM5RPL5RHJ52HO5RHO5RHO5RHO5RLP5bPQ62XS6RXS6RPQ62PQ62TR
6BXS6R`U72hW7S0Y834Z8CL]73L]73L]73L]73L]73H/6cH/6cH/6blZ6blZ6c0[730[730[730[734/
7C4/7CD`8C<^7c4/7BlY72dW72dW72dV7BhW7RXZ72TY6bTX6R`Y6bh[7C0Z7BhX6bdU62HT6RLU6bPV
72PV72LU6bDS6B<Q5b4O5AlM4b8M52@Q4bXU5S4[63Lb7C`f7clj8D@m:TPo:da3;e56<5M;<eU==E]>
=5]>=59==5=>=EI?=UU?=eQ>=UU==EM;<eM9<UM?>5E==U=;=518<Di6;d]3;4Y2:dU1:TM2;DI1;4@o
:T8m:40k9Slj9Cdh8c`g8SPd8CLc83Lc83@b830`82h^7R/[7BTY6b@W7QlR6A/M5aXL5QTJ5QHG5A8C
4A0A3`T<40H93P852P012@002@012`823P@440012P022`043@064@885@<95P8960<:6@<44P424001
3`034@885@D;608:5`085@H>7`H?7@P?7PP@7@X@6``@6`/@6@`>60884`474P474P884`<950@:5@<9
50884`d<70/;6@L94`452P011P002P444PH9600A70PN:@@H8bDf?ea/L`053@0630hH7`0C60HS:2a9
CTUVJcE?E@<M8`0;4@8L8P@I6`0C5P0<3`052@031`0320862`D83@061@081`49204920081`4920<;
2PD=304920H?30`E4Q4K5ALR6R<^93<o<d1<@5eYGG9nLXRCRiFOVIbTXj6YZJ>Z[J:X[IbQXYbQXYfR
XIfRX9nSWZ6RWZ6SWJ6SWIbQV9bQV9bQV9bQV9bQV9bQV9bQV9bQV9fRVIZOUYJKTYJKTYVNUIbQV9fR
VIbQV9jRUijRUinSV9nSV:2TVJ2TVJ6UVZ6UVYfQUY^OU9VMTYRLTIRLTIRLTIZNTi^OU9^SV9nUVZ6W
W::VVinSV9nPUYjOUJ6PUYbOUY^NUIVLTiRKTYVLTiZMU9bOUYjQV:2TVJ2TVJ6UVZ6UVZ6UVZ6UVZ:V
Vj:VVinRVIVLTiFHSiVLTj:UW:V/XjV/XjJYX9nXWYnXWYnXWYnXWYjWWIjWWIfVW9fVW9fVW9fVW9^T
VYZSVIZSVIVRV9ZSVIZSVI^PUi^PUifRVIjSVZ2UW:6VWJ:WWZ>XWibTWIjVWj2XWZ6YWj:XWJ2TV9fQ
UIZOT:2TV9nSUifQUI^OTiRLT9FISIBHS9>GRh^>OhR;O8F8NHB7N8B7N8B7N8:5MX23M8J5MhJ5MhF4
MXB3MHB3MH>2M8:1Lh:1LhB7N864MGn2Lh23M8>6MhB7N8B7N8:5MWJ0Kh:?PDAEBS=7@Ra3?dQOFdmU
H4=GDSM4@SY8A4mJEh>>RfA`L86AV7Z;V7nCY8BIZ8ZO[XfP[hNJZHBGY8RKZ8bMZXZKZ9:W]Y>X]iBY
^9J[^YN/^iR]_9R]_9R]_8ZV/HbW]HbW]HZT]8^U]HnY^XfV^XNP]7nJ]HFN^8JN]X:G[H6BYhFCYHRE
YHVCY8R;RL>lZm73Y/o0X<RoY<BoY]?:ZM?4WM35Ym35Ym35Ym35Ym35Ym35Ym35Ym35Ylo4Y/o4Y/o4
Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4
Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/o4Y/g2Y<g2Y<g2
Y<g2Y<g2Y<g2Y000c<Bmc<Bmc<Bmc<Bmc<Bmc<Bmc<Bmc<BmblC1blC1blC1blC1c<G2c<G2cLK3cLK3
c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2c<G2blC1blC1blC1blC1
blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1blC1aL6laL6la/:mal>nal>nb<BobLG0bLG0
b<G0b<G0bLK1b/O2b/O2b/O2bLK1b<G0a/2iaKnhaKnhal6jb/Bmc<Joc<Job/BmbLG0bLG0b<Bob<Bo
b<Boal>nal>nal>nd/W5dLS4clK2cLC0c<>obl:nbl:nbl:nc<:kbl6jb/2ib;jgakffaK^da;Zc`kVb
`KZa`[^b`kbc`[^b_kR__[N^_kR_`;V`_[F/^:nVakje^[6X`[V`]jjUJf9ICD@kC44iDdQ0>BhVKfAL
/jRP]Z^S_;6Y]Z^S_[F[_KBZ_;>Y_;>Y_;>Y_;>Y_KBZ_KBZ_[>[_kB/`;F]`;F]`;F]`;F]_kB/_[>[
[:>J[:>JZj:IZZ6HZJ2GZJ2GZ9nFZ9nFZJ2GZJ2GZZ6HZZ6HZj:I[:>J[JBK[JBKY9fDYYnFZZ>J[ZNN
/:VP/:VP[jRO[ZNN]:^N/jZM/jZM/ZVL/ZVL/JRK/JRK/:NJZInEZ9jDYYbBY9Z@X9J<W9:8VHn5Uhf3
U8f4U8f4Thb3THZ1T8V0ShQoSXMnSXMnRH1gRH1gQgieQGacPgYaP7M^OgI]OGA[NgAUN75RMFePL6UP
JfENIV1KGeYGFeIEC4E8@C/lBDA1B4E0=3<_<S0_92<U00030@@<0@<=0P<A0P8B0P8D0@4A004?004<
000B000B000B000B000B0@4C0P0C0P0C0`D@0`D@0`D@0`D@0`D@0`D@0`D@0`D@2``F2``F2``F2``F
30dG30dG3@hH3@hH4@lE4Q0F4Q0F4a4G518H5A<I5Q@J5aDK5QPI5QPI6APJ71TK7AXL81/M81/M8Q/N
7Q/M7Q/M7a`N81dO7a`N7a`N7Q/M7AXL6QDF71LH7a/J8alJ9b4J:2<J:R@I:R@G:R4H:R4H:R4H:B0G
:B0G:B0G:1lF:1lF:B<F:28E:28E:28E9b4D9b4D9b4D9b4D8AlD81hC8AdB8QhC9AlD9ahD9A`B8QT?
9AhE9AhE9AhE9AhE9QlF9b0G:B8I:B8I9AhE9AhE91dD91dD9AhE9QlF9b0G:24H<RTK<bXL=B`N=RdO
=RdO=B`N=2/M<bXL<bdP<bdP<bdP<bdP<bdP<R`O<R`O<R`O=2hQ<bdP<B/N;bTN;RLN;BHM;BDN;RHO
92@H8b<G8b<G9B<H:BDJ:BDJ:B<H9b4F7a`G7a`G7Q/F7Q/F7AXE71TD6aPC6aPC5a<>61@?71H?7aXA
9AlB:b@E;RLF<2TH=C0K>C8N?3HO@c/TBT0XCD@YDDH[DTL/CdTbDD/dDddfEdlhFDhhEd`fETTcEDPb
EThgEDdfDd/dD4PaCDD^Bd</BD4ZB40YAT4/AD0[A3lZ@chY@SdX@C`W@C`W@3/V>CDR>CDR>CDR=S@R
<S8R<30P;BdO;2`N8BDJ7b8I7B0G6adG6a`H6a`H6AXH5QLE5ATJ3a8F1`X>0087000600060008000:
00490049000:000;000;004>004>004?000@000@004@0@@C0PLF0PTH0@PG00LE000A000B004B004B
004@008?004>000;00DB00HC00LD00LD00PE00LD00LD00HC000=000?00<>00890006000;1`XI4A<U
01/V5C4l73I2>eANG75i000800076RXa54I2=F9O?F9P83Xj3AXL4aHJ5Q0E2P0600`:00d;0Pd;0`/:
1@/:1@X91PP820P810/81`h;2A0=2A0=20l<20l<2A0=2Q4>4ATB3AH<31D;4Q`@72HJ8B/N7BLJ5b8B
8bdQATm5KgM`R8n:TYVFV9jMW:6RWZ>VW::QW::QWJ:PWJ:PWj>NXJ:NXJ>MXJ>MW:6HW:6HW:6HW:6H
W:6HW:6HW:6HW:6HW:6HVYnFUibCUibCVIjEVj2GW:6HW:6HWZ:GWZ:GWZ:GWZ:GWj>HWj>HWj>HX:BI
W:2EVinDVIfBUi^@Ui^@V9bAVIfBVYjCVZ:GWZBIWjFJX:BIWZ:GWYnEWYnEXJ2FW:2DW:2DW:2DW:2D
W:2DWJ6EWJ6EWZ:FVIfBVIfBVIfBVYjCVYjCVinDVinDVinDXjJMWZ6HVIbCVijEXJBKYJROY:NNXJBK
W:BJW:BJW:BJW:BJW:BJW:BJW:BJW:BJWJFKWJFKWJFKWZJLWjNMXJVOXZZPXj^QXZNNXZNNXZNNXZNN
XjROXjROXjROXjROWJJLWJFKW:BJVj6FV9nBUYZ>U9N8TYF6SI:3S962RXn0R8enQX]lQ8UjPhQiPXMh
PhIgP8=dOH1aOH1aOH1aOX5bO7m`Ngi_PX5cPX5cPh9dQ8=eQHAfQXEgQXEgQhIhQ8MhPhIgPhIgQHQi
QhYkQhYkQXUjQ8MhMgm^OXQkA5A99CTd7C8_=4U6>Ti9<44m9cDa7B/W>4@nMX5nF6ATMhN=PI:OMh^L
NXnNOY>ROiBSNi2ONHjMO96POiBSOY>RNYJWNiNXOIVZOYZ[P9b]P9b]P9b]P9b]PZ>cQ:FePjBdP:2c
PJ2eQ:>hPZ6hO9^bLi6/NYNbP9VcOYF[OI2UOXfPNXRJMhBDPXJ0_[RUd/>Scl2ObL6Ta;nVd/RZd/>L
clBVclBVclBVclBVclBVclBVclBVclBVc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>U
c/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>U
c/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>UcL:TcL:TcL:TcL:TcL:TcL:T003<a;g<a;g<a;g<a;g<a;g<
a;g<a;g<a;g;a<7;a<7;a<7;a<7<aL;<aL;=a/?=a/?<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<aL;<
aL;<aL;<aL;<aL;<aL;<aL;<aL;;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;
a<7;a<7;a<78a;o9aL3:a/7;al;<b<?=bLC=bLC=bLC3`;_3`;_4`Kc6`kk8aL38aL37a;o6`kkFc/OD
c<GAbL;?al3?al3=aKk:`[_8`;W7`[W6`KS3_[Fo^[6k]Zfg/ZVd[jJc[ZFQV8nNUHbJTHRFSHBBRH2@
Qgj?QWf?QWf<OgN;OWJ:OGF9O7B7NW:6NG65N724Mfn0Mff1N6j0MfenMF]kLVQjLFMlLfUnMF]gKF=d
JV1jL6I^I5YgKF=gKF==@cU4>S17>c5@A3Xk;bECAcehK69iKF=kKfEbIUa]I5I/HeE[HUAZHE=ZHE=Z
HE=[HUA[HUA/HUQ/HUQ]HeU^I5Y^I5Y^I5Y^I5Y]HeU`IUa`IUa`IUa_IE]_IE]^I5Y^I5Y^I5Y^I5Y^
I5Y^I5Y_IE]_IE]_IE]_IE]_IE]ZHEM]I5YbJEmfKF=hKfEhKfEfKF=dJf5`J5M`J5M_IeI^IUE]IEA/
I5=[He9[He9ZH5IYGeEWGE=TFU1QEdeNE4YLDTQKDDMFCD=EC49EC49CBT1AB3i?ASa>AC]=A3Y=A3];
@SU8?cI5?3=3>S51>2lo=Rdo=Re0>BXm=BPg<BHb;B@^:2<X8b0R7A`M6APQ6R4@318C3a@E51H:30d:
30d<3a<110P00@X00@`00@l00Q420Q@30QH40QH40QH001<001<00180018001810A420A420A410`h1
0`h10`h10`h10`h10`h10`h10`h41@l41@l51Q051Q061a461a461a461a4=3A<=3A<>3Q@@41HA4ALC
4aTD51XD51XE5aLE5aLE5aLG5aLJ61PJ61PL5aPL5aPH61PH61PJ6QXK6a/K6a/K6a/K6a/J6QXI51<L
5a@R71LT7QLV7aHX81<Y8Q<Z8A<Z81HZ81HZ81HY7aDY7aDY7aDX7Q@X7Q@T8A8S814S814S814R7a0R
7a0R7a0Q7PlN7Q8O7A8O7A8R7Q<T81DU7a@T6a4Q60hS7AHS7AHR71DS7AHS7AHU7aPV81TW8AXS7AHR
71DQ6a@P6Q<P6Q<P6Q<Q6a@Q6a@`:1/b:Qde;B0g;b8h<2<g;b8e;B0d;1lb;R<a;B8a;B8`;24`;24_
:b0_:b0^:QlY9AXX91TW8QTV8APU7aPT7QTT7QTT7QTI6Q4H6A0J610K6A4N6a<Q6a@O6A8O5a0J5QDJ
5QDH51<G4a8G4a8G4a8G4a8G4a8C3`hE40lF4@hJ50lL5PlQ6Q4U71<V7A<X914Z9a8`:aHf<1Tk=Ai1
>R54?B98?bA8A2a:ARi?BC9BC3EFCSMGC3IEBSAFBC=@B35@B35@B35@B35?Ac1>ARm=ABi<A2e5@2]5
@2]4?bY3?RU2?BQ0>bI0>bHo>RDj=R<j=R<j=R<g=B<d=2@b<R8_;b4^;R0O8aPQ9AXP8aXM81LM7aTP
8AdO81`L7ATH7A`G71/D61T@4aL:3A441``00@H000H60@X40@X30P/10`d01A001a402AD02QH00a@0
1AD01QH021P02AT02QX02QT02AP052H05RH05bL162L362L45b@462<35b815b<36BD56bL56bL46RH3
6BD46RH56bL:6RX=7R/@8b/@8bP=82D?7RLD8BlI9SHG=d8D=3lN?4LgE5e4GVD26B4L<SQ3EUe:MF`Y
CTH79Ql24`l83``A3@`O4a<]7AhA6A8B6Q<D6a@F6Q@F618C5@lA4@/?3`T@5Q4B61<E6aHF71LD6QDC
6A@D6QDE6aHK9APL9QTO:QXR;AdV<B4/=bLa?2`e@Bm?F4i/MF^<U8fLY9fOYZ6OYZ>PYZFPYZFLXijL
XijMXijMXijOXijQXYjQXifQXifLXIRLXIRLXIRLXIRLXIRLXIRLXIRLXIRLXIRJWiJIWYFHWIBIWYFJ
WiJKX9NKX9NMXIJMXIJNXYNNXYNNXYNNXYNNXYNNXYNKWiBJWY>HW96FVXnFVXnGVi2HW96IWI:HX9FL
XYNNY9VOXiRMXIJMWYBMWYBPWiFJWi2KX96LXI:NXiBNXiBMXY>LXI:LXI:MXIJNXYNOXiRPY9VQYIZR
YY^SYibTZ9fUZIjQYIZLX9FMXIJQYIZSYibPY9VMXIJLY9VLY9VMYIZNYY^NYY^OYibPZ9fPZ9fRZYnR
ZYnPZ9fOYibOYibOYibOYibOYibQYIZPY9VNXYNLX9FIWI:GVi2EVHjDV8f=UH^<U8Z;THJ8Sh:7Rgn6
RGZ5R7V4QgMhNfaiO6ekOVmnPG:0PgB3QWN5R7V6RGZ<Sh29S7f5R7V4QgR3QWN3QWN1Q7EoPW>1P7:2
PG>3PWB4PgF5Q7J7QWR8QgV8QgV3QWN4QgR6RGZ7RW^8Rgb8Rgb6RGZ5R7UiPG1jQ7M8F4dK;2P?924O
=34T>3<N;b/K:BD:618Y=BmZMW1=FUQ[Nh6>X:^0UJAbR9AcR9MbRIQaR9M_R9QaRYYcRiecRieaTJQc
TjYdU:]fUZegUjihV:mhV:mhV:mkW[9nXKEmX;AkWKAmWkN1Xk]oX;YiV[AfU:miV;5iUJedS:9`QYQ`
PY=]OHeWMXI_LVVbZiO>_ikEaJ7@aJW8`JSAaZS?_YO?a:K?a:K?a:K?a:K?a:K?a:K?a:K?a:K>`jG>
`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>
`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG=`ZC=
`ZC=`ZC=`ZC=`ZC=`Z@00<_3_<_3_<_3_<_3_<_3_<_3_<_3_<_3_<_4`L_4`L_4`L_4`Lc5`/c5`/g6
`lg6`l_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L_4`L[3`<[3`<[3
`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<S2^lW3_<[4_L[4_LW3_<S2^lK0
^LFo^<g:`/_8`<S5_LO4_<S5_LK3^l?0^<2m]Kjf[kVaZ[6YXZVQVZ6ITYVARY69PX^3O7A[HW9YH6iU
G6UPEfAKDUmFCEaCBUYAB5iCBeaABEU>AUI;@e=8@597?e97?e97?e51>e51>e51>e10>U10>Tlo>Dlo
>Dlo>Di4>Ti4>Ta2>4Y0=TPn=4To=Da2>4m5>dm3=e=7>e=7>dTm<Dm3=eA8?4Tm<E55>Di0=5Q:?Tdo
<dm1=EI8?5E7>eI8?553=e]A@5]A@5U??UQ>?EQ>?EQ>?EQ>?EU??UU=@EY>@U]?@ea@A5eAAEeAAEa@
A5a@A5E9?EE9?EI:?UI:?UM;?eM;?eQ<@5Q<@5M;?eM;?eI:?UE9?EA8?5=7>e96>U96>Ta3=Tm6>E=:
?EI=@5M>@EE<?e=:?E58>eA:>EA:>E=9>598=e57=U16=E16=Dm5=5=7?E=7?E96?596?596?596?596
?596?4i5>4i5>4i5>4i5>4a3=TY1=4Po<THm<4<j<D8i<48i<44h;d4h;d4h;d8i<48i<3dg:SXd:C@_
9S8/9BdY92PT8b<N7alJ6aHE7`T84PP64P`<6PP95`P95`dA718F8@055P055P045P045P<55`H56@P5
6`T670025`025`045`845P@450D650H650H64P823P823P823P823P823P823P823P823P833@833@83
3@<43P<43P<43P@53`@53`D73`D73`H840P:4PT;4`X<50/=5@`>5PlC510D5A8D5A@F5aLF61XG6AXG
6A/H6QTH6QTH6Q/J71`K7AdL7QdL7QdL7Q`K7ATD4adH5B<M62DO62HO5RLO4RPQ4RXQ4bXP5RXP5RXP
5RTO5BTO5BTO5BPN52PN520O4B0O4B0O4AlN41lN41lN41hM3ahM3ahN4QdM4AdM4B0N4b<O528N4b4K
41hH3AlK5QlK5QlK5QlK5R0L5b4M62<O6R@P6b<O6R8N6B4M620L5alK5QlK5R0L5b0L5bHR5bPT6B/W
72dY7RhZ7bdY7R/W72TU6R<P62<P62<P628O5b8O5b4N5R4N5R0M5AXH3QXH3QTF3QTE41PD3aPC41LB
3aHA414C3A8B318B31HC3QTE41XF4AXD3aPB3AHD51HD51DC4a@B4Q@B4Q@B4Q@B4QDC4a@@3aDA41HB
4ATD4A`E4QdG4R0G4b0G4b0M3R4O3BHR42XV4c4[63H_6cTb7S/e7S`i944l9dE0:d]4<517<e99=EA9
=EA9=De5;Ti6;dm7<4m7<4m7<4i6;de5;Ta4;DE0:d@o:T<n:D4l9clj9Cdh8c/f8CXe83Hb7cHb7cHb
7c@b834a8Bl_7bd]7b`/7R4U6BHZ7RHZ7b0S6QlR6B<U7b<U7alP71TN71/P7Q`Q81XO7QHJ6`hA5@L:
3P852@@010<01@402@@63PH;50PA6`XF80/J8a8/>1@^>QLa?ATe@1Tg@QXh@aXjAA/kAPLa?PXa?`/c
?`hd@14e?a4f?Q4e?A4e>``c>`he?@lf?Plf?Pdd?0he?A4h@1<j@Pd`>PX^=0P[;PX/;0l^;aDb=QXf
?B0hA3MHHBE4CDAQJ5ahOe9/LS]AETYNHc14BA/X80hK4`/F3Q8J4a@K50lA2`d?2ADE3``A20dB2A0C
2Q8E31DF3ADF3ADF3AHD318F41@H4QLK5ALK5AHJ51HJ51LK5ATM5a8L2adW5R8/6a`V5APR4B`f9UMQ
DGb6MYnWWJR`YZng[Jbc[:J]YZ:XXijTWiZPVibTWIbTWIfTWIfTWInSWJ6SWJ6RWZ6RWYbQV9bQV9bQ
V9bQV9bQV9bQV9bQV9bQV9^PUi^PUi^PUiZOUYVNUIVNUIZOUY^PUifQUYfQUYfQUYfQUYfQUYfQUYbP
UIbPUIZNTiVMTYNKT9FISYFISYJJSiNKT9RLTIJNTiZPUIbRUifQUY^OU9bMTibMTinNU9NLSIRMSY^P
TIbQTYfRTibQTYZOT9VNSiZNTi^OU9bPUIjRUj2TVJ:VVj>WW:BXWJ2TVIjRUifQUZ2TVJJZWjV]XZZ^
XjR/XJR^XjN]XZN]XZJ/XJF[X:F[X:BZWjBZWjBZWj6WW9fSV9NMTY:HSHfCR8Z@QHV?Q8Z>PhV=PXN;
P8F9OX:6Ngn3N7f1MWb0MGb2Mg^1MWZ1M7]oLgaoL7f0L821LH21LGenKWioKh62LXF6MXV:NXf>OY2A
PI:CPhV<OHN:NhB7N8>6Mh>6Mh>6Mh:5MX23M8>2M8B3MHB3MHF4MXJ5MhJ5MhN6N8N6N8:5MXB7N8J9
NXN:NhN:NhJ9NXF8NHF8NH26MGZ3MU=QEQ<T80PK61<V8aHW8aDT81TW8@PG3b8_9em[IDAACeUZKI:U
[HZP[7R>VWB<V7B;VWB=WGB>Wg>>XW:@XgBAYW2D[76E[G>G[gFI/GJJ/WJJ/WJJ/WJJ/WbO/gjP]gjP
]g^M]GbN]X2Q^gfM^WNG]7VJ[WVH[GJAYFn7VFn4TgB5TWF5TG>1SF]_Hk2[T]30W=O5X=75ZLO0Ym76
Z=2mV<k3YLk3YLk3YLk3YLk3YLk3YLk3YLk3YLg2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2
Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2
Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<c1Xlc1Xlc1Xlc1Xlc1Xlc1X`00bl>lbl>lbl>lbl>l
bl>lbl>lbl>lbl>lblC1blC1blC1blC1c<G2c<G2cLK3cLK3blC1blC1blC1blC1blC1blC1blC1blC1
blC1blC1blC1blC1blC1blC1blC1blC1b/?0b/?0b/?0b/?0b/?0b/?0b/?0b/?0b/?0b/?0b/?0b/?0
b/?0b/?0b/?0b/?0bL:ib/>jc<FlcLJmcLJmc<Flb/>jbL:icLBka;^b^:nV[JBKYIbCW9>:TXV0Rh9i
LVQQKF=LIeeFHUQAGE=<F4i7DTQ1CD<lDDE1D4A0CT8nC40lBShjB3`hASXfACTeACTeACTeACTeACTe
ACTeASXfAc/gB3`hASLeASLeASLeASLeAcPfAcPfAcPfAcPfACXbACXbA3Ta@SL_@SL_ACXbBd0hCd@l
DdDiGDm3Fde1ETPlFD/oETPlE4HjGU14E48gFDLlG4XoFDLlED<hED<hFDLlFDLlETTkEDPjDdHhDTDg
DD@fDD@fDD@fDTDgCd<gD4@hDTHjDdLkE4PlE4PlE4PlDdLkE4HjE4HjEDLkETPlEdTmEdTmF4XnF4Xn
EdTmEdTmEDLkE4HjDT@hD48fCd4eCT0dBd8eCD@gCdHiDDPkDDPkCdHiCD@gC4<fETXnETXnEDTmEDTm
E4PlDdLkDdLkDTHjCd<iCd<iCd<iD4@jDTHlE4PnETY0Ed]1FU54Fe95G5=6GEA7G5=6FU54F4m2Edi1
C4<jBd8iBD0gAcheA3/b@CP_?cH]?SD/=S0U<BdR;RTP:2@O9B8N81`K6ALG5A8D6a/W4a@R40lS4A4Y
3@hZ1@HR0@@P1PXS0`TV0@PQ00LK00@F0@@C10@F1`DI2P@K0@<K0@<K0PDJ1@LI20PH2@XH2PXF2``F
1PHB1PHB1PHB1PHB1PHB1PHB1PHB1PHB1@H@1@H@1PLA1PLA1PLA1`PB1`PB1`PB0@8<0@8<0P<=0`@>
10D?1@H@1PLA1PLA0PH;10L<1`X?2`/A3PhD4a4G5a<I61@J4a<I51@J5ADK5aLM5aLM5aLM5aLM5aLM
6A@E7QTJ8alN9B4L9AlH91lF:28G:R@G:R4H:R4H:R4H:B0G:B0G:B0G:1lF:1lF8AlE81hD81hD81hD
7adC7adC7adC7Q`B6a`C6Q/B6aTA71XB7Q/C81XC7QPA7QH?71PC71PC6aLB71PC71PC7QXE7a/F81`G
6aLB6aLB6QHA6AD@6AD@6QHA6aLB6aLB6QL?71TA7AXB7Q/C7a`D7Q/C7AXB71TA6aLB6aLB6aLB6aLB
6QHA6QHA6QHA6QHA6AH>6AD@6QHA6QDB6QDD6A@C5a4B5a4B4A8>414=4Q4=51<?6AHB6QDB6A@A5a8?
4a@B51DC51DC51DC51DC51DC4a@B4a@B5A@@5A@@6AHB6QLC71LD7QLD7AHC7aHC71X@7A/A7Q`A8QhC
9b4D:RDF;bPI<BXK<RhK=30M>S@Q?SPU@c`YB3h/BT0^Bd4_C4@]C4@]CDD^CDD^C4@]BT8[AclXAShW
@chY@SdX@C`W?cXU?3LR>SDP>C@O>3<N<RhK<RhK<RhK<2hL;BdM;2`L:BTK:2PJ9BTM;30T;30T92PM
82<J92LN92HP7b4K728M6b4L6AlJ5Q/I51TH4QLF4ADF41@E10<710880@470049008:00D>00HA00TC
00XA00dD014H01@K01PN01dS0B<Y1BL]138j138j23@k2CDl33Hk3SLj3SLj43Li33Lj3STl3cXm3CPk
33Lj3STl53m26TE87TM:7DA67TE3:e5;@VIPGWimMY>GQ9jTQ9nSPijRX[^oRZ6S@eMH9CLh9cLf0Q0?
1`406Q@=7Q`D3Pl63A896b@J51lE00P04QD<4A@;41<:41<:41<:4A@;4QD<4aH=5QL>5aP?61T@61T@
61T@6AXA71dD7b0G5B0<6B<B8bdL=T0`DUa<M7e`Tib?YjnT[;BZZk>YYJfSWJBMVj:KWZFNWZFNVZ6J
W:JJW:JJWJFKWJFKWj>MXJ>MXJ:NXJ:NW:6HW:6HW:6HW:6HW:6HW:6HW:6HW:6HVYnFVj2GW:6HVj2G
VIjEV9fDVIjEVYnFWJ6FWJ6FW:2EW:2EW:2EVinDVinDVinDVIfBV9bAUYZ?U9R=U9R=UIV>UYZ?Ui^@
U9bAV9jCVZ2EW:2EVYjCVibBVibBWYfCUIV=Ui^?VIfAVYjBVYjBVYjBV9b@V9b@V9bAVIfBVYjCVinD
WJ6FWZ:GWj>HX:BIXZJJX:BHWj>GX:BHXjNKY:RLXZJJXJFIWZ:FWJ6EVYjBUi^?U9R<TIF9SY:6SI65
RXj2RHf1QXYnQ8QlPHEiP8AhOh=gOh=gNgeaNWa`NWa`NWa`NG]_NG]_NG]_N7Y^MG]`MGa_N7a`Ngi_
OH1`PH9bPhEbQHEcR8UiRHYjRHYjRHYjRX]kRX]kRhalRhalOh9cOH1aO7m`OH1aP8=dPhIgPhIgPhIg
Q8=eQHAfQHAfQHAfQXEgQXEgQhIhQhIhPXEfQ8MhQXUjQXUjQHQiQ8MhQHQiQXUjQH]jO8=fGfYP4B0L
1QLD3AhK3ahJ4b4M6RTQ3ahF7B/PDEiF@4i:B5YKRijVRZ2/O9BPN92LMHnMN9:RMYBWM9>XLi>ZMIF/
K9:ZKI>[KiF]L9J^LYR`LYR`LYR`LYR`P:>gPZFiP:>gNifdNifeO9jfNIZdLY>]NYVXNYNVMY2NLHZD
MhZBOY2GQI>IQI6ENWe]^kBIeLBMdl:Kb[nQaK^Se<JYelBOc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>Uc/>U
cL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:T
cL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:TcL:T
c<6Sc<6Sc<6Sc<6Sc<6Sc<6S003:`[_:`[_:`[_:`[_:`[_:`[_:`[_:`[_;a<7;a<7;a<7;a<7<aL;<
aL;=a/?=a/?;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<7;a<79`[o9
`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o9`[o>akk<aKc9`[W4_KBm]Zfe
[ZF^YijYXYV?OgR4M6eeIEiYFE9QDDYHB45??cQ8>359?cQ7?CI6?3E6?3E8?SM8?SM7?CI5>cA2<c52
<c53=393=394=C=4=C=5=SA5=S@n;bdo<2i0<Bm1<S12<c52<c52<c52<c50<SA0<SA0<SA0<SA0<SA0
<SA0<SA0<S@n;b`n;b`m;R/m;R/o<2e5=S==?S]CA45B@SEMCD1FASUGAcYLC3mDA3MA@CADA3MKB3]F
@cIPCD1QCT5KB3]NBciOC3mQCT5MCD5LC41JBSiIBCeHB3aGAc]HB3aHB3aDAcUEB3YGBSaHBceIC3iJ
CCmJCCmIC3iHB3]HB3]HB3]HB3]HB3]HB3]IBCaIBCaGAcYFASUFASUEACQC@cIB@SEA@CAA@CA?A3I@
ACMAASQBAcUBAcUBAcUAASQAASQ=?CI=?CI=?CI=?CI=?CI=?CI=?CI=?CI>?cI>?cI>?cI>?cI@@CQB
@cYEASeFAciGC3iICT1KD49MDTANDdEMDTALDD=JCd5KDTUJDDQHCdICBT5>ACa7?SE2>C0n=B`o>c0l
=bhg=2`d<2/`;BTZ:2PT8B<Q7R0D62<C5BL82B<40bD512`002L0024002D:3cH52bh01b800aH000l0
0@l30Q870aH001X00QX111T51QX821P:31L<3AL=3QP<2QH<2QH<2QH<2QH<2QH<2QH<2QH<2QH92Q@9
2Q@92Q@:2aD:2aD:2aD;31H;31H41Q051a451a46218621872A<72A<72A<00P`10`d310h41@l81a4;
1a8=2A@=2A@:2A<;2Q@<2aD=31H=31H=31H<2aD<2aD?3Q8E51HM6a/N71/N6aLM6Q8P7Q@T8QPT7QTT
7QTT7QTS7APS7APR71LR71LR71LM6QDM6QDM6QDM6QDL6A@L6A@K61<K61<I5aHG5A@E4a8G4a8I51<J
5A@K4a<J4Q8F4`lE4PhE4PhE4PhF4`lG510I5Q8J5a<D4@dD4@dD4@dD4@dE4PhF4`lG510H5A4H5A0H
5A0H5A0H5A0G50lG50lG50lF4`hJ5a<J5a<J5a<J5a<J5a<K61@K61@K61@K61<L6ADM6QHN6QTM61TL
5aPK5QPJ5AL@4a4A4Q0A4Q0F51<H5QDK5aHK5QDI51<C510D5A4E5Q8F5a<G61@F5a<D5A4C510E5PdF
5`hH618K61<M6A@L61<M5Q<L5A8L6ADK61@K61@L61<O6A8Q6a@U7QDV7aHX9a<[9a@/:1D`:QLd;Q/i
<Qln=290=RA4?2E5?BI7?bQ8@2U8@2U6?RM4?2E2>R=0>bHo>RDo>RDm>2<l=b8k=R4j=B0j=B0d<1dd
<1dd<1db<1h_;al^;Qh/;1h[:adZ;b0c>2Tb=RXV:QhQ9AXU:1lT9ahM7aTK8Q/I81TF7AHD6QDC61HD
6ALF6aXH7A`>4AD<3a<72Pl21@X000P000L000L000L00@L00`T01@/01P`02@h03A815AX76b08:S0;
:c0=;C8@;c8A<34C<C8D<30D<3089bP::BX::BX79RL592D::BXC<S<L>c`>;B`D<BhO>cD`Bd99H5QW
N7B2T8nAWZ2R][NY_[bFZ:M>G5X44@l00P043PPD6aH^:RDA3@P60`0G5a4K7AL;4P/=50dP:24M7aTL
7QPJ71HG6A<D618B5Q0B5Q0B5Q0K6Q0K6Q0K6Q0J6@lK6Q0N7A<S8QPX9ad/=2<e?Ba<DdAaN6^GWI:/
/JR//:ZTZ::Y[JNY[JNVZj:QYYfSZ9nZ[jJ//ZNZ/:FLYYVLYYVMYIZMYI^OXifQXifQXYjQXYjLXIRL
XIRLXIRLXIRLXIRLXIRLXIRLXIRIWYFLXIRMXYVLXIRIWYFGW9>HWIBJWiJMXIJLX9FLX9FKWiBKWiBJ
WY>JWY>JWY>IWI:GVi2EVHjDV8fCUhbDV8fEVHjFVXnBVXnGWI:IWiBKWiBIWI:JVi6KW9:NWI>FVI2G
VY6HVi:IW9>IW9>IW9>IW9>HVi:PY9VPY9VPY9VOXiROXiROXiRNXYNNXYNHW92FVXjDV8bBUXZ@U8R=
THF:SX:7Rgn4R7b3Qg^1QGUnPWIkOg=hO71fNVieNFedN6adN6aeNFefNVihO71jOW9lP7AmPGEjO71j
O71kOG5kOG5kOG5lOW9lOW9lOW9hO71iOG5jOg1nPG:2Pg>3QG:5QG>5QG>6QWB6QWB5QG>4Q7:3Pg62
PW21PFn1PFmmP75lOg1kOVmmP760PgB3QWN4QgR4QgR3PWB4PgF4PgF5Q7J7QWR8QgV8QgV9R7Z3QWN5
R7V7RW^6RGZ4QgR4QgR6RGZ9S7f;SWimQ7MWLVP@7QX55Q<96QL<6aLC8AdH9alC8aPD8QM6E4U8EU95
EeR7VZ6:X:]oV:9hT9acSYagTjAfUZUcTjY`TZYaU:igVk=hW;AiWKEkWkMlX;QmXKUmXKUmXKV2Xk>3
XkJ1XKAmW;5mW;5nWKAkVK9dTZ]lUj5kUiijTYQhS95jRhioSHalRHMgPX1nP6fn]YSEaI_D`I_;_J36
^Z;Eaj_KaJ;>`jG>`jG>`jG>`jG>`jG>`jG>`jG>`jG<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<
`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<
`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?<`J?;`:;;`:;;`:;;`:;;`:;;`:800<[2^l[2^l[2
^l[2^l[2^l[2^l[2^l[2^l_4`L_4`L_4`L_4`Lc5`/c5`/g6`lg6`l[3`<[3`<[3`<[3`<[3`<[3`<[3
`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<[3`<W2_lW2_lW2_lW2_lW2_lW2_lW2_lW2_lW2_lW2_lW2
_lW2_lW2_lW2_lW2_lW2_kJ_YZnXWj:KTXn8OgUbJF9KDU19@4Ho=U]8@E=0>D`i<TXg<4hk=54n=e4n
=dll=DLk=DDi<d<g<D<g<D@h<T@h<T8f<40d;T<b=D@c=TDd=dHe>4Lf>DPg>TTh>dTh>d8a=4<b=D@c
=T@c=T8a=40_<Sh]<3`[;T8d>T8d>T4c>D4c>D0b>3la=cla=cla=d4a<T8b<d8b<d<c=4Hf=ddm?UM7
B5i>Cei=@6ACAUM6>Ee<?fUHBf5@@em>@Ei=@6QEB5M4=f9?@VEBAEm<?f5>@Ea9?5a9?5i;@ee:@U]8
@5Y7?eU6?UQ5?EQ5?EQ5?E=6>5A7>EI9>eM:?5Q;?EU<?UU<?UU<?Ui=@5i=@5i=@5e<?ea;?U]:?E]:
?EY9?5Q7>UQ7>UQ7>UQ7>UQ7>UM6>EM6>EM6>De2=4i3=Di3=Dm4=U15=e56>597>E97>EM7@EM7@EM7
@EQ8@UQ8@UQ8@UQ8@UQ8@UI7?UE6?EA5?5=4>eA5?5I7?UM8?eU:@E97>EE:?5Q=?e]@@UeBA5aA@e]@
@UY?@EYAB5]BBE]BBE]BBEQ?AUA;@U17?Te4>cdh;cXe;3Hc:c<`:c4];2`Z:RPU9b8Q8aPN:AHJ;0L7
9@0090D2<`X6>PT7>a4@@PhB@PX?=P889@035P003@002`413`H34`0060006@025`<460L75`T;5P`=
5`d?5`l=6@l=6@l=6@l=6@l=6@l=6@l=6@l=6@X;5@X;5@X;5@X;5@/<5P/<5P`=5``=5``>60d?6@d?
6@d?6@d?6@d?6@d?6@d?6@/<6P/<6PX;6@T95`X75PP550T44`T44`<34@@44PD54`D54`D54`D54`@4
4P@44P852PX:414B5Q@D51<A418A3ALD3a`J4QhI61hI61hI61dH5adH5a`G5Q`G5Q`G5QXF5ATE51TE
51TE51PD4aPD4aPD4aPD4aDE5ADC4a4?3a<>3a@?41H@4AP@4AP@4A4>2Q4>2Q4>2Q4>2Q8?2a<@31DB
3QHC3aTF4QTF4QTF4QXG4a/H51dJ5QlL620M6AdJ5A`I51/H4aXG4QTF4ATF4ATF4AXG4QPE4APE4APE
4ATF4QTF4QXG4a/H51/H51LD41PE4ATE51XF5AXE5QTD5QLB51HA4`lA4@lA4A4A4A<C4aPF5Q/F5aXE
5QTC518D3Q@F41HH4QPJ51PJ51LI4aDG4A<E3a8F2aHG3ALH3a/I4A/I4A`H4a`F4A`F4A/I6AXH61XE
5QPD4aTD4A`E4QdG4R0G4b@S3b@S3bDQ3RDQ3RXT4BhW538[63L]6cXb6c`d7D0h8D@l9DHn9dHn9dDm
9T@l9Cdh8cdh8cdh8cdh8cdh8cdh8cdh8cdh8cTe8STe8STe8SLe8cDe9C@d938b934a8bdb8cLl;CHj
;RP/824U6R@W7R<V7A`O5QHN51LO5APO61TP6ATO6QPM6aPM6aLL6a<J7A<H6a0E60hA5Pd?5`l>5a4@
6Q@@6a@C5aDD618C5`l@50/>4P`A51<H6aLN8@8F6`@G70HI70TJ7@XL7@dM70dM70hL6P/M70`N7@`N
7@TK6PLI60dO7QPZ:B8d<a//:BDd<2ln=SI1=cM0=Sa0>TA5@de;BcI4@TYIEBdk=`XD3Q@K5QTP6@86
01PK4PH>1aLN5alV7aTK5A@D3QTF4A`H4aTE41@E4A@E4A<G4Q<G4Q8H4a8H4a<I51<I51/K3a/K3aXJ
3QTI3AXJ3QhN4RDU6BXZ7U9IBWAkK9ZQU:V_Y:>XWibPVZ:VXJfa[:R/YZb`ZZ^`YjJ[XZ:WWZ6WW9nU
VYZPUIbWUibWUifVVIfUVYnTVj6SWJ6RWZ6RX9bQV9bQV9bQV9bQV9bQV9bQV9bQV9bQV9VNUIbQV9jS
VYfRVIVNUINLTiRMU9ZOUYfQUYbPUIbPUI^OU9ZNTiZNTiVMTYVMTYRLTINKT9FISY>GS9>GS9BHSIFI
SYJJSi:JSiJLTIRNTiZNTiVMTYZKTIZKTIfLTYRJU9RJU9RJU9RJU9VKUIVKUIVKUIZLUXfAQXfAQX^?
Q8V=PXJ:OhB8OH>7O8:6Ngf2Lgf2Lgf2Lgf2Lgf2Lgb1LW^0LGYoL7UnKgUnKgQmKWQmKWMlKGMlKGMl
KGMlKG^0LGYoL7QmKWIkK7EjJgAiJWAiJWAiJWmoLGmoLGmoLGinL7emKgemKgalKWalKWUmLGYnLWf0
LGn2LX62LX:2L8:2L862KWemJgemJginK7moKGmoKH20KX61Kh61Kh23M7j1LWaoL7f0LGn2Lh23M823
M7n2Lh60LX:1Lh>2M8F4MXN6N8V8NXZ9Nh^:O8F8NHN:NhR;O8J9NX>6MhB7N8R;O8b?P8f@P7f4Mf]f
K0lM6@@E4PTG5@/J5Q@R7Q<R6Q8R5``J3d1>@e=QFdaNGhVLXhfS[XBMYgZDX7JAWgRFYgZI[WBF[G6D
[W:G/G2EZg:G[G>H[WFJ/7JK/GNL/WNL/WNL/WfLZh2O[WnM[WfK[WjL[h:O]7nL/GZF[WfGWGnHW7nD
UWR<SGN5Q71nNVI`JU]RGG5cGkJ^T=G3V]S6WM32YLRlY=G4ZMO1W/g2Y<g2Y<g2Y<g2Y<g2Y<g2Y<g2
Y<g2Y<c1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1
Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1Xlc1
Xlc1Xl_0X/_0X/_0X/_0X/_0X/_0XP00b/:kb/:kb/:kb/:kb/:kb/:kb/:kb/:kbl>lbl>lbl>lbl>l
bl>lbl>lbl>lbl>lbL2mbl:ocLC1cLC1cLC1c/G2dLS5e<_8akjkb;nlb/6nc<?0cLC1c/G2c/G2c/G2
c/G2d<O4cLC0bKjjb[jhc/>kcL2haKR`_[F[clJle/g3c<>i`KR^]ZfSWiJ<QGabK5UFIU=@GDY7E44n
Cc`iCc`iDSllE44nC3XiC3XiBcThBcThBSPgBSPgBCLfBCLfASXfASTgASTgASPiASPjASPjASLkASLk
@S4d@c8eA3<fAC@gAcHiB3LjBCPkBSTl@S/h@CXg@3Tf?SLd?SLd?CHc?CHc?CHcASXd@SH`@3@`@3@`
@SDc@cHd@38c?Bl`?c4c?c4b@S@eBchlFTi8IU]CIU]CHEM=HEM=HEM=HEM=HEM=HEM=HEM=HEM=HEM=
He95I5=6IEA7IUE8IUE8I5=6He95HU54H558Ge17GDi5G4e4Fda3Fda3Fda3Fda3E4Y0FDm5FU16FDm5
Fe57HEM=HUQ>H5I<He=7I5A8IEE9IUI:IeM;IeM;IeM;IeM;IEY<HEI8G553Fe12G553GeA6H5E7HEI8
FeA3GEI5HEY9I5e<IEi=I5e<HU]:H5U8IV5HHU]BGEI=GeI=I5]BJ5eEJEaDIEQ@FTe5F4]3EdY2F4]3
FTe5Fdi6FTe5F4]3FTi4FTi4FTi4FDe3FDe3FDe3FDe3FDe3HEE;HEE;H5A:Ge=9G516FDe3Ed]1ETY0
@dPiA4Hc@48/@ClW?c/X>CL]<c4a;R`b41Df20dd004d000l00180PIE20aO2@mR1PeT20aC2@Le1@0F
1P092@0@2@0M1@0T000Z004W0@DR2@XN3`lK61<L7AHM7aLN6aPJ61DG5Q<E5Q<E61DG6AHH5Q<E4a0B
3AHJ210G0`TD0PLF0`LJ10DO0`<Q0@0P0P8V004S000O000K0P8J1@HK2`/M3@dO20XB20XB2@/C2@/C
2@/C2P`D2P`D2P`D1@DA1@DA1PHB1PHB1PHB1PHB1PHB1PHB1`L=20T=2PT=2`X<3P/=40/<4@d<4Pd<
50`=5Ph?610A610A5`l@5`l@6A4B6a<D3Pl;3Pl;3a0<3a0<414=4A8>4Q<?4Q<?5@h;5Pl<614>6Q<@
6Q<@6Q<@6A8?614>5@h;6A8?71HA6Q@?5a4:618;81XC9b4J91lF8A`C7aTB7QPA7aTD81TF7aPE7QLD
7QPA7QPA7QPC7AHC7AHC7ADE71@D71@E61LC5aHB5QDA5QDA5aHB61LC5aHB5QDA61DA61DA6AHB6QLC
6QLC6AHB61DA61DA6AHB6AHB6AHB6AHB6AHB6AHB6AHB6AHB61HE5aDD5A<B518A518A518A5A<B5Q@C
61L=6AP>6QT?6aX@6aX@6QT?6QT?6AP>6a/E5aLA5Q<>5Q<>6aLB7ATD7aTD7ALB81XE8A/F8Q`G8adH
9AlJ9R0K9b4L:28M92DE9bHH:bXL<BhP>3@R>cTQ@3hP@D0N=c4J=c<K>C@O>3DP>CDR=S@R<c<Q<S8P
;blQ;RhP;BdQ;2`P;B`R;R`T<2hV<BlW;CDZ;cL]:c<Y82LP6B0I5adH5Q/I4aPF4QXI4a/J51`K5AdL
5AdL5AdL51`K4a/J41/H41/H3aXG3QTF31LD2aHC2QDB2QDB3QHF3ADE31@D31@D31@D3QHF41PH4ATI
4Q`L3aXH2aHD2aHC3QTF41`F41dE3Q/C4R8K3QhG2ATB11@=1AD>31`E5bLP830Y72/S7RdU8C0X9C@/
:CP`;3/c;C`d;Sde:2T]71dQ5ALH5aTI5aXH4aLB4AD?51T@41X=41X=3aT<4A/>4Q`?4Q`?4A/>41X=
5aLG4aHD5QXE6R4J6B4G41X>3aT<4QlA7RHE6B4@5ah?5A`?5A`?:BlTFf5FS968VZ>IVJ:HVJ:HVZ>I
WJJLXJZPYJjTZ;6W[;2[ZZjYZ:bWYJVTXjNRXJFPX:BOWj>NVj:KVj:KVj:KVj:KVj:KVj:KVj:KVj:K
WjJOWjJOWZFNWJBMVj:KVJ2IUijGUYfFVj:KUijGTYVBTIRAU9^DUijGUijGUYfFRYFCSiJCU9RBVibC
X9fHWIbHV9NITiBHWin1WIn2W9b4VI^7UYV9U9R=TIJ=TIF?UYV@UIVCU9VHSYNKR96NOhZNMhFLLX2L
Hh6NH8:OFGjJE7b?IhV?P9Z<RIYiPXaQNgeaQhUmTiF9TiF9RH]oOX1dNgeaOGmcOgi`Ogi`Ogi`Ogi`
Ogi`Ogi`Ogi`Ogi`NWU[O7]]OGa^O7]]NWU[NGQZNGQZNgY/N7MYN7MYN7MYNGQZNWU[NWU[NgY/NgY/
PX9`PX9`PX9`PX9`PX9`PX9`PX9`PX9`PH1bP7maP7maOgi`OWe_OGa^OGa^O7]]Ng]YO7aZOWi/P81^
PH5_PX9`PX9`PX9`Ogm]Ogm]P81^PH5_PX9`Ph=aQ8AbQHEcRHUgRHUgRHUgRXYhRXYhRXYhRXYhRXYh
RHQjRXUkRXUkRHQjR8MiR8MiRXUkS8]mRXaiRXn0Nh=l3QTG3a`N00X>2ADG2a@G3ATM0Pl=2aH><3``
BeI<=48nW:f`Sj2YSZ6`PIRWMiBRLiJTK9>RIHjMJHnQLIFWKHbSKXfTLI2ULiBXMYNZMi^[NIf]NYj^
Qj>dQIn_PI^YOiNSOiJNPiJMPiJKPYFJO8b;O8Z9NHB1LgYeKG1WJ6QLIV=EIf9CZj20^Zn?b[nOd<FU
cL:Rb[nOcL:RdLJVd<6Qd<6Qd<6Qd<6Qd<6Qd<6Qd<6Qd<6Qbl2Pbl2Pbl2Pbl2Pbl2Pbl2Pbl2Pbl2P
cl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2P
cl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pcl2Pc[nOc[nOcl2Pcl2Pd<6Qd<6Q003:`[_:
`[_:`[_:`[_:`[_:`[_:`[_:`[_;`kc;`kc;`kc;`kc;`kc;`kc;`kc;`kc;`[o;`[o:`Kk9`;g8_kc6
_K[4^kS2^KKBbLKAb<G?a/?<`l3:`Kk7_[_6_K[5_;W4^kRl/k32^KGAa/;=`K^o]:c<_kOVfM7Ba[c1
]J^YWI>BQWaoLfU^HUQQED]JCTAIAT5GA3mC@3]??3M=>SE<>CA=>SE>>cI=>cY=>cY=>cY=>cY<>SU<
>SU<>SU<>SU7>3E7>3E7>3I8>3U8>3U9>3]9>3]9>3a:>S]:>S]:>S]:>S];>ca;>ca;>ca;>ca9?C]9
?C]8?3Y7>cU6>SQ6>SQ6>SQ6>SQ5>cA3>C92=c=3>3A6>SQ8?3Y6>SY4>3Q<?T1<?Sm?@D9JCD]XG5Qc
If5cJ61_I5a`IEe`IEe`IEe`IEe`IEe`IEe`IEe`IEeeIe]fJ5agJEegJEegJEeeIe]dIUYbI5Q]H5Q/
GeM[GUIZGEEZGEEZGEEZGEE[GUIfJf=iKVIhKFEdJF5dJF5hKFEiKVIfJf=iK6AjKFElKfMmL6QnLFUn
LFUnLFUnLFUdJf5aJ5i^IE]]I5Y`IeedJf5gKVAgKVAeKf9eKf9fL6=gLFAhLVEiLfIiLfIiLfIdLVQc
LFMgLVUlMfj4OGB5O7=oMVehKfINDTIMDDELD4AMDDENDTIODdMNDTIMDDELD4ILD4IMDDMNDTQNDTQO
DdUPE4YPE4YSEdeRETaRETaPE4YNDTQKCdEICD=HC497B3Q5AC=6@bi4@Ba0?Bhj=c8b<3H[:cTC63l<
4Ch62Sl51dL72e8<4UdA6FHD76T54F<745<523@001H000X1010301`002400Bd41bd<3b/E5bTK72HR
7R@T7R<T7B0L6A/J5aTH5ALI5QPK61XL6A/J5aTH5ALA5ah;41T421<00Q@001D001T001/001/001d0
01`001P001H001@20AD51AL81aL<2aD;2Q@:2A<921871Q061@l510h40`d92AD92AD92AD:2QH:2QH:
2QH:2QH:2QHE5QXF5ATF5ALH5ALG5ADI5A@J5A@I51<B2PXD30`F3PhE3@dD30`D30`F3PhG3`lD4`lD
4`lC4PhC4PhC4PhC4PhC4PhC4PhG40dH4@hI4PlJ4a0J4a0J4a0I4PlI4PlT7QTT7QTR71LP6QDN614O
6A8Q6a@R71DP6a8N6A0M60lN614P6QDQ6aHP6AHO61DN6a<N6a<M6A@M6A@M61DL5aHL5aHL5aHH5a<G
5Q8F5A4G5Q8G5Q8H5a<G5Q8F5A4J5a<K61@L6ADL6ADL6ADL6ADK61@J5a<J5a<J5a<J5a<J5a<J5a<J
5a<J5a<J5a<E4a8D4Q4C4A0C4A0C4A0E4a8G5A@H5QDJ6@lJ6@lK6Q0L6a4L6a4L6a4K6Q0K6Q0M7ALJ
6Q@I5Q4I5Q4M6A@O6aHP6QDO6A@P6Q<P6Q<P6Q<Q6a@Q6a@R71DR71DR71DP818P81@R81HV8QLZ9aT_
:aPc<QPg=ALe<1Lf<1Tf<1Te<1/b;aXa;AX^;1X]:aTY;1dX:a`V:1`T9QXR8aTQ8QTQ8QTQ8A/L91XP
:1hO9adH7aPE6aHH7QTI7Q`H7A/C6aXD71/D71/E7A`E7A`D71/C6aXB6QTB7A/A71X@6aT?6QP=61H<
5aD;5Q@:5A<B6QXA6AT?5aL>5QH<51@;4a<;4a<;4a<?61/<5AP:51@:51@=61H>6AH=61D;5Q<>71P=
6aL;6AD95a<95a<=6aLC8AdI9b<C8a`E9AhH:24K:b@N;RLQ<BXR<R/R<R/B5aP<4A8;4A0A61DE71LD
6aHG7aPL91dI9ATI9ATI9ATI9ATH91PG8aLE8ADC7a<]=34N9B8C6QDF7QLK91XI8aLC7A0?6@`B6@`>
5@PJ8A@m@cQXKFB7S8>EVI>IWINIXIZHX9VGWiRGWiRIXIZLY9fPZ:6RZZ>Y[JRWZjJUZJBRYZ6PY9nP
Y9nPY9nPY9nPYIbPYIbPYIbPYIbQYYfQYYfQYYfQYYfHWIBHWIBIWYFIWYFIWYFHWIBGW9>GW9>GW9>D
VI2BUhjCV8nGW9>JWiJKX9NJWiJIY9bKXiVJWiJLWIBGV9BCUIJ?TI^=T9j5TZ24TIn0SZ1mS9miRJ1e
QZ1cQ9m`PYmJMJ5GM:5DLZ5@Kj9;KJ=6J:=2IJA0IJ=9CJI<DJa8DJ]8DZIKHJYgM:b3N:1nKXelOW:3
QGV9Rgn7RGf0PWIjO71jO71mOg=mO6imO6imO6imO6imO6imO6imO6imO6ikNVamO6inOFmmO6ijNF]i
N6YjNF]lNfekNVakNValNfelNfemO6imO6inOFmnOFn2PW21PFn1PFn1PFn1PFn0P6j0P6j0P6imO6im
O6ilNfelNfelNfekNVakNVakNValO6YmOF]nOVb0P6j1PFn1PFn1PFn1PFmoOfeoOff0P6j1PFn2PW23
Pg64Q7:5QG>9RGN9RGN9RGN9RGN:RWR:RWR:RWR:RWR9R7Z:RG^:RG^9R7Z8QgV8QgV:RG^=S7j;SGZ;
T85lQ7dC7Q`>6ad02Ph74aD:4aH95AT340h>6A4/>2a6DDL^?3RFYjZDYJjBYKB3VZUeTZ5[SIeTR9QP
Q9IRQYQ[S:1aSZ=dTJIiUjYnW:enWjmoX:mmWZelWZ^2W:Z1VJEoUJ1lTIUhRi9dQhYaPhA_OX1cOgU/
MW1RJV=PI5UYJE^0OFjMUXF`ZIJm/Y;5^Y[>`j??a:C:_io7_9c9_Yk=`Z;@`J7@`J7@`J7@`J7@`J7@
`J7@`J7@`J7;`:3;`:3;`:3;`:3;`:3;`:3;`:3;`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?
`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3?
`:3?`:3?`:3>_io>_io?`:3?`:3?`:3@`J400<[2^l[2^l[2^l[2^l[2^l[2^l[2^l[2^l_3_<_3_<_3
_<_3_<_3_<_3_<_3_<_3_=78a<o6`/g4`<o6`];9aM;9aLo6`/_2_[je/Knf//2g/l>j]/Ro^lg4`=;9
aMC;alk5`]78aM37`m35`MC8`]C9`LBg[jfPV9B3NWYYH6IEC69AB5Y9@4Xi<4Dd:d`k<Tll=e0m>54n
>E8o>U8o>U4n>E0m>4ll=d/l>D/l>D/l>D/l>D/l>D/l>D/l>D/l>D`k>4dl>Dhm>Tlm?50n?e4o@58o
@U8o@U96@596@555?e55?e14?U14?Tm3?Dm3?E95@e95@e54@U54@U54@U13@E13@E13@De3?4a2>de2
?Tm4@5=7AEI:B5I:BUE9BEeADEa@D65EEFeQGg]`K8=hM8=iLX5gL85gL85gL85gL85gL85gL85gL85g
L85gL8=jLH=jLH=jLH=jLH9iL81gKWieK7edJgeaJgeaJga`JWa`JWa`JWeaJgibK7mcKGabJh1fKgme
KWecK7idKHEkM8QnMhIlMHElN8ImNHMnNXV0O8Z1OHZ1OHZ1OHZ1OHZ4OHJ0NH9lMH1jLh1jLh9lMH9l
MH9lMH>1Mh:0MX:0MX:0MXB2N8J4NXV7OH^9OgioMH21MhJ5Nh^:P8b:P8N2NGUdJg5ZHFIKCFEJC6AI
BfAIBfIKCFMLCVEJC6AIBemEBemEBf1FC65GCF=ICfAJD6EKDFEKDF9HCV9HCV5GCF1FC5iDBUaBB5U?
AEQ>A59=?U=<>e5;>519>4Y5?44n@3@dA2/]A@D9?P84?P00?`00A@01C047DP<<EP<>F0PHI@PFF0D?
?P048@005@4270<49P02:P81;@L8;Q4B;Q`L;28R:2DS8b@P7b8M71XG6ATF61PE5aTF61/H6Q`I6a/H
6QTF61@F80lA70T:60D55`@260D270D17PD07`837`837@@470D66`P76`T860X:60d:6A0?6@l>60h=
5`d<5P/:50X94`T84PP74@X94PX94PX94P/:4`/:4`/:4``;50`;50`;3@`;3A0>3Q8@41HB4ATD4A/F
4a/F4alH5B4J5b8K628K620I5R0I5R4J5b<L6A`F4A/E41/E41XD3aTC3QPB3ALA31LA320J5AlI51lI
51lI51lI520J5B4K5R4K5R8L5AlI4Q`F3adG424K52<M5R8L5B0J4b4M4R0L4AlJ4B0J4b4K524K5QlI
51dF4ahM4ahL51dK4adJ5AdJ5Q`I5A`H5a`H5aXG4QXG4QXG4QXG4QXG4QXG4QXG4QXG4QTE41XF4A/G
4Q/G4Q/G4Q/G4QXF4ATE41`H4a`H4a`H4a`H4a`H4a`H4a`H4a`H4aLD41LD41LD41PE4ATF4Q/H51dJ
5QhK5alM4b0N524O5B8P5R8P5R8P5R8P5R4O5B4R6AlP5ahL51hL524N5R8O5b<M5R8L5B0M5B0M5B0M
5AlL51lL51hK4ahK4adJ4QTH3QLE3AHC3QLC3Q`G3R8O4BXV4bh/53</4c8[4S4Y4RdW42/V4BXT4BPT
4BPT4B@V6R@V6R<U6B8S6B0Q61hO5Q`L5QXJ50`D2Q4I3a<J4`lF3`hD3a<H5QDJ61@I618J6A8J6A<K
6Q<K6Q8J6A4I60lG5PlG5QLP8aHO8Q@M81<L7a4J7@lH6`hG6PdF6@lG5`lG5`lG5`hF5P`D50/C4`TA
4@P@40XB6@TA60PA5@TB5P/D5`/E5@TC4`LB40LC4`TE5@XF5PXF5PTE5@TE5@/G5`dI6@PI5@TJ5P/L
60hO6`lP714R7Q4R7Q4R7PhI5`hI5a4L6AHQ7QLS7ADQ6aPU7A`Y8A4P61<R6QDT71LV7QTX81TX81PW
7aLV7Q0R6`/L4`/J4Q@R5a`W7AdW6a/S61/R5BT_9456?F=XGh>7PIbPVjV]Z:NZZ9nRX9fSWYfSWYfS
WYjTWj2VXJ>YY:J/YjR^ZJR/YZFYXj:VX9nSWIjRW9jRW:2TWZ6UWiVNUIVNUIVNUIVNUIVNUIVNUIVN
UIVNUIfRVIfRVIfRVIfRVIfRVIbQV9ZOUYZOUY^PUiRMU9FJTI>HSi:GSY2ES8fBRH^@QhbFQXfDQH^?
Ph>6OGQmO7=hPG5hRg5lTUE/Y5A[Xe5ZXTmXX4]VWdMTWDERVdAQVTIVZ4ATYD9RXcePX3aOWSaOWSeQ
WCeQWF5XVFA]Wf9]Wem[VfY`VGamVHR0THMiQ7j1LWj1LWf0LGYmKWMjJgMjJgYmKWf0LGYiJgYiJgYi
JgYiJgYiJgYiJgYiJgYiJgakKGimKgmnL7imKg]jK7YiJg]jK7elKWmnL7mnL7mnL7mnL81oLH1oLH1o
LH60LX20KX20KX20KWmoKGinK7inK7emJgemJg]jK7]jK7]jK7akKGakKGakKGakKGelKWemJginK7mo
KH20KX61Kh61Kh20KX20KWmoKGmoKGmoKH20KX61Kh>3LHB4LXF5LhR8MXR8MXR8MXV9MhV9MhZ:N8Z:
N8Z:N8R7NHZ9NhZ9NhZ9NhR7NHV8NX^:O8f<OXf?O8bAPWn7P1dX9P`I6`093@DA4`L@4`4=4@8?3@`G
3b8^8T5<@RTg<h^LWiNX/INW^8RL[GNAXF^9VV>4Uf21U6J5VVj;X7ZDY7fGYh:L[8FP[XBPZgnKYWRE
WWBAVW26S764Rg23R6ioPVilNfYgMFMbKfEaJf1WFVI[G79cHh5oKIF?O:^TT<>hX];6[/g2X/k3Xlk3
Xlc1XLVnW/RmWLZoWlc1XM31XM31XM31XM31XM31XM31XM31XM31XL_0X<_0X<_0X<_0X<_0X<_0X<_0
X<_0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0
X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<o0X<joWljoWljoWlo0X<o0X<o0X000
bL6jbL6jbL6jbL6jbL6jbL6jbL6jbL6jbl>lbl>lbl>lbl>lbl>lbl>lbl>lbl>lbL2l`kZf_KB`_KB`
`[Vea;^g`[Ve_KB`clK2bl:na;^g_;>_]JbX/JRT[ZFQ[JBPZZ6NZJ2MXYVEWI:>Wi>=Uhb4NFaTEDQ0
HDa4ET4iDchfFdHnG4LoET4iED0hGDQ0DT0iE48kET@mEdDnEdDnET@mE48kDd4jC3djC3djC3djCChk
CChkCSllCSllCSllF4E0F4E0FTM4FdQ5GDU8GdY<H4]=H4]>G598Fe57Fe57Fe57FU16FU16FU16FU16
Ge1>Ge1>H55?H55?H55?H55?H55?H55?Fe=<G5A=GEA@GeIBHUUFI5]HIE]KIUaLIemOIemOKFEUO7Ad
RH9oSHJ3SHJ3SHJ3S8J1S8J1S8J1S8J1S8J1S8J1S8J1S8J1RhR0RXMoRXMoR8EmQhAlQH9jQ85iPh1h
RH1lRH1lR7mkRH1lRX5mRh9nS8=oSHB0RhF0SXR3SXR3S8J1SXR3UHn:VI>>V9:=TXj=Thn>U92?UI6@
UY:AUi>BUY:AUY:ATXn;Shb8RhR4RXN3RhR4S8V5SHZ6S8V5SXj8SXj8Shn9T92:TI6;Ti>=UIF?UYJ@
UYZ?UIV>U9R=TiB:SXf3PH1fLg5WJ6ILKVABK69@Jf5?Jf5?KF=AKF=AK69@JV1>I5Y@I5Y@IE]AIE]A
IUaBIeeCIeeCIeeCHUQ>HEM=HEM=H5I<GUA:G598FU16FDm5F4m1EdlnEThmE4dnBdM2?ca5<3189BQ7
20M?1`EA0`9B001D001D009C00AC00I@0Q5P119J1@e800Hc008Z0`D]0PDb00<d1`H^3@`^5AD]7AdY
828S8R0O8AhI7Q/F6aPJ6aPJ6QLI6QLI6QLI6aPJ6QLI6AHH2@TE20PD1`LE1`DH1`DI20@M2@@O2@@Q
10DI20LK2@TK30/K30`J3P`H3`/G3PXE2@D@2@D@2PHA2`LB2`LB30PC30PC3@TD4@dB4@dB4@dB4PhC
4`lD4`lD510E510E4a<C5A<C5aDD6aLF7APE7a/F8adH8adF618=6Q@?6aD@6Q@?6A<>618=6A<>6aD@
:1hG:1hG9adF9adF9Q`E9Q`E9A/D9A/D7AL@71H?71H?71H?7AL@7aTB8Q`E8adF8AdB8AdB8QdD9B0G
:28K:R@M:bDN:bDP:2@I9b<H9B4F9B0G9AlH8adF81XE7ALB6a`B6a`B6a`C6Q/B6QXD6QTE6APD6APD
6QLB6aPC71TD71TD6aPC6QLB6aPC71TD6aLB6aLB71PC7ATD7ATD71PC6aLB6aLB7QXE7QXE7QXE7QXE
7QXE7QXE7QXE7QXE7AXF7AXF7AXF7Q/G7a`H81dI8AhJ8QlK8b4F8b4F9B<H9R@I9bDJ9bDJ9R@I9R@I
8bDI8R@H8b<G8b<G928G928G9R8G9B4F928H8b4G8b4G8b4G8R0F8R0F8R0F8R0F6Q/B5aLA5Q<?5Q<?
6QDB8ahE;2TK<blM>C8I=blH=BdF<BXF;bTF;bTF;RXH;b/I92PL9BTM9b/P:2/R9bXQ9RPR92HP8b@P
8RTR9RdV9bhW8RPS7b@R8RLU8bPW8BHU82PW82PW82PW82PW7RHU7BDT6b<R6R8Q4QPO4QPO41HM3Q@K
318I2a4H2@lF20hE10`<1Ph>210@2A4A2Q8B2A4A210@1`l?10/D10/D1@`E1`lF1a0D1PlC10d@0``?
0`d=1@l?1a4A1a4A1Q0@1@l?1Q0@1a4A01<@0A@A0QDB11LD1APE1QTF1QTF1QTF2QXC3alH5BDN62PQ
5BDN4R8K4b@K5RLN6BPT6bXV7RdY7bhZ7bhZ7RdY7RdY7bhZ5RhR738V83@X6b`O5R8F6b<H;S@Y@DDj
IFUSRXj8ZZjY[;2[X:>QWInOWj6QX::RV9fKV9fKVIjLVYnMWJ:PX:FSXjRVYJZX[K6[ZZjXYZZTXjNQ
XJFOXJFOXZJPXjNQYJVNY:RMXjNLXZJKXJFJX:BIWj>HWj>HVinDVinDVYjCV9bAUIV>TiN<T9B9Si>8
Si>8SY:7Rhn4R8b1QHUnPHEjOH5fNWicMGiYN7i[Mge/KW=ZI6UZGFEbGVUoHVj:EFRQE6RQE6VPE6ZN
E6^MDfZJDf^IDF^IIg2AIg6?J72=JG68Jg:5KGF2KgF0KgIoL8I^MHYdLhUfKhA^Kh9YNHEWP8MRPXAJ
P8=dO7m`MgY[MGQYMWUZNGa]Ngi_O7m`O7]]O7]]O7]]O7]]O7]]O7]]O7]]O7]]OGa^Ogi`Ogi`OWe_
O7]]NgY/O7]]OWe_P7maP7maP7maP7maPH1bPH1bPH1bPH1bOWi/OWi/OWi/OGe[O7aZNg]YNg]YNg]Y
O7]]O7]]OGa^OWe_Ogi`P7maP7maPH1bOWi/Ogm]P81^P81^P81^P81^Ogm]Ogm]Ogm]Ogm]OWi/Ogm]
P81^PX9`Q8AbQHEcQhMeQhMeR8QfR8QfRHUgRXYhRXYhRXYhR8MiRXUkRhYlRXUkRHQjRHQjS8]mSXeo
Si5nS962PXZ3:C@b2QLI00T=0`lA1@hA00L;00/91A085B4E@di4;C/gOXnBU:F^U:>cRYf/OIBTLHjM
JhVJKHRLLhbPN8nUNiBNO9FOO9JMO9>KMXjDL8J;Igf2HWQmIG=bHg5_HW1/HfeWHVYSI6aQJG1SKG5U
MGAOR8E`XYj6^[>JakjSbknSbK^OaKNJc/>Sc<6Qb[nOb[nObl2PcL:RcL:RcL:Rd<6Qd<6Qd<6Qd<6Q
d<6Qd<6Qd<6Qd<6Qb[nOb[nOb[nOb[nOb[nOb[nOb[nOb[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nO
c[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nO
c[nOc[nOc[nOc[nOcKjNcKjNc[nOc[nOcl2Pcl2P0039`K[9`K[9`K[9`K[9`K[9`K[9`K[9`K[:`[_:
`[_:`[_:`[_:`[_:`[_:`[_:`[^WWiRLU8f@R869PGZ9PGZ9PGZ7OgR3NgAnMVmmMFilM6emMFioMg23
NgB8P7V:PW^JTHj3NWN7OWZOU92=PG]KD4QCASi_HUYaFU9aFU9/EDeUCTIPBD5PBD5RBd=TCDEKBD9K
BD9JB45IAd1HASmGACiGACiGACiAACmAACmBAT1CAd5DB49EBD=FBTAFBTAPD4UPD4YRDTaTDe1VE5=X
EUEYEeQZF5UTFe5TFe5TFe5TFe5UG59UG59VGE=VGE=YG5YZGE][GUa]H5i^HEm]H5i]H5i/Gee[Hea/
I5e]I61_IV9_IV=aJ6EbJ6QcJFU^JFQ^JFQgLW68Ph:CSXfDShjDSXnFT96FTHjFTHjFTHjFTHjFTHjF
THjFTHjFTHjEUYBDUI>CU9:BTi6@THn?T8j>Shf>ShfAS8VAS8VAS8VBSHZCSX^ET8fFTHjGTXnMV9FO
VYNNVIJJUI:JUI:NVIJOVYNMV9FJV9RJV9RLVYZLVYZMVi^MVi^LVYZLVYZHUYFFU9>ETi:GUIBKVIRN
W9^PWYfPWYfPWi^QX9bRXIfSXYjQX9bNWIVKVYJIV9BAUHZ=THJ6RWn0PGMjNFmaL6IYIeeTHUQ`IUA^
I59]He5]He5^I59^I59]He5[HDmUG59TFe5TFe5SFU1RFDmRFDmQF4iQF4iLDdULDdULDdUKDTQJDDMH
CdEFCD=EC49AB3]@AcU?AcI<A3M2?CXe<C`T93`H6S`60e<60U@60EH205D105@0050004d00D`00U00
1Dh01TL00S`10SD50cL303L003@G5C<J5c4K6b/O7RLP820Q81`Q7QTP7APL6A/L6A/L6A/K61XI5QPH
5ALH5ALH5AL?3QPB4A/E4alH5B@H5BDG4bHE42DD3b@?3a/A4AdC4alG5R0I5B0H5AhH4a`G4Q/>2a@?
31D@3AHA3QLC41TD4AXE4Q/F4a`F4A8F4A8G4Q<H4a@I51DI51DJ5AHJ5AHI5aHI61@J5a<I5Q4I5PhJ
50dI50/J4`XM5a0O6A8P6Q<P6Q<N614N614O6A8Q6a@P5`dP5`dP5`dQ60hQ60hR6@lR6@lR6@lM6@hM
6@hL60dM6@hO6a0R7Q<U8AHW8aPU8Q<Y9QP[:1XW8aPO6Q4I4``H4PdJ50lW91HU8Q@S7a@S7a@T7aHS
7AHP6Q<N614M7A4M7A4L6a4L6Q8L6Q8K61<K61<K61@M6Q8O71@Q7QHP7ADM6Q8L6A4N6a<P7ADR71DS
7AHS7AHT7QLT7QLS7AHS7AHR71DR71DR71DR71DR71DR71DR71DR71DR71DR7QTR7QTS7aXS7aXS7aXR
7QTR7QTR7QTT8A<U8Q@W91HX9ALY9QPY9QPY9QPY9QPP8a@Q91DT91HT91HT8aDS8Q@U8Q@V8aDS8QPT
8aTT8aTT8aTU91XU91XU91XV9A/R9Q/P8APL6aLK5aHN6AHS7aX/:1d`;Alg<1df;a`c;AXb:aX`:a``
;Aha;R0b;b4S9a`U:AhV:B0W:R4W:B<V9b<T9B4S920O9QlT:RDT:RDN8b4J7adJ7ahI7AhF6Q/B6QTB
6QTB6QTA6AP@61L?5aH=5A@<51<62A4521041`l21@d110`00PX00@T000P010@01PH020P22PX32`/3
2`/22PX12@T01@h01a022A832a822`l12Ph02@`020/230`43Ph43Ph43Ph230`33@d53`l84Q845A45
5Q8761@96QH:6aL:6aL:6aL:6aLG:R4O<RTW>S4Z?C@Z?C@Y?3<Z?3D[?CH]?3P^?CT^?CT[>SHV=C4S
<RhR<BdS<RhH<R8M=2DO<R<L:QhS;B4oAca^LVN@THNMXI^WZjFZ[ZVVZZFXZjV_/K6/[ZjQXj>TZ:>T
Z:>TZ:>UZJBVZZFWZjJX[:NX[:NX[JBVZj:RYijNXiZKX9NJWiJJWiJKX9NHW96GVi2EVHjCUhbAUHZ?
ThR=THJ<T8F1QGZ1QGZ0Q7UoPgQlP7EjOW=gNg1fNVmbMV]cMfaeNFifNVmfNVmfNVmfNVmfNVmcNVEh
OfYlOfmgNg1]LW1WKWMVL89WMHa]LhY]M8Q]M8M_MXM_MhA_N85_NH1_NH1aLgAcMGEhNGEnOG>1OVn2
OV^3OfN2OV9/MFQaNfmdOW9cNg5dNVmmOFn3P767PFioPW9lOfmiO6aiO6alOfmmP71mP71lOfmoOW1o
OW1oOW1oOW1oOW1oOW1oOW1oOW1mO6ioOW1oOW1nOFmlNfekNValNfenOFmoOW1oOW1oOW1oOW1oOW1o
OW1oOW1oOW1lO6YlO6YlO6YkNfUkNfUjNVQjNVQjNVQkNValNfemO6inOFmoOW20Og61P7:1P79nOVao
Off0P6j0P6j0P6j0P6ioOfeoOfeoOfeoOfenOVamOF]oOff1PFn4Q7:6QWB6QWB6QWB7QgF8R7J9RGN:
RWR:RWR;RgV8QgV:RG^;RWb:RG^9R7Z:RG^=S7j@Sh6@TWn<TH:5SHHf@Cl85AL02@d23Q0330l02@d0
2`T02`<=6@e?FU0kBDEcQ8N;W:F:V:B5Uj9mTimdSYY`RYQaR9QcQiQdQYMaQha`Q8U/PH=WNgaRM7EN
KVeIJFQHIVAQJEmPJ5iQIeaQIUMXJEUaLEn0Of^:Qg:`ZXfi/IC4^Ig;`:;>`:?>_io>_9g=^ic9_Yk8
_Ig8_Ig;`:3>`j??a:C<`J7:_io?`:3?`:3?`:3?`:3?`:3?`:3?`:3?`:3:_io:_io:_io:_io:_io:
_io:_io:_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>
_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io>_io=_Yk=_Yk=_Yk>_io>_io>
_il00<S0^LS0^LS0^LS0^LS0^LS0^LS0^LS0^L[2^l[2^l[2^l[2^l[2^l[2^l[2^l[2^lg6_LBm];Zc
Z[B]Y;>/XkF^YKF^YKF^YKN`Yk>/XjbUW:FNUIjGSYRAR9B=Q9><PiV@SHf4PIJ=RJbQWIjBS71UGEM:
@U]>AUi9@FE@B6UDC6MBBVMBBVUDC6QCBf=>AVMFCFIEC6=BBF5@Af5@Af5@Af9AB6=BBEiCBemDC61E
CF5FCV=HD6AIDFEJDVIKDfEJDVIKDfMKEFUMEfYNFVaOGFiQGfiQGfaVFfaVFfaVFfeWG6eWG6iXGFiX
GFiXGFmVHg5XIG=ZIgI]JWM^JgM^JgI]JWE/JG=]IWE_J7MaK7MaK7I_K7I_K7Q`L7YbLWIcKgEbKX1l
Ni>?SYfHVIbGVI^FV9nJW:6MW:6MW:6MW:6MW:6MW:6MW:6MW:6MW9nOWijNWYbLW9ZJVYVIVIVIVIVI
VIVIVI^IV9ZHUiZHUi^IV9bJVIfKVYnMW:2NWIfIV:6MW::NWJ2LVj6MW:FQX:JRXJ>OWZRVYJRVYJRV
YJVWYZRVYJNUY:JTXjFSXZVVXZJSWj>PW:6NVZ6NVZ6NVYnLV9fJUY^GTY^GTY^GTYRDSi>?RXb8PhF1
O85mN75bJ6e^I6YYGfETFV9PEV=NEF=NEFENEF]PDVUND6MLCVMLCVQMCfQMCfIKCFEJC5eGC5aFBeaF
BeYDBEUCB5QBAeMAAUI@AEA>@eA>@eA>@e==@U9<@E1:?di8?De7?4U3>4Y2=DU2<dLo<Sli=3<_=B<R
=QPI=@@3@@D3A@L4B@H2B@D2A`D3A@H6@PP9@`45@0D9@`X<@PT:?@`9>Pl<>Pd:>0/5=1dK;Q`L:Q`K
91XL7A/L6QdL61dK6QlK6QHC5ALD5QPE5aHC5A@A4a8?4A<@4Q@A4a8>4aHB61XF71/F7aTC7QH@6a@=
6Q<<6@d>4Ph?4a4@518A5A@@5AD?51@>4a<=4Q4>414>414>418?4A<@4Q@A4a@A4aDB51D@3AD@3AHA
3QLB3aPC41TD4AXE4Q/F4aPE41PE41XG4QdJ4R4L4b<N5BHP5BLQ5R@P5BHR5bPT6BPT6BLS62LS62TU
6R/W73H^8CL_8SL_8SP`8cTa93Xb9C/c9S/c9Sdj;3dj;3hk;Cll;T0m;d8o<DA1<dE2=4E3<DU7=DQ5
=Sdj;2`W7QdG41LA31LA31lL3A`I2aXG2AXF2a`H3AhI41dG41dG42@P5B<O52<O52<N5B8L5B8L5B8L
5b8L5alM4b8P5RDS6B<Q5b0N51hL4R4O5B@R62@M52@M52DN5BHO5RHO5RDN5B@M52@M52DN5BDN5BDN
5BDN5BDN5BDN5BDN5BDN5B8N6B8N6B<O6R<O6R8N6B4M620L5alK5RDO4RHP4bPR5BTS5R/U62/U62/U
62/U61hQ4B4T52DV5RHW5bDU5BDU5BLT5BTV5bDU6BDU6BDU6BHV6RHV6RLW6bLW6bPX728W61lS61`L
5QPG4aPE4AXF4AdK4AlN41`I2a`I2a/G31TG31TH3QXI3aTJ4ATJ4A@J3a@I41@I41<G4A8F4A4E40lB
40hA3`D;1PX@2``A3`L<2P@920D92PD92P861`071P071P081`081`071P061@040`040`H;3PD:3@@9
30<82`872P462@052005200820492@8:2P8:2P8:2P8:2P492@492@8:4@@<4`H?4`D>4P@=40<=3@<=
3@@?3@/D4@`E4P`E4P`E4P`E4PdF4a4J5aDN6a4P61<R6QDT71LV7QTX81/Z8Q/Z8Q/Z8S12=CM9?3]<
@CU:?cM8?cE6?C92>bdm=R0_9b8a:B<b:R4`:1h]9Ah]9B<b:RPg;b/n:cA4<d1=?E=MD6mhJi2FRjV]
X[Ff[J^aYZJ[XYnTVijRW:BXXjR/Yj2SXIBGUJ2SVYnRVIfPUi^NUIVLTiNJTIJIT9FHSh^AQXZ@QHN=
PXF;P8:8OH26Ngn5NWn5NWYlL7UkKgQjKWIhK7AfJW9dJ75cIg1bIW=eJGAfJWEgJgIhK7IhK7EgJgEg
JgAfJW9dJ7=eJGEgJgEgJgAfJWAfJWIhK7QjKWEkJWQnKGf0L7inL7IjKg1eLfaeNF]fOWIdJWEcJ7Ic
IGEbHgIbH7A`GGIaG7EaFF1]Kf=aL6QeLfeiLg9kLG5iKVmiJFmfIgIeLGUhM7]jMWakMgmlN89nNHN1
O8R2Ngj1LGf0L7f0L7n2LX23Lgn2LWf0L7]nKX1oLH1oLH1oLH1oLH1oLH1oLH1oLH1oLGakKGimKgmn
L7imKg]jK7YiJg]jK7elKWimKgimKgelKWelKWelKWakKGakKGakKGYjJ7YjJ7YjJ7YjJ7]kJG]kJG]k
JG]kJGUhJWYiJgYiJg]jK7akKGelKWimKgmnL7emJginK7moKH20KX61Kh61Kh20KX20KX20KWinK7em
JgalJWemJh20KXB4LXJ6M8F5LhF5LhJ6M8N7MHR8MXV9MhZ:N8^;NHR7NHV8NX^:O8^:O8Z9Nh^:O8j=
Oi6@PY2BOh^@PHN?R45<BPHC5@0:3P4=3`8;3P0<408?3@4<10/G2eiYGdIDD6=dMgb=UWZ8SWV<TGF;
TFf5RfV0R6UnQVQhQ6AbOV1eLembKea]JUUXI5MUGeUSGE]SG5aTGEaMCF=SDFe/F7UfHHN3JY^DNJnW
R[bdUl_0X<_0X<VnW/RkVlVjV/bmWM?1X]O5Y/VnW/VnW/_0X<g2X/k3Xlc1XLRmWLFjV/o0X<o0X<o0
X<o0X<o0X<o0X<o0X<o0X<VnW/VnW/VnW/VnW/VnW/VnW/VnW/VnW/fnW/fnW/fnW/fnW/fnW/fnW/fn
W/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fnW/fn
W/fnW/fnW/fnW/fnW/fnW/bmWLfnW/fnW/fnW/joWljoW`00b<2ib<2ib<2ib<2ib<2ib<2ib<2ib<2i
bL6jbL6jbL6jbL6jbL6jbL6jbL6jbL6jb/>jb<6ha[nfaKjea[nfbL:ic<Flc/Nn_kR_`;V``KZa`kbc
aKjeal2gb<6hbL:iaKbiclK3d<O3c<6md<Bnb[ngXiJ>LfINGda4ED8jDd0hGda4JEI>J5E=IE9:IU=;
JEQ?JEQ?JEQ?JUU@JeYAKEaCKeiEL5mFJ5mFJ5mFJV5HK6=JKVELKfIMLFQOLVUPK6IKKFIMKVMNKfMP
LFURLVUUM6]XM6]XMViWMViWMFeVMFeVMFeVM6aUM6aUM6aULFaYLfi[MW5^NGAaNWEbNWEbNGAaN7=`
NG=/O7I_OgUdOgUdOWMdOWMdPGUiQ7alOGahO7]gR8J5WI^KYjBVXYjSXIfRYj>YYjFUYjFUYjFUYjFU
YjFUYjFUYjFUYjFUY:>WXj:VXJ2TWijRWijRWijRX9nSXJ2TWj6QWZ2PWZ2PWZ2PWj6QX::RXZBTXZBT
YjFUZjVY[J^[ZZRXZJNWZZRXYjFUXZ2PZJJRZJJRZ:FQZ:FQYZ>OY:6MXj2LXYnKVIF@UI6<T8b7S8R3
R8AoQ81kP7agOGUdOGE^O7A]NW9[MfmXLf]TKVIOJF5JIemHHf5GI69HIV5HIF1GIUmFJ5mFJ5mFJF1G
HUI:H5A8GU96GU96GU96GU96G514FTi2Dde2DTa1DTa1DD]0D4XoD4XoCdTnCdTnCDLlCDLlCDLlC4Hk
BdDjBT@iB48gAd4f@3le@3hc@ch_@Sd^?ST`=S4b:bLc8R0d6B0k6b4n72526am26ae06ado7B4n82A0
5APd6A`h61/g5QLc61Hc7AXc7Q/a7AP]71/T71dQ7AdM71dI6a`H7Q`K7Q/M7QXO61DG6QLI7AXL71TK
6QLI6QLI71TK7a`N5A0A5a8C6QDF6A@F5a8D5Q4C618G6Q@I5QHF5aLG6ALG6QPH6aHH71DH6a@G6a@G
6ALF6ALF6aTH7A/J7Q`K81hM8R0O8R0O<B/V<R`W<bdX=2hY=S0[=c4/>38]>38]?S`d@3hfA44iBTDl
Cd]0EDm4FE=6G5A7I65CIV=EJ6EGJFIHJFIHJVMIK6UKKfaNJFIGJFIGJFIGJFIGJFIGJVMHJVMHJVMH
HEi?HEi?HUm@HUm@HEi?H5e>Gea=Gea=JfYEKFaHK6YHIV=EG5Q=DD]4BT@oAd0m<RlP;R/L:BHH9R<E
9R8G:2<J:2<J:2<J;bLJ;bLJ;bHL;RDK;RDL;R@M;B<L;B8N8ahE9b8I:RDL:2<J91lF8QdD9R4H:RDL
9QlF9b0G9b0G:24H:24H9b0G9b0G9QlF9b0G9b0G9b0G9b0G9b0G9b0G9b0G9b0G8Q`E8adF91hG9AlH
9R0I9AlH91hG8adF:B@E:RDF;2LH;RTJ;bXK<2/L<2/L<2/L92PE:2`I;S0M;c4N;blM;RhL<BlM<c4O
:B/O:B/O:B/O:B/O:2XN:2XN:2XN9bTM7RLC7R<D720E71dD6QXD6aTA71X?71/=4Q0841484A4;3a4;
3a0<30l=2@h<2@h=41D<3a@;3Q8<3Q8<3A4<3A0>3A0>3Q4?3aD@5Q/I61dK5AXI4aLH5ATJ5QTM4aHJ
4a/J4a/J51`K51`K51`K4a/J4QXI4QXI4aPG4aPG4aPG4aPG4QLF4QLF4QLF4AHE3QHF3ADE3ADE3QHF
3aLG41PH4ATI4QXJ4AXM4a`O51hN4adM41/I41/H4QdJ5B0M5B0F5b8H6RDK72LM7BPN7bXP8RdS9C0V
8blS930T9c<W:cL[;SX^<3``<Cda<Shb=DHh>DXl=dPk<D4f;C`d:cXb8S0Z62HP6RHJ72PL7BTM6bLK
6RHJ7RXN9c<W;c/_Ff5>Jg5NOhEdTIJ7WZ:FXZJKUiZAR8^2R8n2RY64SIB7SiF:R8f4OX=jNGegNgmi
MWY^MWY^MGU]LgM[LGEYKg=WKG5UK71TKWAYKgEZKgEZKgEZKWAYK79WJW1UJFmTM7IZM7IZM7IZM7IZ
M7IZM7IZLgEYLgEYLgEYM7IZMWQ/MgU]N7Y^N7Y^N7Y^N7Y^N7Y^NG]_N7Y^MGM[LWAXLG=WLgEYMWQ/
KgA[LgAZMWIXNGMUMgMUMWIXLGEZL7E/NW][NGYZNWYZNgUWNgMUO7ETO7ISO7ERJG=]JWA^KWEbL7Md
LWMeLWMeLWMeLGIdN7YVMWQTMgUSN7]RNGaSNGaSN7]RN7aSO81]OX9_Oh=`Oh=`OX9_O81]Ngm/Ngm/
OWe_OWe_OWe_OWe_OWe_OWe_OWe_OWe_NgY/OGa^OWe_OGa^NWU[NGQZNWU[O7]]OGa^OGa^OGa^O7]]
NgY/NgY/NgY/NWU[NGUWNGUWNGUWNWYXNg]YO7aZO7aZOGe[NWU[NWU[NgY/O7]]O7]]OGa^OGa^OWe_
O7aZOGe[OWi/P81^PH5_PH5_PH5_PH5_P81^OWi/O7aZNg]YOGe[P81^Q8AbQXIdQ8AbQ8AbQHEcQhMe
R8QfRHUgRXYhRh]iR8MiRHQjRhYlRhYlRXUkS8]mShj0TI22T99oRXn0R929BUEC1A8D00/?0@d?0P/>
00X>114?10l72QH:HfiTA59>C5ePIgR1JW]hKGmnJh5oI7alHgQjIGQkI79hH6YaG6iWG6aUFFQPFFIN
G6EKGVIKI6QMIVYOKf]CO7QPT8]bXif0/jV;`;FEcL6OeLVUa;ZHbKfKc<2NcL6Oc[nOc[nOc[nOcl2P
bKjNbl2Pc<6QcL:Rc<6Qb[nOb;fMb;fMc[nOc[nOc[nOc[nOc[nOc[nOc[nOc[nObKjNbKjNbKjNbKjN
bKjNbKjNbKjNbKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjN
cKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNcKjNc;fMc;fMcKjNcKjN
cKjNc[nO0038`;W8`;W8`;W8`;W8`;W8`;W8`;W8`;W9`K[9`K[9`K[9`K[9`K[9`K[9`K[9`K[8`KS:
`k[<aKc;a;_9`[W8`KS8`KS9`[W:`k[:`k[;a;_;a;_:`k[9`[W8`KS7`;O7_[_7_[_4^kO4^KG9_KO=
`[[;_[K2]JfXVI1gJ5mB@cYB@cYFAci?@3MB@cYQDTUNCT9QDDEUEDUYFDe]GE5`H5AaHEEbHUI/HeY]
I5]^IEa`IeibJF1dJf9fKFAgKVEaKfAbL6EbL6IdLVQeLVYfLVegLfihLg1mM71lLfmkLVijLFehKf]g
KVYfKFUeK6Q_KVYbLFeeM71hMg=jNGEjNGEiN7AhMg=kN71oO7B3OgZ3OgZ2OGZ3OW^7PX6:QHB1PWj1
PWj=SXbSXj>/ZjfWYZZVY:Z/Z[2WYZRWYZRWYZRWYZRWYZRWYZRWYZRWYZR]ZJn/Z:jZYZbYYJ^YYJ^Y
YJ^[Yjf/Z:jRY:FQXjBQXjBPXZ>QXjBRY:FSYJJTYZNZZJ^[ZZbWYZRMW9jCTYB;RXb1P89hMgUjMW5i
MG1iMG1hM6mfLVecKfYaKFQ`K6M]If1[IEiYHeaYHeaZI5eZI5eXHU]VH5UXGeEWGUAUG59SFU1RFDmR
FDmSFU1SFU1DCdIIDTUMETeOETeME4]ICTIHBd=FBD5KCTIIC4AFBD5FBD5GBT9GBT9DAcmBACe:A3U:
A3U:A3U;ACY;ACY;ACY;ACY;ACY8@SM8@SM8@SM8@SM7@CI5?cA4?S=3?C8d=bhg=b/h>2Pl>2Hl=RTe
<2d]:BlW8S4M;2PO:b/O:RhL9BhJ8BXH82LJ8bLO9RTR9bHR9bXN8RLH6b<H6R8Q82@V92@V8alQ8B4Q
8R0S920T9R0V9B4V92@V8RPV8BXU8R@Y9RP]:R`]:R`]:R`]:R`a;S0d<C=0?CU2?c]3@3a2?Se2?Se5
@D1<B4MACDaADTiCDTiBD4mDD4mECe1ECe1FCTmFCTm?C4MACTUDDDaHEE1LFEAPGEQSH5]UHUeTG5ET
G5EVGUMWGeQXH5UZHU][Hea[HeaVI5aWI5aWIE]YIEY[IEY[IEQ]IEQ]IUMVHeEYIUQ[J5Y]JUa]JUa^
JeeaKV1cL69_Kem_Kem^KUi^KUi]KEe/K5a[Je][Je]YIUMYIUMYIUMXIEIVHeARGe1OG4eMFT]KFTEM
G4MPGTaVHeAZIU]YHeaUGeYQFUMIETMCD45:AcQ3@390?34o>c0n>C0m>2lh;20h;20h;28h;28g:R8g
:B<g:B<f:28T7aHY91//9ahZ9A`V8APT7aHW8QT/9ah`:B0a:R4b:b8b:b8b:b8b:b8a:R4`:B0W81LW
81LW81LW81LW81LW81LW81LW81LR71DS7AHV81TX8Q/Y8a`Y8a`X8Q/X8Q/`:a`a;1dc;Qle<24f<B8g
<R<g<R<g<R</<A`a=R4h>RHi>bLi>RHh>BDl>bLn?BTa=2Da=2D`<b@^<B8]<24[;QlZ;AhZ;AhS;1LS
;1PW;1dX;24[;2<];28/;1h];AdS920R9B<S9R@P9B@O92<L8B8J7b0F7B0J8QPJ8QPI81TJ81/L8QdO
928Q9R@S:2LM8R0S:2HV:bTS:2LR9RLS9bPS9RXQ92PK8b8L92<M9B@N9RDN9RDM9B@M9B@L92<K81hK
81hK81hK81hK81hK81hK81hK81hH820H820I8B4K8b<N9RHR:RXV;RhY<C4Q:b/S;R`S;R`Q;2TN:BHN
:R@R;bLV<b/O:AdS;B4Y<bL]=b/^>2``>Rhb?30c?C4_>BTa>b/d?Rhh@S8lASHoBCU1Bc]1Bc]8EDE;
F4Q9ETQ5DDE6DDM7DTY0BT@d?CXf@3<f@3<c?C0[=BPT;R4T;R4/=RTc?C0e=R9=CC]TIEE/K5i[KF5/
KF=YK6=UJ5mLI5=IHE1QJ5U`MfYdNfi[LFIVK65ZKfI]Lf9]Lf9^M6=_MFA`MVE`MVE`MVE_MFAWKF9Y
KfA[LFI]LfQ^M6U]LfQ[LFIYKfA^KV1^KV1`L69aLF=cLfEdM6IeMFMfMVQbLVAbLVAcLfEcLfEcLfEb
LVA`L69`L69[Jee]KEm^KV1]KEm/K5i^KV1dM6IiNF]`Lg5`LfYdLfEiMF9mNVF0OVInP6YmOf]ZM6i]
M6m^M6maMG1dMG=fM7=iMGAiMGB9NfB9NfB7NVB7NFN8NFV:NVj<Ng:=O7=lN7MjMG9iMVj0Ng:4P7F3
PGJ1P7J0PGMkOfamPFioPg1mPFijOV]hO6UiOFYkOfakNVakNVakNVakNVakNVakNVakNVakNVajNF]l
NfemO6ilNfejNF]iN6YiN6YkNVamO6imO6imO6ilNfekNVakNVajNF]jNF]hN6IhN6IiNFMjNVQkNfUm
OF]nOVanOVamO6imO6inOFmnOFmoOW1oOW1oOW20Og5kNfUlO6YnOVb0P6j1PFn2PW22PW22PW20P6in
OValO6YkNfUlO6YoOff3Pg66QWB3Pg64Q7:5QG>6QWB8R7J9RGN:RWR;RgV8QgV9R7Z;RWb;RWb;RWb<
Rgf?SX2BTH>?TGj9SWn9THY?FUP44A<031013@l22`h010P340h540P850QPJf4lBTHhBDaFIg1SLfaU
NGAUNgIPMg=PMg=XNWUZN7MWL7=QLVUOL6MPKV=PK61RJUmWJemZK61]KEnDT7BUWX>k/iK:`:;?`j7=
_i_;^iK:^iC8_9[:_Yc=`Io=`:3:_Ig8^Yg:^Yg;^ik8_Ig:_io<`J7<`J7:_io:_io=`Z;?a:C>_io>
_io>_io>_io>_io>_io>_io>_io9_Yk9_Yk9_Yk9_Yk9_Yk9_Yk9_Yk9_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=
_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=
_Yk=_Yk=_Yk=_Yk=_Yk=_Yk=_Yk<_Ig<_Ig<_Ig=_Yk=_Yk=_Yh00<[1^<[1^<[1^<[1^<[1^<[1^<[1
^<[1^<_2^L_2^L_2^L_2^L_2^L_2^L_2^L_2^LW2^LW2^LW2^LW2^LW2^LW2^LW2^LW2^LS1^<S1^<S1
^<S1^<S1^<S1^<S1^<S1^<Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]]78_l>j/JNLU89eKEmBBThn=dlo
>5M5?Ui?AUa=A5a=A5i?AV=DBfQID6]LDfaME6YQF6aSFVmUGW=YHWEZIWIZJ7M[JGM[JG=`J7EbJWQd
KgUeL7UdLGYeLWagMWiiN85lNH5lNH5lNH1kN81kN81kN81kN81kN7adM7I^KW5YJG1XJ7I^KWeeMH5i
NH=kNhenNhn3Ohj3OhN0OHF1P8J7QHJ8R8:7QXN7QhZ:RYNGUjRXZ:n_[j^[ZjVYZJ^[Zjj^[Zj^[Zf]
[Jf][Jf][Jf][Jf][Jf][JNWYjVYZJ^[Zjb/[:f][Jb/[:^[ZjZZZZFTYZVXZZZYZjJUYjJUYjNVZ:FT
YZ2OXKZg/inLV7mlN6aYIFUVHVaYIFYWHfERGV]VHf]VHfUTHFMRGfEPGFAOG69MFV5LFEmIDUeGD5UC
C5E?B55;A4i8@D]5?TY4?Di8@Di8@De7@4a6?dY4?DU3?4Q2>dQ2>d8l=DI0>DY4?DY4?DQ2>dM1>TU3
?4]5?THo?4Ho?4Ho?4Ho?4Q1?T]4@Di7A519AUAACEEBCUAACE=@C59?Be=@C5ICCeYGDeeJEUeJEUeJ
EUmLF69OFfERGVUVHV]XI6UWIVe[JW1^KFi/JfUWIVESHVESHVMUI7QcL7YeLWiiMX5lNH=nNh=nNh9m
NX5lNGn3OWb0NgIiMfi`L6YZJVeXJWE[LGa`MWYeK7E_J6eXIFMQHV=NGfERGVIWGVUZH6m[IVaXHfQU
H6MWHFUYHfQZI6EWHF1TGV5PI65PI69QIFASIfETJ6IUJFMVJVMVJV]QKV=QM5mSMF=WK6QZGVQZEe]X
FTmUH6EPEfEPEfEPEfEPEfIQF6IQF6IQF6IQF6ISEFISEFISEFISEFISEFISEFISEFISEFAWF6EXFFMW
FFQXFVQWFFQWFFQUEfQUEfEVDVEUDfIVE6MWEfQXF6UXFVYXGFYXGFYXGF]YGVaZGfaZGfaZGfYXGFQV
FfMUFVIUEf5PDV9QDfYYFfa[GF=RE5eLCUaKCEeNE5]LDUaLD5aLCUmOCf1PCV9QCF9QCF1KC69MCVEQ
CfQTDVUUDfQTDFMSD6IRCg=/DfAIBf5CCF9IC5mI@V5O@FAOBUaCBDe<>55??F1NC59?@4e:?4i;?DI2
=dM3>75`HSDd9S4`8UUHBX:1Ld=2=2/Z73Th:SHb82hZ62hZ62/V5bHP4bhX6c<]8RPR5b`/72XZ6Q/K
2de=?BDU5C0`82h^7Rh^7T8j8c`d7C`d7D4i8T0h8C`d7D4i8Ta4;DE09d<n9Clk8Te9<D8o:S@c7Shm
:C8a7Bdb7CLl9c4e8RLZ6bX/82X[8BX[8S8b;3<_7C8^730/6RhZ62dY5b`X5R`X5R`X5QdN6QXK5aDI
51HJ5ALM61LN6AHM61<J5A0G4PlF4A0G4Q<I51XN6B0T7bTZ9Rd^:RD/9bL^:BXa;2`c;R`c;RXa;2L^
:BD/9bD/:BH]:RL^:bL^:bD/:B<Z9b0W91lV8b8Y9QTP7B0W920W91/R7aPO71HM6RL^:b<S<B<V:R<X
7adX51//5bLn<41HF55]M5MaPUaeObm6@R8g:2Pk9R@e82`m;ad^8bdg:R/e:2Xd9b`f:C0j;C<m<38l
;bli;2li;30j;C8l;cI0<ca6>D9<?dE?@TMAA5AKC4U@@eELCdY@ADaBAcm4>dM<@cPl=S]3<SPn;C@j
:C8e9B/^7Rd^7Shn;U5A@FMZFfQ[G6]^Gfa_H6IYFV9UEVY]GWEhJFe^FVe^FVe^FVe^FVe^FVa]FF]/
F6Y[Efi]Gfm^H71_HG1_HG5`HW1_HG1_HFm^H79aHg9aHg9aHg9aHg5`HW1_HFi]Gfe/GW9bH6e]Ffe]
GG9bHWAcIG9aHg1^Hg9`IGAbIgAbIg=aIW=aIW=aIW9`IG9`IG9`IGUgK75_I7IdJG]iKWIdJGQfJgmm
LW]iKX60LWQgJGEdIWakKH:1Lh60LWelKWelKX>1MWekL7MeJWMeJW]iKWekL7QfJg=aIW]kJGMgIGin
K8:2L7UiIg]kJH20KWYjJ7YiJg]jK7akKGUhJWMfJ7QgJGelKX:1Lh:1Lh60LWmnL7elKWakKG]jK7Yi
JgYiJg]jK7YiJgUhJWUhJWUhJWUhJWYiJg]jK7MfJ7MfJ7UhJWYiJg]jK7]jK7]jK7]jK7YiJg]jK7ak
KGelKWelKWelKWakKG]jK7]jK7YiJgQgJGQgJGQgJGYiJg]jK7elKW]jK7]jK7]jK7akKGakKGelKWel
KWelKWinK7inK7inK7inK7moKH20KX:2L8:2L7moKGinK7emJgemJginK861KhF5LhN7MHV7MHZ8MXZ8
MXZ8MX^9Mh^9Mh^9Mhb:N8^;NH^;NH^;NH^;NH^;NHZ:N8Z:N8Z:N924LYB<NiB>PGIgKA4G4P<@3PLF
608E60PA3PTB3`lJ5`@@2U=RFUa]I1X[86UjKf1hMVMmNfj3P7J4PWN2OgQmNgIiMgIgMGMeJW1_HFeX
FFmYEWieHIV=MK:URlFgVl^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<bmWLbmWLbmWLbmWLbmWLbmWLbm
WLbmWLbmWLbmWLfnW/fnW/fnW/joWljoWljoWlfoVlfoVlfoVlfoVlfoVlfoVlfoVlfoVl^mVLbnV/bn
V/foVlfoVlk0W<k0W<o1WL^mVL^mVL^mVLbnV/bnV/foVlfoVlfoVlbnV/bnV/bnV/bnV/bnV/bnV/bn
V/bnV/k0W<foVlfoVlbnV/bnV/^mVL^mVLZlV<^mVL^mVL^mVLbnV/bnV/foVlfoVlfoVlbnV/bnV/fo
VlfoVlfoVlk0W000b/6hb/6hb/6hb/6hb/6hb/6hb/6hb/6hbl:ibl:ibl:ibl:ibl:ibl:ibl:ibl:i
bL:ibL:ibL:ibL:ibL:ibL:ibL:ibL:ib<6hb<6hb<6hb<6hb<6hb<6hb<6hb<6ha[nfa[nfa[nfa[nf
a[nfa[nfa[nfa[nf^K2W`kZacL:jb[ng]JRPTX9kJe]DDT8kE4DlEdPoGTm6IEI=JU]BJEYAI5E<Ge17
KFAKKfIMLVUPM6YSMFYVM6UULVITLFESMFmXMg5ZNWA_NgE`NW=`NgAaOWIfP7QhOgYgOgYgP7]hP7]h
P7]hP7]hP7]hP7]hRH61Q7alOgMgNg=cNg=cNG5aMfm_M6a/MFUUOW=_QWejRX>0SXZ9TI6ASY2@RXb<
Rh^;SHf=UYJFY:BTZJVYYJFUXj>SYJFUXZ:RXZ:RXJ6QX:2PWinOWinOWYjNWYjNXJ6QXJ6QXZ:RXj>S
Xj>SXj>SXZ:RXZ:RW9^MXJ2RXj:TXJ2RXZ6SYJBVYJBVXJ2RUI>BQ8:1Kfe/I69QI69QIVASHf5PGUaK
FEACFEACFUEDFUEDFeIEG5MFGEQGGEQGHEiJHEiJHUmKHf1LIF9NJ6EQJfQTK6UULFiZLVm[MW=_NWMc
OW]gPWmkQX=oQhB0RhR4SX^7THj:THj:SX^7SHZ6SX^7T8f9Ui>BUY:AUY:AUi>BVIFDW9RGWYZIX9bK
Ti6@TY2?SXb;RHN6QH>2Q8:1QhF4RXR7Ti6@Ti6@TY2?TY2?U9:AUYBCV9JEVINFTi6@U9:AU9:ATi6@
THn>Shf<T8j=THn>SHR5S8N4RhJ3RHB1QX5nPgikP7]hOWUfNW5dM6a]JfAQIF1GHemDIEmBJ61CJ61C
HEa=GUY?FeQ@FEEDF5IEF5UGFEeHFUiHFEMGEEEEE5ADE5IFFE]KFf1OFV1OFV1OFEaPFEaPFUeQFeiR
GF1TGV5UGf9VGf9VIV5RGV1XFEmZGf9VJfIMLVUKJfQPHfIZJVELJVELJFAKJFAKJFAKJFAKJFAKJFAK
J6AIJ6AIJ6AIJ6AIJ6AIJ6AIJ6AIJ6AIHVAHHVAHIFEIIVIJIfEJIfEJJ6AIJ6AII6ABI6ABIFECIVIF
IfIHJ6MIJ6IKJFMLK6YOK6YOK6YOK6YOJfUNJVQMJFMLJ6IKIFAFHF1BHF1BIFAFHf9DFeY<EeI8F5M9
F5U?EeQ>F5Q<FEU;Fe];G5a:GUe9GUe9Hei?I5m@IF5?IV9@If=AIV9@IF5>IF5>JF=<IEe@IE]DIeiD
J6A<IFE7IF9=I5iCJfaLJ6UIEEE7DU94Bd/oH5mENgY`THn7QHIlFEY@BDY0HV=IOGidEeQ>@44gBDY0
BTHkB4@iCTXoCTXoAD4fBDDjBdLl@3d_?cdb@T0e=C<XGUaA@Cld>3H[;B/P;B/P>38O=S0M=c4N>S@Q
>S@Q>38O>C<P?3HS>cTQ@3dX@3dXAD@`<c@P:b/IATLgBDXj@4<cATTiADPi@D@e?Clc;S0T8R<I8R<I
9b@F9R<E8b0B8Ah@81d?7a`>81d?81d?71dI6Q/G5aPD5ATD5A/F5Q`G4aXE4APC5ahI5ahI6AlJ728M
8RHQ:R/W;c0/<S<_<3Lb<3Lb<3Lb;cHa;SD`;C@_;3<^:c8];C@a;C@a;C@a;C@a;3<`:c8_:C0]:C0]
9B`Y9bh[;3<`92/X8BPU9RdZ92/X9RdZ8bLX:2/Y:BlT8b/P8R/X;CU5B5=aFfVCKGfbLGnY@DmV:SHj
9C<X82hL;SdX9cDS:38U9S0S9BlR9c4T:cDX;CLZ;3HY:S@W:cDX;SP[<C/^=3ha=T0c>48e>dDh?DLj
@4Xj@d`oB554C5A9?dLl@DTo?DDk=chg=d4`<C/Z<c/Z>D4`@TPgBdhnEeY:HfIFIfYKHfIGH6=DGV5B
G5m@Gf9CJVeNN7]/JFYFJV]GJV]GJV]GJV]GJV]GJV]GJFYFKFaNKVeOKfiPKfiPKfiPKfiPKVeOKVeO
LG1RLG1RLW5SLW5SLW5SLG1RL6mQKfiPKfmMJf]IJf]KLG5QMGAVLg9TLg5VMG=XMWAYMWAYMWAYMG=X
MG=XM79WM79WM79WMgEZL6iSLW1UMG=XLW1UMG=XNWQ]MgEZKVeOMGAVOgi`QHAfR8MiRXUkS8]mShj0
OgebO7Y_MgEZMG=XMgEZNWQ]OG]`OWaaNWYXLg=QMgMUNWYXM7ARNGUWOgm]NGUWNWU[NgY/OGa^O7]]
NWU[NgY/Ogi`PX5cP7maOgi`OGa^O7]]NWU[NGQZNGQZNGQZNgY/NWU[NGQZNGQZNGQZNGQZNWU[NgY/
MgIXN7MYNGQZNWU[NgY/NgY/NgY/NgY/O7]]O7]]OGa^OWe_OGa^OGa^O7]]NgY/NGQZN7MYMgIXMgIX
MgIXN7MYNWU[NgY/NgY/NgY/NgY/O7]]O7]]OGa^OGa^OGa^OWi/OWi/OWi/OWi/Ogm]P81^PX9`PX9`
P81^Ogm]OWi/OGe[Ogm]PX9`QHEcQhMeR8IdR8IdR8IdRHMeRHMeRHMeRXQfRXQfRXYhRXYhRXYhRXYh
Rh]iRh]iRh]iRh]iThakTXenSXj2Mgac7BLQ2QPG21`M21dO3bHQ52/V3B@O52/SCFEKJX9h7cL[Jh=g
LhJ3M8F1M8=oM7ihL7Q^L7AYLW5WLg5VMW5RP7aZTXaiYYj7]j^C_k>Ga;JIa[NGbkbLbkbLbkbLbkbL
bkbLbkbLbkbLbkbLc;fMc;fMc;fMc;fMc;fMc;fMc;fMc;fMc;fMc;fMc;fMcKjNcKjNcKjNc[nOc[nO
cKnKcKnKcKnKcKnKcKnKcKnKcKnKcKnKc;jJc;jJcKnKcKnKcKnKcKnKcKnKc/2LbkfIbkfIbkfIc;jJ
c;jJc;jJcKnKcKnKc;jJc;jJc;jJc;jJc;jJc;jJc;jJc;jJcKnKcKnKcKnKc;jJbkfIbkfIbkfIb[bH
bkfIbkfIbkfIc;jJc;jJc;jJcKnKcKnKc;jJc;jJc;jJcKnKcKnKcKnK003:`KS:`KS:`KS:`KS:`KS:
`KS:`KS:`KS;`[W;`[W;`[W;`[W;`[W;`[W;`[W;`[W9`[W9`[W9`[W9`[W9`[W9`[W9`[W9`[W8`KS8
`KS8`KS8`KS8`KS8`KS8`KS8`KS6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK>akk;`[W7_[G7_;C8^k>o
/ZZbXY^VUXm[GeETF4iLD4IHC49LD4ISEde[GeE`I5YUFe5UFe5UFU9XG5I^HUagJfN0M726NGMfL6Uh
LV]jM6mkMG1kM75kM75nMWJ0N7QnNGIoNWMoNWMoNWN0NgR0NgR1O7V1O7V5P7n4Ogj5P7n5P7n6PH24
OgioNWUkMWEdJFE]I65QFUMHDe9OFeYbLW:6R8VATiB?Shn@T92EUIFMWIfPX:2NWYjLW9bNWYjNWYjN
WYjMWIfLW9bKVi^JVYZIVIVIVIVMWIfLW9bKVi^JVYZJVYZJVYZKVi^KVi^HUiVLVifNWInLVifLVifP
Wj6PWj6LVifZZ:NUXj:PWYfNW9^PWYfPWYfNW9^KVIRKUiJKUiJMVIRNVYVPW9^RWYfSWijTX9nLW9bL
W9bMWIfMWIfOWinPX:2RXZ:SXj>HV9RIVIVKVi^MWIfPX:2RXZ:TY:BUYJFKVi^MWIfOWinNWYjKVi^I
VIVIVIVIVIV=SXb=SXb=SXb>Shf@THnBTi6DUI>EUYBRX9nPWYfLVYVETi:@SXf?SHbAShjDTY6MViZL
VYVKVIRJV9NJV9NJV9NJV9NKVIRHUYFFU9>DTY6CTI2CTI2CTI2AShj@SXf>RXF<R8>7Pgj1OGQkMg9e
LFabKVU`K6McHFQ[FeaQETiNEDMOFDIOFdQLFTQIETMAD4aADE5BDEYBDf5@E6I>EVM<EVM9EVA;Cfa9
CFY5BfQ7CFY:DVm=F7AAG7QBGGUEGg5FH79FH79HHWAIHgEJI7IKIGMKIGMWKG9NJGMFI7MNI75_IfQk
J6=gIV=_I6M/JV1[JEm[JEmZJ5iZJ5iYIeeXIUaXIUaWIEYWIEYWIEYWIEYWIEYWIEYWIEYWIEYQHeMR
I5QVIUYWIe]YIeaYIea[Iea[IeaTI59TI59UIEEVIUIWIUQWIEYXIU]XIUa/JUm[JEiZJ5eXIU]WIEYW
IEYWIEYWIEYVIEMTHeERHE=RHE=MG4iFEDMDDdEGETQCEDUCEDUEEDMEEDMFETIFETIHETAHETAQGD]Q
GD]RGTaRGDiTGe1UH55WHU=XHeALFdMRGU=NEeAIE4]LFdIHFSeCDSeHE4U1ACUNHUMGFe2@ThZ<SXRD
UY2OX9bUYZ:@U8inPWaPI5iWJfEeNG=oPgeiOGN5RH>3PH1VI6=<BdLk>cDe=Re0@SI3ACTd=bQ4@SY@
CTI3@CUEDd]>C4@m>c<k>C52@3Q=BS]?C3e=BS]9ASM7A3E5@S<o?2dh=BI0@2hn?R`j?2U<CCe7BS/l
@C95BCdf>Ri8BCm:Bd5BDdUHFTi@DTHl?c0`<b@a=2Df=bdd=B/a<RP_<2H^;bD_<2Ha<RPb<bT_;bT]
;BLY:bDW:bDX;2HV;BHU;2DR:R<T;2DU;2DV;BHY;BL[;bT_<B/b<R`c<bdZ<BXY<2TW;RLV;BHU;2DV
;BHW;RLX;bPO9B0O9B0N91lN91lN91lN91lN91lO9B0J81/U:bHU:bHK8A`I7aXQ9b8Q9b8F71LM9A/S
:AhU:b0Q9B0N82/V9dTj>g==CY9DFj]JHJHj?VhS9clP9BPN9APZ<alZ=1dV;b8U;R4T;B0V;b8X<B@Z
<bHY<RDX<B@W<2<^=bXf?c8kA3LnAcY1BSe6Cd9;E4LnBCU<ETU6D4=>F4`h@SI2Bd4b>c4`>34`?Bd/
>BT`>b/oBSYBG4aNIEIRJEYVJeaWJU]QI5ENHE9PHeASIUMVJEY]L65eN6UXJEEXJEEYJUIZJeMZJeM[
K5Q[K5Q/KEU]K5i^KEm^KEm_KV1_KV1^KEm^KEm]K5i_KV1`Kf5aL69bLF=bLF=bLF=aL69aL69]KE]Y
JEMYJEU`L61eM6IeM6IeLfQhMV]fM6UfM6UfM6UfM6UeLfQeLfQdLVMdLVMoOG9lNVmjN6eiMfakNFio
OG:2P7F1OgB4PgFCTXBOWY2TXiF/Zife]:Je]:J][9jYYibWYIZPWY>BT8F4PWMlNVmlNVmoOG:8R7Qo
Ofn1PG60P71gMfMjNVZ1PG5lO6aeM6IhMfUkNValNfelNfelNfenOFmoOW1mO6ilNfekNVajNF]iN6Yh
MfUgMVQgMVQjNF]jNF]iN6YhMfUhMfUiN6YjNF]jNF]gMVQhMfUiN6YkNValNfelNfelNfekNVanOFmn
OFmoOW1oOW1nOFmmO6ikNVakNVagMVQgMVQfMFMfMFMfMFMgMVQiN6YiN6YkNVakNVakNValNfelNfem
O6imO6imO6inOVanOVanOVanOVaoOff0P6j2PW22PW20P6ioOfenOVanOVb0P6j2PW24Q7:6QWB6Q7:7
QG>7QG>7QG>8QWB8QWB8QWB8QWB8R7J9RGN9RGN:RWR;RgV;RgV<S7Z<S7Z?Sh66RGZ6S85hPg/^?3P?
8B0<8B8@9bT06148:B828APN?351G59XPWDF;R9FKf5]N71^MVm_MfabMVYgN6QoOVZ8QG2@S7BXX8V^
YXnj/9S6^Yk=_j;@`J7?_Yg?_9W;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;_9c;
_9c;_9c;_9c<_Ig<_Ig<_Ig<_Ig=_Yk=_Yk=_Yk>_io=_i_=_i_=_i_=_i_=_i_=_i_=_i_=_i_=_i_=
_i_=_i_=_i_<_Y[<_Y[<_Y[<_Y[:_9S;_IW;_IW;_IW<_Y[<_Y[<_Y[<_Y[;_IW;_IW;_IW;_IW;_IW;
_IW;_IW;_IW<_Y[<_Y[<_Y[<_Y[;_IW;_IW;_IW:_9S:_9S;_IW;_IW;_IW<_Y[<_Y[<_Y[<_Y[<_Y[<
_Y[<_Y[<_Y[=_i_=_i/00<W0]lW0]lW0]lW0]lW0]lW0]lW0]lW0]l[1^<[1^<[1^<[1^<[1^<[1^<[1
^<[1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<Jo]/Jo]/Jo
]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/2i/;je[<6h[lZo]m33^lk1^LVl]<2dZZbPUXj2N79VG5mCBEM;@EI:
@5M;@FUOEFUOEFYPEVaQFFmSGG9VH7EYIGIZIWQ`JG]cK7edL7ieLGieLWieLX5gMh=iNGmjMgmjMh1k
N85lNH9mNX9mNX=nNhAoO89mO8AoOXV4Phf8Qi2;RY6<Ri2;RXj9R8n8QI6:Qhn:RHb8Qhf;RiBCUIZI
ViRJVi:BTY:BTYFEUIRHV9^KVi^KVibLW9fMWInOWinOWinOWijNWYjNWYjNWYfMWIfMWInOWifMWI^K
ViZJVYVIVIZJVY^KVibLW9ZIVijMWifLWYVHVYRGVI^JW9ZIViJEUiVIVIbLW:2PX:>SXjBTY:BTY:>S
Xj:RXZ>NWj>NWj>NWj>NWj>NWj>NWj>NWj>NWifPY9bOXiZMXIRKWiJIWIFHW9FHW9FHW:6TZ:6TZ:2S
YinRYYjQYIfPY9bOXibOXiNJWYRKWiRKWiJIWIBGVi:EVI2CUi2CUiVNWIVNWIZOWY^PWibQX9jSXYnT
Xj2UY9bLW9bLW9bLW9ZJVYNGUiJFUYRHV9ZJVY^KVi^KViZJVYVIVIRHV9NGUiNGUiNGUiZHUiNEU9BB
TIBBTIFCTY:@Sh^9R8B2PGeiM7YfLGA`Jfm[IVYVHFMSGVIRGFIRGFQOG6EMEV9LCeiKCEYKDUEHG51E
I4eBJdA=Ld=<Md=<OT1;QC]:R3Q:RcA8RC99QcA2U390TRlmSb`mSR`oT313U356Uc=8VCQ>ScQ>ScU?
T3Y@TC]ATSaBTceCU3iDUDULScmGTCaFTTeLRVIWO7M/KWM[IG9XHFi[Hfi[HfeZHVaYHF]XH6YWGfUV
GVUVGVMUFfMUFfMUFfMUFfMUFfMUFfMUFfMUFfAUFfEVG6UXGV]ZH6e[HFe[HFmZHFmZHFMWEfQXF6QX
F6QWFFUWG6YXGFYXGVYXGVYXGFQVFfITFFAREf=QEV=QEVAREfAREfYYFfUXFVMVF6=RE5eLCUUHBUUH
BU]JC59EAUAGB5MGBEIFB5EEAEADA5ICA5ICA5EC@EEC@EEC@EICA5UFAeeJC69ODFAQDf1UEV=TH5MD
ETm>BUiPCFEYD6AVDfeZHWV1Mi>JTg5hLKRn^JJ[ZJ2UXj2UY9^PWifTXJZa[X^BSgQoO5]RGeMNFbhe
<QlV8cLg?AhN90T;300100<70BH/8DM>@DiEASPe<FAQGFUVHVYWHgEbKVQUHFeZIW5^JW1`I7=cIg5a
IFYZGVUYGFYZGVATF5YJCV1SE5aOD5AIBV1TF5AJCdE=@TaDBSe5>cPg<cTh=4];AEYKDE1BATA7>4U<
?59F@dU=AdQ<ATI:A4E9@dI:A4Q<ATa@BTiBC5mOFEmOFEmOFEiPFUeQFeeQFeYQFUYQFU5HDE5HDEAH
DU=GDEAFD5ADCU5ABe1@BTiECTiECTiECTiECTmFCe1GD55HDE9IDTQ>BDM=B4I<AdE;ATI<AdM=B4U?
BT]AC457@TU?BT98@d=9A498@cm5@4=9A3To>S]0=ce3>3i2=c`m>CPj@SXlE4=5KTY=P3i8R4YCS456
KCPiCS`m@Clo>D10<Sm0<3Y3=SY3=SU2=CY3=S]4=c]4=c]4=cY3=SHo<Se6>DM@@daEB4eFBDmHBe=L
CeMPDeMTE65^H5]XFU=ODeUUFF1[HEMRF4iIDDQHAdEEA4IFADmLC5UTE5QSDe5KBdUC@dmB@dmB@eMJ
BfIYFVmbHg1cI6e`HFe`HFY[EfY[EfY[Ef]/F6a]FFi_Ffm`G71aGFm^H71_HG1_HG5`HW1_HFm^H6i]
Gfi]Gfi]Gfm^H75`HW9aHg=bI7=bI7=bI7=bI6i^G6YZF6YZFW1`H7AcIGAcIGEcJ7QfJgEcJ7EcJ7Ec
J7AbIgAbIg=aIW=aIW=aIW5_I7MeJW=aIVm]HWEcJ7YhKGajKh1nLijMSjBSUJBSUJ:QTjj]Wk^j[;6`
XYZIRi^ISZBRUjVWW:BRUiJDRHf;P8f;P9:@QIBDQ96APIFEQHj>OWYjJWAdI7YjJWQhJ71_HG9aHgIe
IgUhJW]jK7]jK7YiJgYiJg]jK7]jK7]jK7]jK7YiJgQgJGMfJ7IeIgYiJgUhJWQgJGQgJGQgJGQgJGUh
JWYiJgQgJGQgJGYiJg]jK7akKGakKGakKGakKGmnL7mnL7mnL7mnL7imKgakKG]jK7YiJgMfJ7MfJ7Mf
J7MfJ7QgJGQgJGUhJWUhJW]jK7]jK7]jK7akKGakKGelKWelKWelKWinK7inK7inK7inK7moKH20KX:2
L8:2L820KX20KWmoKH20KX61Kh:2L8B4LXF5LhN5LhN5LhN5LhN5LhR6M8R6M8R6M8V7MHN7MHR8MXR8
MXV9MhZ:N8^;NHb<NXb<NXR?P829O8VCQh2>Pd=CC1HW8`lR7aP]:a4_91dh;QL_8b8f:S93=TeLCQDO
4TUBAFm_HgAdIWemJh^8LiNCNZJPPkB]S;jeTm76Z<k3YL^nW/VjV/VhUlZjU/jlUlnmV<^lW<^lW<^l
W<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<bmWLbmWLbmWLfnW/fn
W/fnW/bnV/bnV/bnV/bnV/bnV/bnV/bnV/bnV/k0W<foVlfoVlbnV/bnV/^mVL^mVL^mVLZlV<ZlV<Zl
V<^mVL^mVLbnV/bnV/bnV/^mVL^mVL^mVL^mVL^mVL^mVL^mVL^mVL^mVL^mVL^mVL^mVL^mVL^mVL^m
VL^mVLZlV<ZlV<ZlV<^mVL^mVLbnV/bnV/bnV/^mVL^mVLbnV/bnV/bnV/foV`00bL2gbL2gbL2gbL2g
bL2gbL2gbL2gbL2gb/6hb/6hb/6hb/6hb/6hb/6hb/6hb/6hb<6hb<6hb<6hb<6hb<6hb<6hb<6hb<6h
b<6hb<6hb<6hb<6hb<6hb<6hb<6hb<6ha[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nf_[V`_kZaa;fdb;nf
bL2gakbd`kR``KB/dlVoc<:h_kF[[ZBJV8j4OgE[J5iDFDm5FDe1GU96IEU?KF5GLVEMMFMQMVQRMFMQ
MViWNG5ZNg9^OGA`OGAaOWEbPGMgPgUiOgYgOgYgP7]hPWejPgikQH1mQX5nQX5nRXJ5RhN6S8R7SHV8
SHV8SXZ9SXZ9Sh^:RHF4Sh^:Thn>T8j>THj@TI2BSXfAR8N;Ti>CU9BDUIFEUYJFVIVIWIfMX:2PX:2P
W9bLW9bLWIfMWIfMWYjNWinOWinOX:2PXJ6QX:2PWYjNW9bLW9bLW9bLWIfMWYjNW9^MWijPWYfOVIRJ
V9NIViZLViZLUiJHW9bLXJ6QYZJVZ:RXYjNWYZJVZ:RXZJVYZjVYZjVYZZRXZZRXZJNWZ:JVYjFUYjFU
X:BYX:BYX:BYXJFZXZJ[XjN/YJV^YZZ_VYjSVYjSVinTW:2UWJ6VWZ:WWZ:WWj>XWj>XWZ:WWZ:WWJ6V
W:2UVYjSV9bQUYZOTYRGTYRGU9ZIUI^JUYbKUifLUifLUifLWYjNXZ:RYZJVYjNWYZJVYJFUY:BTY:BT
XZ:RXZ:RXZ:RXZ:RXJ6QXJ6QX:2PX:2PWifLWI^JW9ZIViVHVINFT8j=Ph60NGMfLg1XLFiVK6UQJ6EM
IV=KIF9JIV=KIfALGF=BHFMDHFUHFV9KBeAR?4Mc<d69<T2I9SZI93NJ7S:M6bjQ5bfT52bV4bjW4BnV
32>^2R6/1ajY0afW0AfW0anY1R>]2BJ`22ZR2B^S2RbT2bfU32jV3BnW3S2X3S2X3bbO22bR3C:T:DNP
DV2AKg=nMWQ/LGMPLVmZLVmZLFiYL6eXKfaWKV]VKV]VKFYUJfYPJfYPJfYPJfYPJfYPJfYPJfYPJfYP
IfQNJ6UOJfYPKFaRKVaRKVaRL6]RKfYQK6aLKFaNKFaNKF]PKF]PKVaRKV]SKV]SK6YOJVQMJ6IKIF=H
I69GI69GIF=HIF=HJVUKJfYLJFQJI6=EH5mAGUe?GEa>GEa>EeY:FUe=GUm?GUm?G5]=FUU;GEY<GU]=
DU90DE4oD510D510DU53EUA9FUQ>GE]ADeeGBTiC=SQ3<SDiCE=8KG=POX1dPh60F61IJg=/A4]6T9ND
SYFBVj6PZ:j]Z:f^U9bKSiNFC5AC5alN00401@d<00P71`l>0006000410D90@<30@D08RLNDEM<J6mR
4Q0?FeUHMG=bMWAcP7imN7IeNGMfL6i]LW=YMGI/M7E[LW=YM7E[NGY`NGY`MGI/KW=TN7a`LgM[IF]P
?4@i;cL]FV9KLGUb?3Xi?SdiF5QBIVMNE5E;C4m0F5];Gf9BEEUDE5QCE5QCEEUDEe]FFemJGf=NHFEP
IF=KIfEMJ6UPJV]RJFaSJ6eTJ6eTJFiUIFYQIV]RIfaSJVeTJfaSJFYQJ6INIfEMGfAKHFIMHfQOI6UP
HfQOHFIMGV=JG65HHVIPHFEOH6ANGf=MH6ANHVIPI6QRIFUSL7A^KW9/Gf=ML7A^KG5[F5aFIFUSIf]U
JF][JFYVJV]RJfeQK71UJW5/Ig1cI6mgEFUjHG5nHV]dG5mSJfUXM6m/If=NIF5LGFAGGFAGGVEHGFAG
G6=FG6=FG6=FGFAGF5mBG6=FH6MJH6MJG6=FF5mBEeiAF5mBFfIFFVAGGFMJ?dTmNXAhO8EkRI:8MWig
MhIhNHQjNHQjMhAfLG]^IW1SFF9ECeQ;BTdnBdhoEUU:IfYKLWEVL7=TJFaMIFQIJV]GJV]GJV]GJV]G
K6eIKVmKL75MLW=OLW5SLg9TLg9TLg9TLg9TLW5SL6mQL6mQKVeOKfiPLG1RLg9TM7=UM7=UM7=UM7=U
LW9PKFeKJf]KL71PLg9TLW5SLW1UMWAYMWAYMWAYMG=XMG=XM79WM79WM79WM79WM79WQH=hPGmdNGM/
Ph5fR8IkR8IkTi66[:^M/K2RZ:NIUYF7TI22UYF7SXeoOGa^SXb1WifB/:jS]K>XZjVNWifBVIN<V9J;
SHanTY63WIb>U9>5MGAVJ6MIKVeOKfiPKfiPLG1RMGAVNGQZNgY/NgY/NWU[N7MYNWU[NgY/O7]]O7]]
NgY/NWU[N7MYMgIXNGQZNGQZN7MYMgIXMgIXN7MYNGQZNGQZN7MYNGQZNWU[O7]]OGa^OGa^O7]]O7]]
Ogi`Ogi`Ogi`Ogi`OWe_O7]]NWU[NGQZN7MYN7MYNGQZNWU[NWU[NWU[NWU[NWU[NgY/NgY/NgY/O7]]
O7]]OGa^OGa^OGa^OWi/OWi/OWi/OWi/Ogm]P81^PX9`PX9`PH5_PH5_PH5_PH5_PX9`Ph=aQ8AbQ8Ab
R8IdR8IdR8IdR8IdRHMeRHMeRXQfRXQfQhMeQhMeR8QfRHUgRXYhRh]iRh]iS8ajRI60Q8inTI^;QY23
DUeC5B8J2AP@5B<M6b@G7bHG92TJ7Ah>=cDSF550F54nRh5_Ui9mX9V5ZZF<]JjC`;JHaK^Ib;nJcL:L
b;VHbKZIbkfIcknKcknKd;jIc[bGc;ZEbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbL
bkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLc;fMc;fMcKjNcKjNc;jJc;jJc;jJc;jJc;jJc;jJc;jJc;jJ
cKnKcKnKcKnKc;jJbkfIbkfIb[bHb[bHbK^Gb[bHb[bHb[bHbkfIbkfIbkfIc;jJbkfIbkfIbkfIbkfI
bkfIbkfIbkfIbkfIb[bHb[bHb[bHb[bHbkfIbkfIbkfIbkfIbK^Gb[bHb[bHb[bHbkfIbkfIbkfIc;jJ
bkfIbkfIbkfIbkfIc;jJc;jJ0038_kK8_kK8_kK8_kK8_kK8_kK8_kK8_kK9`;O9`;O9`;O9`;O9`;O9
`;O9`;O9`;O7`;O7`;O7`;O7`;O7`;O7`;O7`;O7`;O8`KS8`KS8`KS8`KS8`KS8`KS8`KS8`KS6_kK6
_kK6_kK6_kK6_kK6_kK6_kK6_kK6`KS6`KS4_kK2^k;1^:o2^K38_KG>`k^l/ZS1]jg9_kG=`kW:`;Jm
/jV[XINOUH]bIeUYGE5NDTIGBd5ICD=UF51dIV1nL6YbJ65eJfAhKFUjKf]kKfenLW21MGF4N7QmN7En
NGJ0NgR1O7V3OW^5P7f7PWn7PWn7Ph:8Q8>9QHB9QHB9QHB:QXF=RHR@S8^ATY2BTi6?Shn:RH^=S8jF
UIVLVinMVj6CTi>FUYJFUYJFUYJIVIVPX:2TY:BTY:BNWYjNWYjOWinPX:2PX:2QXJ6RXZ:RXZ:QXJ6P
X:2OWinOWinNWYjOWinOWinOWinJVI^MW9jMW9jJVI^JVI^OWZ2QX::NWInDUYNHVY^KWIjKWIjIVibH
VY^KWIjNX:6SXZBSXZBSXZBTXjFUY:JVYJNVYJNVYJNLWj>LWj>LWj>LWj>MX:BOXZJPXjNQY:ROXZJO
XZJOXZJPXjNQY:RRYJVRYJVSYZZLWj>KWZ:JWJ6JWJ6KWZ:JWJ6GVYjEV9bGVibHW9fJWYnKWj2LX:6L
X:6LX:6LX:6IVibLWYnQXjBSYJJQXjBNX:6LWYnLWYnLWYnLWYnMWj2NX:6MWj2MWj2LWYnKWIjLVYVL
VYVKVIRGUIB@SXf3PH1eLg9/JVUbL6I_KF=[JEmXIUaUHeUUHeUVI5YWIE]HI4iOJeEQKE]DH60lBVLT
<g/E:9LA9:d78ZP47ZP16JT05J/05:h05[806[@37[D03kD03kD04;H04;D04KH04kP06;d07<407;P0
7;P07KT07[X07k/08Kd08Kd08[h07[H07;T09;/G?;A5GJEXMH]cOG5^Nf5jMg9iMW5iMW5hMG1hMG1g
M6mgM6mfLfieLf]eLf]eLf]eLf]eLf]eLf]eLf]eLf]/KFA/KFA_KFE_KFE_K6A^Jf=_JF9^J65aL69a
L69aKfAaKfAaKfEaKVIaKVIaKVIbL6EaKfA_KF9]Jf1[JEiZJ5eZJ5eZJ5eYJ5YZJE]XIeUUI5ISHUAS
HUAMG4iFEDMFFTMKGdaRHe=TIEETHeESHUAWHeQZIU]UIU9TI59RHU9PGe5PGU=RH5IUHUYVHUe=F60_
=dPK83DH7R//<S5HH5IfNWE^KWAoQgf?UXmjPGZ]/jjW[:ZW[:ZRYjJJWij_][>X[jb2RHIVKFYEG5U=
E54c>SL[<Rlh>S/P8R<<3Ph00`40100E6Q4W;2<R:1dA4Pi9BTIFEe=OH5aFEe=GF5AMGUYHFEERHUIP
H5APH5ARHUIOGe=LG51NGU9SHeMFFDYMH55GG4eDF4`f?34/=2UCFe5SJf4j>S@k>cEEEDmLGEA2@cXk
?391@SPe=Ra2AT13Ad54B496BTA8C4I;CdU>DTa?DdePGUARHEMWIUaWJ5iWJ5iUJEiTJUmVK65YKfA[
LFI`M6UeMVagN6iiN6iiN6ijN6i`M6UaMFYbMV]aMFY^LVMYKF9TJ5ePI5UUIf5UIf5UIf5UIf5UIf5V
J69XJVAXJVAWJF=SIEm<CTQSIEmMGeTo@C]GFE=PHUaRHfMSI69UIUaZJe]]Lea[MEiWMEeQLeaGKE]K
KEaOJEaEFDeWIUaiMG1/JFEaKVYYKF5[Kf=[Kf=ZKV9XK61VJUiWJemXK61XK61XK61YKF5YKF5YKF5W
JemUJEeSIe]RJEYMI5MOIUTc>Bj;THJ>ThZUZZ6=TH^?VhnGXiNOZIfLYYZGWiBCVHj<TXN9SH9nPG9g
NV]dMfQfNFYeN6U^LF9XJeaVJEYXJEEXJEEWJ5AWJ5AYJUI[K5Q^Ke]`LEeeM6IeM6IeM6IeM6IdLfEc
LVAaL69aL69_KV1`Kf5aL69cLVAdLfEdLfEdLfEdLfEeMF=_Kee/K5a`L61aL69`Kf5aKfAdLVMfM6Uf
M6UfM6UfM6UeLfQeLfQdLVMdLVN1OgBOWI:MVi2AShBLVXnMVi2MVi2_[J:a/::j^J^c/ZBFUHMjNF]b
LF=fMFMiN6Z9QgbHUX^[ZIjd/ZN]Zj2OWI:AShB9Qgb6QGN>SGnMW8jEU8IfMFMXIeU_KV1bLF=dLfEe
M6IgMVQkNVanOFmoOW1lNfeiN6YiN6YjNF]kNValNfelNfejNF]hMfUgMVQiN6YhMfUhMfUgMVQgMVQh
MfUhMfUiN6YiN6YiN6YkNValNfemO6imO6imO6imO6imO6imO6imO6imO6ilNfekNVajNF]iN6YhMfUi
N6YjNF]kNVakNVakNVajNF]jNF]kNVakNVakNValNfelNfemO6imO6imO6inOVanOVanOVanOVaoOff0
P6j2PW22PW21PFn1PFn2PW22PW23Pg63Pg63Pg63Pg68QWB8QWB8QWB9QgF9QgF9QgF:R7J:R7J7QgF7
QgF8R7J8R7J9RGN:RWR:RWR;RgV8SGR6RgJBUX>2QW=RIEDW:Q/K7PlT9QXb:ADm=21MDSaPDceoLEZO
SWBbXHOA_JBi/I>o]iW8_Z3=a:?=`Z;;_ig7^iW7^IG7^IG8^YK:_9S;_IW<_Y[<_Y[<_Y[<_Y[;_9c;
_9c;_9c;_9c;_9c;_9c;_9c;_9c:^i_:^i_:^i_:^i_:^i_:^i_:^i_:^i_:^i_:^i_;_9c;_9c;_9c<
_Ig<_Ig<_Ig;_IW;_IW;_IW;_IW;_IW;_IW;_IW;_IW<_Y[<_Y[<_Y[;_IW;_IW;_IW;_IW;_IW9^iO9
^iO9^iO:_9S:_9S;_IW;_IW;_IW:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S9^iO9^iO:_9S:_9S:_9S;
_IW;_IW;_IW9^iO9^iO9^iO:_9S:_9S;_IW;_IW;_IW:_9S:_9S;_IW;_IW;_IW<_YX00<Ro]/Ro]/Ro
]/Ro]/Ro]/Ro]/Ro]/Ro]/W0]lW0]lW0]lW0]lW0]lW0]lW0]lW0]lO0]lO0]lO0]lO0]lO0]lO0]lO0
]lO0]lS1^<S1^<S1^<S1^<S1^<S1^<S1^<S1^<Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo][FcZKfk/LW4
^lo:`M39`<g4^lRo]/Nl]<g4^/_2^<[1]lW0]/Ro]LJm/l6h[[fdZ/6dYZnRU9B6NWU[GfMHCf5ABV9B
BfIFCfYPFFeSG75VHWAYIGIZJ7U]JgeaLH1dM7YeLW]fLgehMGmjMh5lNHAoO8F0OHJ1OWekNX5oOXF3
PXN5Q8R6QHZ8Qhj<Ri:@SgUkNhB6QY2BTYRGVIZIWIZIWI:@UXV7SI>CTiNGUiRHV9JFUYVIVJ6QXJFU
YJ>SXj>SXj>SXj>SXj:RXZ:RXZ6QXJ6QXJ6QXJ2PX:2PX:6QXJ:RXZ:RXZ:RXZ6QXJ6QXIbKWInNX9jM
WiZIVi^JW:6PXZ>RY:2OXIjPXJ6SY:>UYZ>UYZ>UYZ>UYZFWZ:JXZInNX:2OXJ6PXZ>RY:FTYZJUYjNV
Z:RWZJV[[:RZZjJXZJFWZ:BVYjBVYjBVYjBVYjNYZZJXZJJXZJFWZ:BVYj>UYZ:TYJ:TYJ:TYJ2RXinQ
XZ6SY:BVYjBVYj6SY9nQXYfOX9jPXJ2RXj:TYJ:TYJ:TYJ6SY:6SY9nQXZ6SY::TYJ:TYJ6SY:2RXj6S
Y:>UYZ>UYZ>UYZBVYjBVYjBVYj:TYJ2RXinQXZBRXJBRXJ6OWYVGUXf;RX5oOWMeM79`Kfm]Hfe[HFYX
GVMUFfESFFARF6ARF6ARF61QEfEXFFMYGEYOH45<JRHeOQ4VV@HN[00JY`0GY`0CZ@0?ZP0>Z`8A[@DE
[PTG[`0@[00C[`0F/P0G/`0G/`0I]@<O^PPT_`0Q_`0Q_`0R`00S`@0U``4Va08Wa@8Wa@H^`P0W`P0W
`Q@k_4AI[VYbUgMkO7AiJW]jMW]jMW]jMW]jMW]jMW]jMW]jMWYiMGYkLWYkLWYkLWYkLWYkLWYkLWYk
LWYkLWEfKGEfKGIdK7EcJgAaJG9_Ig5[I71ZHgAcIGAbIg=aIW=aIg=`J7=`J7=_JW=_JWEcJ7EcJ7Ab
Ig=aIW5_I6m]HVe[H6aZGfYYFfa[GFUXFVMVF6QWFFQWFE]JC4a;?DQ=>51E@5]MBV1QDF=RE6ESF6aW
GW1[HW5cGg1bGW1aHG1`HW5`IW=aJGEbKGMdL5]YNc<lEbH[C20V?A/R:dQ@Cfe`MEEEHf1VFf]aIVic
JX25O8F9PiNKUZFYY;6d/YnUX7Z0NeeSGV5WHXF;QX:8Pg^1O7f3OXN7PFATGTQ8@Slo>DI6@5QHDUQI
D493>T]=AeUKEE=ECgUkMEaNF5]MEeaNF69TGUmND5UHBUiMCfIUEeiMCdi=?e1?@EiMCe1B?dQ9>D93
<e5DADmDADY>@U9HCD57?3`m<c@e:dI7?TU:@CDe;clo>DE4@2HU8CLh;cTj<C/l<cdn=Cho=Sho=Sho
=Sho=Sdk<D4o=DE4>TI5>d=4>Sm3>3m3>455>T96>d=7?4E9?TY;@Di=@e1?AE9@AU=AAe=GC5=GC5=G
C55EBTmCB4a@ADU=@TM;@4=6?D=6?DA7?TE8?dE8?dE8?dE8?dA7?UIID5aOET13>TmBBDE8?bX]94iA
B5=FCDE9A4U;AE1?AE5@@U1@?U1D@E9JBEAPCU9MCEAKCUYLD4E3>De;@EiNDU1BAU]ODeYNDUaPE5eQ
EE]ODeMKCeEICEIJCUQLD5]ODeQLD5QLD5aPE6=WFfQ/H6M[GfAXG6]^GfmaIFMYGCm0=Y:CRJ6RVK6b
ZJ2PVY6ISY^SV:>YWZ6WW::VVjFVW:BUVinPUYRKS8jAPX>6MgaoL7EhJFe`HFY]GVe`HFY[EfQYEFMX
E6MXE6QYEFY[Efe^FVm`G7EdIWEdIWEdIWEdIWAcIG9aHg5`HW1_HG1_HG5`HW9aHgAcIGAcIGAcIGAc
IGAcIGIfI6m_GFa/G6m_Gg5`HW1_HG5_I7AbIg9`IG9`IG9`IG9`IG5_I75_I71^Hg1^Hg=aIY^ISYbJ
Sh^9OY>AQY6?Q8n=PZNUVZRWVJNVV9bKSHJ5Mfm^H6ASEFUXFW9aHfUWG7AbIhJ4NINERZ2NTijLTIFC
R8f;P8^9OXn=PYZHSIBBQgajKg9`IGUgK7UgK7QgJGMfJ7QgJGYiJgimKgmnL7akKGUhJWIeIgMfJ7Uh
JW]jK7YiJgUhJWIeIgEdIWUhJWQgJGMfJ7MfJ7MfJ7MfJ7QgJGUhJWUhJWYiJg]jK7akKGelKWelKWel
KWelKWYiJgYiJg]jK7]jK7]jK7]jK7YiJgUhJWIeIgMfJ7UhJWYiJg]jK7YiJgUhJWQgJG]jK7]jK7]j
K7akKGakKGelKWelKWelKWinK7inK7inK7inK7moKH20KX:2L8:2L861Kh:2L8>3LH>3LH>3LH>3LH>3
LH>3LHJ4LXJ4LXN5LhN5LhR6M8R6M8R6M8R6M8R8MXR8MXR8MXR8MXV9MhV9MhV9MhV9Mhb;LH^9LIVE
OHb8L8n8M6QQCFMNBVaSCiR:KZNIO;V[S/JiVL2cTm?7YLVmVLbnV/6jTlFlUlRoV/VoWLVlW<NiW<Ni
W<NiW=75XLg1WLNkUl>gUL:fU<>iUlRnW<_1Wl^lW<^lW<^lW<^lW<^lW<^lW<^lW<^lW<ZkVlZkVlZk
VlZkVlZkVlZkVlZkVlZkVlZkVlZkVlZkVl^lW<^lW<^lW<bmWLbmWL^mVL^mVL^mVL^mVL^mVL^mVL^m
VL^mVLZlV<ZlV<ZlV<^mVL^mVL^mVL^mVL^mVLVkUlVkUlVkUlZlV<ZlV<ZlV<^mVL^mVLZlV<ZlV<Zl
V<ZlV<ZlV<ZlV<ZlV<ZlV<RjU/VkUlVkUlVkUlZlV<^mVL^mVL^mVLVkUlVkUlVkUlZlV<ZlV<ZlV<^m
VL^mVLZlV<ZlV<ZlV<^mVL^mVL^mV@00b;nfb;nfb;nfb;nfb;nfb;nfb;nfb;nfbL2gbL2gbL2gbL2g
bL2gbL2gbL2gbL2gal2gal2gal2gal2gal2gal2gal2gal2gb<6hb<6hb<6hb<6hb<6hb<6hb<6hb<6h
a[nfa[nfa[nfa[nfa[nfa[nfa[nfa[nfb<JlaL>ia;nf`Kbc`[^baKbca[fdakjea;^a`[V_`;N]`[V_
aKbbakjdb;neakjda[V[bKb^bKb^`K>W[YnFThAkN6QQIeM@IEUCJ5aFK61LL6APLVESMVUWNVa]OW1a
N7=`NGAaNWEbOGQeOgYgPWejQ7mlQH1mPh60QhF4S8Z9SH^:RhV8RXR7RhV8SH^:T9FDTYBDS8j?QHN8
QhJ:T8jDV9BJVIFKTi>CV9RHVIVIUYJFV9RHXJ6QY:BTXJ6QXj>SXZ:RXJ6QWinOWYjNW9bLVi^KVYZJ
X:2PXJ6QXj>SYJFUYZJVYJFUY:BTXj>SXJ2RXj:TXJ2RW9^MViZLWYfOWijPW9^MUYVMV9^OVijRWJ2T
WZ6UWj:VX:>WX:>WXj:VY:>WYJBXYJBXYZFYYjJZZ:N[Z:N[YJ>RYJ>RYJ>RYZBSYjFTZ:JUZZRWZjVX
YZBSYZBSYjFTZ:JUZZRWZjVX[:ZY[:ZYZ:JUYZBSYZBSZ:JU[:ZY[J^ZZjVXZ:JUXinTY:2UYZ:WZ:BY
Z:BYZ:BYYj>XYZ:WVijRVijRVijRVYfQVIbPW9nSXZFYYZV]XjJZXjJZY:N[XjJZXZFYWj:VWJ2TVijR
XInNX9jMW9ZITHn>Ph60MgEdLW1_LFm^KVaRKF]QJfUOJFMMJ6ILIfEKIfEKIfEKKEmSKf=QKVMNIF=R
DEM^>4F37SBJ42VY0abR0AVQ11JS0a>R1a:R2Q:Q31>N3aFN012I0a>L1aNP1QRQ11NP1ARQ1afU2R2X
022c022c026d0B:e0R>f12Fh1BJi1BJi2cBc02Rb02Bb4CBcA5F/KfnMPW^:PGakNgYfNgYfNgYfNgYf
NgYfNgYfO7]gO7]gO7afO7afO7afO7afO7afO7afO7afO7afOgmiOWihOgagO7UdNWIaMg=^MW1[M6iY
M79WM79WM79WM79XM75YLg1XLfmZLfmZM79WMG=XMG=XM79WLW1UL6iSKF]PJfUNKfiPKfiPK6]MJVUK
KFaNK6]MFeY<AdHh>ChY@TLbD58oF5U9GEa>HEmDJfIMLFaSJVaHJfeIKVmOLG5SMGAZNGIaOGYfOg]j
Ceih8be?8BQ?7RA12A4N=ce2H69/@3iA<S@XA4HjIFILIFILJfaSNg]eQhN1V9RB]k^eM7QbCe==EEUC
RHf7Kg=]Gf=MFEeGFe]?Hf=GLg9XLG1VH5iFGEYEHUmJFeQCIVUPGV5HGf9I/;>ZR8^2M7M^GF1GGf9I
J6EFI65BLFiOQ85bOga]JfQIKfaMQX=dKVeIIFIBFe]9IfQHHVEEG5m@J6eNFemCKG1QGEmCIFILJ6UP
Hf=MQ8:1TY2@K6YZH61DHF5EHf=GIFEII6AHHV9FH61DGUiBH5iDI69HJFMMJ6MMHV=IGf1FGF5FGV9G
FemDFemDGEiDGEiDH5mEHEmEHV1FHV1FEEU>E5Q=DeM<DUI;DUI;DeM<EEU>EUY?EEQ?EUU@F5]BFEaC
FEaCF5]BEUU@EEQ?CU58HFAK@D@kADPo>3/b9bXQDEA;CU58Adi1D5A8EeM;De57BdQ0C4U5EUIFGf9V
KFa^L6i^N79cF55>DDa3EUM7?TD`BEHlBdm3CU96Ce=7C514B4a0ATXnAd/oBDe1C514Ad/o@dLkATXn
Ce=7E5Q<DEE9CE55AD@fEeE:B4Hk;bdSMG=YUY>;WY^CV9B?V9jCWZ:GW:2EUIJ<Si26T8n5RhUoPGme
M7MXKW5RK6mPK6mPK6mPJVeNKG1QLgIWKFiJK6eIJV]GJFYFJV]GK6eIKg1LLG9NM7=UM7=UM7=UM7=U
LW5SLG1RKfiPKVeOLG1RLW5SLg9TM7=UM7=UM7=UM7=ULg9TMGESKViLJf]KKViNLG1RL6mQLW1UMWAY
KF]PK6YOK6YOK6YOJfUNJfUNJfUNJVQMKF]PW9Z?WYbARXQmT8j3RXQmQhEjXZ2E/K2RWIb>RHQjPX5c
P7maNgY/MgIXMWEWRhUnSXb1UI>8XInDZJNLZ:JKWYbAU9:7TY25Shf2U9:7Shf2O7Y_MgEZNgU^MgEZ
N7MYMWEWMGAVN7MYNgY/O7]]NWU[MgIXM7=UMGAVN7MYNGQZNGQZMgIXMGAVLg9TN7MYN7MYMgIXMWEW
MWEWMgIXN7MYN7MYNGQZNWU[NgY/OGa^OGa^OWe_OGa^OGa^N7MYNGQZNWU[NWU[NgY/NWU[NWU[NGQZ
MGAVMWEWN7MYNGQZNGQZNGQZN7MYMgIXNgY/NgY/NgY/O7]]O7]]OGa^OGa^OGa^OWi/OWi/OWi/OWi/
Ogm]P81^PX9`PX9`PX9`PX9`Ph=aQ8AbQ8AbPh=aPh=aPX9`QH=aQH=aQH=aQXAbQXAbQXAbQhEcQhEc
RHUgRHUgRHUgR8QfR8QfR8QfR8QfR8QfUY9fUi1eY9f2XYUna;VN]JN@_ZjG`[:K`kNEb[jL^[6<cLBO
[:EndLfT_[ZA_;R?bL:Gb<2Ha[fGa;^F`[NGakVMbkbRd<2Y`[JBa;RFaK^IakfKakjMa[fLaK^Ma;ZL
bkbLbkbLbkbLbkbLbkbLbkbLbkbLbkbLb[^Kb[^Kb[^Kb[^Kb[^Kb[^Kb[^Kb[^Kb[^Kb[^Kb[^Kb[^K
bkbLbkbLc;fMc;fMbkfIbkfIbkfIbkfIbkfIbkfIbkfIbkfIbK^GbK^Gb[bHb[bHbkfIc;jJc;jJc;jJ
b;ZFbK^GbK^GbK^Gb[bHb[bHb[bHbkfIb[bHb[bHb[bHb[bHb[bHb[bHb[bHb[bHb;ZFb;ZFbK^GbK^G
b[bHb[bHbkfIbkfIb;ZFbK^GbK^GbK^Gb[bHb[bHb[bHbkfIb[bHb[bHb[bHb[bHbkfIbkfI0037_[C7
_[C7_[C7_[C7_[C7_[C7_[C7_[C7_[G7_[G7_[G8_kK8_kK8_kK9`;O9`;O6_kK6_kK6_kK6_kK6_kK6
_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK6_kK4_KC4
_KC4_KC5_[G5_[G5_[G6_kK6_kK4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC5_[G3_;?2^k;2^k;2^k:o
^:nk]:^g/:NER826NG5cIUiXFe=YG5A`He]fJF5iK6AfJfMgK6QiKVYkL6aoM723N7B7O7R9OWZ7Q7b9
QWj:QX69Q868Ph2:QHB@RhZESi2>Shf=SXb<SH^;Rh^=S8j@Si6DTiNGUYZ@TiNBUIVEV9bFVIfGVYjI
W:2MX:BPXjNUXIbNVYFBSXV5PGahM6mcKfYnNWF<R8>BTI>EU9JJVI^PWj6SXZBUY:JVYJNVYJNOXJ:N
X:6LWYnJW9fIVibIVibIVibIVibOXJ:RY:FUYjRTYZNQXjBQXjBUYjRYZjbSYJJSYJJSYJJTYZNTYZNT
YZNUYjRUYjRUYjRTYZNRY:FNX:6MWj2OXJ:TYZNXZZ^UYjRUYjRUYjRVZ:VVZ:VVZ:VWZJZWZJZUYJ^U
YJ^UYJ^UYJ^UYJ^SXjVRXZRQXJNQY:VPXjROXZNQY:VSYZ^UZ:fTYjbSYZ^PX:JPX:JPX:JPX:JPX:JQ
XJNQXJNQXJNUYjRUYjRUYjRWZJZXZZ^WZJZSYJJPXZ>SY::RXj6IVYJ:RHF0OGQjMg9gM6abKfM_K6A^
Jf=/JF5ZIemYIUiYIUiYIUiYIUiXIUiWJEeUJU]PJ5eLI6=JGfiIG7]KFX@c@I<Z>i8O<Y<B;9P89j00
8JL06jT05ZT77jd47:`05jP04ZP04Z/05K806KL07;`47kH47kH18;L18KX08kd09[l09l<0:L@5:;h2
;<D0;<L1<[hPBkYCK[5eOYUoOGejNGEkNWIkNWIlNgMkNWIkNWIjNGEiN7AmO7QlNgMlNgMkNWIjNGEj
NGEiN7AiN7AgN6mgN6mfMfieMVedMFacM6]cM6]bLfYfLf]eLVYdLFUcL6QcL6QcL6QcL6QdLFUdLVQd
LVQdLVQdLVQdLVQdLVQdLVQdLVQbL6I_KF=/JV1]Jf5`KVA`KVA^K69[JEmHEdUFEDMDDdEDDdEHEdUN
GDmVIEMZJE]bL6IbL6IcLFMeLfUfM6YgMF]hMVaiMfe[K8QIGWdmBF/R=EPH:TLN;Cd`>C`n@Sdb<2I5
@cUKFDmTHUQSHEMUHeU`KVAlNW2AShEeLfURH5I/JV1iMfefM6Y[JEmUHeUYJEUYJEUXJ5QXJ5QWIeMV
IUIVIUIVIUI]K5iXIU]^Jf>XY9nSWiYUHUYVI5UcLVAZJUY]KEebLF=fMFMgMFYdLVQ`KVA]Jf5bL5i/
JUQVI59THU1WIE=[JEM]JeU]JeU/K5acLf=dLfEbLF=lNVn;RGn:R7inO79aKfA_KF9]Jf1^K65`KV=_
KF9ZJ5eVI5UZJ5e[JEi]Jf1_KF9`KV=aKfAaKfAaKfAaKfAaKfAaKfAbL6EbL6EcLFIcLFIcLFI^KUiZ
JUYUIEEUIEEXJ5Q[Je]/K5a[Je]^KEm^KEm_KV1`Kf5`Kf5_KV1^KEm^KEmXIeUYJ5YYJ5YYJ5YXIeUU
I5IRHE=QH59YJUIQHTiTI5A[JUaTHUQQGER4Ogbc[Zfc/<33`Lfe/kV0P81PHEQVIeM/KUYUJ4mZJEEY
J5AYJ5AXIe=YJ5AZJEE[JUI[JUI]K5Q/JeM[JUIZJEEYJ5AXIe=WIU9VIE5HFd]GFTYIG4eRIEI]Kf=c
M6YcM6Y`LFMdMfQcMVMbMFI`LfA^LF9]L65/Kf1[KUmZJE][JUa/Jee^KEm_KV1aL69bLF=cLVA`L5ia
LEmaLEm_Kee/K5Y/K5Y]KE]_Kee[KUi/Kem/Kf1/Kf1/KV9[K69ZJf5YJV1ZK61ZK61XJUiXJUiXJUiZ
K61[KF5]Kf=`LfA`LfAbLVA`L69_KV1`Kf5dLF=gM6I_KV1_KV1^KEm^KEm_KV1`Kf5aL69aL69eMf^9
RgnHVXjIVhnEUh^GVHfJW92JW92UY9JYZ9Z^[In][9jUY9JEU8J5Q7IkNVbLWi2VZIZ`/jB_/Z>OXY>:
SGihNfa^LF9bMfQcN6UcN6UfNFYiNF]jNValNfemO6ieN6UgNV]iO6eiO6egNV]fNFYhNfakOVmjOFih
NfafNFYeN6UdMfQdMfQeN6UfNFYjNVQkNfUlO6YmOF]mOF]mOF]lO6YlO6YjOV]jOV]jOV]iOFYhO6Ug
NfQgNfQgNfQhNfahNfagNV]fNFYeN6UdMfQdMfQcMVMcMVIcMVIeN6QfNFUgNVYgNVYgNVYfNFUmP71m
P71lOfmlOfmlOfmiO6afNFUcMVIoP6b1PVj2PW21PFmoOfmnOFmoOW20Og5iNFN3PWB5PGJ2OGAoNFj4
OFjCSGZ0O6B8PfZ8PfZ8PfZ8PfZ8PfZ9Q6^9Q6^9Q6^CQFnDQW2HRW>NTGNXWGnaYXJg[8bj/8jl[X[2
/i;5]YG6]iO9^Y[<_9o6]IZlZi32^9K2^9K1]iG1]YK2]iW3^9[5^Ig6^Yjn^9^n^9^o^Ibo^9g0^J31
^Z71^J;1^J:i/YW0]Yk?aZ_5^ig4^IWAaJ75^YC7^i?:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S:_9S:
_9S:_9S:_9S:_9S:_9S:_9S:_9S;_IW;_IW;_IW;_IW;_IW;_IW;_IW;_IW;^iO;^iO;^iO<_9S<_9S<
_9S=_IW=_IW=_iG=_YO=_YO=_IS=_IS=_IW=_IW=_9_8^YK8^YK9^iO9^iO:_9S;_IW;_IW;_IW;^iO;
^iO;^iO<_9S<_9S<_9S=_IW=_IW<_9S<_9S<_9S<_9S<_9S<_9S<_9S<_9S;^iO;^iO;^iO;^iO;^iO;
^iO;^iO;^iO<_Y[<_Y[;_IW;_IW;_IW;_IT00<Nn]<Nn]<Nn]<Nn]<Nn]<Nn]<Nn]<Nn]<Nn]LNn]LNn
]LNn]LRo]/Ro]/W0]lW0]lJo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo
]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/Jo]/>l/lBm]<Bm]<Bm]<Fn]LFn]LFn]LJo]/Bm]<Bm]<Bm
]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<>l/l:k//>l/lBm]<>l/l2i/;jg[/k1^L>f[[:UWJ6DS964O7mbJVeP
F65DC6eSG75WH7I/IGY`JGabJg]aJWQ^IgI/IG1ZHgYdKHV3OY:<Qi><RHj6QXR0P8EmOHb=RHj?SI2A
Si>CTi>BU9:ATi6@U92?Ti>EUYFGV9RJViVKW9ZLWIbNWj2RXjBVYjFQW7eiM55=B48n>E5=B6aXHhJ2
OIJBSIVHVYbKWJ2OXJBSYJNVZ:RWZJRWZJRWZJZ/[JNYZZ6SY9bNWiZLWI^MWYjPXJ2RXj:TYJ:TYJ:T
YJ2RXifOX9fOX9jPXInQXZ6SY:6SY:6SY:6SY::TYJ:TYJ>UYZ>UYZ6SY:2RXinQXYbNWi^MWYbNWj2R
Xj>UYZ>UYZ>UYZBVYjFWZ:JXZJNYZZRZZjRZZjNW[JNW[JRX[ZRX[ZNW[JJV[:FUZjBTZZBW[::UZZ:U
ZZ>VZjJY[ZNZ[jJY[ZFX[JBTZZBTZZFUZjFUZjJV[:JV[:NW[JNW[JFWZ:FWZ:JXZJRZZjZ/[JV[[:FW
Z::TYJ>TXZ:SXIRIUHV8Q7ikMWUfLGMdK7=`J71]IFi[HfeZHV]XH6YWGfUVGVUVGVUVGVUUH6YYGfY]
GVQ/H6=YI61UKUmQNF5PP5aRSeANSTaGT4=CUC]@VcE=XBi9Y2M5Y2DjYb4eY1L_X@lWWPPRWPDPX0@P
X`<PYP<NY08OYP8PY`0QZP0S[@0U[`0W/P0X/`DZ/0@]^00]^@0^/QM3[TESZVIgV79hPgelN7elN7el
N7elN7akMgYiMGQgLgMfLWQgLgQgLgQgLgMfLWMfLWIeLGIeLGEdL75bJG5bJG5bJG5bJG1aJ71aJ6m`
Ifm`IgIcJgIcJgEbJWAaJGAaJGAaJGAaJGAaJGAbJ7AbJ7AbJ7AbJ7AbJ7AbJ7AbJ7AbJ79`IVm]Hfe[
HFi/HW1^I71^I6i/HVaZH6YXGFUWG6MUFVITFFQVFfaZGg1^Hg=aIW5_IG5_IG9`IW=aIgAbJ7EcJGId
JWIdJVe]OEAJKBlkDa<R?0`J<1`X=3]0@E5CCF5OEFQVG6m]Hfm]HfYXGVARF6=QEfESFGIdJVESFEiL
DVYXGW9`IVi/HVMUFfMUFf][Ff][FfYZFVYZFVUYFFUYFFQXF6QXF6ASEFYXGFaYHHj:QHZ6PFERFVUW
G6]ZG6UYFF][Ffm^H79aHg=aIW5_IFi/HV]YGg5_GFaZF6QVE6MUDfYXEVaZF6e[FFe[FFUYFFm_Gfm^
H6e/GWEcJ8:0MX5oMGIdJW5_I71^Hfi/HG1^Hg5_I75_I6e[H6UWG6]YGVaZGfe[H6m]HW1^Hg5_I75_
I71^Hg1^Hg1^Hg5_I75_I75_I79`IG9`IG9`IG1`H6e]GFUYFFQXF6][Ffi^GVi^GVe]GFi]Gfm^H71_
HG1_HG1_HG1_HFm^H6i]GfYYFfYYFfYYFfYYFfQWFFMVF6IUEfETEVQYEF5RCV9RDVUXFVITFVAQFGUe
L9NBShf=TinNXYRHV7UhM6AUFf]/G75bGVa^F6]ZEVYYEFYYEFUXE6UXE6YYEF]ZEVa[Efi]FFi]FFe/
F6a[Ef]ZEV]ZEVYYEFYYEFAYE69VDf5UDVIYFFa_H6mbHfa^HVQZGV]^Gf]^Gfa_H6a_H6e`HFiaHVia
HVmbHf]ZG6]ZG6a[GFe/GVi]Gfm^H71_HG5`HVi^G6m_GFm_GFe]Ff][FFYZF6a/FVi^G6]^GVa_Gfe`
HFe`HFe_Hfe^I6a]Hf]/HVmaIFi`I6e_Hfa^HVe_Hfi`I71bIW5cIg1cI71cI75aHfm_HFi]Gfi]Gg=`
HWIcIG5`HW5`HW1_HG1_HG1_HG5`HW=bI7=bI6i`I7]mLHF7Nh>5NGn1MGn1MGn1MGeoLi2?PIZIRjRW
VK:aXk>bY:^ZW9jMSiFDQ[6dYK2cY:Z]WYbOT8V<OGYmKW=fIg5dIFmdIG1eIW1eIW=fIgIfJ7MgJGUh
JWUhJWEhJGIiJWQkK7QkK7QkK7MjJgQkK7QkK79eIW9eIW=fIg=fIgEhJGMjJgQkK7UlKGEeHgIfI7Qh
IWUiIgYjJ7YjJ7YjJ7YjJ7QlJGQlJGUmJWYnJg]oK7]oK7b0KGb0KGUlK7UlK7UlK7YmKGYmKG]nKW]n
KWaoKgEhJ7EhJ7IiJGIiJGEhJ7AgIg=fIW9eIG=fIWAgIgMjJW]nKWf0L7f0L7]nKWUlK7enJWmoKH:2
L8>3Lh:2LX>2M8B2MhJ4NHj?OhZ9Nh:0MHR3NXEoM8N2LgYdHGahH7efFh1iGXIoI8b5JY><LIVBMifF
NinHOK^]U[b_UKjaUl2dV<>hV/FjV/FkVLBjV<W0W/NnWLNnWLRnX<JlW/6fV[N/TK2URZBLOYnGNIJ>
LHj6JHQoI8MmIHQnIXUoIgmkHX5mI8F1J8Z6KXn:MI>>NIF?O9J@OJbUT[B[UlJkYKjcV<2eUm74Y<^m
VLfoVlZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<ZlV<^mVL^mVL^m
VL^mVL^mVL^mVL^mVL^mVLZjU/^kUl^kUl^kUlblV<blV<blV<fmVLfoULfnUlfnUlfmV<fmV<fmVLfm
VLflVlVkUlVkUlVkUlVkUlZlV<ZlV<ZlV<ZlV<ZjU/^kUl^kUl^kUlblV<blV<blV<fmVL^kUl^kUl^k
Ul^kUl^kUl^kUl^kUl^kUlZjU/ZjU/ZjU/ZjU/ZjU/ZjU/ZjU/ZjU/ZlV<ZlV<ZlV<ZlV<ZlV<ZlV000
a[fca[fca[fca[fca[fca[fca[fca[fca[fda[fdakjeakjeb;nfb;nfb;nfb;nfaKjeaKjeaKjeaKje
aKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKjeaKje
`kbc`kbca;fda;fda;fdaKjeaKjeaKjea;fda;fda;fda;fda;fda;fda;fda;fd`[^b`[^b`[^ba;fd
al2gal2ga[nfa;fd`kR``kR``kR``kR`_kB/]JZRYY^CVXn7MF]TLFMPK69KJEmHK69KLfURO79[PGM`
PGacOgUbO7I_NG=^NgAaPW]hSHF5UHf=PH9nQ8F1R8V7S8f;Shn?TI2BTI2BTI2BTI>DU9JGUYRIV9ZK
VI^LVifNWj6RXjFVYZ>OS8V5IfAPBDI2@ChjF5EARHJ2/Zn[ZJRZZjZ/[Jb^/:na/K2b/[6c/K2b/:na
/kFf[Jn`Y:JWW9jOVI^LW9jOXZBUYZRYXjFVXJ>TWZ2QWInPWZ2QWZ2QWInPW9jOWInPWZ2QWZ2QWZ2Q
Wj6RWj6RWj6RX::SWZ2QWj6RWj6RWZ2QW9jOW9jOWj6RXJ>TWj6RWj6RXJ>TXjFVYJNXYjVZZJ^/ZZb]
ZJV_ZJV_ZZZ`ZZZ`ZZZ`ZJV_Z:R^YjN]YZV^YJR]Y:N/YZV^Z:^`ZZfbZJbaZ:^`YZJ/YZJ/YjN]Z:R^
ZJV_ZZZ`Zj^aZj^aYJNXYJNXYZRYZJ^/Zjf^Zjf^ZJ^/YZRYYJJTXZ>QUiRDQhJ2O7UdN7E`MgA/M75Y
LFiVKfaTKV]SK6UQJfQPJVMOJVMOJVMOKVERKfURL6iSLG5UKVmVJF][J6UcJFQhMGEeLG=dKFmgJFaj
IFaoI6^6GfV7GFR8Cf2IBUbI@eFF>dfD<dFB;T2C:SbE:3^F7SJJ7cNK7SRL7CVN73^R73fT6cjV6cjV
73bO6d2X4SfZ3CVT74BM?UbMFfjCIg>5O7]gO7]gNgYfNWUeN7McMWEaM7=_Lg9^Lg9^Lg9^Lg9^LW5]
LW5]LW5]LG1/LG1/KVmVKVmVKVmVKg1WKg1WKg1WKg1WL75XMgA/MW=[MW=[MW=[MG9ZMG9ZMG9ZM75Y
Lg5WLg5WLg5WLg5WLg5WLg5WLg5WLg5WLW1VL6iTKfeSKfeSL6iTLFmUKfeSKF]QM79WLg5VLW1ULFmT
LFmTLFmTLW1ULg5VLFmULFmULFmULW1VLW1VLg5WLg5WLg5WM7IfJFiaEf1YBEEQAe5KDEMLHfARLFiV
NGM]MgE[M79XLg5WLW1VKfeSJ6ILHf5GJ6ILI69HIfEKLW1VM79XKF]QJfUOKfeSKFaNK6]MK6]MK6]M
JfYLJfYLJfYLJfYLGei@KF]PK6UQM71[LFeXIfALKfeRJ6MIJf]KK6aLKVeOL6mQL6iSKfeSKVaRKF]Q
KfeKKF]IJfUGJfUGKF]IKVaJKVaJKF]IJ6QHK6aLK6]MJVUKL6iSNGM]MgE[KVaRLFmTL6iSKfeRLFmT
LW1ULW1UL6iSKVaQKF]PKF]PKfeRL6iSL6iSL6iSL6iSKfeRKfeRKfeRL6iSL6iSL6iSLFmTLFmTLFmT
Lg9TL6mQKFaNKFaNKVeOL6mQLG1RL6mQKVeOKfiPL6mQL6mQL6mQL6mQKfiPKVeOK6]MK6]MJVUKJVUK
JFQJJFQJJFQJJFQJIFIBHV9@HV9BIVEGJ6IKJFMMKV]SM71[IFMQL79/MGI]JV]QIFEGJVYJKFeKJfaH
K6]GK6]GJfYFJVUEJVUEJfYFK6]GK6]GKVeIKVeIKVeIKVeIKVeIKVeIKVeIKVeIKW5KJfiHJFaFJVaH
KFmLKFmLJV]KIVMGIfQHJ6UIJFYJJfaLKFiNKVmOL75QL75QK6]MKFaNKFaNKFaNKVeOKVeOKfiPKfiP
KFeKKViLKViLK6aJJVYHJFUGJf]IKFeKJfiNK6mOKG1QKW5RKg5UKg1VKg1VKVmULG=WLG=WL79VL79V
L79VLG=WLWAXLgEYKg9SL7=TLG5SKViPKFaNKFaNLFiPM75SLg9TLg9TLW5SLW5SLW5SLg9TM7=UMGAV
KW1TMGM[N7Y^MWQ/LgEYLgEYLG=WKFmSNGQZPX5cT8n1WIb>Y:>EY:>EX9nAW9^=X:>DVij?TIB5PhIg
MgY[LgIWMWUZNgi_LGIWLWMXLWMXMGQYN7QZNGU[NWU[NWU[MGQYMGQYMWUZN7]/NWe^NWe^MgY[MGQY
Ngi_O7m`O7m`O7m`Ngi_NWe^NGa]NGa]NW][Nga/OGi^OWm_Oh1`Oh1`Oh1`Oh1`NGa/NGa/NWe]NWe]
Ngi^O7m_O7m_O7m_MGUVMGUVMGUVMGUVMWYWMWYWMWYWMWYWOH1aOH1aOH1aO7m`NWe^N7]/MWUZMGQY
M7MXMGQYMgY[N7]/N7]/MWUZM7MXLWEVLgERMgQXO7e]P81bPX9dQHEiR8MmRhZ0RHalR8QjQ8=iTi67
THb3XIj@OGUVYZ>>[JF7/:R:]Zj@_;BF`[ZLa[jPbL6Sb/:T_;BG_[JI`;RJ`[ZL`[^J`;ZG_[RE_;JC
/k2AXin2TXiaPgmSKf]?Ee8iC4H_CDL`BdL_Cd/cEe8mHUe8KfUFOGIUR85`SXMfZZVE[jjJ]K>Q_K^Y
`l2aalBfbLJhb/Ni`KV/aKb^d/Rfa;VU`;FJc/2SakRHb[^JbK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^G
bK^GbK^GbK^GbK^GbK^GbK^GbK^GbK^Gb[bHb[bHb[bHb[bHb[bHb[bHb[bHb[bHb[ZFb[ZFbk^Gbk^G
bk^Gc;bHc;bHc;bHc;jDc;fFc;fFc;bGc;bGc;bHc;bHc;^Jb[bHb[bHb[bHbK^GbK^GbK^GbK^GbK^G
b[ZFb[ZFbk^Gbk^Gbk^Gc;bHc;bHc;bHbk^Gbk^Gbk^Gbk^Gbk^Gbk^Gbk^Gbk^Gb[ZFb[ZFb[ZFb[ZF
b[ZFb[ZFb[ZFb[ZFbK^GbK^GbK^GbK^GbK^GbK^G0036_K?6_K?6_K?6_K?6_K?6_K?6_K?6_K?6_KC6
_KC6_KC7_[G7_[G7_[G8_kK8_kK5_[G5_[G5_[G5_[G5_[G5_[G5_[G5_[G5_[G5_[G5_[G5_[G5_[G5
_[G5_[G5_[G5_[G5_[G5_[G5_[G5_[G5_[G5_[G5_[G3_;?3_;?3_;?4_KC4_KC4_KC5_[G5_[G4_KC4
_KC4_KC4_KC4_KC4_KC4_KC4_KC3_;?2^k;2^k;3_;?6_kK8`KS7`;O5_[G4^K73^;33^;36^k?8_KG8
_KG5^[;1]Zjf[JB[XYVIT8N6OGAhKfI`Iei_IUe_IUe`JF1cK6=hL6UmMFj1N7B4NgR6OGZ7OW^4Q7j4
Pgn4Pgn5Ph:9QhJ=Rh^BSi6ETYB?ShnBTY:DU9BFUYJGUiNJVYZOWinRXZ:SX9b[Z:BXYJ6=RXIZIf=V
Hen=RXJj]k>`[k6a/;:c/[Bd/kFd/kFc/[Bb/K>b/K>_/K:YZjbQXjBKWIjIVibLWYnQXjBUYjRSYJJO
XJ:LWYnNX:6RY:FUYjRTYZNRY:FKWIjKWIjKWIjKWIjLWYnLWYnMWj2MWj2PXZ>RY:FTYZNSYJJQXjBP
XZ>QXjBSYJJJW9fKWIjMWj2PXZ>SYJJVZ:VXZZ^YZjbYZJnYZJnZZ[2[Zk6ZZ[2ZZ[2YZJnXZ:jWZZnU
Z:fUZ:fVZJjY[;6Z[K:Z[K:XZk2SXjVTY:ZUYJ^VYZbXZ:jYZJnZZ[2[Zk6VZ:VVZ:VWZJZYZjb/[Zn^
/;6/[ZnZ[:fVYjFSY::FUi>6QH5kN7=hMG1hMFeeLVYbKfMaKVI_K6A]JV9/JF5/JF5/JF5/JF5]Hf=a
J6AdKfIfLVMdLVMbL6Q`KVe`KFmbL5iaKUm`KEm^K65_KF=_K6M`KFU`KFUYLgeVLGmTKX1OJ8=JHhAG
GhMCG8QBFHY<FHe<FHe=Fi1=GI9>GIE=GYM;GYM;GYM7FXe7GYI0Fi/gDYDiDhm;GX]NJhEWL7ieM71e
M71eM71eM71dLfmbLFeaL6a`Kf]`Kf]`Kf]`Kf]`Kf]`Kf]`Kf]`Kf]`Kf]`LFQ`LFQaLVUbLfYcM6]c
M6]dMFadMFagM6agM6ahMFehMFegM6afLf]fLf]eLVYcLFMcLFMcLFMcLFMcLFMcLFMcLFMcLFMcLFMb
L6IaKfEaKfEaKfEaKfE`KVA`KVAdLVQdLVQeLfUeLfUdLVQbL6IaKfE`KVAbL6IbL6IbL6IcLFMcLFMc
LFMcLFMcLFMYK5e]LFI`Mg1bN7MaMgIcM79dLFUfKfIeLfUaKfE^K69`KVAdLVQfM6YcLFM`KVA_KF=^
K69bL6IhMVafM6Y_KF=]Jf5aKfE]K5i]K5i]K5i/Jee/Jee/Jee/Jee/JeeTHeE^K65]JV9[If9ZIV5/
JF5bL6E]K5i_Kem`L61`Kf5`Kf5`KV=`KVA`KVA`KVA^K5Y^K5Y^K5Y^K5Y_KE]_KE]^K5Y]JeU[Je]_
Kem^KEm/Jee_KF9eLfUcLFM/JV1_KF9_KF9_KF9`KV=aKfAbL6EaKfAaKfA^K65_KF9`KV=`KV=`KV=`
KV=_KF9_KF9^K65_KF9_KF9_KF9`KV=`KV=`KV=`KV=cLVAbLF=`Kf5_KV1`Kf5aL69aL69aL69]K5i^
KEm^KEm_KV1_KV1^KEm^KEm]K5i]K5i/JeeZJE]XIeUXIeUYJ5Y[JUa/JeeSHe5VIUAWIeMVIUIXIeU[
JEiYIeeSHEMLHU5QI5AUJ5QYJUYYJEUYJEMZJ5IZJ5I^KEU]K5Q/JeM[JUI[JUI[JUI/JeM/JeM]K5Q]
K5Q]K5Q^KEU^KEU_KUY_KUY_KUY/LEIZKeAYKEAZKEM/KeU]Ke][KEUXJUMYJUYYJUYZJe]ZJe][K5a/
KEe/KEe]KUi_KV1_KV1_KV1_KV1_KV1_KV1_KV1_KV1]KE]^KUa^KUa]KE][JeUZJUQ/K5Y_KeeZKEe/
Kem]L65_LV=`LVIaLVQaLVQaLVQ`LVI`LVI`LVI`LVIaLfMaLfMbM6QbM6Q_LV=_LV=`L69^KV1/Jee/
Jee`KEmcL69cLVAcLVAbLF=bLF=cLVAcLVAeM6IeM6IbM6QbM6QbM6QcMFUdMVYfN6aeMf]bM6QfMFMg
MVQiN6YkNVaoOW23PWB7QWR9R7YjOFikOVmjOFigNV]dMfQcMVMfNFYiO6ecN6UcN6UcN6UfNFYhN6Yi
NF]jNF]jNF]fNFYeN6UfNFYhNfakOVmkOVmhNfadMfQdMfQeN6UfNFYgNV]fNFYeN6UcMVMaM6EgN6Qg
N6QhNFUiNVYiNVYiNVYhNFUhNFUmP71mP71lOfmkOVijOFeiO6aiO6ahNf]nPfinPfimPVekP6]iOVUh
OFQgO6MfNfIeN6UeN6UeN6UdMfQcMVMaM6E_LV=^LF9]L65]L65/Kf1ZKEiYK5eZKEi]L65_LV=iNF]n
OW26QWR=SH6BTHNGUXbLVY:PWYJQYYN//:B_/:Je/j^WYYbo_[1oOffh]j;6_Z36_Z35_Io2^Ybn]YRi
/I>d[8jaZH^h]IJe/Y>/ZHZPWWb@SVb2P5iiMeEdLU1@DCM2@bTj>R8h>20^;APU910d<am>CCUkNf^5
QGFEUHFWYYRe/jRm^k30_[C1_kFf^JZi^jno`KG5a[c8bKo9b/79b/78b<;Fd<WHdLSPf<_;`K32]Io;
_:;3/iK8]YO9^iO9^iO9^iO9^iO9^iO9^iO9^iO9^iO9^iO9^iO9^iO9^iO9^iO9^iO9^iO9^iO9^iO9
^iO9^iO9^iO9^iO9^iO9^iO9^iO:^YK:^YK:^YK;^iO;^iO;^iO<_9S<_9S<_YC<_IK<_IK<_9O<_9O<
_9S<_9S<^i[:_9S:_9S:_9S9^iO8^YK8^YK7^IG7^IG:^YK:^YK:^YK;^iO;^iO;^iO<_9S<_9S:^YK:
^YK:^YK:^YK:^YK:^YK:^YK:^YK:^YK:^YK:^YK:^YK:^YK:^YK:^YK:^YK7^IG7^IG7^IG7^IG8^YK8
^YH00<Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl/lFl/lJm]<Jm]<Nn]LNn]LNn]LNn]LBm]<Bm]<Bm
]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm
]<Bm]<:k//:k//>l/l>l/l>l/lBm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<:k//6j
/L:k//Bm]<Fn]LBm]<>l/lg4^lW0]lBk//2g[[nf[L2g[/2g[/6h[lW0]l[1^<Ro]/2g[[6XWijES8^2
NGmfKGE_I7A^Hg=/Hg=[I7E]IWM^JWQ_JgU`KHB1O8F2OHJ3OXR5PH^7QXf9R92;S96<SHf=SHn?Si:B
TYBDU9JFUYVIVIfMWJ6QXJ2NWJ:PWjJTXjBRXI^IV9BBTIVGUZBRXJZYZjZYZjZYZjZYZjZYZjVXZZVX
ZZRWZJJXZJ>UYZ2RXifOX9bNWijPXJ6SY:>UYZ>UYYnQXYbNWijPXJ>UYZFWZ:BVYj:TYIVKW9VKW9ZL
WIZLWIZLWI^MWY^MWY^MWZ2RXj>UYZFWZ:FWZ:>UYZ:TYJ:TYJ>UYYRJViVKW9^MWYjPXJ6SY:BVYjJX
ZJNYZZNW[JRX[ZVY[jVY[jVY[jVY[jRX[ZRX[ZJY[ZBW[:BW[:FX[JR[/:V//JR[/:NZ[j>SZJ>SZJBT
ZZJV[:NW[JRX[ZVY[jZZ/:NYZZNYZZNYZZV[[:f_/:na/Zj`/Jf_/:NXYZBUXiNHU8N6PWaiM7UfLGUf
KWIcJg=`J79_Ig5^IVm/I6i[HfeZHVeZHVeZHVeSHg5XIGI^IgIaJ7IbIg=aIg9_Ig=_JVm]IFi/I6i/
I6i[HfeZHVmYHW1ZHg5[I6Y`GfU`HFU^IFU/JVMZKVMXLVIVM6EUMFYYLV]ZLfe/MVe]NFi^NVi^O6e^
O6a/O6MZLV]^O6Q_Pf5XPEaSO65UMfU[Lfm^L75`K75`K79aKG=bKWAcKg=bKW=bKW9aKG5`K75`K75`
K75`K75`K75`K75`K75`K79cJW9cJW=dJgAeK7EfKGIgKWMhKgQiL7QeKGUfKWUfKWYgKgUfKWQeKGMd
K7IcJgAbJ7AbJ7AbJ7AbJ7AbJ7AbJ7AbJ7AbJ7=aIgAbJ7AbJ7=aIg9`IW5_IG9`IW9`IWAbJ7EcJGMe
JgUgKGUgKGMeJgEcJGAbJ7EcJGEcJGEcJGEcJGEcJGEcJGIdJWIdJVe_FfeaGVaaHVa`IFe^IG5_IgMb
JGaeK7EcJGAbJ79`IW5_IG1^I75_IG9`IW=aIgEcJG5_IFm]Hg5_IG9`IVm]Hfe[HFi/HVaZGfaZGfaZ
GfaZGfaZGfaZGfaZGfe[H6e/GVUWG6i[Hfm[IVm[IVm/I6e[H7AcIG1`H71`H71_HFm^H6m]HVm]Hfm]
Hfm]Hfe[FFi/FW1^G71^G71^G6m]Ffi/FVi/FVi^GW1`H71_HFm^H71^Hg9`IW5_IFaZH6e[H6i/HFi/
HFm]HVm]HW1^Hg5_I79`IFi/HFm]HW1^Hg5_I75_I75_I71^Hfm]HVi/HFm]HVm]HVm]HW1^Hg1^Hg1^
Hg1^Hg9`IG9`IG9`IG5_I71^Hfm]HW1^Hg5_I6]ZG6a[GFe/GVe/GVe/GVe/GVa[GF]ZG6a[GF]ZG6UX
FVQWFFQWFFUXFVYYFf]ZG69RD6YZF6a/FVQXF6MWEf]ZG6]ZG6IUEf]_G6Q/FFY/FFe_G71`GVm]FfeZ
FfmZFfm^FVi]FFe/F6]ZEV]ZEV]ZEV]ZEVa[Ef]ZEV]ZEV]ZEVa[Efe/F6i]FFi]FFi]FF]^E6U/DVU/
DfU[EF]]Efa]FFa]FF][FFYZF6][FF][FFa/FVe]Ffe]Ffi^G6i^G75`HW5`HW5`HW5`HW1_HG1_HG1_
HG1_HFe]Ffm_GFm_GFi^G6a/FVa/FVm_GG5aGfY]GFa_Gfe`HFmbHg5cIg9cJG9cJG9cJG1bIW5cIg5c
Ig9dJ79dJ7=eJG=eJG=eJFiaHVmbHg1`HVi^H6a[GFa[GG5^H7=`HW=bI79aHg9aHg9aHg9aHg=bI7Ac
IGEdIW5cIfi`I6e_Hg1bIW=eJGEgJgEgJgAfJW]jK7UhJWEdIW=bI7=bI7EdIWQgJGYiJg5dIGAgJ7Mj
JgQkK7IiJW=fIg5dIG1cI75fIg5fIg5fIg=fIgIfJ7IfJ7MfJ7MfJ7EhJGEhJGIiJWQkK7UlKGUlKGMj
JgIiJW=fIgEhJGQkK7]nKgf0LGf0LGf0LGf0LGMjJgMjJgQkK7QkK7QkK7MjJgIiJWEhJGIiJWIiJWIi
JWEhJGEhJGAgJ7AgJ7AgJ79fHg9fHg5eHVmcH6ibGfeaGVa`GF]_G6EWFfEWFfIXG6MYGFMYGFIXG6IX
G6EWFf=UFF=UFF5SEf5SEf=UFFa^HWMiKH22MYFGRi^MTJFVW:f^Y;>dZkVi/kjn^<;2_;Fl[lW?a<g@
alk@b/O8_n7QeHJ7MiZLR:VTQJJQPZ6LOIVDMI2;K8N2HgmjFg]fEeAE=E5B<TY;:d108SDe5bh^42d]
3bd]3cHh93Tk9dM9=EUKB5iOCfEVEXF5MjZZW:>WVjV]X[:fZkVl/kbn^;Vk]KBe/K2a[L?7_<G8_lW<
`lc>b<g?bLc=bLW:b<O8a/o:am;<aM[DbLFl[[naW/ZkXLFeV<bjVlRjU/RjU/RjU/RjU/RjU/RjU/Rj
U/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/RjU/ViULViULZj
U/ZjU/ZjU/^kUl^kUl^kUl^mTl^lUL^lUL^kU/^kU/^kUl^kUl^jVLZlV<ZlV<VkUlVkUlRjU/NiULNi
ULNiULViULViULZjU/ZjU/ZjU/^kUl^kUl^kUlViULViULViULViULViULViULViULViULViULViULVi
ULViULViULViULViULViULJhU<JhU<JhU<NiULNiULRjUP00aKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbb
aKbcaKbcaKbca[fda[fdakjeakjeakjea;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fd
a;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fda;fd`[^b`[^b`[^b`kbc`kbc`kbca;fda;fd
a;fda;fda;fda;fda;fda;fda;fda;fdaKje`[^b`;V``;V``KZa`[^b`[^b`;V`_KJ]_KJ]_[N^_kR_
`KZaa;fdaKjeal2g^:nU_KBZaKbbb/6gbl:hakjd`KR^_;>Y/:NMXYV?SXEkOGA[M6YSM6YSMfaXNVm[
KF]SLW1XNWMbPWmjRHJ2S8R7SHV8SHR9SH^:Shf<TY2?U9:AUYBCVYRGWYbKXZ2OYJFUWIfMVi^KXZ:R
Z:RXYjNWY:BTXj>SYZFWYZFWYJBVYJBVYJBVYJBVYJBVYJBVXJ>TXJ>TX::SX::SX::SXJ>TXJ>TXZBU
XZBUWj6RWInPW9jOWInPWInPW9jOVifNVI^LVI^LVYbMVYbMVifNVifNVifNVifNWZ2QX::SXZBUXJ>T
X::SWj6RWj6RX::SVifNVifNWInPWj6RXJ>TXjFVYJNXYJNXYZJ/YZJ/YjN]Z:R^ZJV_Z:R^Z:R^YjN]
YJR]XjJ[XjJ[Y:N/YjZ_Z:^`Z:^`YZV^YZJ/YZJ/YjN]Z:R^ZJV_ZZZ`Zj^aZj^aZ:Z[YjVZYjVZZJ^/
[:j_[[2a[[2a[Jn`YjRVYJJTVY^GRXV5OgagNgQcNWM_MgA/MG9ZM75YLVmWL6eUKfaTKV]SKV]SKV]S
JfISKVUVLViYLfmZLVmWLVmWLVmWLg1XKVmcLG1dLG1bKfi`KVa/KF][LFa]LVi]K6iKK6iKK6aNK6]Q
K6YRK6UUK6MXK6MXLVaOLfePMW1UN79WN75XN71YMfmXMViWLFYKM6iSMW1[M6m^LF]/L6]ZLFeXM6iW
LW5]Lg9^MGA`MWEaMgIbMgIbMgIbMgIbLg9^Lg9^Lg9^Lg9^M7=_M7=_M7=_MGA`LW=ZLW=ZLgA[M7E/
MGI]MWM^MgQ_MgQ_NGI^NWM_NgQ`O7UaNgQ`NWM_N7E]MgA/MWAZMWAZMWAZMWAZMWAZMWAZMWAZMWAZ
M79XMG=YMWAZMG=YLg5WLW1VLg5WM79XLFiVLg1XMW=[N7E]NGI^N7E]MgA/MG9ZMWAZMWAZMgE[MgE[
N7I/N7I/NGM]NGM]M7MXM7MXMWIZMGEYMG=YMgE[OGQ_PW]bMWAZMgE[N7I/MWAZLW1VLW1VMWAZNWQ^
N7I/Lg5WKVaRKfeSLW1VLg5WLW1VLFmUK6YPK6YPK6YPKF]QKF]QKF]QKVaRKVaRLG1RHf5FKV]SLFeX
LViYL6eUIVAIMGAVKFeMKFeMKFaNKFaNK6YOK6YPK6YPJfUOK6YHKVaJL6iLL6iLKVaJKF]IKVaJKfeK
KViNKfmOL6mQL6mQL6iSL6iTKfeSKVaRKF]PKVaQKfeRKVaQKF]PKVaQL6iSLg5VKVaQKfeRL6iSLFmT
LW1ULW1ULFmTLFmTKfeRKfeRL6iSL6iSL6iSLFmTLFmTLFmTLW1VLg5WM79XLW1VL6iTKVaRKfeSL6iT
K6]MK6]MKFaNKVeOKVeOKFaNK6]MK6]MK6]MK6]MJVUKJVUKJFQJJFQJJFQJJFQJI6ABJVYHK6aJJFUI
IfMGJFUIK6aLKFeMK6eMJfaLJV]KJf]KKV]LKfaMLFeKKf]IKVeIKVeIK6]GJfYFJVUEJVUEJVUEJVUE
JVUEJVUEJVUEJfYFJfYFK6]GKFaHKFaHK6iHJfeGJVaFJV]GJFUGJVYHJVYJJf]KJ6UEJFYFJV]GK6eI
KVmKKg1LLG9NLG9NLG1RLG1RLG1RLG1RL6mQL6mQL6mQL6mQKFeKKfmMKfmMKViLKFeKKFeKL71NLW9P
JVeMJfiNKG1QKg9SLG=WLG9XLW=YLW=YLWAXLWAXM7IZMGM[MGM[MGM[M7IZM7IZKW5RKW5RL71RKViP
KFaNKVeOLg1RMW=ULg9TLg9TLW5SLW5SLW5SLg9TM7=UMGAVM7IZKg5UKW1TLG=WLgEYLWAXLWAXM7IZ
MGAVMgIXNGQZNgY/NgY/NGQZMgIXMGAVMgY[MgY[MgY[MgY[MgY[N7]/N7]/NGa]M7UZM7UZM7UZMWUZ
N7QZN7QZNGQZNGQZLWEVM7MXMGQYMGQYLgIWLgIWMGQYMgY[NGa]NGa]NGa]N7]/N7]/MWUZMGQYM7MX
KW=TKgAUL7EVLGIWLWMXLWMXLGIWLGIWJFaMJVeNK6mPKW5RL7=TLWEVM7MXMGQYK6mPKG1QKG1QKW5R
Kg9SL7=TLGAULGAUMGI/MWM]N7U_NW]aNgabNgabNgabNgabOWmeOGidNW]aMgQ^MgQ^Oh1fSHj4UiR>
[[:W];R]_;nf`lFoalW3b/_7c/o;d=7?_lRkb=35`l[3a/[4a/S2c=35KG1PDEE2@D0T?chR?C`P>STM
=SDI<c8F<C0D<2lC;S8E<SHI>CdP?d8XAdXaDeHmHVA>K6iHMWUYPHAdTiJ7X::FWZ2DVibBZJZP_[nf
][V`]kZa^[fd_Kni`<6m`lC0a/O5alS6`/Fla<NnalW3bL_5b/_7b/_9b<W7alS6bl[6clc7fMG:a;f/
_;6KbK^OakJEckbIb;ZFb;ZFb;ZFb;ZFb;ZFb;ZFb;ZFb;ZFb;ZFb;ZFb;ZFb;ZFb;ZFb;ZFb;ZFb;ZF
akVEakVEakVEakVEakVEakVEakVEakVEbKVEbKVEbKVEb[ZFb[ZFb[ZFbk^Gbk^GbkfCbkbEbkbEbk^F
bk^Fbk^Gbk^GbkZIb;ZFb;ZFb;ZFb;ZFb;ZFakVEakVEakVEbKVEbKVEbKVEb[ZFb[ZFb[ZFbk^Gbk^G
b;RDb;RDb;RDb;RDb;RDb;RDb;RDb;RDbKVEbKVEbKVEbKVEbKVEbKVEbKVEbKVEaKNCa[RDa[RDakVE
b;ZFb;ZF0034^k74^k74^k74^k74^k74^k74^k74^k75_;?5_;?5_;?5_;?6_KC6_KC6_KC7_[G4_KC4
_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4
_KC4_KC4_KC1^[72^k;2^k;2^k;3_;?3_;?3_;?4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC4_KC2
^k:o^:no^:o1^[73_;?3_;?2^k;4_KC5_[G6_kK5_[G3_;?0^K2n]jjn]jk9`;K6_K?2^Jno]Zbn]J_0
]jg4^k77_[C0^:_0^:^n]J^j/JN`YijOUHj<PW]nLfmgM6agM6agM6aiMG1mN7F1O7V6PH29Q8>7QHB9
QhJ<RXV?SHbAShjDTY6IUiJMViZTY:BTY:BVYZJVYZJQXJ6MWIfSXj>/[:bUY:JUY:JUY:JUY:JVYJNW
YZRXYjVXYjVRY:FQXjBPXZ>OXJ:NX:6OXJ:OXJ:OXJ:LWYnMWj2LWYnJW9fHVY^GVIZHVY^JW9fJW9fK
WIjKWIjKWIjLWYnLWYnLWYnMWj2LWYnNX:6OXJ:NX:6LWYnLWYnMWj2OXJ:PXZ>PXZ>QXjBRY:FSYJJU
YjRUYjRVZ:VUYJ^VYZbWYjfYZJnYZJnYZJnYZJnXZ:jUZ:fTYjbSYZ^UZ:fWZZnY[;6XZk2WZZnXZ:jX
Z:jXZ:jYZJnYZJnZZ[2ZZ[2ZZ[2YZjbXZZ^WZJZXZZ^[[Jj][k2][k2/[ZnXZJNVYjFLWIV=S8R2OgYm
NWEkN71gM6afLf]eLVYcL6QaKVI`KFE_K6A_K6A_K6A/JfM^KFU`Kf]bKVeaKFa`KFUbKf]cL6acLG5d
LW9eLg=cLG1_KFa^K6]`KVecLVicL6]bKfY`KFQ_K6Q^JfM_JVU`JfY`JfY^KV9_Kf=bLFMdLfUfLf]e
LFacKfYbKFY`KEibK5meKVEgKfQgKVYdKVUbKfYbLVaeM71fMG5gMW9hMg=hMg=hMg=gMW9gMW9dLfmd
LfmeM71eM71fMG5fMG5gMW9gMW9cM6]cM6]dMFaeMVeeMVefMfigN6mgN6miMVijMfmlNG5mNW9mNW9k
N71iMVigM6ahMVahMVahMVahMVahMVahMVahMVahMVadLVQfM6YhMVafM6YcLFMbL6IdLVQfM6Y`KFEb
KfMdLFUgM6ahMFegM6afLf]eLVYeLfUfM6YgMF]hMVaiMfejN6ijN6ikNFmZK6I_LF]gN6mlNW9kNFmh
MVaeLVYdLFUeLfUfM6YhMVaiMfeiMfelNW1oOG>2P7IiMfehMVafM6YdLVQdLVQfM6YfM6YdLVQ^K69^
K69^K69_KF=_KF=`KVA`KVA`KVAbLF=UHeQcL6Q^JVE_JfIeLVYVI5UbLF=/K5a]KEe^KEm^KEm]Jf1/
JV1ZJ5iZJ5i/JUQ^K5Y`KUa_KE]/JUQ[JEM]JeU`KUa^KUi_Kem`Kf5bLF=bL6E`KVA`KVAbL6I_KF9a
KfAbL6E`KV=^K65^K65aKfAeLfQ]Jf1^K65`KV=aKfAbL6EcLFIcLFIbL6E`KV=`KV=aKfAaKfAaKfAb
L6EbL6EbL6EbL6IdLVQfM6YdLVQaKfE^K69_KF=aKfE^KEm^KEm_KV1`Kf5`Kf5_KV1^KEm^KEm^KEm^
KEm^KEm]K5i/Jee[JUaYJ5YXIeUWIeMUIEEVIUAYJEMYJEMXJ5IZJeM^Ke]RH5QXIeeZJ5iXI5UYIUQb
KEibKUa^IeI^KEU]K5Q[JUIZJEEYJ5AYJ5AYJ5AYJ5AZJEE[JUI[JUI[JUI[JUI/JeM/JeM/JeM^KEU^
K5Y^K5Y]JU]/JE]]JUa_Jf1`K65/JeM/JeM]K5Q^KEU_KUY_KUY`Ke]`Ke]^KEm^KEm^KEm^KEm^KEm^
KEm^KEm_KV1/K5Y]KE]^KUa]KE]/K5Y]KE]_KeeaLEmZKEe[KUi]L65_LV=`LVI`LFM`LFM`LFM`LVIa
LfMbM6QdMVYdMVYcMFUbM6QbM6Q]L65^LF9`L69_Kf5_KV1`Kf5fLfEiMVQeM6IdLfEdLfEdLfEdLfEe
M6IfMFMgMVQeMf]aLfMbM6QfN6afN6abM6QcMFUhNVibLF=dLfEhMfUkNValNfejNF]hMfUeM6IeN6Uc
MVMbMFIbMFIdMfQhNfakOVmmP75bMfQbMfQbMfQdMfQeMFMeMFMfMFMfMFM]L65aM6EcMVM`LfA[KUmZ
KEi`LfAgNV]`LfA^LF9/Kf1ZKEiXJeaWJU]VJEYVJEYWJemYKF5[Kf=^LVIaMFUcMf]dN6aeNFekOG5l
OW9nP7B1PgN4QWZ7RGf9Rgn;SH6CU8ZCU8ZDUH^FUhfHVHnIVY2KW9:KW9:IVY2JVi6LWI>MWYBNWiFO
X9JNWiFNWiFRXiVRXiVOX9JIVY2EUXbHVHnQXYRYZZ2f^K2j_KC0`[c3a<33a<31`/31`/31`L78d/K1
b/2c^kB//ZfJWYR2R7e=DT<]<b0l?bTl?bTl?bTn@B]1A2i5B399C3I;CSQLH4MRITeYK5I^L5acMF9l
OFf8RGVATH>JVXjSXiN_[ZBf]:bf]:be/Zff/jjh]K72aKc0`kZn`KRm_kVm_[Zn_k_0`Ko2`l77b;k8
bL3:bl;<c<K>cLW?c/[?cLc?cLc@d/cDeLcNgLo9`k2n]I[8^i_4]8o<^iC7^IG7^IG7^IG7^IG7^IG7
^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG7^IG6^9C6^9C6^9C6^9C6^9C6^9C6^9C6^9C8^9C9
^IG9^IG9^IG:^YK:^YK:^YK;^iO;_I?;_9G;_9G;^iK;^iK;^iO;^iO;^YW7^IG7^IG7^IG7^IG8^YK8
^YK8^YK8^YK8^9C9^IG9^IG9^IG:^YK:^YK:^YK;^iO7]i?7]i?7]i?7]i?7]i?7]i?7]i?7]i?8^9C8
^9C8^9C8^9C8^9C8^9C8^9C8^9C6^9C6^9C7^IG8^YK8^YK9^iL00<Bk/LBk/LBk/LBk/LBk/LBk/LBk
/LBk/LBk//Fl/lFl/lFl/lJm]<Jm]<Jm]<Jm]<>l/l>l/l>l/l>l/l>l/l>l/l>l/l>l/l>l/l>l/l>l
/l>l/l>l/l>l/l>l/l>l/l>l/l>l/l>l/l>l/l>l/l>l/l>l/l>l/l6j/L6j/L:k//:k//:k//>l/l>l
/l>l/lBm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<Bm]<>l/l6j/Knh[knh[l:k//Bm]<Fn]LFn]L:k//:k//:k
//6j/L2i/<6j/L>l/lFn]L2hZl6i[<:j[LBl[lFm/<Fm/<Fm/<Fm/<Ro//Jm/<Fk/LJl//Rm]LJj]<6e
[kb`ZZRVW9^HT8V6OWQdKg1/Ig5/JGQcLWiiN85nNXB1OHN4P8Z7Phb9QI2=RIBASIRETIVIVIVIVIfM
WJ:RXZ2PX9^KVibLW:6QXJ6PXZ6PXZ6PXZ:QXj>RY:BSYJJUYjNVZ:>UYZ6SY9jPXI^MWYZLWIZLWI^M
WYbNWiJHVIVKW9^MWYZLWINIVYNIVY^MWZ2RXi^MWYbNWibNWibNWifOX9fOX9fOX9jPXIfOX9jPXIjP
XIfOX9^MWY^MWYfOX:2RXjFWZ:FWZ:FWZ:FWZ:JXZJJXZJNYZZNYZZJV[:NW[JRX[ZVY[jZZ/:ZZ/:ZZ
/:VY[jJY[ZFX[JBW[:FX[JR[/:V//JV//JNZ[jNW[JNW[JNW[JNW[JRX[ZRX[ZRX[ZRX[ZZ/[JRZZjNY
ZZRZZjZ/[Jb^[jb^[jb^[jRYYjNXYYjOVhn>RXB1O7mlMg]hL7MdK7IcJgEbJWAaJG9_Ig5^IW1]IG1]
IG1]IFe_JFi_Jfm`KVi^KVi[KFi/K7=^KgEaL7MbJGUdJgQfK7IdJW9aIg5`IW=bJ7MfK71^M6m]Lfm[
L6eYKVmZK6mZK75/KW=/Kf=/JFE^JfQ`KfaaLVaaLVa_LfY]LFU/LGAfL7=bKW=`K7E`KgE`Kg9`Kfma
LFidLgIeLGIeLGMfLWMfLWIeLGEdL7AcKg=bKWAcKgEdL7EdL7IeLGIeLGMfLWMfLWQgLgIgKWIgKWMh
KgMhKgMhKgQiL7QiL7QiL7UfKW]hL7ejLWikLgikLgaiLGUfKWMdK7UgKGUgKGUgKGUgKGUgKGUgKGUg
KGUgKGAbJ7MeJgUgKGMeJgAbJ79`IWAbJ7MeJgIbKGMcKWUeL7YfLG]gLWYfLGUeL7UeL7AbJ7EcJGId
JWMeJgUgKGYhKW]iKg]iKgEgN7QhN7]jMWaiM7aiLGaiLGikLgmmMG]iKgYhKWUgKGYhKWekLGmmLh1n
M7mmLgIdJWYhKW]iKgMeJg9`IW1^I71^I71^I6m]Hg1^I71^I75_IG5_IG9`IW9`IW=aIg=bI6YXGGYg
KfYVHF]WHW]hL6YXGG1_HFi^GVm_Gg1_HG5`HW1^Hfi/HVaZH6]YGfaZF6i/FVm]Ffe[FFYXEVYXEVe[
FG1^G71`H71`H7=bI7EdIWEcJ7=aIgAbJ7MeJg5_I7=aIWAbIg9`IFm]HVm]HW9`IGIdJFaZGfe[H6m]
HW5_I7=aIW=aIWAbIgAbIg5_I75_I75_I79`IG9`IG=aIW=aIW=aIW=aIgIdJWQfK7IdJW9`IVm]Hg1^
I79`IW1_HG5`HW5`HW9aHg9aHg5`HW5`HW1_HFm^H71_HG1_HG1_HFm^H6a[GFYYFfQWFFUYFF1PD5mO
CFQXEVa/FVQYEFMXE6]/F61MFFeXIG5]J6aWGViXGGQcI7YcHW5[F6e/F6a[Ef]ZEVUXE6QWDfQWDfQW
DfQWDfa[Efa[Efa[Efa[Efa[Efa[Efa[Efa[EfaYFVaYFVeZG6eZG6iZGg1[HWA_IWMbJG5`G75`G71_
Ffi]FFa[Ef]ZEVUXE6UXE6]ZG6]ZG6]ZG6a[GFa[GFe/GVe/GVe/GVYZF6][FFa/FVa/FV][FF][FFi^
G71`GV]^GV]^GVe`HFiaHVmaIFm`IVm`IVm`IVa^HVe_HfmaIG1bIW5cIg1bIVmaIFi`I6a_H6e`HG1`
HVm_HG1_HG9aHgMdIW]hJWMfJ7IeIgIeIgEdIWIeIgMfJ7QgJGUhJVi`I6a^HVmaIGEgJgEgJg5cIg=e
JG]mLGakKGYiJgQgJGIeIgIeIgIeIgQgJGUhJW=fIg5dIG1cI6mbHfmbHfmbHfe`HFa_H6M/GFM/GFM/
GFQ[G6YZG6YZG6]ZG6]ZG6Q[G6iaHW5dIFa_H6AWF6AWF6e`HGMjJgMjJgMjJgUlKGaoL864MHJ9NX^>
OhjAPXR<P8Z>PXjBQY>GRiRLT9^OTijRUYnSUj6SUj:TV:BVVZFWVjNYWJV[WjZ/X:^]XJVYXjVYXjZZ
Y:ZZY:ZZY:^[YJ^[YJ^[YJZ[XJ^/XZb]Xjf^Y:f^Y:f^Y:f^Y:b]XjJWWJVZX:Z[XJRYWjBUVjJWWJj_
YKJg[KJh/[Vk]Kbn^;bm^KRi]k>d/[2`/:n_[iVUVIFPUYFMUYBKUWb3O6=YGW9iJWQnJfU^FFU^FFQ]
F6Y_FVicGWAiI7YoJWj3KX26KhR=N96FPIJJQiZMSZ2RUZV[Wk6bZ;>bZ;FdZ[>aZK>`ZkZg//:o^l2m
^KRd/kbm/kjo]/72^L?3_LG4`<C3_l?1`<;0_lO8_/O8_/S9`<[;`/_;aLc;alg<b<g<b<O;aLc@aMWI
blG2[KfeV<RlV<JgT<jnTlNiULNiULNiULNiULNiULNiULNiULNiULNiULNiULNiULNiULNiULNiULNi
ULNiULJhU<JhU<JhU<JhU<JhU<JhU<JhU<JhU<RhU<RhU<ViULViULViULZjU/ZjU/ZjU/ZlT/ZkU<Zk
U<ZjULZjULZjU/ZjU/ZiV<JhU<JhU<JhU<NiULRjU/RjU/VkUlVkUlRhU<RhU<ViULViULViULZjU/Zj
U/ZjU/NgTlNgTlNgTlNgTlNgTlNgTlNgTlNgTlRhU<RhU<RhU<RhU<RhU<RhU<RhU<RhU<JhU<JhU<Ni
ULRjU/VkUlZlV000a;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa[fca[fca[fca[fca[fca[fca[fca[fc
a[fca[fca[fca[fca[fca[fca[fca[fca[fca[fca[fca[fca[fca[fca[fca[fc`[^b`[^b`[^b`[^b
`[^b`[^b`[^b`[^ba;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa[fca[fcaKbbaKbba;^aa;^a`kZ``kZ`
a;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^a`kZa`kZa`kZa`kZa
`kZa`kZa`kZa`kZaa;^aa;^aa;^a`kZ``kZ``kZ``kZ``kZ``[V_`kZ``kZ`_[F[/jZPXYV?THQnQgid
QgidQ7]aPWU_PGQ^QGabS8=iU8^1VI26VinJVinJVinJVinJVYjIV9bGUi^FUi^FXJ2RXJ2RX9nQX9nQ
WijPWYfOWYfOWIbNWZ6OW9nMVYbLV9ZKVI^LVibPWYnSX:2VWIfMVi^KVYZJWIfMXZ:RYJFUYJFUXj>S
WYjTX:2VXZ:XXZ:XXJ6WXJ6WXj>YYJF[Y:BZXj>YXZ:XY:BZYjN]YjN]Xj>YWinUYjVZYZRYYJNXYJNX
YJNXYZRYYjVZZ:Z[YJF[YJF[YZJ/YjN]YjN]Z:R^ZJV_ZJV_YJR]YJR]YZV^YZV^YZV^YjZ_YjZ_YjZ_
YjZ_YjZ_YZV^YJR]YJR]YZV^YjZ_YjZ_YZZ_Y:R]XZFZX:>XXZ:XZ:J/[:Z`[jfcWZ>RYZRXX::RSHj<
OGijO7]gN7QbLg1[JfYVKVeYLG1/LG1/KVeYKFaXKfiZLG1/LG1/LG1/L6m[L6m[LG1/LG1/Lg9^Lg9^
MGA`MGA`MGA`MGA`M7=_Lg9^LG1/L6m[Lg9^Lg9^LW5]L6m[KfiZKVeYKFaXK6]WKfiZL6m[LG1/LW5]
LW5]LW5]LW5]LG1/LW5]Lg9^M7=_MGA`MgIbN7McNGQdNWUeNGQdNWUeNgYfNgYfNgYfNGQdMgIbMGA`
NGQdNGQdNGQdN7McN7McN7McN7McN7McMWM^MGI]MGI]MGI]MWM^N7U`NGYaNW]bNgQ`NgQ`O7UaO7Ua
O7UaNgQ`NGI^NGI^N7U`N7U`N7U`N7U`N7U`N7U`N7U`N7U`N7I/NGM]NGM]NGM]N7I/MgE[MWAZMG=Y
M7E[MGI/MWM]MgQ^N7U_N7U_N7U_N7U_NW]aNGY`N7U_MWM]MGI/MGI/MGI/MGI/OGidOGidOGidOGid
OGidOGidOGidOGidMgQ^N7U_NW]aO7ecO7ecNgabNW]aNGY`M7E[LgAZLG9XL75WKg1VKg1VKg1VKg1V
LFmULg5WM79XMWAZMWAZMG=YM79XLg5WKg1VKg1VKg1VKVmUKFiTK6eSK6eSJfaRLg5VLW1ULFmTL6iS
KVaQKVaQKF]PKF]PJ6]LK6mPLW9TLW9TKfiPK6]MKV]MKfaNL6iSL6iSL6iSLFmTLg5VMG=XMgEZNGM/
N7AYMW9WLfmTLFeRL6aQL6aQLFeRLViSJfQJK6UKKFYLKfaNLFiPLFiPL6eOKV]ML6]RLFaSLfiUM6mV
MG1WMG1WMG1WM6mVLVmQM75SMG9TM75SLFiPL6eOLFiPLVmQKVUJKfYKLFaMLVeNLfiOLfiOLfiOLfiO
LW1NLW1NLFmML6iLKVaJK6YHJFMEJ6IDI6YCHVQAH6I?HFM@I6YCJ6iGJFmHJFmHK6QFJfMEJFECJ6AB
J6ABJVIDK6QFKVYHKFMDKVQEKfUFKFMDJVAAJVAAKVQELVaIK6]GK6]GKFaHKVeIKVeIKVeIKFaHKFaH
L71NL71NKfmMKfmMKfmML71NLG5OLW9PLgAPL75MK6eIJVYHJFUIJ6QHJ6MIIfIHJW1GJg5HJW1GJ6iE
IF]BI6YAIF]BIfeDJVYJJVYJJf]KJf]KJf]KK6aLK6aLK6aLKFeOK6aNK6aNK6aNKViPLG5SM7AVMGEW
LW9TLg=UM7AVMGEWMGEWMGEWM7AVM7AVN7QZM7AVLg=UMgMYN7QZM7AVLG5SLW9TLGMVLGMVLGMVLGMV
LGMVLGMVL7IUL7IUL6mUL6mUKfiTKFaRK6]QJVUOJFQNJFQNJFUKJFUKJ6QJJ6QJIfMIIfMIIVIHIVIH
IFYKIFYKIV]LIfaMJ6eNJFiOJVmPJVmPK71UKG5VKg=XLGEZM7Q]Mg]`NGebNWicQH^0OhEjPHMlOXAi
LgU^Nh5fSI>8TYR=VijEVijEVijEW9nFWJ2GWZ6HX:>JX:>JY:NNYJROYJROYJROYZVPYZVPYZVPYZVP
ZZfTZZfTZjjU[:nV[K2W[[6X[k:Y[k:YZjjUZjjUZZfTZZfTZjjU[:nV[K2W[[6X/;>Z/;>Z[k:Y[[6X
[[6X[K2W[K2W[:nV[:nV[:nV[:nVZjjUZZfTZZfTZJbSZJbS[[6X[:nVZZfT[K2W/[F//kJ]/;>Z[:nV
[K6VZ:bQXJFJV9bAT9B9Rhn4R8b1QXYoRHUgRXYhRh]iSHekTI5oUIF3VIV7Vi^9UiZAW9nFXZFLYZVP
ZJbSZjjU[[6X/KB[]KR_][V`]kZa][V`/kJ]/KB[/KB[/[F/_Kjj_Kjj_[nk`<6m`/>o`lC0a<G1aLK2
b/g4b/g4bL_5bL_5b/_7b/_7blc:c<g;bLg8cm7;e]C9c<Fd_;6KaKNKd;jOb;FDb;RDb;RDb;RDb;RD
b;RDb;RDb;RDb;RDb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RDb;RDb;RDb;RDb;RDb;RDb;RDb;RD
b;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCbKVDbKVDbKVDbKVDbKVDbKVDbKVDbKVDb;RCb;RCb;RCb;RC
b;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RCb;RC
bKVEbKVEbKVEbKVEbKVEbKVEbKVEbKVEb;RDb;RDb;RDb;RDb;RDb;RD0034^k74^k74^k74^k74^k74
^k74^k74^k75_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5_;;5
_;;5_;;5_;;5_;;5_;;5_;;5_;;2^k;2^k;2^k;2^k;2^k;2^k;2^k;2^k;4^k74^k74^k74^k74^k74
^k74^k74^k76_K?5_;;5_;;5_;;4^k73^[33^[33^[34^k74^k74^k74^k74^k74^k74^k74^k74^k74
^k74^k74^k74^k74^k74^k74^k73^[73^[73^[73^[73^[73^[73^[73^[74^k73^[33^[33^[33^[33
^[33^[33^[2m]:Zo]Zc3^[35_;;4^k70]jfk/ZRh[jF/XiVXWiFPUhfHShF@Qgf:PGN6OG>4Ng67QX:8
Qh>9R8B<RhN@Sh^FUI6KVYJNWIVASY2ETYBLVI^QWZ2SX::QWZ2NVifKV9ZNWifPXInSY::UYJFTXjFQ
X::LVinIV9bKVi^HV9REUIFGUiNKVi^PX:2QXJ6QXJ6OWjFQXJNSXjVTY:ZSXjVSXjVUYJ^XZ:jRXZRQ
XJNQXJNSXjVUYJ^UYJ^QXJNNWZBQXjBQXjBQXjBQXjBRY:FTYZNVZ:VWZJZWYjfWYjfWYjfVYZbVYZbW
YjfXZ:jXZ:jQY:VQY:VRYJZSYZ^TYjbUZ:fVZJjWZZnUZ:fUZ:fTYjbSYZ^SYZ^TYjbUZ:fUZ:fX[;6U
ZJjSYZ^RYJZTY:ZYYjf]Zk6_[K>UZZVXZZZPXZ:?T8inOg]hMg=gMg5hMG1]K6Q`Kf]bLFebLFe_KVY^
KFU_KVYaL6aaL6a`Kf]`Kf]_KVY`Kf]aL6abLFecLViiN7AjNGEjNGEjNGEiN7AhMg=gMW9fMG5cLVib
LFebLFebLFeaL6aaL6aaL6aaL6a_KVY`Kf]aL6abLFebLFebLFebLFeaL6aaL6aaL6abLFecLVidLfmf
MG5gMW9hMg=jNGEkNWIlNgMmO7QlNgMkNWIiN7AgMW9hMg=hMg=gMW9gMW9gMW9gMW9gMW9gMW9fMfie
MVeeMVeeMVefMfihNG1iNW5jNg9nNg=nNg=oO7AoO7AnNg=mNW9kN71jMfmgN6mgN6mgN6mgN6mgN6mg
N6mgN6mgN6mgMF]hMVahMVahMVahMVagMF]eLfUeLfUcM6YdMF]eMVagN6ihNFmhNFmhNFmgN6ikO79j
Ng5iNW1hNFmgN6ihNFmhNFmiNW1kO79kO79kO79kO79kO79kO79kO79kO79fMfegN6iiNW1jNg5kO79j
Ng5iNW1hNFmeMVadMF]cM6YbLfUaLVQaLVQaLVQaLVQdLVQeLfUgMF]hMVahMVagMF]fM6YeLfUaLVQa
LVQ`LFM_L6I^KfE^KfE]KVA]KVA_KF9`KV=cLFIeLfQgMFYgMFYfM6UfM6U/Kf1^LF9aLF=_Kf5]K5i[
JUa^Jee`KEmbL6EcLFIdLVMeLfQeLfQeLfQdLVMdLVMdLVMcLFIbL6EbL6EbL6EbL6EcLFIdLVM_KV1]
K5i]K5i_KV1cLVAdLfEbLF=_KV1cLFIdLVMeLfQfM6UfM6UfM6UfM6UfM6UbLF=cLVAcLVAaL69^KEm/
Jee/Jee^KEm_K5e`KEiaKUmbKf1cL65cL65cL65cL65_Kem_Kem_Kem_Kem_Kem]KEe/K5a[Je]TIU9Q
HdmOHDeOHDeRI51TIU9UIe=UIe=/JeM/JeM]K5Q^KEU_KUY_KUY`Ke]aL5a^KEU_KUY^KEUYJ5ATHdmQ
H4aRHDeTHdmZJEE[JUI[JUI/JeM/JeM/JeM[JUI[JUIUIE=UIE=UIE=VIUAXJ5IZJUQ]KE]^KUabLem`
LEe]KUY/K5Y/K5a]KEe^KEm^KEmYKUU[L5]]LUe]LUe]LUe^Lei`MF1cN6=eMFEeMFEdM6AcLf=aLF5`
L61_Kem_KemfN6aeMf]dMVYcMFUcMFUcMFUeMf]eMf]cMFUcMFUbM6QaLfM`LVI`LVI_LFE_LFEWJEeT
IUYUIe]XJUiWJEeSIEURI5QUIe]GGDaHGTeIGdiJH4mKHE1LHU5MHe9MHe9TIE]UIUaVIeeWJ5iYJV1Z
Jf5/KF=/KF=fN6agNFeiNfmkOG5mOg=oPGF0PWJ1PgN8S828S829SH6:SX:;Sh><T8B=THF=THF=THJ>
TXN@U8VBUX^DV8fFVXnHW96IWI:NY9VHWY>JX9FFW96:T8F@UX^PYY^SZIjWZZ6WZZ6XZj:XZj:Y[:>[
[ZF/[jJ/[jJZ[JB[[ZF[[ZF[[ZF/[jJ/[jJ/[jJ]/:N[[ZF/[jJ/[jJ]/:N^/JR_/ZV`/jZ`/jZ`/jZ`
/jZ_/ZV_/ZV_/ZV`/jZa]:^b]Jba]:^a]:^`/jZ`/jZ_/ZV_/ZV^/JR^/JR^/JR]/:N]/:N]/:N/[jJ[
[ZF[[ZF[[ZFWZZ6Z[JB_/ZVb]Jbb]Jba]:^_/ZV^/JR_/jR[[jBVZYnOXiRJWY>GVi2FVXnEVHjNWHnN
WHnOWY2QX9:TXiFXYiV[ZYb][9jY[:>/[jJ`/jZb]Jbc]Zfc]Zfe^:nf^K2m`;Nm`;Nl_kJi_;>g^[6g
^[6j_KBl_kK0`Kg1`[k2`ko3a<34aL75a/;6al?7b<C:cLC9c<?9blG:c<K;c<S<cLW=c/c=c/c3a/C=
c/[IeloAbkk1]jG7^J;@_jC7]IS8^9C8^9C8^9C8^9C8^9C8^9C8^9C8^9C8^9?8^9?8^9?8^9?8^9?8
^9?8^9?8^9?8^9C8^9C8^9C8^9C8^9C8^9C8^9C8^9C8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?9^IC9
^IC9^IC9^IC9^IC9^IC9^IC9^IC8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8
^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?9^IG9^IG9^IG9^IG9^IG9^IG9^IG9^IG8^9C8
^9C8^9C8^9C8^9C8^9@00<Bk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LFl//Fl//Fl//Fl//Fl//Fl//Fl
//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//Fl//:k//:k//:k
//:k//:k//:k//:k//:k//Bk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LFl//Fl//Bk/LBk/LBk/L>j/<>j
/<>j/<Bk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/L>j/L>j/L>j
/L>j/L>j/L>j/L>j/L>j/L>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<:i[l>j/<Bk/LFl//Jm/lNn]<Ro
]LRo]L:i[l6h[[fdZ[R_YK2WWJNNU9nFS9^BR9B>RI6;QXf7PXV3OXN1O8N1O8V3OX^5P9:>SIFAT9RD
Ti^GUYbHUiZFUIRDTiJBTJ2OVijMVI^JUYVGUYRFUYRFUYVFV9ZGVI^KViRHV9FEUIJFUYVIVIfMWInO
Wj2PX9NHW9VJWY^LX9bMXIbMXIbMXIjOXj2QYJ:SYj6RYZ:SYj>TZ:FVZZFVZZ:SYinPY9nQXYnQXYnQ
XZ2RXj:TYJBVYjJXZJRZZjNX[:JWZjBUZJ>TZ::SYj>TZ:BUZJFVZZFX[JJY[ZNZ[jR[/:Z]/Z^^/jb_
]:f`]JZ]/ZZ]/ZV//JR[/:R[/:V//JZ]/ZZ]/ZBX[J>W[:6TZJ2SZ::RZ:JTZZVW[J^Y[j^`[jV[Zj6S
XiJGUH>4P7IeLGEeKgikMWAcKgEdL7IeLGEdL79aKG5`K75`K7=bKW9aKG9aKG5`K75`K75`K79aKG=b
KWAcKg1_Jg5`K75`K75`K75`K71_Jfm^JVi]JG1_Jg1_Jg5`K75`K79aKG9aKG=bKW=bKW1_Jg1_Jg5`
K79aKG=bKW=bKW9aKG9aKG9aKG9aKG5`K75`K79aKGEdL7MfLWUhM7YiMG]jMWelN7imNGelN7akMgYi
MGUhM7IeLGIeLGIeLGIeLGIeLGIeLGIeLGIeLGIgKWEfKGEfKGEfKGIgKWQiL7UjLGYkLWmlM7mlM7ml
M7mlM7ikLgaiLG]hL7YgKgIgKWIgKWIgKWIgKWIgKWIgKWIgKWIgKWIdJWMeJgMeJgMeJgMeJgIdJWEc
JGAbJ79cJG=dJWEfK7IgKGMhKWMhKWMhKWMhKWQiKgQiKgMhKWMhKWMhKWQiKgUjL7YkLGUjL7UjL7Uj
L7UjL7UjL7UjL7UjL7UjL7IgKGMhKWQiKgUjL7YkLGYkLGUjL7UjL7QiKgMhKWEfK7AeJg=dJW=dJW=d
JW=dJWMeJgQfK7UgKGUgKGUgKGUgKGQfK7MeJg=dJW=dJW9cJG9cJG5bJ71aIfm`IVm`IW9`IG=aIWEc
J7MeJWIdJGAbIg5_I6m]HViaHViaHW1`HVi^H6a[GF]ZG6m/GW5^H6e[H6m]HW9`IGAbIgAbIg=aIW5_
I6m]HVi^H6m_HFm_HG1`HW5aHg9bI7=cIG=cIFm`H6Y[FfIWEfQYFFi_Gg5bHVm`H6]/G6i^H6m_HG1`
HW5aHg5aHg5aHg1`HVm_HG5bHW9cHg=dI71aHFe^GV]/G6]/G6a]GFATDVEUDfMWEFQXEVUYEfUYEfUY
EfQXEVQXFVQXFVQXFVQXFVQXFVMWFFIVF6EUEfUZEVIWDf=TD69SCf=TD6EVDVEVDVAUDF5SCF9TCV=U
CfAVD6AVD6=UCf=UCf9TCVMXE6QYEFQYEFIWDf=TD65RCV9SCf=TD6YYEFYYEFYYEFYYEFYYEFYYEFYY
EFYYEF][FF][FF][FFa/FVi^G71`GW5aGg=cHFi_Ffe^FVa]FFa/FVa/G6i^GW5`HW9aHfiaHFmbHVmb
HVe`H6Y]GFQ[FfQ[FfU/G6YZG6YZG6UYFfQXFVMWFFMWFFIVF6IVF6EWFfAVFV=UFF9TF69TF6=UFFAV
FVAVFVMYGFIXG6AVFV=UFF=UFFAVFVEWFfIXG6i`I6i`I75cIgAfJW1bIV]]HFa^HW9dJ7IkK7MlKGUn
Kg^0LGf2Lh25MX66Mh:7N8R9OhV:P8^<PXj?QI6BR9BERiJGSINHSYJHS9NISIRJSY^MTIjPU:2RUZ:T
V:>UVJ:VVZ:VVZ>WVj>WVjBXW:FYWJJZWZJZWZJZWjJZWjN[X:R/XJZ^Xj^_Y:b`YJb`YJfcZ:N]XZZ`
YJJ/XIRNTi^QUZR^XjZ`YJb_YZb_YZb_YZf`YjjaZ:nbZJnbZK2cZZnbZJnbZJnbZK2cZ[2cZ[2cZ[6d
Zk6dZjf`Yjf`YjjaZ:nbZJnbZK2cZ[6dZk6dZkBg[[>f[K:e[;6dZk6dZk6dZk:e[;:e[;6dZk6dZk6d
Zk2cZ[2cZ[2cZZnbZJnbZJnbZJjaZ:jaZ:jaZ:f`Yjf`Yjf`Yjf`Yj2SVZR[X[6dZkBg[[:e[:nbZK2c
Z[:e[;6eZZncZ:b`YJV]XZR/XJN[X:N[X:R/XK2_YK2_YK6`Y[:aYkBcZKNf[;Vh[[^j/;Fh[kRk/[^n
]Kbo][^n]K^n]Kg0]kk1^<74^l74^ko2^Kbo][^n]Kg0]l74^lG8_lG6`/G6`/K7`lK7`lO8a<O8a<O8
a<S9aLW<`lW<`l[<a/_=alc=bLg>b/k?cLk?cMWKg=GEeLc9aK:]Y9bCQJZLR/>bWLZhXLRhU<RhU<Rh
U<RhU<RhU<RhU<RhU<RhU<RhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhU<RhU<RhU<RhU<RhU<RhU<Rh
U<RhU<RhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlViU<ViU<ViU<ViU<ViU<ViU<ViU<ViU<RhTlRhTlRh
TlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlRh
TlRhTlViULViULViULViULViULViULViULViULRhU<RhU<RhU<RhU<RhU<RhU000a;^aa;^aa;^aa;^a
a;^aa;^aa;^aa;^aaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbb
aKbbaKbbaKbbaKbbaKbbaKbbaKbbaKbb`[^b`[^b`[^b`[^b`[^b`[^b`[^b`[^ba;^aa;^aa;^aa;^a
a;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^a`kZ``kZ``kZ``kZ`a;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^a
a;^aa;^aa;^aa;^aa;^aa;^aa;^aa;^a`[V``[V``[V``[V``[V``[V``[V``[V``[V_`[V_`[V_`[V_
`kZ``kZ``kZ``kZ`akjda[fca;^a`[V_`;N]_kJ/_[F[_[F[`;N]`[V_aKbbb;neb;neakjdaKbb`kZ`
_;2Z]j^U[Z:LXiNAVHf7T8AnRWihR7afNgMbNgMbO7QcP7agQh=nTHf8VYJAX9bGU9::U96<U96<U96=
UI6@Ui>BVIBEVYFFV9JEUiFDUYBCUYBCUiFDUiFDV9JEV9JEVY^OWIjRWj2TX:6UWj2TX:6UXZ>WYJJZ
X:6UXJ:VXZ>WY:FYYJJZY:FYXZ>WXJ:VXJ>TX::SX::SXJ>TXZBUY:JWYJNXYZRYYZN[YJJZXjBXXZ>W
XZ>WY:FYYZN[YjR/XJBYXJBYXZFZXjJ[Y:N/YJR]YZV^YZV^Y:N/Y:N/XjJ[XZFZXZFZXjJ[Y:N/Y:N/
Y:R]XjN/XjJ[XZFZY:BZYjF[Z:J/ZZR^[;6`YjVYXjFUWYnMRhb8N7McM7A^OgagM7=_M7=_Lg9^LG1/
KfiZKVeYKVeYKVeYKfiZKfiZKVeYKVeYKVeYKfiZL6m[LG1/M7=_MGA`MWEaMWEaMWEaMWEaMGA`MGA`
KfiZL6m[L6m[L6m[LG1/LG1/LG1/LG1/L6m[LG1/LW5]Lg9^Lg9^Lg9^LW5]LW5]M7=_Lg9^LW5]LW5]
Lg9^MGA`MgIbNGQdN7McNGQdNgYfO7]gO7]gNWUeNGQdN7McM7=_M7=_M7=_M7=_MGA`MGA`MGA`MGA`
MWM^MGI]MGI]MGI]MWM^N7U`NGYaNW]bOGYbOGYbOGYbO7UaNgQ`NGI^N7E]MgA/MGI]MGI]MGI]MGI]
MGI]MGI]MGI]MGI]MG=YMWAZMgE[MgE[MgE[MWAZMG=YMG=YLW=YLgAZM7E[MWM]MgQ^MgQ^MgQ^MWM]
M7E[M7E[LgAZM7E[MGI/MWM]MgQ^N7U_NGY`NGY`NGY`NGY`NGY`NGY`NGY`NGY`NGY`NGY`NW]aNW]a
NgabNgabNgabNgabNW]aNGY`N7U_MgQ^MWM]MWM]MWM]MWM]NGM]NGM]NGM]NGM]NGM]N7I/N7I/MgE[
MGI/M7E[M7E[LgAZLW=YLG9XLG9XLG9XM79WM79WMG=XM79WLg5VLFmTKfeRKVaQJVeNJfiOKViPKViP
KfiPKVeOL6eOL6eOJfUNKF]PL6iSLW1UM79WM79WM79WLg5VKG1QKW5RKg9SL7=TL7=TLGAULGAULGAU
L7=SJVeMI6MGIVUIKG1PLGATKg9RJfiNJfiNJfiNK6mOKG1PKG1PK6mOK6mOJfiNKFmLKW1MKg5NKFmL
JfeJJF]HJVaIJfeJJ6YDJF]EJfeGK6iHKFmIKFmIKFmIKFmIKFeOKFeOKFeOKFeOK6aNJVYLJFUKJ6QJ
KFUFJVICIV9?I61=I61=IF5>I61=Hem<HfI=HfI=I6M>IVU@J6]BJVeDK6mFKG1GJVeGJfiHJfiHJfiH
JVeGJVeGJVeGJVeGKFaHKFaHK6]GJfYFJfYFJfYFJfYFK6]GKViLKViLKFeKK6aJJf]IJf]IK6aJK6aJ
H65=HF9>HV=?Hf=AIFEEJ6QHK6]ML6mQKW1TKg5UKg5UKFmSJF]OIFMKIFMKIFMKIVIHIfMIJ6QJJFUK
Jf]MK6aNKFeOKViPKg=XL7AYLGEZLWI[M7Q]MWY_Mg]`N7aaNWicNGebN7aaN7aaNWicOX9gPXIkQHUn
R8b1RXj3Si>8TIF:Rhn4QHUnR8b1T9B9U9R<UIV=Ui^?VIfAW:2DWZ:FX:BHXJFIX:>JXJBKXJBKXZFL
Y:NNYJROYJROYZVPZjnTZjnTZjnTZjnTZjnTZjnT[;2U[;2UZ:bQZ:bQZJfRZJfRZZjSZZjSZjnTZjnT
ZZfTZZfTZjjUZjjU[:nV[:nV[:nV[:nV[;6XYjbSZk2WYjbSVIjEVj2GYZ^RYZ^RZjjUZjjU[:nV[K2W
[[6X[[6X[[6X[[6X[k:Y[k:Y[k:Y[k:Y/;>Z/;>Z/;>Z/KB[[k:Y[k:Y/;>Z/;>Z/KB[/KB[/KB[/[F/
/[F//KB[/;>Z[k:Y[[6X[[6X[[6X[k:Y/;>Z[k:Y[k:Y[k:Y[k:Y[k:Y[k:Y[k:Y[[6X[[6X[[6X[[6X
[K2W[K2W[K2W[K2WXjJMZ:^R[[6X/KB[/KB[/KB[/[F/];N^/kN//[J[/KFZ/;BY/;BY/KFZ/[J[/kN/
][>^][>^]kB_^;F`^KJa^kRc_;Vd_KZe]KR_]kZa^kje_;nf_L2g_/6h`<>j`/Fl_/6h_l:i_l:i_/6h
_/6h_l:i`lJma/W0b<W5b<W5alS4alS4alS4alS4alS4alS4b<_2bLc3b/c6c<k8cLk:c/o;c/o=c/o=
`lG6bl[<eM?Bc/[5_kJ]a;V[dlJfeLNeakNCakNCakNCakNCakNCakNCakNCakNCakNBakNBakNBakNB
akNBakNBakNBakNBakNCakNCakNCakNCakNCakNCakNCakNCakNBakNBakNBakNBakNBakNBakNBakNB
bKVDbKVDbKVDbKVDbKVDbKVDbKVDbKVDakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNB
akNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBakNBbKVEbKVEbKVEbKVEbKVEbKVEbKVEbKVE
akNCakNCakNCakNCakNCakNC0033^[33^[33^[33^[33^[33^[33^[33^[34^k74^k74^k74^k74^k74
^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k74^k71^[71
^[71^[71^[71^[71^[71^[71^[73^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33
^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[32^K32
^K32^K32^K32^K32^K32^K32^K30]jg1^:k1^:k2^Jo2^Jo3^[33^[33^[30]jg1^:k3^[34^k75_;;5
_;;5_;;4^k71^:k1^:k3^[34^k75_;;6_K?6_K?6_K?:_[C9_K?6^[32]Zbl/:JfZZ2`Y9Z/X9J@Rh:;
QWf5P7MoNW5lMfimN6n0Ng:3OWEoOG>5PgV>Rh>ETXZIUI2GTXnBSHZ>RHR>RhN?S8RBSh^BSh^ASXZ?
S8R=RXJ;R8B<SXn>T96ATiBBU9FBU9FCUIJEUiRHVY^JW9fLWYnNX:6PXZ>PXZ>OXJ:NX:6NX:6MWj2L
WYnKWIjKWIjJW9fKWIjKWIjLWYnRY:FQXjBQXjBQXjBRY:FTYZNVZ:VWZJZWZZnWZZnXZk2XZk2XZk2X
Zk2XZk2XZk2Y[;6XZk2WZZnWZZnWZZnWZZnXZk2Y[;6VZZnVZZnVZJjVZJjXZ:jZZ:jZZ:jZZ:jVZjZS
YJFSYJFUYZBEUY:0Og]fMW1lNGAaL6a_KVY]K6Q[JVIZJFEYJ6AYJ6AXIf=[JVIZJFEZJFEZJFEZJFE[
JVI/JfM]K6QaL6abLFecLVidLfmeM71eM71eM71dLfmcLVicLVicLVibLFebLFeaL6aaL6aaL6a`Kf]a
L6abLFecLVidLfmcLVicLVicLVibLFeaL6aaL6a`Kf]aL6acLVidLfmfMG5dLfmeM71gMW9hMg=hMg=g
MW9fMG5eM71cLVicLVicLVidLfmdLfmeM71eM71eM71fMfieMVeeMVeeMVefMfihNG1iNW5jNg9lNG5l
NG5lNG5lNG5kN71jMfmhMFegM6adMFadMFadMFadMFadMFadMFadMFadMFaeLfUfM6YgMF]gMF]gMF]g
MF]fM6YfM6YcM6YdMF]eMVafMfegN6igN6igN6igN6idMF]cM6YcM6YdMF]eMVagN6ihNFmiNW1kO79k
O79kO79kO79kO79kO79kO79kO79lOG=lOG=lOG=lOG=lOG=mOWAnOgEnOgElOG=kO79jNg5hNFmhNFmg
N6ihNFmhNFmiMfehMVahMVagMF]fM6YfM6YfM6YfM6YeMVadMF]dMF]cM6YbLfUaLVQaLVQaLVQbL6Eb
L6EaKfAaKfAbL6EdLVMfM6UgMFYWJU]XJea]KEm`L69bLF=bLF=aKV1_K5i_KF9`KV=`KV=aKfAbL6Ec
LFIdLVMdLVMbLf=bLf=bLf=bLf=bLf=bLf=bLf=bLf=cMF9^L5eZK5U[KEYaLf1eMfAcMF9`LUm/KU]]
Kea^L5e_LEi_LEi_LEi_LEi^L5eVJ59XJUAZK5IZK5IYJeEYJeE[KEM]KeUXITiYIdmZJ51/JU9/JU9]
Je=/JU9/JU9VIUIWIeMXJ5QYJEUYJEUYJEUYJEUYJEUfKe]cK5Q^Ie=/IE5/IE5/IE5[I51ZHdm[JU1Y
J4iWITaUI4YVID]XIde[JU1]K59[KUEZKEAXJe9VJE1UJ4mSITeRIDaQI4]THdmSHTiRHDePGd]PGd]P
Gd]QH4aQH4aIFDMHF4IGEdEFETAFETAGEdEGEdEHF4IBDcmFEd=JFdMOGdeSHe=YJEUbLF=gMVQbLfUf
MfejNg5mOWAnOgEoP7J1PWR3Q7Z3QGV4QWZ5Qg^7RGf9Rgn;SH6<SX:=Sh>?ThR@U8VBUX^DV8fEVHjG
Vi2HW96HW96FVXnEVHjEVHjEVHjHW96LX9FPY9VSYibKWiBMXIJQYIZSYibMXIJFVXnIWI:QYIZLWiJM
X9NNXIROXYVPXiZRYIbSYYfSYYfVZ::VZ::VZ::VZ::VZ::VZ::VZ::VZ::]/JJ]/JJ//:F[[jBZ[Z>Y
[J:X[:6WZj2]/JJ]/JJ]/JJ]/JJ]/JJ^/ZN^/ZN^/ZN][jV][jV][jV][jV][jV][jV][jV][jV[[jVV
ZZB[[jVY[JNKWiVMXI^X[:JX[:J^/JR_/ZV`/jZa]:^b]Jba]:^`/jZ`/jZ^/JR_/ZV_/ZV_/ZV`/jZ`
/jZ`/jZ`/jZ`/jZ`/jZ`/jZa]:^a]:^a]:^a]:^b]Jb`/jZ_/ZV^/JR/[jJ/[jJ/[jJ/[jJ]/:N]/:N]
/:N]/:N]/:N]/:N]/:N]/:N]/:N/[jJ/[jJ/[jJ/[jJ]/:N]/:N]/:N]/:N]/:NZ[JBWZZ6Y[:>^/JRc
]Zfe^:ne^:nc]jbc]jbb]Z^b]Z^c]jbd^:fd^:fe^Jje];2e];2f]K6g][:h]k>h]k>h]k>h]k>e^:ng
^[6i_;>j_KBj_KBk_[Fn`KS0`kZi_;>m`;O1a;_3a[g3a[g3a[g3a[g4akk8bLG7b<C7b<C7b<C7b<C6
al?6al?6al?8bl;9c<?;cLO<c/S=c/[=c/[=c/c<cL_;cm3<c/kBdm79a/6e/:Ng[ZC4^jg7_:k7]i?7
]i?7]i?7]i?7]i?7]i?7]i?7]i?7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i?7]i?7]i?7]i?7]i?7
]i?7]i?7]i?7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;8^9?8^9?8^9?8^9?8^9?8^9?8^9?8^9?7]i;7
]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;7
]i;7]i;7]i;8^9C8^9C8^9C8^9C8^9C8^9C8^9C8^9C7]i?7]i?7]i?7]i?7]i?7]i<00<>j/<>j/<>j
/<>j/<>j/<>j/<>j/<>j/<Bk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk
/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/LBk/L6j/L6j/L6j/L6j/L6j/L6j/L6j/L6j/L>j/<>j/<>j
/<>j/<>j/<>j/<>j/<>j/<:i[l:i[l:i[l:i[l>j/<>j/<>j/<Bk/L>j/<>j/<>j/<>j/<>j/<>j/<>j
/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<6h[l6h[l6h[l6h[l6h[l6h[l6h[l6h[knf[<2g[L2g
[L6h[/:i[l>j/<>j/<>j/;fdZ[nf[<:i[lFl//Nn]<Nn]<Nn]<Nn]<>j/<:i[l6h[/2g[Knf[;nf[<2g
[L2g[L6eZL>gZlNk[lZn//^o/lZn//Nk[lFi[L:j[KjfZKN_XZbTUinGRY::OHR0Lh9jKH=oM85mLWeh
Kg]fKGafKh1jMHEoNXR2OHN4P8Z7Phj;Qhn<R8j;Qhb9QH^8Q8^8Q7j0P863Ph>5QHF7QhF7QhJ8R8V;
Rh^=SI:DU9FGUiRJVYZLW9VKViRJVYRJVYVKViFGV9BFUi:DUI6CU92BTi2BTi2BTi2BTiBFUYBFUYFG
UiJHV9NIVINIVIRJVYRJVYnRYinRYinRYj2SZ:2SZ:2SZ:6TZJ6TZJ>VZj:UZZ6TZJ6TZJ6TZJ6TZJ:U
ZZ>VZinSZ9nSZ:6TZJ6TZJ>SZJBRZ:>QYj:PYYjSXYnQXJ6SXjBUXi^LV8b;QginN7YgLWEdL79aKFi]
JFa[Ifa[Ife/J6a[If]ZIVe/J6e/J6a[Ifa[Ifa[Ife/J6i]JFm^JVe/J6i]JFm^JW5`K79aKG=bKW=b
KW=bKWIeLGIeLGEdL7EdL7AcKgAcKg=bKW=bKW5`K79aKG=bKWAcKgAcKgAcKg=bKW=bKVi]JFi]JFm^
JW1_Jg1_Jg1_Jg1_Jg1_Jg1_Jg9aKG=bKWEdL7EdL7EdL7=bKW9aKG9aKG=bKW=bKWAcKgEdL7IeLGIe
LGIeLGIgKWEfKGEfKGEfKGIgKWQiL7UjLGYkLWejLWejLWikLgikLgikLgejLWaiLGaiLGAeK7AeK7Ae
K7AeK7AeK7AeK7AeK7AeK7IdJWIdJWQfK7QfK7UgKGUgKGQfK7QfK7AeJgEfK7IgKGMhKWQiKgQiKgQi
KgQiKgQiKgMhKWMhKWQiKgUjL7YkLGamLgenM7enM7enM7enM7enM7enM7enM7enM7enM7ioMGioMGen
M7enM7enM7ioMGn0MX21MgenM7amLg]lLWUjL7UjL7QiKgUjL7UjL7UgKGQfK7IdJWEcJGAbJ7AbJ7Ab
J7EcJG=dJW=dJW9cJG9cJG5bJ71aIfm`IVm`IWAbIg=aIW9`IG1^Hfm]HVi/HFi/HFi/HFU/GFU/GFe]
Gfm_HG9aHg9aHg1]GfeZG6aZGfe[H6i/HFm]HVm]HVi/HFe[H6e[H79_H71]GVi[G6eZFfeZFfi[G71]
GW5^Gfe/F6]ZEVYYEF]ZEVe/F6m^FVm^FVi]FFYYE6]ZEFe/Efi]F6m^FFm^FFm^FFm^FG9^EWEaFGMc
FgQdG7QdG7UeGG]gGgijHWE`EgIaF7MbFGUdFgYeG7YeG7YeG7UdFgUdGgYeH7ehHh1kIX=nJHF0JhN2
KHN2KIbCN9V@MIF<LI>:KiB;L9B;L9B;L9>:KhZ6JXF1IGahG79^DVUUBF9N@UiJ?UaH?5EC>e5?=di<
=4a:<Te;<di<=4i<=4e;<d]:=TY9=DQ7<dI5<DE4<4E4<4M6<TM6<TI6=4I6=4M7=DU9=d];>Di>?51@
?U5A?e5B?UIG@eiOBfEUDfa/G7EeIH1oLHR7NHF7NhV;OhnAQI>ERIFGRiNISIVKSi^MTI^OU9bPUIbP
UIfQUYfQUYjRUijRUinSV9ZOUY^PUibQV9bQV9bQV9bQV9^PUiZOUYfRVIbQV9^PUi^PUi^PUifRVInT
Vj2UW:6VWJ6VWJ>XWjFZXJ6VWI^PUibQV:6VWJNYXjNYXjNYXjRZY:RZY:V[YJV[YJV[YJV]YjZ^Z:Z^
Z:^_ZJb`ZZfaZjjb[:jb[:Z_YZZ_YZZ_YZZ_YZZ_YZZ_YZZ_YZZ_Y[2cZ[2cZ[2cZ[2cZ[2cZ[2cZ[2c
Z[2cZ[2b[;2b[:naZjnaZjnaZjnaZjnaZjnaZj^_ZJJZY:^_ZJR/YY^OVIfQVjV]YjV]YjjaZ:nbZK6d
Zk:e[;:e[;6dZjnbZJjaZ;2cZ[2cZ[6dZk6dZk6dZk:e[;:e[;:e[;2cZ[2cZ[2cZ[2cZ[2cZ[6dZk6d
Zk6dZjnbZJnbZJjaZ:f`Yjf`Yjf`YjjaZ:jaZ:^^YJ^^YJb_YZb_YZb_YZf`Yjf`Yjf`Yj^^YJb_YZb_
YZb_YZf`Yjf`Yjf`Yjf`Yk>f[Jb_YZJYX:JYX:b_Y[:e[;Bg[[>f[K:fZk>g[;>g[;>g[;>g[;>g[;>g
[;>g[;Fg/KFg/KNi/kRj];Vk]KVk]KRj];Rj];^n]Kbo][bo][Zm];Rk/[Rk/[Zm];bo][Vl/kk1^<C7
_/O:`LO:`LK9`<G8_lG8_lO8a<O8a<O8a<K7`lK7`lK7`lK7`lK7`lO:`LW<`l_=alc>b<c=bL_<b<[;
bLW:b=3Edko2`:j_ZiRIT8>2N8n;P:^UV;NbXlJfT/JfT/JfT/JfT/JfT/JfT/JfT/JfT/JfTLJfTLJf
TLJfTLJfTLJfTLJfTLJfTLJfT/JfT/JfT/JfT/JfT/JfT/JfT/JfT/JfTLJfTLJfTLJfTLJfTLJfTLJf
TLJfTLRhTlRhTlRhTlRhTlRhTlRhTlRhTlRhTlJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJf
TLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLRhU<RhU<RhU<RhU<RhU<RhU<Rh
U<RhU<JfT/JfT/JfT/JfT/JfT/JfTP00`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`kZ``kZ``kZ``kZ`
`kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ`
`;V``;V``;V``;V``;V``;V``;V``;V``[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`KR^`KR^`KR^`[V_
`kZ``kZ``kZ`a;^a`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_
`KR_`KR_`KR_`KR_`KR_`KR_`KR_`KR__kJ/_kJ/`;N]`KR^`[V_`[V_`kZ`a;^a`KR^`KR^`KR^`KR^
`KR^`KR^`KR^`KR^`;N]`;N]`KR^`[V_`[V_`kZ``kZ``kZ`_[FW_kJX`KRZ`kZ/a;^]a;^]`[V[`KRZ
_kJX`KRZ`kZ/a;^]a;^]`[V[_kJX_KBVY9jAViF8SHMlPWaaO7E/OWI_Q7aeR81iOg]fPWiiQH5lQX9m
QX9mR8AoSHV4THf8Rhf=SY2@T9:BTYBDTYBDU9JFUiVIVI^KSi6ATiFEUiVIV9ZJUYRHUINGUYRHV9ZJ
TiFFTYBETI>DT9:CT9:CT9:CTI>DTI>DSY2@Si6ATI>CTYBDTI>CSi6ASHn?Rhf=QHR=QHR=QhZ?RHbA
RXfBS8nDSY6FSY6FTIBIT9>HSi:GSi:GSi:GSi:GT9>HTIBIVIfRVYjSWJ2UWJ2UWinUWifSWI^QViVO
VIjMWInOWInOWIjLW9fIUiJBQhN1NWMbLW5]KVeYJFQTJ6MSJFQTJfYVJVUUJFQTJ6MSJ6MSIfIRIfIR
IfIRJ6MSJFQTJVUUL6m[LG1/Lg9^MGA`MgIbMgIbN7McN7McLG1/LG1/LW5]LW5]LW5]Lg9^Lg9^Lg9^
LG1/LW5]Lg9^M7=_M7=_M7=_M7=_Lg9^KVeYL6m[LW5]M7=_M7=_Lg9^LG1/L6m[KVeYL6m[LW5]Lg9^
M7=_Lg9^LW5]LG1/Lg9^Lg9^M7=_MGA`MWEaMgIbMgIbN7McMWM^MGI]MGI]MGI]MWM^N7U`NGYaNW]b
NgQ`O7UaOGYbOW]cOW]cOW]cOW]cOGYbMGI]MGI]MGI]MGI]MGI]MGI]MGI]MGI]MgE[MgE[NGM]NWQ^
NWQ^NWQ^NWQ^NWQ^MGI/MWM]N7U_NGY`NW]aNW]aNW]aNGY`NW]aNW]aNGY`NGY`NW]aNgabOGidOGid
OGidOGidOGidOGidOGidOGidOGidOGidOWmeOGidO7ecO7ecO7ecOWmeOh1fP85gOGidO7ecNgabNW]a
NGY`NGY`NGY`NGY`NWQ^N7I/MWAZMG=YM79XM79XM79XMG=YLG9XLG9XL75WKg1VKVmUKVmUKFiTKFiT
L6iSLW1UMG=XMgEZN7I[MG=XLW1UL6iSM7MXKg9SKFeOJf]MKFaNKVeOKV]MK6UKJ6IKK6YOLg5VNGM/
NgU^NGM/MWAYLg5VNG9QMVmNLfaKLV]JLV]JMVmNNW=ROGIUNgEROGMTP7YWPG]XOgUVOgUVP7YWPWaY
PWiVPgmWQH5YQh=[RHE]RXI^RXI^RXI^UheeVHmgVi5iVi5iVi5iW99jWYAlX9InZ9f2ZIj3ZYn4[:66
[J:7[J:7[J:7[:66[ZF:[jJ;/JR=/jZ?]JbA]jjC]jjC]jjC_kBF_;6C^Jj@^:f?^Jj@^ZnA^ZnA^ZnA
^ZnC]jb@/:F9Yib0W95eTHIZR7eQPgQLI5m6GUU0EE0gD4/bCTT`CDP_BdH]BTD/@D0/?chZ?3/W>STU
>CPT>CPT>cXV?3/W@D4_@T8`@d<aADDcB4PfC4`jCThlD50nCTlkE5E1Fea8H61>I6ADJf]KMGAVOWe_
Oh9cQ8MhRXenSi:3TYF6TiJ7UYV:UiZ;VYjCVYjCVinDW:2EWJ6FWZ:GWj>HWj>HXZNNXjROYJZQYJZQ
YJZQY:VPXjROXZNNYjbSYjbSYjbSYjbSZ:fTZ:fTZ:fTZ:fTZJjUYZ^RYZ^RZ:fTYZ^RX:FLWjBKXJJM
YZNSYZNSYjRTYjRTZ:VUZJZVZJZVZZ^WYJVTYZZUYZZUZ:bWZJfXZZjYZjnZ[;2[[K:Y[[>Z[[>Z[[>Z
[kB[/;F//;F//;F/[k:Y[k:Y[k:Y[k:Y[k:Y[k:Y[k:Y[k:Y/;6][k2/[k2/[k2/[k2/[k2/[k2/[k2/
[K6/Z:bWZjnZYj^VVIfHW:2KZ:bWZ:bW[:nV[K2W[k:Y/;>Z/;>Z[[6X[:nVZjjU/;>Z/;>Z/KB[/KB[
/KB[/[F//[F//[F//;>Z/;>Z/;>Z/;>Z/;>Z/;>Z[k:Y[k:Y[[6X[K2W[K2W[:nV[K2W[K2W[[6X[k:Y
ZjjU[:nV[:nV[K2W[K2W[[6X[[6X[[6X[:nV[K2W[K2W[K2W[[6X[k:Y[k:Y[k:Y/[F/[k:Y[:nVZZfT
ZjjU[[6X/;>Z/KB[/[J[/[J[/kN//kN/];R]/kN//kN//kN/];N^]KR_]kZa^Kbc^Kbc^Kbc^;^b^;^b
_;nf_L2g_L2g^kje^Kbc^Kbc_;nf_/6h_;nf`<>ja<Nna/W0a/W0a/W0a/W0b<_2alS4alS4alS4alS4
alS4alS4alS4alS4al[1bLc3b/c6blg7blc8bL[6alS6aLK4XJRQVZ6JXZNNZ:bQYZRL/k>UaLFeblRi
a[JBa[JBa[JBa[JBa[JBa[JBa[JBa[JBa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JBa[JBa[JBa[JB
a[JBa[JBa[JBa[JBa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAakNBakNBakNBakNBakNBakNBakNBakNB
a[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JA
a[JAa[JAa[JAa[JAakNCakNCakNCakNCakNCakNCakNCakNCa[JBa[JBa[JBa[JBa[JBa[JB0032^Jo2
^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo3^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33
^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[30^K30^K30^K30^K30^K30^K30^K30^K32^Jo2
^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo0]jg1^:k1^:k2^Jo2^Jo3^[33^[34^k72^Jo2^Jo2^Jo2^Jo2^Jo2
^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo1^:o1^:o1^:o1^:o1^:o1^:o1^:o1^:nn]J^o
]Zbo]Zc0]jg1^:k2^Jo3^[34^k73^[32^Jo0]jfo]Zc0]jg2^Jo4^k76_K>m]:Zo]Zc1^:k3^[33^[32
^Jo1^:k0]jg3_:g3_:g2^jc2^jc1^Z_2^jc2^jc2^jc4_:_2^ZVo]jJm]JBm]JBo]jK1^JS3^jZo^:W1
^Jc2^Zfn]J^bZInRVI2AQh27OGIaKFQcKfYdL6]eLFagLfimNGB7Pgj?RhJ6R8R9Rh^<SXj=Shn>T92?
TI6BU9BEUiN@TY:EUiNIVi^JW9bHVYZGVIVHVYZJW9bGVIZGVIZFV9VFV9VGVIZHVY^IVibJW9fHVYZI
Vi^KWIfKWIfIVi^EUiN@TY:=Shn@TiRAU9VDUibGVYnJWJ:MX:FOXZNQY:VSYZ^RYJZRYJZQY:VQY:VR
YJZRYJZSYZ^NXZNOXjRRYJZSYZ^TY:ZTXZRQWjFPWZBFViZLWYjIVi^GV9JJViNNWIV?ShUkN7=UI61P
Ge]KFUIJFEELFeMNGEUMG5QLFeMIF5AHEe=HEe=HEe=HEe=IF5AJFEEKFUIHEe=JFEELFeMNGEUPGe]Q
H5aQH5aQH5aZJFEZJFE[JVI]K6Q^KFU`Kf]aL6aaL6aaL6abLFecLVidLfmeM71dLfmdLfmdLfmbLFed
LfmgMW9jNGEjNGEhMg=eM71cLVi^KFU`Kf]bLFecLVidLfmdLfmbLFeaL6acLVicLVidLfmeM71fMG5g
MW9hMg=hMg=fMfieMVeeMVeeMVefMfihNG1iNW5jNg9hMFehMFejMfmkN71lNG5lNG5lNG5lNG5fMfif
MfifMfifMfifMfifMfifMfifMfigMF]hMVaiMfekNFmkNFmkNFmkNFmkNFmfMfegN6iiNW1jNg5kO79k
O79kO79jNg5iNW1iNW1hNFmhNFmhNFmiNW1kO79kO79mOWAmOWAmOWAmOWAmOWAmOWAmOWAmOWAmOWAl
OG=kO79jNg5kO79lOG=nOgEoP7ImOWAlOG=kO79jNg5iNW1iNW1iNW1iNW1kNFmiMfegMF]eLfUdLVQd
LVQeLfUeLfU_L6I_L6I_L6I^KfE]KVA/KF=/KF=[K69SHEI[JEihMV^5PgR=Rh2@SX>?SH:=Rh1mP75e
N6U]KEmXJ5YXIeUYJ5Y/JE]/JE]ZJ5ecLFJ0OW><RWnBT8FAShB=Rh28QW^9Ofj7OFb3NFR2N6N4NVV9
Ofj?QGBCRGRNU8:TVXRZX8jZX8jVW8ZTVXRVW8ZZX8j^YXn`Z96bZY>d[9Fg[iRh/9Vi/IZi/IZj[9Fl
[YNn/9Vn/9Vl[YNl[YNn/9W0/Y^n/9Bn/9C0/YK1/iO2]9S2]9S2]9S2]9Ro]9Jo]9Jo]9Jn/iFm/YBl
/I>j[i6i[Y31]iFn]9:k/Hnk/Hnm/i6o]I>o]I>o]I>gZHbk[I30/YG3]IS2]9Nn/9>iZhjeYhZWWHFK
TGV:P6QjL5Q^I4aUFd=MDc]HCSI<BcM:BCE7AS94@bm3@Ri4@bm5A316AC4l?2Xl?2Xl?2Xm?B/o?be1
@Bm3@c54A392@bm7B3A<CCU<C3Y<C3a?CcmFEDMNGDmNHE5UJ5Q_LV9hNf^0Pg>6RGV;SWj?TX:CUhbD
V8fFVXnIWI:LX9FOXiRQYIZRYY^JXIZLXibNYIjQZ:6SZZ>SZZ>SZZ>SZZ>OYYnPYj2RZJ:U[:FV[JJW
[ZNX[jRX[jR//jbV[JJTZjBW[ZNW[ZNRZJ:NYIjNYIjYZZJZZjN[[:R/[JV][ZZ_/:b`/Jf`/JfZ/:^Z
/:^Z/:^Z/:^Z/:^Z/:^Z/:^[/Jb[/Z^[/Z^Z/JZZ/JZZ/JZZ/JZY/:VY/:Va/jfa/jfa/jfa/jf`/Zb`
/Zb`/Zb`/Zba/Zja/Zja/Zja/Zjb/jnb/jnb/jnb/jnc]k:]/Jb_/jjZ[ZVKWiZMXIbZ[ZV[[jZ^/JR`
/jZb]Jbc]Zfc]Zfa]:^_/ZV]/:N^/JR^/JR_/ZV_/ZV_/ZV`/jZ`/jZ`/jZ`/jZ`/jZ`/jZ_/ZV_/ZV_
/ZV_/ZV_/ZV[[ZF[[ZFZ[JBZ[JB[[ZF/[jJ]/:N^/JR/[jJ]/:N]/:N^/JR^/JR_/ZV`/jZ`/jZ^/JR^
/JR^/JR_/ZV`/jZ`/jZa]:^a]:^^/JRa]:^b]Jb_/ZV[[ZFY[:>/[jJ`/jZb]Z^b]Z^c]jbd^:fe^Jje
^Jje^Jje^Jj`]:Rb]ZZd^:bf^Zjg^jng^jnf^Zje^Jfg^[6i_;>j_KBj_KBj_KBl_kK0`k[3a[fn`KS0
`k[1a;_2aKc2aKc3a[g6bL38bl;7b<C7b<C7b<C8bLG8bLG9b/K9b/K9b/K7b/78bl;:c<K;cLO:blO8
bLG5a/C3a<:j`[N/]:V[/ZF]/JF/[j2l_Jg@d[oFe/C6]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y76
]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y;6]Y76]Y76]Y76]Y76]Y76
]Y76]Y76]Y77]i;7]i;7]i;7]i;7]i;7]i;7]i;7]i;6]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76
]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y77]i?7]i?7]i?7]i?7]i?7
]i?7]i?7]i?6]Y;6]Y;6]Y;6]Y;6]Y;6]Y800<Fi[LFi[LFi[LFi[LFi[LFi[LFi[LFi[LNk/LJj/<Fi
[lBh[/Fi[lJj/<Rl//Vm/l>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j
/<>j/<:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l>j/<>j/<>j/<>j/<>j/<>j/<>j/<>j/<6h[/:i[l>j
/<>j/<>j/<>j/<:i[l6h[/6h[/6h[/:i[l:i[l:i[l>j/<>j/<>j/<:i[l:i[l:i[l:i[l:i[l:i[l:i
[l:i[l6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h
[/6h[/6h[/6h[/6h[/6h[/Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh
[<Bh[<>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZlFi[LBh[<Bh[<>gZl>gZl:fZ/:fZ/6eZL:hYkBZVJ2F
QHn5M8EkJX5gIX9hIh=iJ7]lLgmmMHN3OXn:Qhf9R8F5QH>8RHVCTiJEUiRGVINIVYRJViVJWYZKWiRI
WIBEVIVJV9fNW9NHUXf>S8n@SYZKVIZKVI2ASi2DUIBHVIZLWIfLWYfJW9bGVI^DUibCUYZMVi6DTYJF
UZ:RXZ6PXY>EUXfBTiNLWIBHWIRLXIZNXiFIWY2DVI>GW:6UZZfa]YbRXIJLVi^QX9nSY9ZNWj2RXjJW
Zj6RYZ2SXJJYYjV/ZZ>XYYfRX9VPWIROW9ROW8N=PWb1N6mgKFadJVedKFeaJf]/J6UXI6i]JG=bKWAc
Kfm/J6]VHfeXIG9[J79[J6QWHfMVHVETH6ETH6IUHFQWHfa[Ifi]JFe/J71_Jg9aKG=bKW9aKG5`K79a
KG=bKWA_K7A_K7IaKWIaKWIaKWA_K79]JW5/JFi]JHF4P8F4P9^JUYZIUHJ5PHb;QgYiMG5bJFa]I6a]
I79cJWAeK6m`Ifi_IW9cJWAcKgAcKgEdL7IeLGIeLGMfLWMfLWQgLgIeLGIeLGUfLGYgLW]hL7ajL7mj
LGmjLGajL7ajL7]iKg]iKg]iKgajL7ekLGilLWIdJWMeJgUgKGYhKW]iKgYhKWQfK7MeJgilLWekLGaj
L7]iKg]iKgajL7ajL7ekLGYkLGIgKGUjL7n0MW]lLW9cJGIgKH:3NGmmLg]iKgekLH>1MhB2N7ilLW]i
KgekLH21Mh60MWmnM7mmLgilLX1kLX9kLX9kLX1lLH=oM8B0MHB0MH9nLh5mLX5mLX9nLhJ4NX>1Mh1n
LginLWj1LWf0LGQmKWAiJVQ`IFY`IFY`IFa`IFa`IFi_IFi_IG1_IF1XGVI[HVY_IVe`Ifa_IVa]I6QY
H6ITG7AaHW1]GW=`HH5nKi6>Oi>@PHF2LgEbHgQcFWQcFWUdFgUdFgYeG7]fGG]fGGagGXn1JYF7L9nA
NZRJPjjPRJnQRZfOR:^MQ[:WRK>XR[BYRkJ[SKN/S[V^T;Z_TK^`T[faUKfaUKfaUKjbU[jbU[jbU[nc
UkncUkjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKndU[ndU[ndU[ndU[ndU[ndU[ndU[ndU[ndU[ndU[nd
U[ndU[ndU[ndU[ndU[ndU[jcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjc
UKjcUL:bUL6aU<2`Tl2`Tl2`Tl2`Tl6aU<:bUKf^S[f^S[f^S[j_Skb]SKBUQJRINIn@L8emH81bEF]P
@UQ@<e1<<51=<DM8;Sho9DU2;dM2;D13:Se3:SY09cHl8c/m9d91;CXi9C`k9cln:T=2;TM6<TY9=Da;
=de<>4i@?55C?eIHA5]MBV9SDfUZFW5aHgIfJ7alK8B4M8n>P9JFRYJHS9NHSYNKT9VLTiNMTY^QUYnU
VZ6VWJ:VX::VX:>WXZBXXjZ/YZ^]Yjf_ZJb^Z:^]Yj^]Yjb^Z:j`ZZV]XJV]XZV]XZV/XjRZY:JXXZFV
XZBUXJJZYJV]Z:^_ZZb`ZjZ^ZJV]Z:Z^ZJ^_ZZf^ZZj_Zjj_Zjn`[;2a[K2a[K6b[[6b[Zf`Yjf`Yjf`
YjjaZ:jaZ:jaZ:nbZJnbZK:e[;>f[K:e[;2cZ[:e[;Ji/;>f[Jb_Y[Rl/JZ^XjN[X;>f[KZl][Fg/Jn`
[:n`[;6dZk:e[;>f[JnbZJJYX9nRVJFXWk2cZZnbZJnbZK2cZ[2cZ[6dZk6dZk6dZk6dZkJi/;Ji/;Bg
[[:e[:nbZJf`Yj^^YJZ]Y:JYX:JYX:JYX:NZXJNZXJNZXJR[XZR[XZBXWJBXWJFYWZNZXJRZY:Z/YZ^/
Z:^/Z:b_YZf`YjjaZ:nbZK6dZk:e[;>f[KBg[[2cZ[6dZk6dZk6dZk:e[;:e[;:e[;>f[KFf[KBe[;Be
[;>dZk6bZJn`Yjf^YJb]Y;Jg[[Vj/Kbm];^l/kRi/;Jg[[Nh[kVj/K6dZk>f[KFh[kRk/[Vl/kVl/kRk
/[Nj/K:e[;Bg[[Ji/;Zm];g0]ko2^L33^/74^ko0_<31_L72_/;3_l?4`<C5`LG6`/G6`/G6`/K7`lO8
a<S9aLS9aLS9aLO8a<O8a<[;alW:a/[;alc=bLg>b/_<b<K7`l?4`;Fi[K6eZJjbY[2bY[>cYkRh[<O5
^]GCb<FiWL2eUl2dT<>iTLJjT/>gSl>cSlFdTlFeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<Fe
T<FeT<FeT<FeT<FeT<FeT<NgT/NgT/JfTLJfTLJfTLJfTLJfTLFeT<RgT<RgT<RgT<RgT<RgT<RgT<Rg
T<RgT<RgT<NfSlNfSlJeS/JeS/NfSlNfSlRgT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<FeT<NgT/NgT/Jf
TLJfTLJfTLJfTLJfTLFeT<JfTLJfTLJfTLJfTLJfTLJfTLJfTLJfTLNfULRgU/RgU/RgU/VhUlVhU`00
aKV]aKV]aKV]aKV]aKV]aKV]aKV]aKV]ak^aa[Z`aKV_a;R^aKV_a[Z`b;bbbKfc`kZ``kZ``kZ``kZ`
`kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_
`kZ``kZ``kZ``kZ``kZ``kZ``kZ``kZ``KR^`[V_`[V_`kZ``kZ``[V_`[V_`KR^`KR^`KR^`KR^`[V_
`[V_`kZ``kZ``kZ``[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`;N]`;N]`;N]`;N]`;N]`;N]`;N]`;N]
`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^a;R/a;R/a;R/a;R/
a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[
a;R/a;R/a;R/`kN[`[JZ`[JZ`[JZ`KFY^k6P_K>R`;JU`;JU^[2O[ZBCWYB3ThUhNGQZLViSLVeTOWQc
QX:1PH>3NH23Lgn1PHR;PhZ=QHb?R8jCSI6FTYJKUYRPUiVQVifNVYbMSY2AP8:3Q8J7UINHWZ2QW9jO
TIRKTiRKTiRKU9NKUYNKViZNXYjSYZ:WVj2OVYnNVifMWInPWj6RWJ6RW:6RW:6TWJ:UX:FXX:FXW:6T
UIZMU9VLVj2SXZNZZ:f^VIjOT9FFTIFFTYJGVinPX:BUVYjO/;6_/;6_[Jj/YjZXY:NUXJBRW9nMV9^I
TiB;RHZ1NWedLGA[K6mVJVaVK6aVKViXHUmJJ6EPK6UTJfMRKVQSLfeXN6m[MfiZLg1[LVmZLFiYL6eX
LFiYLg1[MG9]MW=^KFaXL6m[LW5]Lg9^LG1/LG1/LG1/Lg9^Lfi[M6m/MG1]MW5^MW5^MG1]M6m/Lfi[
M7=_RHR4SXf9YjJR[:^WW9^GW9^GRHR4OWmfLgA[KVmVLW=ZMgQ_MGI]LW=ZLW=ZM7=_M7=_M7=_MGA`
MGA`MWEaMWEaMWEaMWEaMWEaNGIaNGIaNgQ`O7Y`OgYaOgYaNgU_NgU_NWQ^NWQ^NgU_O7Y`OG]aOG]a
MgE[N7I/NGM]NWQ^NWQ^NGM]N7I/MgE[O7Y`O7Y`NgU_NgU_NgU_O7Y`O7Y`OG]aNgabMWM]MWM]Ngab
OGidNW]aN7U_NGY`QXAjPX1fOWabOWabPGmePh5gPGmeOgecNWicNWicOGidP7mePX5gQ89hQXAjRHAk
P7idPGmePX1fP7idOWabOG]aOG]aOgecP7]bOgYaOG]aOWecP81dOGmcNG]_LgM[M7Q/MGM[LgEYLg=W
LW1UL6iSL6aQKf]PKW9VIfUMJF]OMGEYMG=XJVQMJVIKLViSKFMDKfUFMW1MPgeZT8YgUi5nUHmlTH]h
VY5fW9=hWiIkY9^0ZJ25[ZF:/ZV>]:^@/jJ<]JR>^:^A_:nE_K2F_[6G_K2F_:nE^ZnA^ZnA^k2B_;6C
_K:D_kBF_kBF`;FG_K6E_K6E_K6E_[:F_[:F_[:F_k>G_k>G_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E
_kBF_kBF_kBF_kBF_kBF_kBF_kBF_kBF_kBF_kBF_kBF_kBF_kBF_kBF_kBF_kBF_[>E_[>E_[>E_[>E
_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E`[:E`K6D`;2C`;2C`;2C`;2C`K6D`[:E
`[>C`K:B`;6A`K:B`kBD`K:B_:f=]jR8]ZN7/ZB7ZYn1UHe`L6U>CDX^AD@ZCTleAD8]A4<^@4@[?48Y
>d4X?T4X@3dX?cXUBTTdB4LbAD@_@d8]@D0[@D0[@D0[@T4/ADLaATPbB4TeBT/gC4`jD510E5A4EeM7
Hf5?IfAEJVYJKViPM7AXNWa`Q8EkRHf2Si>7U9R<VIfBWJ6FWj:IXZBNYJNQYjVSYjVSZJ^UZZbVZJ^U
YjVSYJNQYZRRZ:ZTZZjSZZfTZjjUZjfWZjfWZZ^WZJZVZJZXZjnZ[;2[[[:][[:][;2[ZjnZ[;2[[[:]
[JjZ[Zn[[Zn[[Zn[[k2/[k2//;6]/;6]/KB[/KB[/KB[/KB[/KB[/KB[/KB[/KB[/[F//kJ]/KB[/;>Z
/[F//kJ]ZjjUX:>JU9R=RHf2QHUnTIB;XjFO[k6[/[>_/kB`/[F//[F//kJ]/;>ZYZVPWj:IYJRO/;>Z
[k:Y[k:Y/;>Z/;>Z/KB[/KB[/KB[/KB[/;>Z[k:Y[[6X[:nVZjjUZJbSZ:^RYjZQY:NNY:NNY:NNYJRO
YJROYZVPYZVPYZVP[;2U[K6V[[:W[k:Y/;://[B^/kB`/kB`];N^];N^]KR_]KR_]KR_]KR_]KR_]KR_
/;>Z/KB[/KB[/KB[/[F//[F//[F//kJ]];F/];F/];F//kB[/[>Z/;6X[ZnV[JjU/kB[][N^^KZa^;V`
][N^]KJ]][N^^;V`/[F//kJ]];N^][V`]kZa]kZa]kZa]kZa];N^]KR_^;^b^kje_L2g_l:i`<>j`<>j
_l2l`<6m`L:n`/>o`lC0a<G1aLK2aLK2aLK2a/O3alS4b<W5b<W5b<W5alS4alS4b/_7bL[6b/_7c<g9
cLk:blc8a/O3`lC0][Z^/[JZ[k>W/K>W];BX^KV]b<Jke]C9a[ZN`;FG`;B@`kVAa[ZB`[J>`k>?aKBC
aKF@aKF@aKF@aKF@aKF@aKF@aKF@aKF@aKF@aKF@aKF@aKF@aKF@aKF@aKF@aKF@a[JAa[JAa[JAa[JA
a[JAa[JAa[JAa[JAb;N@b;N@b;N@b;N@b;N@b;N@b;N@b;N@b;N@akJ?a[F>a[F>a[F>a[F>akJ?b;N@
aKF@aKF@aKF@aKF@aKF@aKF@aKF@aKF@a[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JAa[JA
a[JAa[JAa[JAa[JAakNCakNCakNCb;RDb;RDbKVE0035^Jg5^Jg5^Jg5^Jg5^Jg5^Jg5^Jg5^Jg6^[35
^Jo5^Jo5^Jo5^Jo6^[37^k78_;;3^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33^[33
^[33^[33^[32^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo2^Jo3^[33^[33^[33^[33^[33^[33^[33^[31^:k1
^:k2^Jo3^[33^[32^Jo1^:k1^:k1^:k1^:k1^:k1^:k2^Jo2^Jo3^[33^[32^Jo2^Jo2^Jo2^Jo2^Jo2
^Jo2^Jo2^Jno]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zc1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1
^:k1^:k1^:k1^:k1^:k1^:k1^:k4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4
^:c4^:c4^:c3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_2]Z[2]Z[2]Z[1]JW3^JS4
^ZW6_:_8_Zg8_Zg3^JRl/Z6f[9^CSGYkM6=NETU:@S]1?3Tk?ChkA4LnBThiC4m0DEA8EUa?Ff5AFV=@
EV5@E5m?DV1JH6MHGVE=DeY2B4m6C5=HGVETJW5UJg9TKg=XLGEZLgM/LWM]LgQaMGYeNGiiO863R8^;
T9>=U9N:TIB>UIRJWj:NXjJIWZ6OY:>RYjJTZJRUZZVUZZVUZZVX[JbZ[jjY[K:TZ:fQYZVRYjZVZjb[
/;6//K:Z/:nQXZ2MWYbMViZRX9nYYjJ/ZZVZZ:NWYJB[Z:2VXi^KV92;RH5mNg=bLfY^KfIZKFAbL6Qe
LVYdLFUaJfAcJfAdK6EcJF9/HU]YIUiZIemZIem/JF5]JV9^Jf=_K6A`KFE]K6Q_KVYbLFebLFeaL6a`
Kf]`Kf]bLFeaKVYbKf]cL6adLFeeLVieLVieLVidLFenOGV>SHVDThnYZ:B`[j^VYJ6WYZ:HUi>>ShJ0
PGQcM6]cM6]gN6mhNG1dMFaaLVUcLVicLVicLVicLVidLfmdLfmdLfmdLfmeM71fMG5hMG1iMW5kN71l
NW1nNG1oNW5jN6ijN6iiMfeiMfejN6ikNFmlNW1lNW1hMVahMVaiMfejN6ijN6iiMfehMVahMVajN6ij
N6iiMfeiMfejN6ikNFmmNg5mNg5kO79hNFmdMF]eMVanOgF4QG]nOgEdMF^>S8:>S8:7QG]mNg5nO7:7
QG^8QWb0OWAlPWMlPWMmPGImPGInOgF0OgF0OgEoOWAlNg5mO79nOG=mO79lNg5nOG>1P7J4PgV6OgJ5
OWF3OWF2P7J0OWAkNW1dLfU]KVAcL69cL69dKV5dKV5eKF1eKF1eK5meK5miMfEhMVAeLEm`K5YgL5n5
OVfARGRESGbQUgnUVh>[XHV_YHfaYhndZY:i[iNm/i^j[I>k[YBl[iFn/IO0/iW2]I_3]Yc4]ig5^9k4
]ig2]I_1]9[1]9[1]9[2]I_3]Ybo]9Jo]9K0]IO0]IO1]YS1]YS2]iW2]iVm/IFm/IFm/IFn/YJn/YJn
/YJo/iNo/iNn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn
/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFm/YBm/YBm/YBm/YBm/YBm
/YBm/YBm/YC2/YG1/IC0/9?0/9?0/9?0/9?1/IC2/YG1/Y:o/92m[Xjm[Xk0/I72/i?3]9C3]9C2]IG2
]IG6^ifn]9JDSW5RGT9BCc=NFcmTIdiWJUARJ55HGTMEF49HED1DBcM:?bTm>B4l>20k=alk=aln>R92
?RI8A2a;Abm5A2Y5@b]6A2a7A2m9AC9<B3E>BSQ?BcUDD3eFDSmGED=HF4INGTiUIEM_Kf5dMfQmP721
Q7F8Rgb?THFDUH^IVY2NWiJRXiZRYIbSYYfUZ9nTYijRYIbQY9^SYYfTYijUZ9nVZJ2WZJ>XZJFYZZJY
ZZRYZZRXZ:R]/J^^/Zb_/jf]/J^[[jVZ[ZR//:Z^/Zb^[j^^[j^^[j^^[j^^[j^_/:b_/:b_/:bb]Jbb
]Jbb]Jbb]Jbb]Jba]:^a]:^a]:^a]:^b]Jba]:^a]:^d]jja]:^RYIbBUHb@U8V9SH:1QGZ3QWfEUi6[
[JNf]k>e][:b]Jbb]Jbc]Zf`/jZVZJ2PXiZUZ9n`/jZ_/ZV_/ZV`/jZ`/jZa]:^a]:^a]:^a]:^/[jJ/
[jJ[[ZFZ[JBY[:>Y[:>XZj:XZj:]/:N]/:N]/:N]/:N^/JR^/JR_/ZV_/ZVc]jbc]jbd^:fe^:nf^;:h
^[Bh^KFi^[Jj_KBi_;>h^k:g^[6f^K2e^:nd]jjc]Zf`/jZa]:^a]:^a]:^b]Jbb]Jbb]Jbc]Zfd]Jbd
]Jbd]Jbd]Jbc]:^a/ZV_/:N^[jJ`/JRc]:^e]Zff]jje]Zfd]Jbe]Zff]jjc]Zfc]Zfc]Zfc]Zfc]Zfd
]jjf^K2f^K2g^[6h^k:j_KBm`;Nn`KS0`k[0`k[0`kZo`;c0`Kg1`[k2`ko3a<34aL75a/;5a/;5a/;6
al?7b<C8bLG8bLG8bLG7b<C7b<C:blO9b/K:blO<cLW=c/[;c<S6al?3a<2h_;2c]j^_/jNa/jNd]:Ri
^Jg8a[_GeL[6^Yk0]INo/ho2^935^I72]Xk3/ho5]9?4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o4
]8o4]8o4]8o4]8o4]8o4]8o4]8o5]I35]I36]Y76]Y76]Y76]Y76]Y76]Y78]i38]i38]i38]i38]i38
]i38]i38]i37]Xo7]Xo6]Hk5]8g5]8g6]Hk7]Xo7]Xo4]8o4]8o4]8o4]8o4]8o4]8o4]8o4]8o5]I35
]I36]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y76]Y;6]Y;7]i?7]i?8^9C8
^9@00<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Fi[lFi[lFi[lFi[lFi[lJj/<Jj/<Nk/L:i[l:i[l:i
[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l6h[/6h[/6h[/6h[/6h[/6h[/6h
[/6h[/:i[l:i[l:i[l:i[l:i[l:i[l:i[l:i[l2g[L6h[/:i[l:i[l:i[l:i[l6h[/2g[L2g[L2g[L6h
[/6h[/6h[/:i[l:i[l:i[l6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[[nf[;nf[;nf[;nf[;nf[;nf[;nf
[;nf[<2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L>gZl>gZl>g
Zl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>g
Zl>gZl:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/JlZl6gY[^aX;V_W[bbXL6gY/FkZ/Rn[LBlYK:YUI26
MF=ICcPb;B0P81hU:2Hb=QTb=24g?2e1ASM7CS<oBbD/>aPM;14E9aPO;Q`S<Q/R<APO;Q/R<BD/>bT`
?bL^?B/f?S<nASm:DTIAFDQAFTA=ESm8DCa5CSLoASi8CdIBF4QDF4MCEdiGFUaSIVY]LFicLFicLFmd
LW9gMGEjN7QmNgUnO7UnO7UlPHJ9SXjBUi>HViNNXI>JWI2HV9:LW;>e]Jf_[jV[Zjb/[:ZZZZNUYJ:P
X:2NWYJDTifIV:2KV9fHUIJBSHf=Qh:4OWQmM6YYGf]YGfUWGFUTFfmXGgI_IWM^IG9YH6eXGfiYH71[
HW9]I7A_IWE`IgIaJ7IaJ6e/J6m^JW5`K75`K71_Jfi]JFm^JW1_Jfm/J71]JG5^JW=`K7AaKGEbKWIc
KgIcKhJ5PI2?RiNFTZ2OVj:QWJ2OVj>RWZ:QWI^LThj?QWn0MgMhKgEfKGEfKG=dJg9cJW9aKG9aKG9a
KG9aKG9aKG=bKW=bKW=bKWEdL7EdL7QeL7UfLGYgKg]iKgiiL7iiL7YhKWUgKGUgKGQfK7UgKGYhKW]i
KgajL7UgKGUgKGUgKGUgKGUgKGQfK7QfK7QfK7QfK7QfK7MeJgQfK7UgKGYhKWajL7ekLGYkLGamLgMh
KW=dJWenM8Z;PHV:P7enM92>Q9ZHSYJDRXB2N7ilLXN5NhZ8OX5oMGb5N7b5N7f4Mgj2MWf1MGeoLg]m
LGalL7mnM7mnM7elLW]jL7UhKWYiKgelLX60MX=jL8=jL89kLX=lLh9lMGmlM7ikLgahLg]cHWeeI89h
IhIlJhaoKi:3LiJ7MiN8N8n9LZFOR9R@NG1XDGQ]EjfPR/BgXK>VT<:dV<FgVlJhW<BfV[naUKj`U<6c
UlFgVlJeV/FdVLBcV<:aU/2_U;j]T[b[T;^ZSkjbU[faUK^_TkZ^T[^_TkfaUKncUl6eVKjcUKjcUKjc
UKjcUKjcUKjcUKjcUKjcUKfaUKfaUKfaUKjbU[jbU[jbU[ncUkncUkjcUKjcUKjcUKjcUKjcUKjcUKjc
UKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjc
UKjcUKjcUKjcUKjcUKjcUKfbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU<:bUL6aU<2`Tl2`Tl2`Tl2`Tl6a
U<:bUL6bT[n`T;f^S[b]SKb]SKf^S[n`T;n`T;^_SKJYRKN/S;fcUK2XRXj8JfeVBeYF>UUN@fQ^EGAj
HgAiI7enJY:;Mif@NYZ:LgA]DVmXCFEN@eYC>4m8;DM09D4j7chg74A19D=094=094A09dM3:dU5;DU4
;dU4;dI2:TU5;D]8<di;=Tm>>Tm??E1@?U5A@F9TDFMYEVi`GGIgIgemKhB4MX^;Oi2@Q9FGRiNISI^M
TIfOTijPU9nQUJ>UVJFWVj6RVJ:SVZ>SWJBSWjFTX:JTXjJTXjFSXjb`ZZb`ZZb`ZZZ^Z:R/YZR/YZZ^
Z:b`ZZj_Zjn`[:n`[:n`[:n`[:n`[:n`[:n`[;2cZ[2cZ[2cZ[2cZZnbZJnbZJnbZJnbZJnbZK2cZ[2c
Z[:e[;Ji/;:e[:2SVXf@QiJJSiNKT92DRHN:PI2BS:JXX[Be/KFf/[:e[;>f[KBg[[2cZZNZXJ2SVZJY
X;2cZZnbZJnbZK2cZ[2cZ[6dZk6dZk6dZk6dZjnbZJnbZJnbZJjaZ:jaZ:jaZ:jaZ:jaZ;Bg[[Bg[[Fh
[kFh[kFh[kJi/;Ji/;Ji/;>g[;>g[;Bh[KFh[kJh/[Ni/kNh];Ri]KNj/KJi/;Fh[kBg[[>f[K:e[;6d
Zk6dZk2cZ[6dZk6dZk6dZk:e[;:e[;:e[;>f[KBe[;Be[;Be[;Be[;Be[;:cZ[6bZK2aZ:n`Yk6bZK>d
ZkBe[;Ff[KFf[KFf[KJg[[>f[K:e[;6dZk6dZk6dZk>f[KFh[kJi/;Zm];^n]Kg0]kk1^;o2^L33^/33
^/33^[o0_<31_L72_/;3_l?4`<C5`LG6`/G6`/G6`/K7`lO8a<S9aLS9aLS9aLO8a<O8a<[;alW:a/[;
alc=bLg>b/_<b<K7`l?4`;Vm/KBh[;2dZ;6cYk>cYkVi[LS6^mOEb/NkWl2eUkncSl:hT<FiTL:fS/>c
SlJeU<BdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlFeT<Fe
T<FeT<FeT<JfTLJfTLJfTLNfSlNfSlNfSlNfSlNfSlNfSlNfSlNfSlNfSlJeS/JeS/FdSLFdSLJeS/Je
S/NfSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSlFeT<FeT<FeT<FeT<JfTLJfTLJfTLFeT<FeT<Fe
T<FeT<FeT<FeT<FeT<FeT<FeT<JfTLJfTLJfTLNgT/NgTP00a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/
`kN]a;R^a;R^aKV_aKV_a[Z`a[Z`a[Z``[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_
`[V_`[V_`[V_`[V_`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`[V_`[V_`[V_`[V_`[V_`[V_`[V_`[V_
`;N]`;N]`KR^`[V_`[V_`KR^`;N]`;N]`;N]`;N]`;N]`KR^`KR^`KR^`[V_`[V_`KR^`KR^`KR^`KR^
`KR^`KR^`KR^`KR^_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/`;N]`;N]`;N]`;N]`;N]`;N]`;N]`;N]
`;N]`;N]`;N]`;N]`;N]`;N]`;N]`;N]`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[
`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`KFY`KFY`KFY`KFY`[JZ`[JZ`[JZ`[JZ
_[BS_[BS_kFT`[RWaK^Za;ZY`KNV_[BSaKfVbl2/akZZ[J6EPg]dFEIB=c`k9bl_6Rl`6Rd`83<h:3Po
9c0m5ah]1`hO0PHI00DH10XM1`dP20hQ2@lR318U318U2@lR41TV72Db:cM3>4A@?TYF?DUE>DEA=49>
=Sm<<3a6<D9;=4M>:3]09C4e@dY=K6mcQX^2PhQoOhAkOH9iOhAkP8ElOhAkOX=jJVeaK6mcG65TEE]P
HFY^HFU`FF=ZH6YaAU5ECEIJG6EYL7IkOX:7Q8N<ShnEVIVOUZ6UX:NZYJR/YZ>UXInOVY^IRY2;NXAn
QXMnPX=jNgUaLg5YMG9ZNgE^NWA]MViWKV]SKfaTL6eUL6eUL6eUKfaTKV]SKV]SK6]WKfiZLG1/L6m[
KVeYKFaXKFaXKVeYK6]WK6]WKFaXKVeYL6m[LW5]Lg9^M7=_PH1lS8^7WYfIXJ2LWYfIWYfIWijJYZFQ
XJ:IVibCSXn6Oh1gMGI]LW=ZMGI]MgQ_LW5]LW5]LW5]LW5]LW5]LW5]LW5]LG1/M7=_MGA`MgA_N7E`
NWM_NgU_OGQ_OWU`NWQ^NGM]NGM]N7I/NGM]NWQ^NgU_O7Y`NWQ^NWQ^NGM]NGM]N7I/N7I/N7I/N7I/
MWAZMWAZMWAZMWAZMgE[NGM]NgU_O7Y`NGY`OWmeO7ecMGI/NGY`R8UoT967SHj4S8Z0WYbBXInESXb2
P7idQ89hQhEkPGmeN7m`NH1aO85bOH9cOh9cPH5cP81bOgmaOWaaOWaaNgU^N7I[MG=XM79WMgEZNWQ]
OWEWP7MYQ7]^RH1fT8V0VY>:XI^DYj6JXiR4YIZ6ZYb9[Z2=]:FB^ZVF_JbI`JfK/j^>bL6T^k2DShAX
T8AX_k6Ecl6U_:^@_Zn?_Zn?_k2@`;6A`K:B`K:B`;6A_k2@a;6Fa;6FaK:GaK:Ga[>HakBIakBIb;FJ
^ZjB^jnC_;2D_K6E_[:F_k>G`;BH`;BH_;6C_;6C_;6C_;6C^k2B^k2B^k2B^ZnA_K6E_K6E_K6E_[:F
_[:F_[:F_k>G_k>G_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E
_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E_;6C_;6C_;6C_;6C
_;6C_;6C_;6C_;6C`[:E`K6D`;2C`;2C`;2C`;2C`K6D`[:E`kBD`kBD`kBD`kBD`K:B`;6A`;6A`;6A
_K6?^[2>]jf;^Jj>_[BF/ZR:R81SGEDhCU8eHVI=M7UTOGi^RXMhXib9^jfGa[FK]jf?/ZR:Z9j0Vi5c
Rh5SNg5CKVA6IedoFU<bETh`DDT[CDDXBT4VAC`Q?cDM>c4IA40TAD4UAd8YBDD/BDL_BTLbAdHaATD`
B4/bCDliDeDoFU]7H61>IfMEKfmOLg=SNg]]OgmaQHEgRXYlShn1U9B6VYZ<WYj@X9nEXJ2FXj6IYJ>K
YZ>NYjBPYjBPYjBPYjbSZ:fTZJjUZ:fTYjbSYjbSZJjUZk2W[JjZ[Zn[[Zn[[Zn[[Zn[[k2/[k2/[k2/
[k:Y[k:Y[k:Y[k:Y[k:Y[k:Y[k:Y[k:Y[:nV[[6X/;>Z/kJ]]kZa];N^YJROU9N>Rhn4UIV>Ui^@SY68
Si6;XJ>M/K:^][Nc/kJ]/kJ]];N^/KB[YjZQXJBKYZVP/KB[[k:Y[k:Y/;>Z/;>Z/KB[/KB[/KB[/KB[
/KB[/[F//[F//[F//kJ]/kJ]];N^];N^/;>Z/KB[/KB[/KB[/[F//[F//[F//[F//KFZ/[J[/[J[/kJ]
/kF_];J`]KJb]KJb/[F//[F//[F//[F//[F//[F//KB[/KB[/;>Z/KB[/KB[/KB[/[F//[F//[F//kJ]
/kB[];F/]KJ]]KJ]]KJ]];F//kB[/kB[/;6X/K:Y/[>Z];F/]KJ]][N^][N^]KJ]/[F//KB[/;>Z/;>Z
/KB[/[F/]KR_][V`^kje_;nf_L2g_l:i`<>j`<>j`<>j`<>j_l2l`<6m`L:n`/>o`lC0a<G1aLK2aLK2
aLK2a/O3alS4b<W5b<W5b<W5alS4alS4b/_7bL[6b/_7c<g9cLk:blc8a/O3`lC0^[jb];R/[k>W/;:V
/[:V]kN[alFjemG:ak^O`KJH_k>?`KN?a;R@`[J>a;B@akJEa;B?a;B?a;B?a;B?a;B?a;B?a;B?a;B?
a;B?a;B?a;B?a;B?a;B?a;B?a;B?a;B?`k>>`k>>a;B?a;B?aKF@aKF@a[JAa[JAakJ?akJ?akJ?akJ?
akJ?akJ?akJ?akJ?a[F>a[F>aKB=aKB=aKB=aKB=a[F>a[F>a;B?a;B?a;B?a;B?a;B?a;B?a;B?a;B?
`k>>`k>>a;B?a;B?aKF@aKF@a[JAa[JAaKF@aKF@aKF@aKF@aKF@aKF@aKF@aKF@a;B?aKF@aKF@aKF@
a[JAa[JA0033]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_2]Zc3]jg4^:k5^Jo6^[35^Jo5^Jo4^:k1^:k1
^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:k0]jg0]jg0]jg0]jg0]jg0
]jg0]jg0]jg1^:k1^:k1^:k1^:k1^:k1^:k1^:k1^:jo]Zc0]jg1^:k1^:k1^:k1^:k0]jfo]Zbo]Zbo
]Zc0]jg0]jg1^:k1^:k1^:k1^:k0]jg0]jg0]jg0]jg0]jg0]jg0]jg0]jfo]Zbo]Zbo]Zbo]Zbo]Zbo
]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zbo]Zc2]Z[2
]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[3]j_3]j_3]j_3]j_3]j_3
]j_3]j_3]j_0]:S0]:S1]JW1]JW1]JW2]Z[2]Z[2]Z[1]jK1]jK2^:O4^ZW5^j[4^ZW0]ZFl/Z6f[ibm
/j74]jO5^:Zg[J>HTHQWIEe0@cXN9RD?5aH330l53A@631L00a8000l00140018001<00A@001800180
01<00aH01AP01aP73b0D72dN:3TY<d@a?ThiAUHlBe]0BU/_?ThZ@4`[AD`L=3XD92XkA4QdMg^=THJ:
SX>8S867Rh29SH::SX>;ShB;ShB@U8mgO7XoAD@P9bX`=d0d?TP]>4HjA5E7GFQ;GfYGJGAPL7aMJgMC
G6U@F6EEGFX`D5]4GFMFIFiNIFiZKGEhOH1mQhMjR8N1Qh:1QH1hO7M`LFe_KVYaL6acL6a_K6Q`Kf]_
KVY^KFU/JfMZJFEYJ6AXIf=WIV9/JfM^KFU`Kf]`Kf]]K6Q/JfM/JfM]K6QYJVIYJVIYJVIZJfM[K6Q]
KVY_L6a`LFehMg>2PGfOWYZSXYjQX9bSXYjJVIFSXYjMWYFMWYFDUHb3Q7]fMfidMFagN6mjNg9cLVic
LVicLVibLFebLFebLFeaL6aaL6adLfmdLfmgM6mhMG1iMVijN6imN6mmN6mjN6ijN6iiMfeiMfejN6ik
NFmlNW1lNW1lNW1kNFmiMfehMVagMF]gMF]gMF]hMVafM6YfM6YeLfUeLfUfM6YgMF]hMVaiMfefMfel
OG=mOWAhNFmgN6j0PGN<SH>CU8Z5PgVEThVLVY2@SXB3PGN1OgF2P7J1OgElOg1lOg1nOW1nOW1mO6il
NF]hMFMgM6IgL5mjLf9mMVF1NVV4OFb9PW6@RGRDSGbOU7jOUX:RV8JTW8^/XiFf[Z71^k39`[W0]9c0
]9c0]9c1/ic4]9g4]9g6]9g6]9g1]Y[2]i^n/iNh[92j[92o/IG4/iS3/YO5]YK4]IG3]9C5]YK9^Y[9
^Y[5]YK0/I71/IC1/IC2/YG3/iK4]9O5]IS6]YW6]YVm/YBn/iG0]IO1]YS1]YS0]INn/iFm/YBm/YBm
/YBm/YBl/I>l/I>l/I>l/I>l/I>m/IFm/IFm/IFn/YJn/YJn/YJo/iNo/iNn/iFn/iFn/iFn/iFn/iFn
/iFn/iFn/iFm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBn/iFn
/iFn/iFn/iFn/iFn/iFn/iFn/iFl/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I?2/YG1/IC0/9?0/9?0/9?0
/9?1/IC2/YFm[Xk0/I73]9C4]IG3]9C1/Y;1/Y;1/Y:e[8O0]i;2^9Jj/8jl/I6l/I>RUgUoLeMRHTAY
JU1cM61iN6Z0OFnARWNZWXJj[Y:i[H^k[hfm/Hnn/Y2l/8ji[H^dZ8JaYH>IT6jAR6J6OE]lLe9bJ4YV
G3iJCc=AARY=ABM7@R=2?1lo>ai1?B54@2M4@bU5@b/m?RA0@BM4AB]8B31<BcI@CcYFED5KFTILGDeP
HE5WJ5Q]KUicM6AiNVZ0PG65QWJDUHFEUXJHV8ZLW92OWi>RXINSXYRTXYZMXiRQYibTZYnV[:6V[:6V
[:6X[Z>Y[jBYZZJZZjNZZjN[[:R/[JV][ZZ^[j^^[j^_/ZV_/ZV`/jZ`/jZa]:^a]:^a]:^b]Jb[[ZF_
/ZVa]:^b]Jbd]jje^:n]/:NRYIbIWI:SYibX[:6SYYfOXI^UYj6`/Jfg^;Bc]Zfd]jjd]jja]:^XZj:Q
Y9^WZZ6a]:^_/ZV_/ZV`/jZ`/jZa]:^a]:^a]:^a]:^a]:^a]:^a]:^b]Jbb]Jbc]Zfc]Zfd]jj^/JR^
/JR_/ZV_/ZV`/jZ`/jZ`/jZ`/jZb]Z^b]Z^b]Z^c]Zfc]Jnd][2d]K6d]K6a]:^a]:^a]:^b]Jbc]Zfc
]Zfd]jjd]jj`/jZa]:^a]:^a]:^b]Jbb]Jbb]Jbc]Zfc]:^d]Jbe]Zff]jjf]jjf]jje]Zfe]Zfa/ZVa
/ZVa/ZVc]:^e]Zff]jjd]Jbb/jZ`/jZ`/jZ`/jZa]:^b]Jbd]jjf^K2g^[6j_KBk_[Fm`;Nn`KRo`[W0
`k[0`k[0`kZo`;c0`Kg1`[k2`ko3a<34aL75a/;5a/;5a/;6al?7b<C8bLG8bLG8bLG7b<C7b<C:blO9
b/K:blO<cLW=c/[;c<S6al?3a<2j_[:d^:b^/ZJ^/:B`/:Bf]Z[6a;WFe<W8_:31]YRo/ho0]Xk3]ho1
]Hg4]937]YG3/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk2/Xg2
/Xg3/hk4]8o5]I35]I36]Y76]Y76]Hk6]Hk6]Hk6]Hk6]Hk6]Hk6]Hk6]Hk6]Hk5]8g5]8g4/hc4/hc5
]8g5]8g6]Hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk3/hk2/Xg2/Xg3/hk4]8o5]I35]I36]Y76]Y74]8o4
]8o4]8o4]8o4]8o4]8o4]8o4]8o4]Hk4]Hk4]Hk4]Hk5]Xo5]Xl00<>gZl>gZl>gZl>gZl>gZl>gZl>g
Zl>gZl:f[<>g[LBh[/Fi[lJj/<Fi[lBh[/Bh[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h[/6h
[/6h[/6h[/6h[/6h[/6h[/2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L6h[/6h[/6h[/6h[/6h[/6h[/6h
[/6h[[nf[<2g[L2g[L6h[/6h[/2g[L2g[Knf[;nf[;nf[;nf[<2g[L2g[L6h[/6h[/6h[/2g[L2g[L2g
[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[L2g[Knf[;nf[;nf[;nf[;nf[;nf[;nf
[;nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[;nf[<:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:f
Z/:fZ/:fZ/:fZ/:fZ/:fZ/>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZkncYl2dZ<2dZ<2dZ<6eZL:fZ/:f
Z/:fZ/Rn[L>iZ;fcX[Z`WkbbXL2fYL>iZ<BjZKjk[;fhZKfdY/:eYlJiZl2eYjBMSXV4MEEAC3Pc<1dI
61<B5Q0?60H84`024@435@@56@@56@@56@<460425P425PD66PX;7`004P00500360<:7P/B9QDN<QlZ
?RLbAS]9G3U;G41JJ4YXLdMSJTYMHV]dN9JFW8^@PHfBPi2EQY>HRIFJRiJKS9JKS9NLSI:IS8F=Pd]B
CAXQ91DN:0`F9`XE:bPaC3EGIcAEICeKK4YTMD=KKC14ER<dAb<bADEiREZ6UfF4Te][NdaEHTMAFdMD
G4AGG3e5A4=;BTQ@Cd]AD55FEEYOGV9TI6=UIFY/K6U[JfQZJVQZJVU[Jf]]KFi`L6maLFa[Ifi]JG1_
Jfm^JVe/J6]ZIV]ZIVa[IfQYIFMXI6MXI6MXI6QYIFY[Ifa]JFi_JgIeLGAcKhf<R8f<R96@S9^JUX^:
QYBCShn@Qi2AR8V:PGamM7EfKGIgKWMhKgEfKGAcKgAcKgAcKg=bKW=bKW9aKG9aKG5`K7AcKgAcKgMd
KgMdKgUfKWYhKWagKWehKg]iKg]iKgYhKWYhKW]iKgajL7ekLGekLGekLG]iKgUgKGQfK7MeJgMeJgMe
JgQfK7IdJWIdJWEcJGAbJ7EcJGEcJGIdJWMeJgAeJgEfK7MhKWYkLGQiKgMhKWn0MXZ;PH1nM8F3NHV7
OHV7OHB2N81nM81nM85oMH61LH:2LXJ3M8R3M8N2LhN0LHAmKXAkKH^0K925LIN<N9jCOjBIQJ^PS;:W
TkN/V<6gVKngV[nfVkbdWKbcWkjfYLFn[l_3][jeV[fdVKjcV;jaUkf`U[j_UKf^U;n^U;ZbUK:ZSKR]
TLJjW/NkWknaUKj`U<RgW<>eV<:dUl2bUKnaU;naU;j`Tk^]T;V[S[naU;naU;j`Tkf_T[b^TK^]T;Z/
SkZ/SkbaTkfbU;fbU;jcUKjcUKfbU;fbU;baTkjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKfaUKfaUKfa
UKjbU[jbU[jbU[ncUkncUkjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKfbU;fbU;fbU;fbU;fbU;fbU;fb
U;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU;jcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKbaTkbaTkba
TkbaTkbaTkbaTkbaTkbaTl:bUL6aU<2`Tl2`Tl2`Tl2`Tl6aU<:bUKZ[Rkf^S/2aTL2aTKj_Skf^S[j_
Sl2aTK6XPkZaS;jeT;Z`S[^^S[f`T;JXRjZLOfaWB6=NAF=OCG1/HGmkL96:NJZSR/:jW;f_Rkj`S<2b
S/6cSl2bS[naSKf_Rk^]RLFjU;ndS[JZQ[2TP:^OOJ>FMYR;Jhn1I6iUA6EN?EaE=5=>;dm9;4U5:4A1
9D0m8D108T9294=29T=29T=2:4E3:dU7;da9=4I6=4Y:>51@?UEE@eUIAeiNC6=SDFMWEG=eGgIgHg]l
J861KhN7MHf=OI2?PI:APhnERYBJSiZPUInUVZ6WW:6WW::XWJ>YWZ>TX:>TX:FVXZJWXjRYYJVZYZZ[
Yj^/Z:b_YZb_YZf`YjjaZ;2cZ[6dZk:e[;:e[:^^YK2cZ[6dZjnbZJnbZK:e[;:e[:jaZ;Bh[K>g[;Bh
[KJi/;>e[jj`Z[2a[KJg/kBg[[Bg[[Fh[k:e[:R[XZ6TVjNZXK:e[:nbZJnbZK2cZ[2cZ[6dZk6dZk6d
Zk6dZjnbZK2cZ[2cZ[2cZ[6dZk6dZk:e[;:e[;2cZ[6dZk6dZk6dZk:e[;:e[;:e[;>f[K:fZk:fZk:f
Zk:e[;>e[k>e[k>d/;>d/;6dZk6dZk6dZk:e[;:e[;>f[K>f[K>f[K2cZ[6dZk6dZk6dZk:e[;:e[;:e
[;>f[K>dZkBe[;Ff[KJg[[Nh[kNh[kNh[kJg[[6bZK2aZ:n`Yk2aZ;>dZkBe[;6bZJj_YZf`YjnbZK6d
Zk>f[KFh[kNj/KNj/KRk/[Vl/kZm];bo][k1^;o2^L33^/33^/33^[o0_<31_L72_/;3_l?4`<C5`LG6
`/G6`/G6`/K7`lO8a<S9aLS9aLS9aLO8a<O8a<[;alW:a/[;alc=bLg>b/_<b<K7`l?4`;Zn/[>gZjfa
YJb^XZj^X[BdZ<C2]mCBalVmXL6fV;jbS/2fS/>gSl6eSLBdT<RgU/>cS/>cS/>cS/>cS/>cS/>cS/>c
S/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/>cS/6aS<:bSL:bSL>cS/BdSlFeT<JfTLJfTLJeS/JeS/Je
S/JeS/JeS/JeS/JeS/JeS/JeS/FdSLBcS<BcS<BcS<BcS<FdSLJeS/>cS/>cS/>cS/>cS/>cS/>cS/>c
S/>cS/6aS<:bSL:bSL>cS/BdSlFeT<JfTLJfTLBdSlBdSlBdSlBdSlBdSlBdSlBdSlBdSl>dSL>dSL>d
SLBeS/BeS/FfS`00`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`KF[`[J/a;R^aKV_a[Z`aKV_a;R^`kN]
`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^`;N]`;N]`;N]`;N]
`;N]`;N]`;N]`;N]`KR^`KR^`KR^`KR^`KR^`KR^`KR^`KR^_kJ/_kJ/`;N]`KR^`KR^`;N]_kJ/_kJ/
_kJ/_kJ/_kJ/`;N]`;N]`;N]`KR^`KR^`;N]`;N]`;N]`;N]`;N]`;N]`;N]`;N]`KR^`KR^`KR^`KR^
`KR^`KR^`KR^`KR^_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/_kJ/
`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`kN[`kN[`kN[`kN[
`kN[`kN[`kN[`kN[_k>W_k>W`;BX`;BX`KFY`KFY`[JZ`[JZ`;JU_kFT_kFT`KNVa;ZYa;ZY`kVX`KNV
/;2T^;BY_[FX`;>UaKJVbkf[a[^W_;>OW8b5MVQRD4A2?cLh<Bdc7A`V2``J1@PG000>000A10@F1`LI
1@DG0@4C0@4C1@DG2@LM1`PM10LL0@HK0PTM10dQ2A@X3aX^2QL]6bm1>59RCfmjGW^2Jgj5P8V=U9BJ
SI>2TYR7V9j=VIn>UI^:TIN6SI>2S9:1PXYiV::BNh=lA4e@9Bdj1PlS2A4^=d1QDWb?Bg>6Bg24DgB8
AVEj:4=H32@j0AP^0DEH:61cA6ao@EU[<d5C<3e;=dMC?E1HAU9DCUYLE5ePD5ULC5=FBe9EBe1CB4e@
@TM:@dQ;A4U<B4e@CU=FE5ULFf1SGfAWK6]WKVeYKfiZKfiZK6]WJVUUJVUUJfYVJ6UUIfQTIVMSIVMS
IfQTJ6UUJfaXK6eYO7]gJVUUMWEaKFaXMWEaRHR4NGQdPh9nPX=jPH9iNgacLW=ZLG9YMWM^M7E/KFiU
MGA`MGA`M7=_M7=_Lg9^Lg9^LW5]LW5]Lg9^M7=_MW=^MgA_NGI^NWQ^O7M^OGQ_O7Y`O7Y`NgU_NgU_
NgU_O7Y`OG]aOWabOG]aO7Y`NGM]MgE[MWAZMWAZMgE[N7I/MgE[MWAZMG=YM79XM79XM79XMG=YMG=Y
LgAZKVmULW=YNW]aNGY`LG9XLgAZOWmeOG]aN7I/N7I/P7idQ89hPX1fP7idPX1fPWe^QX5bT8UjV962
X9N9Yib>ZYnAZj2B^J^D^jfF_[2I_k6J_k6J_k6J`;:K`[BM_[FC_kJE_[JH_KBI^;2I]k2L_;BS`;RW
^K6D^[:E^k>F_[>G`;BH`[JJaKNKaKNK_;>H_KBI_;>H_;6F_:nE_K2F_ZnE_JjD_[:F_[:F_[:F_K6E
_K6E_[:F`[JJaKVM_;6A_K:B_K:B_K:B_K:B_[>C_[>C_[>C^k2@^Zn?^Zn?^Zn?^k2@_K:B_kBD`KJF
_K:D_K:D_K:D_K:D_[>E_[>E_[>E_kBF_K6E_K6E_K6E_[:F_[:F_[:F_k>G_k>G_[>E_[>E_[>E_[>E
_[>E_[>E_[>E_[>E_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D
_[>E_[>E_[>E_[>E_[>E_[>E_[>E_[>E^k2B^k2B^k2B^k2B^k2B^k2B^k2B^k2B`[:E`K6D`;2C`;2C
`;2C`;2C`K6D`[:E`K:B`[>C`kBD`;6A_:f=^jb<_Zn?`K:B`;NA^K2;]Zf8^[2>_k>A_:n?_Jf@_jnB
SX=SLfY?IEe<L6YOOWY_Qh=aVIIj[jf;_Jf8_Jf8_Jf8_Jf8_Jf8_Zj9_jn:`;2;_K69^Zf7^Jb6_Jn;
`[B@`kBC_k2@^Z^;]Zf;/JR6YYmnViAcS8MXNGEHIf=6FeLjB4HWBDLYB4HXAT<W@d0T@clVAT8ZB4@/
?Sl[@D8^ADHbAdPdBDXfC4diD54mDeA0D5<jE5LnFei5HfE?K6eILgAPN7QVNg]YPhUnRHn4TIN<UifB
VZ2EVj6FVj6FW::GWYnKWj2LX:6MXZ>OY:FQYZNSZ:VUZJZVYjZQZ:^RZJbSZjjU[:nV[[6X[k:Y/;>Z
[:nV/KB[/[F/[:nVZZfT[k:Y/kJ]]KR_]KV^ZjnTZJfR/kJ]]kVc/K>][Zn[/kB`];N^];N^]KR_/[F/
Z:^RXJBKYjZQ/[F/[k:Y[k:Y/;>Z/;>Z/KB[/KB[/KB[/KB[/;>Z/;>Z/;>Z/;>Z/KB[/KB[/KB[/KB[
[k:Y[k:Y/;>Z/;>Z/;>Z/KB[/KB[/KB[/KFZ/KFZ/KFZ/KB[/K>]/K>]/K:^/[>_/;>Z/;>Z/;>Z/;>Z
/;>Z/;>Z/;>Z/;>Z/;>Z/KB[/KB[/KB[/[F//[F//[F//kJ]/kB[];F/]KJ]][N^]kR_^;V`^;V`]kR_
/K:Y[ZnV[JjU[ZnV/K:Y/K:Y[ZnVZjbS[:nV[[6X/KB[];N^]kZa^;^b^;^b^;^b^;^b^Kbc^kje_L2g
_/6h_l:i`<>j`<>j_l2l`<6m`L:n`/>o`lC0a<G1aLK2aLK2aLK2a/O3alS4b<W5b<W5b<W5alS4alS4
b/_7bL[6b/_7c<g9cLk:blc8a/O3`lC0^[jb/kN[[;2TZjfQ[JfQ/[:V`l6fdm76bKfQ`KJH_[:>`;J>
`[J>`KF=a;B@b;NF`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>
`K6<`K6<`[:=`k>>a;B?aKF@a[JAa[JAa[F>a[F>a[F>a[F>a[F>a[F>a[F>a[F>a[F>aKB=a;><a;><
a;><a;><aKB=a[F>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`k>>`K6<`K6<`[:=`k>>a;B?aKF@a[JAa[JA
a;B?a;B?a;B?a;B?a;B?a;B?a;B?a;B?`kF;`kF;`kF;`kF;a;J<a;J<0033]j_3]j_3]j_3]j_3]j_3
]j_3]j_3]j_4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:c4^:k4
^:k4^:k4^:k4^:k4^:k4^:k4^:jo]Zbo]Zbo]Zc0]jg0]jg1^:k1^:k1^:k3]j_3]j_3]j_3]j_3]j_3
]j_3]j_3]j_4^:k4^:k4^:k4^:k4^:k4^:k4^:k4^:k0^:_0^:_0^:_0^:_0^:_0^:_0^:_0^:_3]j_3
]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_2]Z[2]Z[2]Z[2]Z[2]Z[2
]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[3]j_3]j_4^:c4^:c4^:c2^:O2
^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O2^:O3^JS2^:O1]jK1]jK1]jK1
]jK2^:O3^JS0]ZG0]ZG0]ZG0]ZG1]jK1]jK2^:O2^:No]JBo]JC0]ZG0]ZG0]ZG0]ZFo]JBo]JC?`[:_
YIB1N6]ME4Y>ASm=AT=7@T50>S/d;S<[9bdI5Ql61@l000`31Q@21aH00A<001P001H10a/00QX001<2
11`;3BD51al52B4542HN<DI6GW17Gf]JKG:9TI1nPWb>VHFFWXfIWI6IVY6LViNOXZ2JX9n=V9JIVYRF
UiF:RhVCV9M>Ee/V=ChR=TLiDFMEM9=9JhUHNia2I88oHGT]BeiFKWX97RHL>4TfEfHjHf`FA4/A?D@j
H6a>K7dcC60C<chI=D0Q=d<F9c@7528B7bdZ>TLa@DhL?D0dDED`BDdkCEA4CeLB62<83QU<D5]HGV=^
LW=dLfmdLFUkMfakMfacLFM/JF5VJVAYKFQZL6]]Lfi/Lg1YLVmUL6eTKfedLVQeLfUfM6YeLfUdLVQc
LFMdLVQeLfUfMFMgMFYgMVafLfi_KfU/K6I_L6MeMVe/KfI]L6M^LFQ_LVU_LVU^LFQ/KfI[KVE`LfY`
LfYcM6]dMFagMFeiMVijMfmjMfn4P7EkNFihMV]jN6eiNFegMf]lO724QWYiMfmjN71kNW1mNg5nNVml
NF]lMVUjMFIdLG=fLG9eLG1eLFadLVQfLVMgM6EiM6EhL6=hL6=iLFAkLfIlM6MmMFQnMVUoMfZ9O6J?
PVbHRgFQU7jXVhF[WXR[WXRZWHN3NfB3N6:AQW2`Xhg1]9k2]9jo/I_5]9no/iNo/iNo/iNo/iNo/iNo
/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo/iNo
/iNo/iNo/iNo/iNo/iNo/iNo/iNn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn
/iFn/iFn/iFm/YBm/YBm/YBn/iFn/iFn/iFo]9Jo]9Jm/YBl/I>l/I>l/I>l/I>m/YBn/iFo]9Jn/iFn
/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFn/iFm/YBl/I>l/I>k/9:k/9:m/YBm/YBm/YBm/YBm/YBm
/YBm/YBm/YC1/IC1/IC1/IC1/IC1/IC1/IC1/IC1/IC2/YG2/YG2/YG1/IC0/9?0/9>o[i:o[i:o/92o
/92o/92o/930/I70/I70/I71/Y;0/I70/I70/I70/I70/I70/I70/I70/I6o/Hfo/Hfo/Hfo/Hg0/Xk0
/Xk0/Xk1/hnm[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^lZhZ8OeiPH49QJ4eaMV5jNVZ?QG^YUi2m/YBk
/9:l[Y6l[Y6o[i;0/9?0[Y6n[8nm[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^k[HVk[HVk[HVj[8RiZhNi
ZhNhZXJhZXJXVWJOTFf?PEemKd]/GSYPDRiIBbMEAb=3@c4o?be1@Bm6ASA0@2hf=R@m?B]=CC]@CcE>
CC=>CC=DDcULFd5QH4IPGdEMG49XKEQ/LEabMf9kOfb4QgN<SgnBUHJEV8VPWHjRWi2QX9:OWi>OWi>O
X9JVYifY[:>VYYJXYiVZZI^/ZYn]Zj6]Zj6]ZZ:]ZZ:X[:2Z[Z:]/JF]/JJ]/:N^/JR`/Zbb]:j^/jB`
]JJb]ZZb]Z^`]:V_/ZV`/jZa/jf]]ZVa^Zf[]:NW/:>X/JBPZIbOZ9^]]ZVZ/JZZ/JZZ/JZZ/JZZ/JZ[
/Z^//jb]]:f`]:R`]:R`]:R`]:R_/jN_/jN_/jN_/jN/[ZR][jV^/:Z`/Zb`/Zb_/J^^/:Z][jV^]Jj`
]:ja]Jnc]Jnc]Jne]Jne]Jng]:nb]Jbb]Jbb]Jba]:^a]:^a]:^a]:^a]:^b]:jb]:jb]:jb]:jb]:ja
/jfa/jfa/jfd]jjd]jjd]jjc]Zfb]Jbb]Jba]:^a]:^_/jRa]JZa]JZ//:FUZIjTZ9fX[:6]/JJ]/:N_
/ZVa]:^d]jjf^K2g^[6h^k:h^k:h`;Ji_[Fh_KBj_KBk_[G1`[W4aKc8a[k2`ko2`ko3a<34aL74aL74
aL73a<33a<33a<35a/;7b<C9b/K:blO9b/K7b<C5a/;7b/77b/78bl;8bl;7b/76bL35b;o4akjd]jN^
/J:Y[:>Z[:JYZZJ[[jVj`;G<dlK6_Ic3^INo]I>o/ho0]Xk3]hg5]hg5^8c5]8g4/hc4/hc4/hc3/X_3
/X_3/X_3/X_5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5]8g5
]8g5]8g5]8g5]8g5]8g5]8g5]8g4/hc4/hc4/hc5]8g5]8g5]8g6]Hk6]Hk2/H[2/H[3/X_4/hc5]8g6
]Hk7]Xo7]Xo5]8g5]8g5]8g6]Hk6]Hk6]Hk7]Xo7]Xo2/hc4]Hk6]i38^I;8^I;6]i34]Hk2/hc4]8o4
]8o4]8o4]8o4]8o3/hh00<>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZlBh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh
[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[<Bh[/Bh[/Bh[/Bh[/Bh[/Bh[/Bh[/Bh[[nf[;nf[;nf
[<2g[L2g[L2g[L6h[/6h[/>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>g[L>g[L>g[L>g[L>g[L>g[L>g
[L>g[L2hZl2hZl2hZl2hZl2hZl2hZl2hZl2hZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>g
Zl>gZl>gZl>gZl>gZl>gZl:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:f
Z/:fZ/:fZ/:fZ/:fZ/>gZl>gZl>gZlBh[<Bh[<:hYl:hYl:hYl:hYl:hYl:hYl:hYl:hYl:hYl:hYl:h
Yl:hYl:hYl:hYl:hYl:hYl>iZ<:hYl6gY/6gY/6gY/6gY/:hYl>iZ<2fYL2fYL2fYL2fYL6gY/6gY/:h
Yl:hYkneY;neY<2fYL2fYL2fYL2fYKneY;neY;N^V/>iYkjfYJ2GRWE/HUI>AdY4?dU2?dm=CDY8B3hm
?c4d>2/^=R8W<0dC7P002`436`0060@67PD77`026PP:8PlA:@H880036`8<91<S>S18G3E<FdYLHh6;
Ri6DTWn9O8><OhN;P8R9P8^;QHnCSYFLUiNQVjFVXYfNVYNHU9VLVVA[KSA3C2i2Dd5IKDUVPE=aS6V9
YU]nV5IhT4=TM65mR2a8C`dW>291D3aPJRmIH3URJdmePFF3UUE`QCYHHaliAB@jAS];F2/kB14Q;QX[
>313D1Th>c1=DAL_=@0=52hk@bH_>0hD7gUmR826RfM[K8N8QWaiM7IdK8J3OVi_KHN9RHR8PX20NWIh
LWIhLWanN7j0NWMkMG5eKgQfKWUgKgUgKgQfKWMeKGIdK7IdK7IdK7MfK7EcJgEbKGMdKgIeLGAdKW5a
Jfm_JG=eKgAfL7IhLWIhLWMiLgIhLWAfL7AfL6maJfmaJg1bK79bK7AaK7AaK7IbKGIbKGYgKgQeKGYg
KgmlM7ajLWAbJW5_Ig=aJG]lLg]lLgajLW]jL7]iKW]gK7UfJ7YdIgIaKWIaKWQbJgUbJGUcIWYcI7Ub
HGYcH7meI85gIXIlJhb2LI>9N9V?OYjDPj2FQK6TS[BWTKV/U[jaVl6dW/2cWKnbW;f`V[N_V;2USk:W
TL:eWlNjY<2bW;V[UKb[U[ncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUknc
UkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkncUkjcUKjcUKjc
UKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKfbU;fbU;fbU;fbU;jcUKjcUKnd
U[ndU[baTkbaTkbaTk^`T[baTkfbU;jcUKndU[jcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKjcUKfb
U;fbU;baTkbaTk^`T[^`T[fbU;fbU;fbU;fbU;fbU;fbU;fbU;fbU<6aU<6aU<6aU<6aU<6aU<6aU<6a
U<6aU<6aU<6aU<6aU<6aU<2`Tl2`Tl2`Tl2`Tkj_Skn`T;n`T;n`T<2aTL2aTL2aTL2aTKn`T;n`T;n`
T;n`T;n`T;n`T;n`T;n`T;j`S;naSKnaSKnaSL2bS/2bS/2bS/2bS[f_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_
Rkf_Rl:aT:>HN7ajG6=XCFEXDWUgIIB8O:RESKR]SkV^T;b^TKf_T[n_T[j^TL2^TL2^TKf_Rkf_Rkf_
Rkf_Rkf_Rkf_Rkf_Rkf_Rkb^R[b^R[^]RK^]RKZ/R;Z/R;V[QkV[Qkf_Rkf_Rk^]RKNYQJjPO:BFLYZ<
J9B6HVYWDT]8<cDb7C/h8dU6<D]8<dI3;T8o:TQ4:dA09d8n9DI2:Di:<EA@=eEA>5A@=dU<=Te@>U=E
@EaNBVIXEFm`H7MhJ7]lK8B4LXf=OIZJRZ2PTYnQUI^MTIFISY>GS::RU:>SUJBTV:FUVJNVW:RVWZVW
WjZXX:BXW:JZWZR/XJV/XjR[XZV[YJ^]Yjj_Zjb`Y:ncYk6eZ[6eZZnbZJj`ZZj`ZZnaZjbaZ;2e[:^`
YjN/XjV^YJ2UW9jSVZbaZ:jcZZfbZJbaZ:^`Yj^`Yj^`Yj^`YjbaZ:nbZK2cZ[2cZ[6dZk:e[;>f[K>f
[KBg[Z^^YJf`YjnbZK6dZk:e[;:e[;:e[;6dZjjf[:ndZjfbZJf`Yjf`Yk2aZ;6bZKBbZ[Fh[kFh[kFh
[kFh[kBg[[Bg[[Bg[[Bg[[2cZ[2cZ[2cZ[2cZZnbZJnbZJnbZJnbZKBg[[Bg[[>f[K>f[K:e[;:e[;6d
Zk6dZjncZ;6eZ[6eZZfaYZN[X:FYWZV]XZjbYk2cZ[6dZk>f[KFh[kNj/KRk/[Rk/[Rk/[>k/KNl/kZo
][k1^;g0]kfn]KZk/[Zh/;Ff/[Nh];Vj][fn^[o0_<72_/?4`<?4`<72_/?4`<G6`/O8a<O8a<K7`lC5
`L?4`<[=a<[=a<_>aL_>aL[=a<W<`lS;`/O:`KVn[kFi[KFf[;Jg[[Jd[;JfZ/72/]3A_LFkVL6gUKfd
SkfbS<2cSL:fS/BfS<>eRlBcS<BcS<BcS<BcS<>bRl>bRl>bRl:aR/FdSLFdSLFdSLFdSLFdSLFdSLFd
SLFdSLFdSLFdSLFdSLFdSLFdSLFdSLFdSLFdSLFdSLFdSLFdSLFdSLFdSLFdSLFdSLFdSL>bRlBcS<Bc
S<BcS<FdSLFdSLFdSLJeS/>bRl>bRlBcS<BcS<FdSLFdSLJeS/JeS/FdSLFdSLFdSLFdSLJeS/JeS/Nf
SlNfSl:cS<>dSLBeS/FfSlFfSlBeS/>dSL:cS<BdSlBdSlBdSlBdSlBdSl>cSP00`[JZ`[JZ`[JZ`[JZ
`[JZ`[JZ`[JZ`[JZa;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/a;R/
a;R^a;R^a;R^a;R^a;R^a;R^a;R^a;R^_[F[_kJ/_kJ/_kJ/`;N]`;N]`;N]`;N]`[JZ`[JZ`[JZ`[JZ
`[JZ`[JZ`[JZ`[JZ`[J/`[J/`[J/`[J/`[J/`[J/`[J/`[J/_kNZ_kNZ_kNZ_kNZ_kNZ_kNZ_kNZ_kNZ
`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`KFY`KFY`KFY`KFY
`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`[JZ`[JZ`[JZ`kN[`kN[`kN[`kN[
`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV`KNV`[RW`[RW`KNV`;JU
`;JU`KNV`[RW`[RW`;JU`;JU`;JU`;JU`KNV`KNV`[RW`[RW_kFT_kFT`;JU`;JU`;JU`;JU_kFT_kFT
^;2Ia;bUbL:^`[ZYZjBES8AgIV1ECDHm@D8iBTe4DEE?CeABAde<>4929c<e6bHZ000C000?000A000C
000A0PDJ1@PM000A000G0@PQ00hU4B<j5RLj7R/iDEUPL7EhNH=mOXAoQXR2RHZ1QhQoQ8QmQhn4SiV=
W9jHT9:<VYbFTiNBM7al>4E=9SI6:3i@<dYP?5A/>EM`?UefBfj2BValDgJ0>E]Q;TAF7SM78d=>9dYD
F7b6I8NEK8^PEG69B6A_9cm;<DAAEfQeDF5^:ci;83I2:49>AV=XCVQ^C6AZ7cDk?4iE?daD0``E>3m8
VYnRNWioOH1nO7ekNW]iNGenJgAhO8F>O7mmNWekNW]gNW]gOGegOWihOgagOWadOGilO7ekNgajN7Ug
MWMeLgAbLG9`L75_OgelN7McLW5]LG1/MWEaNGQdMGA`L6m[LW=_LW=_LgA`M7EaM7EaM7EaLgA`LgA`
MGUdMGUdMgQdN7McN7McNWMcNGIbNWEbO7UdNGIaN7E`NgQcOGUdOGUdP7agQH5lP81jOgmiOWmfOWad
OWabOWaaOg]`Oga^PWU_QGabRh9eT8QgUhekW95mWY=mWiEm/J>@/ZBA]JND^J^H_JnL`;:O`kFRaKNT
`[JN`kNOaKVQa[ZRa[ZRa;RP`[JN`KFMbL:Y`;JN_K>Ka;RPaKVQ_k6J^ZbE_ZjG_[:F_[:F_[:F_[:F
_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F
_[:F_[:F_[:F_[:F_[:F_[:F_[:F_[:F_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D
_K:D_K:D_K:D_K:D_;6C_;6C_K:D_K:D_[>E_[>E_[>E_[>E_;6C_;6C^k2B^k2B^k2B_;6C_K:D_[>E
_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_K:D_;6C_;6C_;6C^k2B^k2B_;6C_;6C_;6C_;6C
_;6C_;6C_;6C_;6C`;2C`;2C`;2C`;2C`;2C`;2C`;2C`;2C`;2C`;2C`;2C`;2C`;2C`K6D`K6D`K6D
_Zn?_Zn?_Zn?_k2@_k2@`;6A`;6A`;6A_k2@_k2@_k2@_k2@_k2@_k2@_k2@_k2@_[2<_[2<_[2<_k6=
_k6=`;:>`;:>`;:>_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_jj=^k2@WIYkLWAGHFA;MW9OS89aU8=f
/:F5]JZ:_:n?_[6A_Zn?_:f=_jf>`Jn@_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_:j:_:j:_:j:_:j:
^jf9^jf9^jf9^jf9]:J2^J^7_[2<`[B@`K>?_:j:]JN3/J=oWYMlMFiCDT/`EDhcJfA9MFiCKVM<IEi3
H5a0F5@hCDT]AT8V@clS@3`P?3PL>3@HBDX`BDTaBTXbBdXeCTdiDU4mEUA2F5I4Fea8HF9>JF]HLGER
Ngi^PhQiS962T9N8TiJ7U9J:UYR<VIZ@W9fDWj2GXZ:LXj>MWZ:GX:BIXjNLYJROYJNQYZRRZJZVZjbX
ZjnT[[:W/;>Z/;>Z[[2Z[Zn[[Zn[[k2/ZjnY/;B^ZjnYZ:bVZZjXXJFOWZ:LZjnY[[>Z[K:YZk2WZZnV
ZJjUZJjUZJjUZJjUZZbVZZbVZjfWZjfW[:jX[JnY[JnY[JnYZZfTZjjU[K2W[[6X[k:Y[k:Y[k:Y[[6X
/k^a];V`/KJ]/[F//[F/][N^^KZa_K^c/KB[/KB[/KB[/KB[/KB[/KB[/KB[/KB[/[F//[F//KB[/KB[
/;>Z[k:Y[k:Y[k:Y];N^/kJ]/kJ]/kJ]/[F//[F//[F//[F//;BY/[J[/[J[[[:WZJfRZ:bQZjnT[k>X
/[F//kJ]]KR_][V`]kZa^;^b]kZa]kZa[kN]/kR_]kbc_L2g`LBkaLJmaLJmb<Jn`/Bn`lFoa<K0aLO1
aLO1a<K0a<K0`lFo`/Bn`lFoaLO1alW3alW3a/S2aLO1a<K0`/Fl`/Fl`lJm`lJm`/Fl`LBk`<>j`<>j
][f`]K^`^KZ`^kV_^kFX^[>O`;VNbL6S`[RF_kJA_K6=_;6;_k:<`[><`[><`k>9a;><a;><a;><`k:;
`k:;`[6:`[6:`[6:a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><a;><
a;><a;><a;><a;><a;><a;><a;><a;><`k:;`k:;a;><a;><a;><aKB=aKB=aKB=a;><a;><a;><a;><
a;><a;><aKB=aKB=a;><a;><aKB=aKB=a[F>a[F>a[F>a[F>`[><`[><`[><`[><`[><`[><`[><`[><
`k>>`k>>`k>>`k>>`k>>`k>>0032]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[3]j_3]j_3]j_3]j_3]j_3
]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]j_3]jg3]jg3]jg3]jg3]jg3]jg3]jg3]jfn]J^n
]J^n]J^o]Zbo]Zc0]jg0]jg0]jg2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[1]J_1]J_1]J_1]J_1]J_1
]J_1]J_1]J^o]jZo]jZo]jZo]jZo]jZo]jZo]jZo]j[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2
]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1
]JW1]JW1]JW1]JW1]JW1]JW2]Z[2]Z[3]j_3]j_3]j_1]jK1]jK1]jK1]jK1]jK1]jK1]jK1]jK1]jK1
]jK1]jK1]jK1]jK1]jK1]jK1]jK2^:O1]jK0]ZG0]ZG0]ZG0]ZG1]jK2^:O0]ZG0]ZG0]ZG0]ZG1]jK1
]jK2^:O2^:No]JBo]JC0]ZG0]ZG0]ZG0]ZFo]JBo]JC2^j:j/iZd[YNl]J78`Jk0^:NLU8=gKV17BSY4
AcM1ASM2B3e7D4I9E4a4D4XmBdL?4R462AP62AP62AP521L?4R4B5B@521L00AH52b800QX13bH34BL0
11@?5b@X;CI8DEAEFU][KfZ1PWV5Qg]lPG9iP75lQWJ3R7mjOGBBUHb6RXAmPh8g@DP<72T55bPD93DM
<D<B:T0N?EA1I7QKOhmSRIE^TY`jBUXY?4TW@4XP?DIGMh9KO8]JNHhmFg@Y@dlQ>DD_@Tm4EF9;G6U7
GFTeCe/M>D@mE5`fD5MWPHQ[PhUJL7ITM7Xg@dT12A1dNGbLXJ9TJFQcMGF1QXULI6]VLWi8EfMEH6QU
L7QfP8MkPhYgOH9fNWmnPXN9S961Q8R0PhN0PhN1Q8R4Qh^5R8b5R8b4Qh]oP8AkOGifMgE`LFeeMFml
NgN0OWf1OGahNGEhNGEhNGEiNWIiNWIiNWIhNGEhNGEfNWEfNWEfNWEhNGEjNGEjNGElNGElNGEnOGUn
NgMmNWJ0OGV4Ogb6PGj7PWn:Ph26Qgj5QWf6Q7b7QG^9Qgb=RGj@SGnCSH2OTh6SV8BZWh^cYY2j[9Fn
/IO2/iW3]IW2/iW2/iW2/iW1/YS0/IO0/INo/9Jo/9Jl/9Rm/IVm/IVn/YZn/YZo/i^n/YZn/YZm]Yfh
[YJf[9Bn/Y[1]Ifo/IZo/I[4]9fn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn
/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJn/YJm/YBm
/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBl/I>l/I>l/I>m/YBm/YBm
/YBn/iFn/iFl/I>k/9:k/9:k/9:k/9:l/I>m/YBn/iFm/YBm/YBm/YBm/YBm/YBm/YBm/YBm/YBl/I>l
/I>l/I>l/I>l/I>l/I>k/9:k/9:l/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I?0/9?0/9?0/9?0/9?0/9?0
/9?0/9?0/9>n[Y6n[Y6o[i:o[i;0/9?1/IC1/IC1/IBn[hnn[hnn[hnn[hno/92o/930/I70/I6o/92o
/92o/92o/92o/92o/92o/92o/92n/8bn/8bn/8bn/8bo/Hfo/Hg0/Xk0/Xjm[h^m[h^m[h^m[h^m[h^m
[h^m[h^m[h^hYhK2]YBe[Xf@S6mjMe]mMf24NFF0L5nZWgnbYhNl[hno/Y:m[Xjk[8bo[Hk2/96l[XZl
[XZl[XZl[XZl[XZl[XZl[XZl[XZm[h^m[h^m[h^l[XZl[XZl[XZl[XZl[XZk[HVj[8Rj[8Rj[8Rk[HVl
[XZn/8bn/8bi[XjTVGVAQVJ?Q6BGS6bMTW:QUWJUVWZITG>@R6Z3NeeeKDmYHD=MECMCBbe=ABM3@2A3
@2A3@2A5@BQ8A2a<B31AC3MCCSUEF3mBECa@DSa>DC]AET5KGdaTJUM/LV5fNFYiO6eoPGF5Qg^;S8:?
T8NBThZCU8^DUXZGVHfKW9:NWiFPXIRSXifWYj6ZZJFXZIn[[::^[jJ^[jJ^[ZR][:R^[JV`[j^/[JVb
/jn^[j^/[JV][ZZTYJ6OX9b/[JV`]:V_/jR^/ZN]/JJ]/JJ]/JJ^/ZN^/ZN`[j^_[ZZ_[ZZ_[ZZ^[JV^
[JV^[JV^[JV^/ZN^/ZN^/ZN^/ZN^/ZN^/ZN^/ZN^/ZNY/JJ[/JJZ/:F]/JJ^/ZNb/jVd]J^g]Zb_/ZV_
/ZV`/jZ`/jZ`/jZ`/jZa]:^a]:^e^Jje^Jjd^:fd^:fc]jbb]Z^b]Z^a]JZc]Zfc]Zfc]Zfc]Zfc]Zfb
]Jbb]Jbb]Jba]JZb]Z^b]Z^`]:V]/JJ//:F^/ZNa]JZc]Zfd]jje^:nf^K2f^K2f^K2e^:ne^:o1bKnn
`kZh_KBd]jjb]Jbe]Zfi^[6n_;Ba/jfa/jfb]:jb]:jb]:ja/jf`/Zb_/J^Z[:JZ[:J/[ZR][jV][jV]
[jV/[ZR/[ZRh^k:i_;>j_KBj_KBj_KBi_;>h^k:h^k:b^Zne^k2j^k6n^jfm]Z>l/IJl/8k1/X_2]Y;0
]Hnm/Xbn/H_2/Xg3/hk4/Xg3/X_4/hc4/hc3/X_3/X_2/H[2/H[2/H[2/H[4/hc4/hc4/hc4/hc4/hc4
/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc4/hc3/X_3
/X_3/X_4/hc4/hc4/hc5]8g5]8g4/hc4/hc4/hc4/hc4/hc3/X_3/X_3/X_4/hc4/hc4/hc5]8g5]8g5
]8g6]Hk6]Hk3]8g2/hc2/hc1/X_1/X_2/hc2/hc3]8g2/Xg2/Xg2/Xg3/hk3/hk3/hh00<:fZ/:fZ/:f
Z/:fZ/:fZ/:fZ/:fZ/:fZ/>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>gZl>g
Zl>gZl>g[L>g[L>g[L>g[L>g[L>g[L>g[L>g[KfdZ[jeZkjeZkjeZknf[;nf[;nf[<2g[L:fZ/:fZ/:f
Z/:fZ/:fZ/:fZ/:fZ/:fZ/2dZ/2dZ/2dZ/2dZ/2dZ/2dZ/2dZ/2dZ[ngZ[ngZ[ngZ[ngZ[ngZ[ngZ[ng
Z[ngZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/2dZ<2dZ<2d
Z<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<6eZL6eZL6eZL:fZ/:fZ/:f
Z/>gZl2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL2fYL6gY/6gY/2f
YKneY;neY<2fYL6gY/6gY/2fYL2fYL2fYL2fYL6gY/6gY/:hYl:hYkneY;neY<2fYL2fYL2fYL2fYKne
Y;neY;ZeW;bfWkjfWkjfWl6hY<FlZ<6gYKZ`WY6COFa]FDA6<cLj:T99>TeEBTUBB419?a<F7PP;4`@7
3`853@032``?5a8E7@H94@044`D<7@015@PC:A<N=0@>804:60054PPA6QlV:D98@fQZGWUlK7YmKGIk
K7ImL7Z0MG1dJ8V=PG]nMGn5P49;CPXF80@C8`TF91/[?1D]@AXfCSMIL4U/P41TMU5eQAPT;T1@EeAW
K3M=DTEQJ4ERL4IWNSaNMAPf@AHb?AL_>aP[>28e@S]AGCUAGAPd?aP/=b8h@ceGGUejOe1ZL5ibMfMf
NADP92/a=YZOXWEiNVa`LGf4QeENIdmLJS=3E3=8EcmDHdaPLE1TME5RME9SMUe[PFMeRdiEGTiEGU5H
HEMNIemVKfI]MVQ_N6Q_N75eNX24QHV?RXZ?QXZ>Pi:CRY^HTifIV8N9PhJ8PXF7PHF7PHB6P8B6P8B6
P8B6P8B;Q8B;Q8N;QHN;QHZ<QXb<QXb<QXf=QhZ<QY2@RYBDSYZGTYbHTi^ET9:<Qhb3Oi2>Pi:>PiBA
PiRBQIbGR:>LSJRQT:^ST[Z^U[^`UKnbV<6dV/>eVL>bUl6aU<2`TkZYS[ZYS[^ZSkb[T;f/TKj]T[j]
T[n^Tl2eV/2eV/2eV/6fVl:gW<>hWLBiW/BiW[jgW;fdVKbcV<6fVl6fVknbV;f`U[n`U[jbU[jbU[jb
U[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jb
U[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[jbU[baTkbaTkbaTkbaTkbaTkbaTkbaTkbaTkbaTkbaTkba
TkbaTkbaTkbaTkbaTkbaTk^`T[^`T[baTkbaTkfbU;fbU;fbU;fbU;^`T[^`T[Z_TKZ_TKZ_TK^`T[fb
U;fbU;baTkbaTkbaTkbaTkbaTkbaTkbaTkbaTk^`T[^`T[^`T[^`T[^`T[^`T[baTkbaTk^`T[^`T[^`
T[^`T[^`T[^`T[^`T[^`T[n_T[n_T[n_T[n_T[n_T[n_T[n_T[n_T[j^TKj^TKj^TKn_T/2`Tl2`Tl6a
U<6aU;f^S[f^S[j_Skj_Skj_Skn`T;n`T;n`T;j_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skf_Rkf_Rkj`
S;j`S;j`S;naSKnaSKnaSKf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_RkZZQ[j_S[Z_SjfUQinGNYF<LI65
KI22JjVOOK6WQKb`S[jbT;f^SKZ[R[j]S<:aT;b^R[b^R[b^R[b^R[b^R[b^R[b^R[b^R[b^R[b^R[b^
R[b^R[b^R[f_Rkf_Rkf_Rl:dT;naSKb^R[V[QkRZQ[^]RKj`S<2bS[^^R;V/Q[R[QKJYPk:UOk6TO[V/
Q/:eSk^`T;R]SK>XR:jSPjNLO9nDM9N<K9:7Ig1YB6aTAVAL?U]C=U=:;da3:4Lm9DDk8dE4:4I5:DQ7
;DU:<4Y==4a>>4]>>4]>>55C@5IHAEiOCfMXF6i^H7=cIGEeJGEeJGamKGn0L8B4MXV9Nhb<P96@QYJE
RiVHSYVISIbLT:2PU::QUj:PV::PV:BQW:JSWZ:TWZRZY:JXXZBVX:JXXY^MUiJHTZ6SWJ>WW:>WW:>W
W:BXWJFYWZJZWjR/XJV]X[2]Z;2]Z;2]Z;6^ZK:_Z[:_Z[>`Zk>`Zj^_Y:^_Y:b`YJfaYZncZ;6eZ[:f
Zk>g[:ng[;6g[;:h[KFi[[Fi[[Nh[[Jg[KNf[;:e[;>f[K>f[K>f[KBg[[Fh[kFh[kFh[kBh[KBh[K>g
[;>g[;:fZk:fZk:fZk6eZ[:e[;:e[;:e[;>f[K>f[K>f[K>f[K>f[K6eZ[:fZk:fZk6eZ[2dZK2dZK6e
Z[:fZk:e[;:e[;>f[KBg[[Bg[[>f[K:e[;:e[5mWGEmTFeiSFV1SFVEXGg1aJ7UjLH1nMYjQV:2SVZBW
WZR[XZb_Y[2cZ[:e[;>f[Kbo][g0]kk1^;o2^Ko2^Ko2^Ko2^Ko2^KVl/kZm];^n]Kbo][bo][^n]K^n
]KZm];Jo]Kg3^<?4^/O1]<JmZLJhVl>cS/6`QL:hT<6dS/2cSL:bSL>cS/JdSlJcS/FaS/>bRl>bRl>b
Rl:aR/:aR/:aR/6`RL6`RL>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>b
Rl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl>bRl:aR/:aR/>bRl>bRl>bRlBcS<BcS<BcS<BcS<BcS<Bc
S<>bRl>bRl>bRl>bRl>bRl>bRl>bRlBcS<BcS<FdSLFdSLFdSLFdSLBeS/BeS/>dSL:cS<:cS<>dSLBe
S/BeS/6aS<6aS<:bSL:bSL>cS/>cSP00`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`[JZ`[JZ`[JZ`[JZ
`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[J/`[J/`[J/`[J/`[J/`[J/`[J/`[J/
_KBZ_KBZ_KBZ_[F[_[F[_kJ/_kJ/_kJ/`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KF[`KF[`KF[`KF[
`KF[`KF[`KF[`KF[_[JY_[JY_[JY_[JY_[JY_[JY_[JY_[JY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY
`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX
`;BX`;BX`;BX`;BX`;BX`;BX`;BX`KFY`KFY`[JZ`[JZ`[JZ`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU
`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`KNV`;JU`;JU_kFT_kFT`;JU`;JU`KNV`;JU`;JU`;JU`;JU
`KNV`KNV`[RW`[RW_kFT_kFT`;JU`;JU`;JU`;JU_kFT_kFT]k2L_[NS`[VU^k:N^JjJ_[>OakVVbkfZ
_[RQYJ69P7eXGee;AdLg?3l`@4@hBTi3ADa9?4=0>T4n>3ll=Sdj@TU6BU5>@4M41@dD0`XC000<31@U
8bXm9Bm07bXh00/G6B@/=Ci1EeiGKG9SNG]XO7e]NG]_M7M^N89bKGAUOH9cKg=WN7afDEUI41/S62Hb
0a0N014R0QT_0ahh=eEb?eej4Bm:01D^9S8bJ7AdJgQf?Ti=;TE7?U]R?f9`@VQj<5MP6ci83RXe1adY
1aXW6B`i9C]77cE14R8_>TeJ6SDo;4aB?eiQ?UMIGFm`?d]=1`lFHFM/UIZKN7amMGUjJg5f@DaDCUYV
?UEM=deH;dMC;4EE;dMK<TYR<DUU;dMU5Al`4Q`]4A//4ad^5b4b6B<d5b4b51h_5Q`S>410FfAJIFmO
IVaIJFaMKFaRKFYUOX9fOH5eNgmcNGeaN7a`Mg]_Mg]_Mg]_OHMjOXMjOXMjP8MjP8MjPXIjQ8IjQ8Ij
NX1eNWicN7U_NWU_QH=iUI27WiR?XIR?XYZ9Xi^:YIj;Zj6?/JJB]JZD^jjH_K2J^k2D_;6E_[:F_[:F
`;:F`:nD_ZfB_JbA`K>G`K>G`K>G`[BH`[BH`kFI`kFIa;JJ`KJJ`KJJ`KJJ`[NK`[NK`[NK`[NK`[NK
_KNJ_kNJ`;RK`[NK`KJJ_k>G_K6E_JnC_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E
_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E
_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C^k2B^k2B^k2B_;6C
_;6C_K:D_K:D_K:D^k2B^ZnA^ZnA^ZnA^ZnA^k2B_;6C_K:D_;6C_;6C_;6C_;6C_;6C_;6C_;6C_;6C
^ZnA^ZnA^ZnA^k2B^k2B^k2B_;6C_;6C^k2B^k2B^k2B^k2B^k2B^k2B^k2B^k2B_jnB_jnB_jnB_jnB
_jnB_jnB_jnB_jnB_ZjA_ZjA_ZjA_jnB_jnB_jnB_jnB_jnB_Jj>_Jj>_Jj>_Jj>_Zn?_Zn?_k2@_k2@
_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Jn;_Jn;_Jn;_Jn;_[2<_[2<_k6=_k6=_Jn;_Jn;_Jn;_Jn;
_Jn;_Jn;_Jn;_Jn;aKFA_Jf9^Z^:_K2@^Jj>/:F7[Z:6]JV=[ZB2/jV7^jn=_K6?_Jj=^jb;_Zf<`:n>
^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9_:j:_:j:_:j:_:j:]jV5^:Z6^J^7^Zb8
^J^7^:Z6]ZR4]JN3^j^6^j^6^j^6_Jf8_Jf8_:b7^ZZ5^JV4^:V8^Z^:_Jj=_k2?_k2?_Jj=^JZ9]jR7
]J^9[jF3Y9YhUHYZQW]MMfa>K614IUXnF50bDTd^C4HYAd<VAT8VAD4XA40W@ClW@T0XAD<[BDL_CT/f
DdllEU8oF5A2FEE3G5m9Gf9<I6IBJF]GKFmLLG=PMWMWNW][OGm/P89_QHIfR8UiRHUkRh]oSXj2T924
SXn5UYN=U9F;TiB:UIJ<RX^1PhAjSXn5QhUmQhUmQhUmR8YnRXb0S8j2SY24T9:6TI26TY67U9>9UYF;
VIR>ViZ@WIbBWYfCTYJ:TiN;UIV=V9b@W:2DXJFIYJVMYj^O[;FX[[FX[[FX/;BX/;BX/K>W/;:V/[:V
[K2W[[6X[[6X[k:Y/;>Z/KB[/KB[/KB[[k>W[k>W[k>W[k>W[k>W[k>W[k>W[k>W/[F//[F//[F//[F/
/kJ]/kJ]/kJ]];N^/[J[/[J[/kN//kN//kN/];R]];R]];R]/;>Z/KB[/[F//kJ]/kJ]/[F//[F//KB[
Q8b2Ri27UIZAXZFL[[6X^KZa`<6haL>k/[J[];R]]k^`^[jc_L6f_l>h`<Bi`LFj];R]];R]]KV^]KV^
]KV^][Z_][Z_][Z_^[fd^[fd_;nf_;nf_L2g_L2g_;nf_;nf^<:f_lFjaLJla/>ea[n/b;fRaKNC_k29
`[J<`;B<`K:;`[:=a[B?ak>@a[:?a:n?`k:;`k:;`[6:`[6:`K29`K29`K29`K29`k:;`k:;`k:;`k:;
`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;
`[6:`[6:`[6:`k:;`k:;`k:;a;><a;><`[6:`[6:`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;`k:;a;><
a;><aKB=aKB=aKB=`kB=`kB=`kB=a;F>a;F>`kB=`kB=`kB=`;2;`;2;`K6<`[:=`[:=`k>>0031]JW1
]JW1]JW1]JW1]JW1]JW1]JW1]JW2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2
]Z[2]Z[2]Z[2]Zc2]Zc2]Zc2]Zc2]Zc2]Zc2]Zc2]Zbm]:Zm]:Zm]:Zn]J^n]J^n]J^o]Zbo]Zc1]JW1
]JW1]JW1]JW1]JW1]JW1]JW1]JW1]J_1]J_1]J_1]J_1]J_1]J_1]J_1]J^n]ZVn]ZVn]ZVn]ZVn]ZVn
]ZVn]ZVn]ZW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW0]:S0
]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S0]:S1]JW1]JW1
]JW2]Z[2]Z[0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG0]ZG1]jK0
]ZFo]JBo]JBo]JBo]JC0]ZG1]jK0]ZG0]ZG0]ZG0]ZG1]jK1]jK2^:O2^:No]JBo]JC0]ZG0]ZG0]ZG0
]ZFo]JBo]JBm]JBk/j:i[ijf[9^l[io3]J?2/Z6kZiZm/9[0/ifj[i^OUhIeKUmBC3m<B3eEDdU7D4=5
CT5;E4M<EDQ9DTEDGE1MIUUEGU4]=C@G7al010/52aPF7B`c?4XlB5@9624/>T1FHV9jPgUnQ7=iNfQj
NVaiNW5dLW5aNfY/M6=eNfY_LV=_M6]JH5l94aXL9S065RH02ad:83T0538gDWA2G80N=5L02B`f?SMm
QGiXLf]5E4`W?3U1Gf0^De/dHF`mK7@YDU/M?DPD;3P65b@75b@C8c0F9S<23alO;cl<9c4H>T0ZCE0d
D55NLg5^NWXR;CDR:S5oQ8NBU9AhNGMgNGULHFASJFiTLVIOKfAEIV96FE`fBe<W?ThM=4XI<DT<6Rd6
52L13b803R413b803R4021/00aH23A4]>3IFHeEULUYUL5IXKUMZJe]XIUaWKEYUJeQRJ5EOIE9MHe1L
HTmLHTmLHTmDH4aCGd]CGTYAG4QBFdMBF4EAEdAAEdA5Ccm5C3e4BCY=CCmUI5J9PgJRVXf[XYFdYi6e
ZI6gZI:i[9:m[YC0[iC0/9?0/9>e[I2e[I2i[Y:j[i>m/IG0/IO1/YS1/YRm/9Jm/9Jl[iFk[YBj[I>i
[9:hZi6hZi6j[i>k/9Bm/YJn/iNo]9Rn/iNn/iNm/YJf/9>j/YFk/iJm/YJl/IFn/YJo/iO1/iNm/IFm
/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm
/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFl/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I>l
/I>l/I>l/I>l/I>l/I>l/I>l/I>k/9:k/9:k/9:k/9:l/I>l/I>l/I>m/YBj[i6j[i6i[Y2i[Y2j[i6k
/9:l/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I>l/I>i[Y2i[Y2j[i6j[i6k/9:k/9:l/I>l/I>j[i6j
[i6j[i6j[i6j[i6j[i6j[i6j[i6n[Y6n[Y6n[Y6n[Y6n[Y6n[Y6n[Y6n[Y6o[i:o[i:o[i:o[i:n[Y6n
[Y6n[Y6n[Y6l[Hfl[Hfm[Xjm[Xjn[hnn[hnn[hnn[hnm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjl[XZl
[XZm[h^m[h^n/8bn/8bn/8bn/8bm[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h_6]Y:n[XZl[8S1/8o1/Y6m
/92l/I72]iNe[8Ng[XVj[XZk[h^m[h^l[XZn[XZm[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HViZhNi
ZhNj[8Rj[8Rk[HVk[HVl[XZl[XZj[8Rl[X[0/Xk2]931/hno/Hfk[HViZhNj[HNhZhFgZXBhZhFl[hVm
/8Zi[8JdYh6bXWjdY82gYh>iZHFiZHFhZ8BgYh>gYh>i[8Jj[HNl[XZm[h^l[HbjZh^hZHVfYXVTUgNH
Rf^4NEUcJ4YUFSiIDCABBBi=A2UED35BCBi=AbY9@RM8@BI:@bY=ARe@B359CRm<D3=@E3MCESaFFD1I
G4=MGdUPHTaRIDaVJE1/KUQ`LEecM61fMVAiNFMlO6ahNfb0PgAoPW=oPW>0PgAdMfQ]L65gNV]aLfMa
LfMaLfMbM6QcMFUeMf]fN6agNFehMfUhMfUiN6YjNF]lNfemO6inOFmnOFmdN6aeNFefNViiOG5mPGF1
QGV5RGf8S822Rgj3RWf2RGb5RGf9SH6@TXJEUh^KVhnUZ9nVZJ2WZZ6WZZ6XZj:Y[:>Z[JBZ[JB[[j>/
/:B//:B]/JF^/ZJ_/jN_/jN`]:Ra]:^a]:^b]Jbb]Jbc]Zfc]Zfd]jjd]jjc]jbc]jbc]jbd^:ff^Znf
^Znf^Zne^Jj`/jZa]:^b]Jbc]Zfd]jjd]jjc]Zfc]Zf_]jfc^:ne^[6h^k:h^k:g^:nc]:^c/JVj_[>k
_kBk_kBk_kBj_[>h_;6g^k2f^Znn`[Nn`[Nn`[Nn`[Nn`[No`kRo`kS0a;Vh^k:i_;>j_KBk_[Fl_kJl
_kJk_[Fk_[Ff_[>m`kS2`kW0_[?3_:g5_JK3^I^j/8jo/hW0/XRo/8W2/8_5/Xg6/Xo6[ho4[Hg2/H[2
/H[2/H[2/H[1/8W1/8W0[hS0[hS2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2
/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[1/8W2/H[2/H[2/H[3/X_3/X_3/X_4/hc1/8W1
/8W2/H[2/H[3/X_3/X_4/hc4/hc3/X_3/X_3/X_3/X_4/hc4/hc4/hc5]8g0/H[1/X_3]8g4]Hk4]Hk3
]8g1/X_0/HZo[hZo[h[0/8_1/Hc2/Xg3/hh00<6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL:fZ/:fZ/:f
Z/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:f[<:f[<:f[<:f[<:f[<:f[<:f
[<:f[;bcZKfdZ[fdZ[fdZ[jeZkjeZkjeZknf[<6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL:f[<:f[<:f
[<:f[<:f[<:f[<:f[<:f[;jfZKjfZKjfZKjfZKjfZKjfZKjfZKjfZL6eZL6eZL6eZL6eZL6eZL6eZL6e
ZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZKncYkncYkncYkncYkncYkncYkncYkncYkncYkncYknc
YkncYkncYkncYkncYkncYkncYl2dZ<2dZ<2dZ<6eZL6eZL6eZL:fZ[neY;neY;neY;neY;neY;neY;ne
Y;neY;neY;neY;neY;neY;neY;neY;neY;neY<2fYL2fYKneY;jdXkjdXkneY<2fYL2fYL2fYL2fYL2f
YL2fYL6gY/6gY/:hYl:hYkneY;neY<2fYL2fYL2fYL2fYKneY;neY;VaY;nfZL:gZL2cYL6aY<FeYLRe
Y/FbXlRgX/>bWl:bXLFhZ;R]Wi26O6=JDDDn=CM2;SY5<DIA?DaG@dUD@5=NBU]VDUAOBemZHSQ1?PdD
5`053P@:5bhgA4=BF`TK8P0?4Sa9AfmiKGAjIfi`G7AdIW]hM7MdMVYdHfeeI7EkJWMjJg9eK5mTH`06
2PlI8c94EC15FU1WP@PQ@`hUB`@H@@<E?P06;@<;06]dIgAmL6]gJc=8@3]JEa@m@2YHGbQNIBaKHbmC
GAdg@`LH9@HC8@TD8P085PH@8P003`PT;a@h?P0U9b91@65fM7>1OdmKI@8;54E:CJNXYXB3Og5`K8F6
Q5iPH61UAW5fFgIoJV1ZGS90?P`O900C808F9`4?9@0;8@097`0=8`HD:PTG;@LE:`@B:0LB5R/i=E5O
CEYYCEYVB61WC6=UDV5PDUmWD5eUCUUQBUINAe=KA59J@e5I@U5I@T]I@DYH@4QF?TIC>dE?>49<=D9:
<d18<CM2;TE>>UQNBg5cH8j>O:bXU[N`WkB/VknaUKnaUL:aU/:bUL>aT/:^Sl2]S;j[R[VcU[RbUKVa
U;V^TkR]T[V[U;V[U;b/UKJ]T[N^TkR_U;V`UKZaU[bcV;fdVKfdVKV^T[^`U;ndV<:gVlBiWLFjW/Fj
W/FjW[bfVKngV[jfVKbaUKZ_Tkb`U;ncUl6cUkfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfa
UKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfaUKfa
UKfaUK^`T[^`T[^`T[^`T[^`T[^`T[^`T[^`T[^`T[^`T[^`T[^`T[^`T[^`T[^`T[^`T[Z_TK^`T[^`
T[^`T[baTkbaTkbaTkbaTkZ_TKZ_TKV^T;V^T;Z_TKZ_TKbaTkbaTk^`T[^`T[^`T[^`T[^`T[^`T[^`
T[^`T[V^T;V^T;V^T;Z_TK^`T[^`T[baTkbaTkZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKj^TKj^TKj^
TKj^TKj^TKj^TKj^TKj^TL2`Tl2`Tkn_T[n_T[j^TKf]T;f]T;f]T;b]SKb]SKf^S[f^S[f^S[j_Skj_
Skj_Skf^S[f^S[f^S[f^S[f^S[f^S[f^S[f^S[b^R[b^R[f_Rkf_Rkf_Rkj`S;j`S;j`S;f_Rkf_Rkf_
Rkf_Rkf_Rkf_Rkf_Rkf_Rkn_Rl2`S<:_S<6^Rkn^SKf^SKZ^S;J/R[^bSKV`RkV]RKZ^R[f_Rkf_Rkj^
R[b/R;^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RKRZQ[RZQ[V[QkV[QkZ/R;^]RK^]RK^]RK^]RKZ/R;Z/
R;V[QkRZQ[NYQKNYQKNYQKFWPkRZQ[Z/R;NYQKJXQ;RZQ[f_RknaSKZXPk^YQ;bZQKf[Q[f[Q[j/Ql6_
R/>aS;JWP;RXPk^[Q[j^R[j^R[b[R[VWR;JTQKRWQ[VXQkVZR[Z[RkBVRJVKOiR<L8b0I7=ZB6YQ?eeD
<e589d]18da19E15:EE:;TA:9dM<;4Y?;daA<TaA<TiB=E5E>5AG?E=G>UMJ@5ePAV9UC6IYD6U[EFi`
FW5bGVa^FgEgI7EgI7EgI7IhIFY/FF9TDFa^FgAdIWAdIW=cIG=cIG=cIGAdIWEeIgIfJ7]kJGYjJ7Ui
IgMgIGEeHg=cHG9bH75aGfU^GfU^GfQ]GVQ]GVU^GfaaHVicI71eIVegIfedIFacI79gJ7YoL8V<OIJI
RZ2PTZFXWjJYX:JYX:NZXJV/XjZ]Y:Z]Y:^^YJbaXZbaXZfbXjjcY;2eY[6fYk:gZ;:gZ;6dZk6dZk:e
[;:e[;>f[KBg[[Bg[[Bg[[>g[;>g[;>g[;Fi[[Nk/;Rl/KNk/;Jj[k6dZk:e[;>f[KBg[[Fh[kFh[kFh
[kFh[k2h[[:g[[6f[K>f[KFh[kZk/[fn]L6o]kJj[kNk/;Rl/KZn/k^o];^o];^o];Zn/kRl/KRl/KNk
/;Nk/;Rl/KRl/KVm/[Zn/kZm];^n]Kbo][k1^;k1^;k1^;k1^;k1^;W0/kk4^L;3^Knn]<6n/<K0[L:m
Y;^eV;nbQ[j`Q[f_QL6`RLB`SLB_SlF^S/>[SL:aR/:aR/:aR/6`RL6`RL6`RL2_R<2_R<:aR/:aR/:a
R/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:aR/:a
R/:aR/6`RL6`RL:aR/:aR/:aR/>bRl>bRl>bRl2_R<2_R<6`RL:aR/>bRlBcS<FdSLFdSL:aR/>bRl>b
Rl>bRlBcS<BcS<BcS<BcS;f^Qkn`RL6bRl>dSL>dSL6bRkn`RKf^Qkn_R[n_R/2`Rl6aS<:bSL>cSP00
a;JZa;JZa;JZ`kFY`[BX`[BX`K>W`K>W`kN[`kN[`kN[`kN[`kN[`kN[`kN[`kN[`[JZ`[JZ`[JZ`[JZ
`[JZ`[JZ`[JZ`[JZ`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY
_k>W_k>W_k>W_k>W`;BX`;BX`;BX`KFY`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`KFY`KFY`KFY`KFY
`KFY`KFY`KFY`KFY`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU
`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU`;JU
`;JU`;JU`;JU`;JU_kFS_kFS_kFS_kFS`;JT`;JT`;JT`KNU`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT
`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT`[JT`KFS`KFS
`;BR`;BR_k>Q_k>Q`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`;BR`KFS_[:P_;2N_k>Q_[:P[Z:@VXil
EeI2BDTg?d8b?dHi?dY0>dY2>DY6>dm:A5I9>dY67BH`000G000I6aLd;R]1;b/n2``@<S@dGfAKLgY[
KGETHV]GI6aKK7ASIGMZIW=SL7UUL7AQM7UZGfIQ9c<i52@aM9NKHh>8MYBIUkBiNiFK:D5700lE018I
0041D5A>MgMWJfaHHFUH=4Y543<m84iP8E9L;eeX=5iZ;U5N:TEC9CY95BDe00hN00``00LT00XL4b8U
=d<mEV1CI6aKIfeJPXf3;3@c3Q@KJfilT9BOMG^0OXR2MH9dFF=SHFiVBUY9EFM@AEE43QTG1``K10DQ
20dV20hU10TN00HI1`/M4aHT5QXU4aLR@TP_BU<iDei4EFA9D656BV14Bf96CFI:D5e7CEU5BeM5BUM7
BEQ:AeE9?dm4>TU1@4Pn@TPm@dLkADHfBDLeEU4lIV19MFiEX9EiZ9f1/jR<^k2D_kBH_[>G_K:F_K:F
_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D^jnC^jnC^jnC^jnC_;2D_;2D_;2D_K6E_;2D_;2D_;2D_;2D
_;2D_;2D_;2D_;2D_K6E_K6E_K6E_[:F_[:F_k>G_k>G_k>G_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E
_K6E_K6E_K6E_K6E_K6E_K6E_K6E_K6E`;BH_k>G_k>G_[:F_[:F_K6E_K6E_;2D_K6E_;2D_;2D_;2D
^jnC^jnC^jnC^jnC^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA
_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_ZjA_ZjA_ZjA_ZjA_ZjA_ZjA_ZjA_ZjA_Zn?_Zn?_Zn?_Zn?
_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>_Jj>
_:f=_Jj>_Zn?_Zn?_Zn?_Zn?_Jj>_:f=_Zn?_Zn?_Jj>_:f=_:f=_Jj>_Zn?_Zn?_Jj>_Jj>_Jj>_Jj>
_Jj>_Jj>_Jj>_Jj>_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;_Jn;
_Jf8_Zj9_jn:_jn:_jn:_jn:_Zj9_Jf8_Zj:_Zj:_Zj:_Zj:_Zj:_Zj:_Zj:_Zj:_:j:_:j:_:j:_:j:
_:j:_:j:_:j:_:j:^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9_Jf8_Jf8_Jf8_Jf8_Jf8_Jf8_Jf8_Jf8
^ZZ5^j^6_Jf8_Zj9_Zj9_Jf8^j^6^ZZ5_:b7_:b7_:b7_:b7_:b7_:b7_:b7_:b7_:b8_:b8_:b8_:b8
_:b8_:b8_:b8_:b8^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5_:b8^j^7^ZZ6^ZZ6^ZZ6^ZZ6^j^7_:b8
^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6/J5l/J5l[YiiYiMbV8QSQWIAM6@oJUXeCTTXBdHUB4<RBD@S
C4LVD4/ZDdh]E4l^FTldFe@iHUi5JVQ@Jf]CKFQCLV]HO71NLG9NLgAPMWMSMgQTMWMSLgAPKVmKJfaH
MgMUMWITMGESLg=QLW9PL71NKfmMKViLKViLK6aJJ6QFIVIDIVIDJFUGKFeKL71NJfiHI6MALGANMgUU
NWaYMGMTKFiNMWMWLW9TO7a^QHEgVIV;Y:BFX:2BZZZLZZZLYjZKZJbMYjVM[JnS]kJ/[ZbT[:VQ_;Va
]kJ/[ZfS_[fc[ZfS_kjdZ:NM[:^Q`;ne`K^^Xj:D];JZ`<BhYJVN[JjUalBl_[J_]KR_]kZa]kR_]kR_
[ZbT/JjV_kbd];6Y];F[/kBZ/[>Y/K:X/[>Y];F[][N]]kR^[k2V/kBZ^;V_^[^a^[^a^KZ`^KZ`^KZ`
^KZ`^KZ`^[^a^[^a^kbb^kbb^kbb^kbb^[^a^kbb^kbb^kbb_;fc_;fc_;fc_Kjd_Kjd_Kjd_Kjd_[ne
_[ne_[ne_l2f_l2faKnh`;fh_;^g^kbh_kni`Knd`;^/_kRU^[2>_k6=`k:;`k:7`k25`;26`K6<_k>?
`K29`K29`K29`K29`K29`K29`K29`K29`K29`K29`K29`K29`K29`K29`K29`K29`K29`K29`[6:`k:;
a;><a;><`k:;`k:;`[27`[27`k68`k68a;:9aK>:aK>:aK>:`K29`K29`K29`K29`K29`K29`K29`K29
`K29`[6:`[6:`[6:`k:;`k:;`k:;a;><a;:=a;:=a;:=a;:=`k6<`k6<`k6<`k6<`[6:`[6:`[6:`[6:
`[6:`[6:`[6:`[6:aK>>aK>>aK>>aK>>aK>>aK>>0034]Z[4]Z[3]JW3]JW2]:S2]:S1/jO1/jO3]j_3
]j_3]j_3]j_3]j_3]j_3]j_3]j_2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[1]JW1]JW1]JW1]JW1]JW1
]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JVn/ZJo/jNo/jNo/jO0]:S0]:S0]:S0]:Ro/jNo
/jNo/jNo/jNo/jNo/jNo/jNo/jO1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JVo/jNo/jNo/jNo/jNo/jNo
/jNo/jNo/jNo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo]JBo
]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBo]JBn]::o]J>o]J>o]J?0]ZC0
]ZC0]ZC0]ZC1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1]J?1
]J?1]J?1]J?1]J?1]J?1]J?1]J?2]ZC1]J?1]J?1]J?0]::o/j6o/j6o/j70]:;0]:;0]:;0]:;0]:;0
]:;0]:;0]::o/j70]::n/Z2l/9k1]J?4^:Jl/9j_Xi6KUH9gLf5@D411A3DoAc`mB40f@S`a?cTmCT<g
AD<R:c@93B0001H201H20Q8000P00@4S9b9@ET]YLF1ZLeiUKUUYLUi`N6MSLf9TKUe`Mf9aLem^LfAE
GU/V=SdR=D@nGfQ]SYNA/;VH/kfP^L>K/KaNLWdB92l74aE6CDQYK5e]KUYVKe]0DdXM>d0PB5@CC5DL
De`ODU`KBE@KAE4M@dlC=D82934:63@01A/02ADR<S5@GU=TKemUKUYSK5MRKf5dOgLh?d8f>dB:SYVH
WZ=hPGihPg]SKFeULF]FIUEIJUE9FDPJ9B<62aX7228642453Q`741dE7RLW<cDf@CllAD8kACmAG4Q@
FdM>FDE:ET95E3m2Dci2Dci1E3mEGdi>F4M4CSdlASHh@S8g@3<h@C@j@C@o@CE<Cd1SHe=hMVB<Qg:M
Uh2_Z8fk/YNaYXZeZXjj[i>l/IFl/IFk/9Bk/9Bk/9Bk[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>j[Y:k
[i>k[i>k[i>l/9Bl/9Bl/9Bl/9Bk[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>m/IFm/IFm/IFm/IFn/YJn
/YJn/YJo/iNm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFm/IFo/iNo
/iNn/YJn/YJm/IFm/IFl/9Bl/9Bl/9Bl/9Bl/9Bl/9Bk[i>k[i>k[i>j[Y:j[i6j[i6j[i6j[i6j[i6j
[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6j[i6n[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[Y6n
[Y6n[Y6n[Y6n[Y6n[Y6n[Y6n[Y6n[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn[hnn
[hnn[hnn[hnm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjl[Hfm[Xjn[hnn[hnn[hnn[hnm[Xjl[Hfn[hnn
[hnm[Xjl[Hfl[Hfm[Xjn[hnn[hnm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[h^m[h^m[h^m[h^m[h^m
[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m[h^m[HRn[XVn[XVo[hZo[hZn[XVn[XVm[HRn[XZn
[XZn[XZn[XZn[XZn[XZn[XZn[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZk[HVk[HVk[HVk[HVk[HVk
[HVk[HVk[HVm[HRm[HRm[HRm[HRm[HRm[HRm[HRm[HRjZXFkZhJl[8Nm[HRm[HRl[8NkZhJjZXFl[8Nl
[8Nl[8Nl[8Nl[8Nl[8Nl[8Nl[8Nl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rl[8RjZXFjZXFjZXFjZXFjZXFj
ZXFjZXFjZXFl[8RkZhNjZXJjZXJjZXJjZXJkZhNl[8RkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJjZXFl
[8Nn[XVo[hZm[HRhZ8>cXgj`X7^VWGbNUGBBRFR3NUUdJdYUG3]GCRe?AREQFCaPFSeQH4AXJDmYK5=Z
JEA`JUMfKeaYJUIYJUIYJUIYJUIXJEEXJEEXJEEWJ5A]KE]]KE]]KE]]KE]]KE]/K5Y/K5Y/K5Y/K5Y]
KE]_KeeaLEmeMF=lO6Z6QWB<S7Z=Tgb:T7V<TGagO6N2QW>@Th>JWHfHVhbQXiNNX9BMWi>MWi>][j>[
[J6e]j^/[Z:`/jBh^jb][j>PXYJ[ZZ2h]Zje/j^]ZZF`/JN^[jFb/jVMWYBh^Jng^:je]Zb^[jG0_Jnl
^jfg^Jf^]JRZ/:Fa/ZVe/ZZ_ZJBc]Zf]/:N^/JRi^[6h]Zjh]Zk1_[Jg]:bf]jfe]Zbc]:Z`/JN_/:J^
[jF_/:J_/:JWZ9j/[J>a/ZRe]Zbf]jfg^:jh^Jnj^k6i^[2i^[2j^k6j^k6j^k6k_;:k_;:k_;:j^k6j
^k6k_;:k_;:k_;:l_K>l_K>l_K>l_K>m_[Bm_[Bm_[Bn_kFn_kFn_kFo`;K3`KO0_[Jm_KNl_KW0`;[2
`;K2_Jk2^jRl/I6m/Ho0/H[2/8O2/HK2/8O0/8^o/Hg1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1
/8W1/8W1/8W1/8W1/8W1/8W1/8W0[hS1/8W2/H[3/X_3/X_3/X_3/X_2/H[2/8O2/8O2/8O3/HS3/HS4
/XW4/XW5/h[1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W1/8W2/H[2/H[2/H[3/X_3/X_3/X_3/Hc3
/Hc3/Hc3/Hc3/Hc4/Xg4/Xg4/Xg2/H[2/H[2/H[2/H[2/H[2/H[2/H[2/H[3/Hc3/Hc3/Hc3/Hc3/Hc3
/H`00<>eZL>eZL>eZL:dZ<:dZ<:dZ<6cYl6cYl:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/:fZ/6eZL6eZL6e
ZL6eZL6eZL6eZL6eZL6eZL2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2d
Z<2dZ;jbY[jbY[jbY[ncYkncYl2dZ<2dZ<2dZ;ncYkncYkncYkncYkncYkncYkncYkncYl2dZ<2dZ<2d
Z<2dZ<2dZ<2dZ<2dZ<2dZ;ncYkncYkncYkncYkncYkncYkncYkncYkneY;neY;neY;neY;neY;neY;ne
Y;neY;ncYkncYkncYkncYkncYkncYkncYkncYkneY;neY;neY;neY;neY;neY;neY;neY;neY;neY;ne
Y;neY;neY;neY;neY;neY;jdX[jdX[jdX[neXkneXl2fY<2fY<2fY<6eXl6eXl6eXl6eXl6eXl6eXl6e
Xl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl6eXl2d
X/2dX/2dX[ncXKncXKncXL2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX[jbX;ncXKjbX;b`W[ncXLBhY/>g
YKncXL2fY:^TTHn8Mfm/GU9BASa0=C@i<3Dl=AHW7PhL6P@>5@044@0140854`T?5PhE62<W8CTo=5AK
C6=/Ef=]EV5[E6E^FF]dGf=^FV9ZDg1dFfmbG6M/GDQEDb@g?ba4ER95CeinRI6_^Z6mb:k8e;gCgjJi
aWb?W51QI5YXI6U`Hg9gHVYaG4eLCRm8A2A3A0m;DA=?EA==Da17CQ=:DA]AF1]?EQ55C1PX>0HG810R
8Cm@AF5aGf=`FUeZDV9/EEa/EF]hJVMaJca2AdM<EHnEW9jUZ7Z2PF]dMf5/JEi/H59RDD=AAB8]:`04
4@D77`dI8`<@60/G6bDc<D1@AD]KBTUJADQJ@ci=?cm>@4=@@TQEAdmIC4mIC4]DAdM@@cLn;cPo<3]0
<D54=4];>eUGAFQTDW1/FXb:N9RDPJNRSK6[U;J_U[V^TkZ^T[^`T[fbU[fbU[baUKZ_TkN/T;N/T;V^
T[baUK^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_TkZ^T[Z^T[Z^T[^_Tk^_Tkb`U;b`U;b`U;^_Tk^_Tk^_
Tk^_Tk^_Tk^_Tk^_Tk^_Tkb`U;b`U;b`U;faUKfaUKfaUKjbU[jbU[b`U;b`U;b`U;b`U;b`U;b`U;b`
U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;b`U;jbU[jbU[faUKfaUKfaUKb`U;b`U;b`U;b`U;b`U;b`
U;^_Tk^_TkZ^T[Z^T[Z^T[Z_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_TKZ_
TKZ_TKj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_
Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skj_Skf^S[f^S[f^S[f^S[f^S[f^S[f^
S[f^S[b]SKb]SKf^S[j_Skj_Skf^S[b]SKb]SKj_Skf^S[b]SKb]SKb]SKb]SKf^S[j_Skf^S[f^S[f^
S[f^S[f^S[f^S[f^S[f^S[f_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_Rkf_
Rkf_Rkf]R;f]R;j^RKn_R[n_R[j^RKf]R;f]R;j^R[j^R[j^R[j^R[j^R[j^R[j^R[j^R[b^R[b^R[b^
R[b^R[b^R[b^R[b^R[b^R[^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RKf]R;f]R;f]R;f]R;f]R;f]R;f]
R;f]R;ZZQK^[Q[b/Qkb/Qkb/Qkb/Qk^[Q[ZZQK^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Qk^[Qk^[
Qk^[Qk^[Qk^[Qk^[Qk^[QkZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQK^[Qk^[QkZZQ[VYQKVYQKZZQ[^[
Qk^[QkZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKFUP;FUP;JVPKNWP[VYQ;^[Q[b/Qkf]R;:VQ;6UPk2T
PZjRP:ZNO::FM9V=Ji:6I6UTAF9O@5]M?eaQAUmSBUmRC6ASCfYVE6IWDfAUDF9SCf1QCF5RCVAUDFQY
EF]/F6a]GFe^GVi_Gfm`H71aHG5bHW9cHg=dI79bHWQhJ7moKh>3LhN7Mi2@P9fMSJNWUj2UT:6VTJ^_
W9ZNRjnbXZV/WK:eYZ6SUj^]XJFWVjj`Y9fOTjj`Y:JXW;6cYjRZWZNYWK6cYk6cYjRYWjVZXK:cZ[>c
[Jf]YjJWWKJg[Kjo]K2aYkfn];BeZk2aYjRYWjNUV[NgZjZ^XZB/XLG=`m[Me=CAc=C@bk2e[:^`Yk^n
]M3Ab=OHcm_IdLk<a;Nd[;Nh[[Jg[KBeZk6bZ:n`YZj_YJf^Y:f^Y:NXWZ^/X[2aYk>dZ[BeZkFf[;Nh
[[Ri[kVj/;Vj/;Vj/;Zk/KZk/KZk/K^l/[^l/[Zk/KZk/KZk/K^l/[^l/[bm/kbm/kbm/kbm/kbm/kfn
];fn];fn];jo]Kjo]Kjo]L;0]L2o]K^m]kbm^Kk0^/;1]lFo//Fn[KjfV;baTKb_RKn_QL:`Ql>cRKn_
R[^]RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RKn^Ql2_R<6`
RL:aR/>bRl:aR/:aR/:aR/:`Ql:`Ql:`Ql:`Ql>aR<>aR<>aR<>aR<6`RL6`RL6`RL6`RL6`RL6`RL6`
RL6`RL6`RL6`RL6`RL:aR/:aR/>bRl>bRl>bRl6_R/:`Rl:`Rl>aS<>aS<BbSLBbSLFcS/:aR/:aR/:a
R/:aR/:aR/:aR/:aR/:aR/6_R/6_R/6_R/6_R/6_R/6_RP00`[BX`[BX`[BX`[BX`[BX`[BX`K>W`K>W
`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`[JZ`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY`;BX`;BX`;BX`;BX
`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX_[:V_[:V_[:V_[:V_k>W_k>W`;BX`;BX
_k>W_k>W_k>W_k>W_k>W_k>W_k>W_k>W`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX_k>W_k>W_k>W_k>W
_k>W_k>W_k>W_k>W_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_k>W_k>W_k>W_k>W_k>W_k>W_k>W_k>W
_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_kFT_[BR_[BR_[BR_[BR
_kFS_kFS`;JT`;JT`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS
`KFS`KFS`KFS`KFS`KFS`KFS`KFS`KFS`;BR`;BR`;BR`;BR_k>Q_k>Q_k>Q_k>Q`;BR`;BR`;BR`;BR
`;BR`;BR`;BR`;BR_[:P_k>Q_k>Q_K6O^jnM_;2N_[:P_k>Q`;:Pa;JT_k:RZZ:AQh9cI65CC4Xo@T8f
;CXb7BPU4a`O6B8V92X_:C0c<c`i?TQ2D5I;EUe>FfA@G6M=FFE9FFA:GVQAHfaGIFeFHVI=K6mEK6iH
HVUJ@U1>73<k:DEF<E9QCg1oO9^ZVkS7XK[:WkK6ZKg>^/cMVk2bLhB0IW1SK7=NHf]DEF5=BE]>=Ti4
6DU=7dmC851D6d]?6Da?8EAG95UL8eQK:C/l:C`i>Ti2DVEBF6]BDV56Df16GfY@I7II?ThgMX9fHVYY
8bT^HVQ_X:J]TiVNLWUlHVYYI6mUBeM;?TTo:c<c00<A30dQ0`dN000<00P>7b`Z?D]0?Thl>4Pa=TL/
?Tm4?De2?D]0?dPn?THl@4<j@44h@3hf>cdaBDTmGUe?M71NQh1]VXmkZYf7/jF>]ZjG^K6J_K>K_[>H
^jnC^Zb?^J^>_:f=^ZnC^ZnC^ZnC^:fA]Z^?]jb@^ZnC_K:F^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC
^ZjB^ZjB^ZjB^ZjB^jnC^jnC_;2D_;2D^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC^jnC_;2D
_;2D_K6E_K6E_K6E_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D
_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D_;2D^jnC^jnC^ZjB^ZjB^ZjB^ZjB^ZnA^ZnA^ZnA^ZnA
^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA^ZnA_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?
_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?_Zn?
_Zn?_Zn?_Zn?_Zn?_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=^jb<_:f=_Jj>_Jj>_Jj>_Jj>_:f=^jb<
_Jj>_Jj>_:f=^jb<^jb<_:f=_Jj>_Jj>_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:j:_:j:_:j:_:j:
_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:b7_Jf8_Zj9_Zj9_Zj9_Zj9_Jf8_:b7
_Jf9_Jf9_Jf9_Jf9_Jf9_Jf9_Jf9_Jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^Zb8^Zb8^Zb8^Zb8
^Zb8^Zb8^Zb8^Zb8_:b7_:b7_:b7_:b7_:b7_:b7_:b7_:b7^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6
^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^7^j^7^j^7^j^7^j^7^j^7^j^7^j^7^ZZ5^ZZ5^ZZ5^ZZ5
^ZZ5^ZZ5^ZZ5^ZZ5^j^7^ZZ6^JV5^JV5^JV5^JV5^ZZ6^j^7^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5
_Zj9_Jf8^ZZ5^:R3]jN2]jN2^:R3^:R3]:>2]ZF4^:N6_:^:_Zf<_Jb;^:N6]:>2PgeJLg5?HVE5GF95
G699GF=<HVAAIfMEKfmMKViLK6aJK6aJKViLLW9PMWITNGUWOGi^OGi^OWm_P85aPH9bPhAdQ8EeQ8Ee
Ph=cRXYjT920TI61T920UIF5XJ6A[:bL[;:OWZBCX:JEVj2A/KJWVIfA[;2UYJVNY:RMWZ:G^kndZjnT
]k^`XJFJY:RMYJVNZZZNXJ>GZZ^Q/[>ZYJROWj6K[[:/`/K1f=_Bf]gD`LBk[K2WZjjUXZFL/[F/_/6h
/[:V/kN[[KFZ[KJ/^/>ia/g6dM?=gmcH]KZa[[>Z/KJ]ZZfT^[^bgn3GemG=]K>[]KJ/]KJ/];F[];F[
/kBZ/kBZ/kBZ/kBZ[k2V/[>Y]KJ/][N]]KJ/];F[]KJ/][N]^;V_^;V_^KZ`^KZ`^[^a^[^a^[^a^[^a
^KZ`^[^a^[^a^[^a^kbb^kbb^kbb_;fc_;fc_;fc_;fc_Kjd_Kjd_Kjd_[ne_[ne`<2b_[ne_;nf^kni
_/2j`/2haL6fb<6b`KZO_;BF^Zj<_Zf6`k68`k>9_Zn8^:^5`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8
`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8_jj7_jj7`:n8`K29`[6:`[6:`K29`K29`Jn6`Jn6`Jn6`[27
`[27`[27`[27`[27`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8`K29`K29`K29`[6:`[6:`[6:`k:;
`:j9`:j9`Jn:`[2;`k6<a;:=aK>>aK>>`[6:`[6:`[6:`[6:`[6:`[6:`[6:`[6:`Jn:`Jn:`Jn:`Jn:
`Jn:`Jn:0031/jO1/jO1/jO1/jO1/jO1/jO2]:S2]:S2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[2]Z[0]:S0
]:S0]:S0]:S0]:S0]:S0]:S0]:Ro/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNo
/jNo/jNo/jNm/JFm/JFn/ZJn/ZJn/ZJo/jNo/jNo/jNn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJo/jNo
/jNo/jNo/jNo/jNo/jNo/jNo/jNn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn]:>n]:>n]:>n]:>n]:>n
]:>n]:>n]:>n/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>n]:>n
]:>n]:>n]:>n]:>n]:>n]:>n]:>m/j6m/j6n]::n]::n]::o]J>o]J>o]J?0]:;0]:;0]:;0]:;0]:;0
]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]:;0]::o/j6o
/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6l/9jm/Io0]:;0]::m/Ini
[I^i[I^l/9k3]:6o[ijl[Ybo/j6n]:>YXI22NfaPFda7Cd@a>BlV;2La=S@nAD91B4=4CD=:DdU<DdI>
ETE@FDAAG49CGTAFH4UJHdiNIe=SJeANHTUVJDmWJU5QJEQ3Dd`H<3HL>DLdEfEJOH]lWJb;Z;NH//:X
`M6W_/jI[KjR^;IWO7ABHU5NIe9KI4YMIe1NKEQ<GTd]BTLgE54jFEHcE50[C4PYC4P^DdleFUHkCd=8
Fda@Hdi>HDI:G3m<Fcm@GD=AGTIBI4E?H4EPKUaGHUYFGUe>E5U@EUfIWjJ7Ri1iOWmiP7]GGeQ3BTD_
=3L210l92AT51al000h00a8S:C10ATE1BT0jA3@iA30^?30^?30`>Rha=b`i>S1;ASePFE1aJ5n3P7:>
RgbQVXV_YI>gZIJl[9G1/9K5/IRdYhfeZ8jfZHngZhniZhnl[Y71/IC4]9NfZhnh[I6j[i>k/9Bj[i>i
[Y:k/9Bm/YJj[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:i[I6i[I6j[Y:j[Y:j[Y:k[i>k[i>k[i>j[Y:j
[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:k[i>k[i>l/9Bl/9Bl/9Bk[i>k[i>k[i>k[i>k[i>k
[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k[i>k
[i>k[i>j[Y:j[Y:j[Y:i[I6i[I6i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i
[Y2i[Y2i[Y2m[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xfm[Xfm[Xfm[Xfm[Xfm[Xfm[Xfm[Xfm[Xjm
[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjm[Xjl[Hfl[Hfl[Hfl[Hfl[Hfl
[Hfl[Hfl[Hfk[8bk[8bl[Hfm[Xjm[Xjl[Hfk[8bk[8bm[Xjl[Hfk[8bk[8bk[8bk[8bl[Hfm[Xjl[Hfl
[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl
[XZl[XZl[XZl[8Nl[8Nm[HRn[XVn[XVm[HRl[8Nl[8Nm[HVm[HVm[HVm[HVm[HVm[HVm[HVm[HVk[HVk
[HVk[HVk[HVk[HVk[HVk[HVk[HVj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rl[8Nl[8Nl[8Nl[8Nl[8Nl
[8Nl[8Nl[8NkZhJkZhJjZXFjZXFjZXFjZXFkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhNk
ZhNkZhNkZhNkZhNkZhNkZhNkZhNjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXJjZXJiZHFhZ8BhZ8Bi
ZHFjZXJjZXJiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBl[8Nl[8Nl[8Nm[HRm[HRn[XVn[XVo[hZmZXNl
ZHJkZ8FkZ8FkZ8FiYX>fXh2cX7fZXG^GTFb1P5icN5U]M5U]LeacMF9iNFUmOFenOVioOfn1PG63Pg>5
QGF7QgN8R7R<Sh2<Sh2=T86=T86>TH:>TH:?TX>?TX>?SX2EU8JIV8ZFUHNAT8:AT8:JVH^SXYBVZibY
[YnZ[j2b]Z[3akb[[jBj_KBZ[JBb]Z^QYIZl`;Ff^Zo5bKjh_;6Z[Z>]/JJm_;:][::^[jJc]ZfWZjFW
[JR`][6[/Zfc]JoEem6n`;Z][jVUYj6WZJ>`/ZbUYj6d^:fSZIja^[2U/:I[MViTJfJRYZ7Bdlo0b;j_
]jf>ThY7C4=IG5>l_KCCe<^g^:ne]Zbe]Zbe]Zbd]J^d]J^c]:Zb/jVb/jVb/jVd]J^f]jff]jfe]Zbe
]Zbf]jfh^Jnh^Jnh^Jnh^Jni^[2i^[2i^[2j^k6j^k6i^[2i^[2i^[2j^k6j^k6k_;:k_;:k_;:k_;:k
_;:l_K>l_K>l_K>m_[Bm_[Bm_[Bm`;2l`;Bj_kJh_kRk_kVo`;O4`[S9`kK3_jNn]ibj[hnn[XW2/H[3
/hW0[hRjZXG0[hS0[hS0[hS0[hS0[hS0[hS0[hS0[hS0[hS0[hS0[hS0[hS0[hS0[hS0[hS0[hRn[HJn
[HJo[XO0[hS1/8W1/8W0[hS0[hS1[hK1[hK1[hK1[hK1[hK0[XG0[XG0[XG0[hS0[hS0[hS0[hS0[hS0
[hS0[hS0[hS0[hS0[hS0[hS1/8W1/8W2/H[2/H[2/HZo[HS0[XW1[h[2/8_3/Hc4/Xg4/Xg5/hk1/8W1
/8W1/8W1/8W1/8W1/8W1/8W1/8W2/8_2/8_2/8_2/8_2/8_2/8/00<2bY/2bY/2bY/6cYl6cYl6cYl:d
Z<:dZ<6eZL6eZL6eZL6eZL6eZL6eZL6eZL6eZL2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ<2dZ;ncYkncYknc
YkncYkncYkncYkncYkncYkncYkncYkncYkncYkncYkncYkncYkncYkfaYKfaYKfaYKfaYKjbY[jbY[nc
YkncYkjbY[jbY[jbY[jbY[jbY[jbY[jbY[jbY[ncYkncYkncYkncYkncYkncYkncYkncYkjbY[jbY[jb
Y[jbY[jbY[jbY[jbY[jbY[jdXkjdXkjdXkjdXkjdXkjdXkjdXkjdXkjbY[jbY[jbY[jbY[jbY[jbY[jb
Y[jbY[jdXkjdXkjdXkjdXkjdXkjdXkjdXkjdXkjdXkjdXkjdXkjdXkjdXkjdXkjdXkjdXkfcXKfcXKfc
XKfcXKjdX[jdX[neXkneXl2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX/2d
X/2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX/2dX[jbX;jbX;jbX;jbX;ncXKncXKncXL2dX[ncXKncXKnc
XKncXKncXKncXKncXKncXKZ^W;^_WKncXL>gYL:fY;faWkb`W[ncXL2aW[f_W;^]V[^`W<6fX[nfX[2Y
UJ2IQGEgI5MHB3Xj;30b9S4e:SHj;cY0=D97?SY1=417>4QA?DmI@U=MAUAMBE9JBE5HBeMQD5ELAemS
BUaPAeiTDDQHCAdb<aDb=bM>EeIjQ7jQZhVY]9>a_:O1cJc4d:6iaH:JT5Q]GTeNBEYWCeUTBUaWCEe[
DdiNAdEEBTeMDU9SF4aMDSmCAcY>@SeCAdAJCTQKAT]OB4MJ?cmA=4=E>59QAU1LAT=>>SmA=5QYCT=B
?Cm<?VegLDiFEB0W:UUOI96EVYFJWI6GUW1gM55GER/`<`001`002P8050003@H34QlN9cHf=SXl=STj
<3Tk;bP`7cTo;U=DA6MWEgYeIXn6N:BIRk>VV;>/V;F^V[R_VkZ_VKZ]Ukb/UKf[U;j/UKf^U;j_UKn`
U/2aUkj_UKb]TkV[SkNYSKV^T[baUKndV;ndV;fbU[^`U;Z_TkZ_TkZ^T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^
T[Z^T[V]TKV]TKV]TKV]TKZ^T[Z^T[^_Tk^_TkZ^T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^T[Z^T[V]TKV]TKZ^
T[Z^T[Z^T[^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_Tk^_
Tk^_TkV]TKV]TKZ^T[Z^T[Z^T[^_Tk^_Tk^_Tk^_Tk^_TkZ^T[Z^T[V]TKV]TKV]TKV]TKV^T;V^T;V^
T;V^T;V^T;V^T;V^T;V^T;V^T;V^T;V^T;V^T;V^T;V^T;V^T;V^T;f^S[f^S[f^S[f^S[f^S[f^S[f^
S[f^S[f^SKf^SKf^SKf^SKf^SKf^SKf^SKf^SKf^S[f^S[f^S[f^S[f^S[f^S[f^S[f^S[f^S[f^S[f^
S[f^S[f^S[f^S[f^S[f^S[^/S;^/S;^/S;^/S;^/S;^/S;^/S;^/S;Z[Rk^/S;b]SKb]SKb]SKb]SK^/
S;Z[Rkb]SKb]SK^/S;Z[RkZ[Rk^/S;b]SKb]SK^/S;^/S;^/S;^/S;^/S;^/S;^/S;^/S;^]RK^]RK^]
RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^]RK^[Q[b/Qkf]R;f]R;f]R;f]R;b/
Qk^[Q[b/R;b/R;b/R;b/R;b/R;b/R;b/R;b/R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;V[QkV[QkV[
QkV[QkV[QkV[QkV[QkV[Qk^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[ZZQKZZQKVYQ;VYQ;ZZQKZZ
QK^[Q[ZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQKZZQKZZ
QKZZQKZZQKZZQKZZQKZZQKZZQ[VYQKVYQKRXQ;RXQ;VYQKVYQKZZQ[VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VY
Q;VYQ;:ROK>SO[FUP;NWP[RXPkRXPkRXPkRXPkBTOk>SO[:ROKFUP;ZZQKj^RKn_R/2`Rl:dR[2VOY^H
LXj?KhB7KGn2K8>3LHR8N8N7MhV9NHb<O8n?Oi6API6API6API2@P8nDQHnDQHnDQHnDQHnDQI2EQY2E
QY2EQY>BQ9JEQiRGRIJEQi6@PY2?PIFDQY^JS9JMT:V`XiFKT:BZWjJ[XZJZY;k2_;6e[iNLThJ;PYBI
T92ES:BYX<K;`ZjcZZjcZZFTVZRVW[6bZJf_ZJZ`ZkNn^HjGU3U2?da@B/75_mOKeLW=ajR/Y[Jj]<kB
c;o3_LoEb[c4^];Mdk;1^DECCC0j=92ETn;UhlcEbkg5^hfERb8W7Rhc:[6dZmOHckbm];Ff[;Ff[;Be
Zk>dZ[6bZ:n`YZb]Xj^/XZb]Xjn`Y[6bZ;>dZ[>dZ[BeZkNh[[Zk/KNh[[Ri[kRi[kRi[kVj/;Vj/;Vj
/;Vj/;Vj/;Vj/;Vj/;Vj/;Zk/KZk/KZk/K^l/[^l/[^l/[^l/[bm/kbm/kbm/kfn];fn];c0[Kc1/[S0
]KRo^;Nm^;^m]l?1]lO3^<?2[/2lY;jdU[naSL:aR/:bR<2_R;b]Q[n^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^
Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkf/QKf/QKn^Ql2_R<2_R<2_R;n^Qkn^Ql6_Q/6_Q/2^
QL2^QL2^QKn]Q;n]Q;n]Q;n^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Qkn^Ql2_R<2_R<2_R<2_R<6`RL6`RL6`
RL:aR/2^RL2^RL6_R/6_R/:`Rl>aS<>aS<>aS<6`RL6`RL6`RL6`RL6`RL6`RL6`RL6`RL6_R/6_R/6_
R/6_R/6_R/6_RP00_k6U_k6U`;:V`;:V`K>W`K>W`[BX`[BX`KFY`KFY`KFY`KFY`KFY`KFY`KFY`KFY
`;BX`;BX`;BX`;BX`;BX`;BX`;BX`;BX_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V
_[:V_[:V_[:V_[:V_;2T_;2T_K6U_K6U_[:V_[:V_[:V_[:V_K6U_K6U_K6U_K6U_K6U_K6U_K6U_K6U
_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_K6U_K6U_K6U_K6U_K6U_K6U_K6U_K6U_K>R_K>R_K>R_K>R
_K>R_K>R_K>R_K>R_K6U_K6U_K6U_K6U_K6U_K6U_K6U_K6U_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R
_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_;:P_;:P_K>Q_K>Q_[BR_[BR_[BR_[BR_k>Q_k>Q_k>Q_k>Q
_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q
_K6O_K6O_K6O_[:P_k>Q_k>Q_k>Q`;BR_[:P_[:P_[:P_[:P_[:P_[:P_[:P_[:P_[:P^ZjL_;2N`[JT
`kNU_[:P_K6O`;BR^:ZG`;FQ`kRT^k2J/JVB]ZjG_kNP`kfV`kjUZjN?R8I^JFEBDTm0@d4f?3Xb>cPc
>T0e?dHiADdlBE8nBeA0BE11B4i3Ada3@e55BeE5EUe8DEDlEUe8Cea<9c`d7SHd:4mGAVeeKY>KQjRa
RjZcRjRaTJbfW;FoHWISDFA?DF59FFI<E696DEi4D5i6BUM1Bea7CEi9CUm:Bea7B5M2A5<nAUE0BUU4
@eHm@U<h?U0c?4h_A5<gBUQ0AU90@4Xj>d/c?Thg=dHa@4dmB5A8B59<@TY99bl_HVEZR8^@TIFFSI6B
MWYkAdY?828Z10D?0P031`@650l@924M=S@ZAT<eCT/lDdlmNGMORHE]W9R0[ZJ?]jbF^:^E]JRB]:J@
]jbA]JZ?/ZN</jN?]JVA^:^E^ZfG^ZfG]ZV?]jZ@^J^D_:jG_[2I_k>K_[6K_K2J^ZnC_;6E_[>G_K:F
^k2D^JjB^JjB^ZnC^JfA^JfA^JfA^JfA^JfA^JfA^JfA^JfA^:b@^:b@^JfA^JfA^ZjB^ZjB^ZjB^ZjB
^JfA^JfA^JfA^JfA^JfA^JfA^JfA^JfA^:b@^JfA^JfA^JfA^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB
^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^ZjB^:b@^:b@^JfA^JfA^ZjB^ZjB^jnC^jnC
^ZjB^ZjB^ZjB^ZjB^JfA^JfA^:b@^:b@^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?
^:f?^:f?^:f?^:f?_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:j:_:j:_:j:_:j:_:j:_:j:_:j:_:j:
_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=_:f=^jb<^jb<^jb<^jb<
^jb<^jb<^jb<^jb<^Z^;^jb<^jb<_:f=_:f=^jb<^jb<^Z^;_:f=^jb<^jb<^Z^;^Z^;^jb<^jb<_:f=
^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9
^jf9^jf9^jf9^jf9^j^6_:b7_:b7_Jf8_Jf8_:b7_:b7^j^6_:b8_:b8_:b8_:b8_:b8_:b8_:b8_:b8
^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^J^7^J^7^J^7^J^7^J^7^J^7^J^7^J^7^j^6^j^6^j^6^j^6
^j^6^j^6^j^6^j^6^j^6^ZZ5^JV4^:R3^:R3^JV4^ZZ5^j^6^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5
^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ6^JV5^:R4^:R4
^:R4^:R4^JV5^ZZ6^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4_Jf8_:b7_:b7^j^6^ZZ5^j^6^j^6^j^6
_:n9^Zf7^:^5^:^5^:^5^Jb6]jZ4]JR2`:f2^:QnZj9lXiimUYEiS8]fS8QfT8]lSHanSXeoT8n1TY63
TY63TY63TY63TI22SY:6SY:6SY:6Si>7Si>7T9B8T9B8T9B8U9:7UI>8UYB9U9:7Ti66Ti66UI>8V9J;
W::GSI>8D5E<MgacI6QRJ6aWV9bG`LG0GfAKNGieR8f4LGI]JVmV_L:iZ:fTZZnV`l2hcL_3gMgGe=SB
cmG@f^?PWJRU9S@`>Cdh][ZedmOBf=cGZZjYZZjYd=C?f=cGb];8a<g3a=79WZfUBUQB;CPeKGAa];Vg
cmS>aLk4XJVO;cL]=c`c^Kbce]W@_;nf/kBZ];F[];F[/kBZ/[>Y/;6W[JjT[:fS[:fS[ZnU/;6W/K:X
/K:X/kBZ][N]^;V_]kR^]kR^^;V_^;V_^;V_^KZ`^KZ`^KZ`^;V_^;V_^KZ`^KZ`^KZ`^[^a^[^a^[^a
^[^a^kbb^kbb^kbb_;fc_;fc_;fc_Kjd^/6/^/:a^<2e][jg];Ze^K^e`;jfa/6h`l>a`[nZ`[ZM`;BB
`;6:`;26`:n8`K29_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7_jj7
_:^4_Jb5_Zf6_jj7_jj7_jj7_jj7_Zf6`:j5`:j5`:j5_jf4_jf4_Zb3_Zb3_Zb3_jj7_jj7_jj7_jj7
_jj7_jj7_jj7_jj7_jj7_jj7`:n8`:n8`:n8`K29`K29`K29`Jn:`Jn:`Jn:`Jn:`Jn:`[2;`[2;`[2;
`:n8`:n8`:n8`:n8`:n8`:n8`:n8`:n8_jf8_jf8_jf8_jf8_jf8_jf8002o/JFo/JFo/JG0/ZK1/jO1
/jO2]:S2]:S1]JW1]JW1]JW1]JW1]JW1]JW1]JW1]JVo/jNo/jNo/jNo/jNo/jNo/jNo/jNo/jNn/ZJn
/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJl/:Bl/:Bm/JFm/JFm/JFn
/ZJn/ZJn/ZJm/JFm/JFm/JFm/JFm/JFm/JFm/JFm/JFn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJm/JFm
/JFm/JFm/JFm/JFm/JFm/JFm/JFm/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/JFm/JFm/JFm/JFm/JFm
/JFm/JFm/JFm/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:l/Z2l
/Z2m/j6m/j6m/j6n]::n]::n]::o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o
/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6l/9jm/Inm/Inn/Z2n/Z2o/j6o/j70]::n/Z2n
/Z2n/Z2n/Z2n/Z2n/Z2n/Z2n/Z34^:Jl/9ji[I^n/Z30]::k[ifi[I^l/9jk/Yjm]:2k/ibf[YNh/9Vn
]ijj]Ibb[IBbZXbj/YFj/iRZY8f?RGI`JUmCCDI0>cPk@3Lk@CHj@C8i@C0i@34mA3M3Ad58C4LdACa3
Cd=AFTI7CCI>ESmBGT`b@cPX?STbFei:LgISRHecV9b6YZ^9Yja[R8e3H6E3ESe6ESi;FSm=Fcm:F3a8
EC]:F41;Fd@oF3hlDSThCSDjCcHnDCQ0D3Q2D3Q2D3PgB2dhBRdoDC98F3U2DCDgA2hiA3A5Cd<gAc0i
B3<fAC11Ccdb?c53CTAXLV`i@D0H6R9LGfAmP8BPXjNRYJUjOH9TIVi3A4hT8QLf<RM8ACMKEdE`K5V=
R7>QWHF[YXfi/IBe[I2cZ8bbYh^fZXjh[92i[I6k[I6m/Y:j[i6h[92i[Y>j/9Rk/9Ze[9RaYiFn/9Vj
[9FeYi2aY8jbYHncZ9BfZiNg[9RfZhng[92h[I6g[92fZhng[92j[i>m/YJi[I6i[I6i[I6i[I6i[I6i
[I6i[I6i[I6h[92h[92i[I6i[I6i[I6j[Y:j[Y:j[Y:i[I6i[I6i[I6i[I6i[I6i[I6i[I6i[I6h[92h
[92h[92i[I6i[I6j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j[Y:j
[Y:j[Y:j[Y:gZhnh[92h[92i[I6i[I6j[Y:j[Y:k[i>j[Y:j[Y:j[Y:i[I6i[I6i[I6h[92h[92h[Hnh
[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnl[Hfl[Hfl[Hfl[Hfl[Hfl
[Hfl[Hfl[Hfl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[XZl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl
[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfk[8bk[8bk[8bk[8bk[8bk[8bk[8bk[8bjZh^k[8bk[8bl[Hfl[Hfk
[8bk[8bjZh^l[Hfk[8bk[8bjZh^jZh^k[8bk[8bl[Hfk[8bk[8bk[8bk[8bk[8bk[8bk[8bk[8bk[HVk
[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVk[HVkZhJkZhJl[8Nm[HRm[HRl
[8NkZhJkZhJl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rl[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8Rj[8RiZhNi
ZhNiZhNiZhNiZhNiZhNiZhNiZhNkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJjZXFiZHBhZ8>hZ8>i
ZHBjZXFkZhJjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXFj
ZXFjZXFjZXFjZXFjZXFjZXFjZXFiZHFiZHFhZ8BgYh>gYh>hZ8BiZHFiZHFhZ8>hZ8>hZ8>hZ8>hZ8>h
Z8>hZ8>hZ8>iZHBhZ8>fYX6eYH2fYX6iZHBl[8Nn[XVdZH>dZH>dZH>fZhFh[HNh[HNeZXBcZ8:lYGRi
YGbfZH>`ZHRTX8BGTWfBRgZDS7n@Sh6@Sh6?SX2?SX2@Sh6@Sh6AT8:AT8:=THF=THF>TXJ?ThNAUHVB
UXZCUh^CUh^GUHZGUHZFU8VEThREThREThRFU8VGUHZ>UX]bNW18D4Ji`;VGWIQPIV5[L6j^/k58CdRD
ViB_]ZmlPga9D4V`]k2OYYnW[ZN]ZZ:TXYZYZJ>JWYV7SXV@VII_OGTM:RPJ81]aMg:CVICLh]g1al:4
RXERJ6=:D4]3Bd59E4XlBd<]?CHS<b`F920Y<RmGG5_<eL^ka;ZHXILW;bD[<2NX[JC9c<>k_[F`/JNa
/ZRc]:Ze]Zbf]jfe]Zbd]J^d]J^b/jVc]:Zc]:Zb/jVa/ZRa/ZRc]:Ze]Zbg^:jg^:jg^:jh^Jnh^Jnh
^Jni^[2i^[2h^Jnh^Jnh^Jni^[2i^[2j^k6j^k6j^k6j^k6j^k6k_;:k_;:k_;:l_K>l_K>l_K>j`Jbj
`[6h`KBe_KJc^KBg^;Bo_;O5_kS3a;C3`Zg4_J;2]YBo/8Vo[hG0[hS3/X^o[XNo[XNo[XNo[XNo[XNo
[XNo[XNo[XNo[XNo[XNo[XNo[XNo[XNo[XNo[XNo[XNlZhBlZhBn[HJn[HJo[XNo[XNn[HJn[HK0[XG0
[XG0[XFo[HBn[8>n[8>mZh:mZh:o[XNo[XNo[XNo[XNo[XNo[XNo[XNo[XNo[XNo[XNo[XO0[hS0[hS1
/8W1/8W1/8W2/8_2/8_1[h[1[h[1[h[1[h[1[h[1[h[0[hS0[hS0[hS0[hS0[hS0[hS0[hS0[hRn[8Nn
[8Nn[8Nn[8Nn[8Nn[8L00<:eYL:eYL:eYL:eYL:eYL:eYL:eYL:eYL2bY/2bY/2bY/2bY/2bY/2bY/2b
Y/2bY/:dZ<:dZ<:dZ<:dZ<:dZ<:dZ<:dZ<:dZ;jbY[jbY[jbY[jbY[jbY[jbY[jbY[jbY[nbX[nbX[nb
X[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[naYKnaYKnaYKnaYKnaYKnaYKna
YKnaYKfcX[fcX[fcX[fcX[fcX[fcX[fcX[fcX[fcX[fcX[fcX[fcX[fcX[fcX[fcX[fcX[nbX[nbX[nb
X[nbX[nbX[nbX[nbX[nbX[bbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKnbX[nbX[nbX[nbX[nbX[nbX[nb
X[nbX[jbX;jbX;ncXKncXL2dX/2dX/2dX/2dX[ncXKncXKncXKncXKncXKncXKncXKncXKncXKncXKnc
XKncXKncXKncXKncXKncXKfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkjbX;jbX;jbX;jbX;jbX;jbX;jb
X;jbX;jcWkjcWkjcWkjcWkjcWkjcWkjcWkjcWkfbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[fbW[fb
W[fbW[fbW[fbW[fbW[fbW[baWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKJ[Uk>XU;J[UkZ_VkFZUZFJ
QYR=NEeGC5=?A4I4>S`k<CLh;cXl=Sm3?DE9@d96>d96>cm7?3m9?Ca:?SY<?cU=@3M>@4=NFdQSH4eX
I51/ITi[HTMUFSiLCcQGB4M@?4M@?4I?>dI?>dE>>TA=>DA=>DA=>DI@>DE>>DA=>49;=d18=ci6=Ca3
=3a3=3Q4>3Y4>3Y4>3Y2=c]1=S]1=Sa0=Ca0=B@k<bHk<bPj<bXh<Rhh<S<j=Ca0>d14?dU9@d=0>dU7
?fYXGYFCR:j[WJRUUYVDQJfRQjjSR;6VRk>XSKFZSkN/TKN/TKR]T[N/TKN/TKN/TKN/TKN/TKN/TKN/
TKN/TKV^TkV^TkV^TkV^TkV^TkV^TkV^TkV^TkR]TKR]TKR]TKV]TK^]TK^]TKf/TKf/TKZ^T[Z^T[V]
TKR/T;R/T;V]TKZ^T[Z^T[Z_TKZ_TKZ_TKZ_TKV^T;V^T;R]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]
SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkV^T;Z_TKZ_TKZ_TKZ_TKV^T;R]SkV^T;V^T;V^
T;V^T;V^T;V^T;V^T;V^T;^`T[^`T[Z_TKZ_TKV^T;R]SkR]SkR]SkV^T;V^T;V^T;V^T;V^T;V^T;V^
T;V^T;N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[^[S[^[S[^[S[^[S[^[S[^[S[^[S[^[S[Z[RkZ[Rk^/
S;^/S;^/S;b]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKb]SKVZR[Z[RkZ[Rk^/S;^/S;b]SKb]
SKf^S[^/S;^/S;^/S;^/S;^/S;^/S;^/S;^/S;Z[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[Rk^]RK^]RK^]
RK^]RK^]RK^]RK^]RK^]RKb/R;b/R;b/R;b/R;b/R;b/R;b/R;b/R;V[QkV[QkV[QkZ/R;Z/R;^]RK^]
RK^]RKb/R;b/R;b/R;b/R;b/R;b/R;b/R;b/R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;f]RKb/R;b/
R;^[Qk^[Qkb/R;b/R;f]RKb/Qkb/Qkb/Qkb/Qkb/Qkb/Qkb/Qkb/Qk^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[
Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[^[Q[ZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZ
QKZZQKZZQKZZQKZZQKZZQKVYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VY
Q;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;RXPkRXPkRXPkRXPkVYQ;VYQ;VYQ;ZZQKVYQ;VYQ;VY
Q;VYQ;VYQ;VYQ;VYQ;VYQ;NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[VZPkVZPkVZPkVZPkVZPkVZPkVZ
PkVZPkVZPkVZPkVZPkVZPkVZPkVZPkVZPkVZPkb/PKV[PKRYP[NYQK:WQjbRQ:BIOY^BMh^<N92@OYFE
PiFFQY:BQ92@Q96@QYBCRI6DQI6DQI6DQI:EQY:EQY:EQY>FQi>FQi6DQI6DQI6DQI6DQI6DQI2CQ92C
Q92CQ8fGQgj7NU9KCUEMDTI>@ca4>YBLT[c3_7AkN3Hm>U]RGDY@Be5ECl_@ajnbZK>f[DYIEBdl>2<a
:aPU7CQ3>B@^8QDN4B<Z6aLO5B/`9gn2NL?6_KBi/82;PA8R5b8f:R<W7457?2`f:QHP52H`92H/8CLf
;6i/H/k6_jbaZ9b]XRDe:RP]9:JSVm[Kd[O0][Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[:j`Y:naYK6c
Yk:dZ;:dZ;6cYk2bYZnaYKRi[kNh[[Nh[[Nh[[Ri[kVj/;Zk/K^l/[Ri[kRi[kVj/;Vj/;Vj/;Zk/KZk
/KZk/KZk/KZk/K^l/[^l/[bm/kbm/kbm/kbm/kfn];fn];fn];fn];jo]Kjo]Ko0][o0]/C4^<G5^L71
/kZhY[:]U;FYQkj]P/NcPkj]Q[j]Q[j]Q[j]Q[j]Q[j]Q[j]Q[j]Q[n]Q;n]Q;n]Q;n]Q;n]Q;n]Q;n]
Q;n]Q;n]Q;n]Q<2^QL2^QL2^QL6_Q/6_Q/6_Q[n]Q;n]Q;n]Q;n]Q;n]Q;n]Q;n]Q;n]Q;j/Pkj/Pkj/
Pkn]Q;n]Q<2^QL2^QL2^QKj/Pkj/Pkj/Pkn]Q;n]Q;n]Q<2^QL2^QL>bRl:aR/6`RL2_R;n^Qkn^Qkn^
Qkn^Qkf/QKj]Q[n^Ql6`RL6`RL2_R;n^Qkj]Q[n^Qkj]Q[j]Q[j]Q[j]Q[j]QP00`KBT`KBT`KBT`KBT
`KBT`KBT`KBT`KBT`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V`K>W`K>W`K>W`K>W`K>W`K>W`K>W`K>W
_[:V_[:V_[:V_[:V_[:V_[:V_[:V_[:V_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R
_k:R_k:R_k:R_k:R_k6U_k6U_k6U_k6U_k6U_k6U_k6U_k6U_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R
_K>R_K>R_K>R_K>R_K>R_K>R_K>R_K>R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_;:Q_;:Q_;:Q_;:Q
_;:Q_;:Q_;:Q_;:Q_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_[:P_[:P_k>Q_k>Q_k>Q`;BR`;BR`;BR
_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_k>Q_K6O_K6O_K6O_K6O
_K6O_K6O_K6O_K6O_[:P_[:P_[:P_[:P_[:P_[:P_[:P_[:P_[>O_[>O_[>O_[>O_[>O_[>O_[>O_[>O
_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_;6M_;6M_;6M_;6M
_;6M_;6M_;6M_;6M_[>O^ZnK^:fI^k2L_kBP_kBP^:fI/JJB[jRIWYN8PG]^HUiCBdTn?chd?3/a>c`c
>SX^>CT]>3X^=Sd`=d4d>dPj?Tdo@553;44n;dE0<dU4=Te5=De3<DTm;4Dg:D8d?4`j?4`j?4`j?4`j
?4`j>d/i>d/i>d/i=4H_=4D`=4D`=4@b<d<a<d<b<d<b<d8d<D8d;d0b;Sd_:cX/:3DW9c4T92hQ8R`O
93DX9cDY:CDY:S8W:c4V<C8X=cH/>cT_DU16FeU?KFUNPWa_ThioXIZ9Z:6@ZjBA/ZN</jR=]JZ?]jbA
^JjC^ZnD^ZnD^ZnD]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA^JjC^JjC^JjC^JjC^JjC^JjC^JjC^JjC
^:fA^:fA^:fA^JfA^jfA^jfA_JbA_JbA^ZjB^ZjB^JfA^:b@^:b@^JfA^ZjB^ZjB^ZnA^ZnA^ZnA^Jj@
^Jj@^Jj@^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?
^:f?^Jj@^ZnA^ZnA^ZnA^ZnA^Jj@^:f?^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^k2B^ZnA^ZnA^Jj@
^Jj@^:f?^:f?^:f?^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@^Jj@]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>
^j^>^j^>^j^>^j^>^j^>^j^>^j^>^j^>^Z^;^Z^;^Z^;^jb<^jb<^jb<_:f=_:f=_:f=_:f=_:f=_:f=
_:f=_:f=_:f=_:f=^Z^;^Z^;^jb<^jb<^jb<^jb<^jb<_:f=^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jb<
^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^jf9^jf9^jf9^jf9^jf9^jf9^jf9^jf9_:b8_:b8_:b8_:b8
_:b8_:b8_:b8_:b8^J^7^J^7^J^7^Zb8^Zb8^Zb8^jf9^jf9_:b8_:b8_:b8_:b8_:b8_:b8_:b8_:b8
^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8_Jf9_:b8^j^7^j^7^j^7^j^7_:b8_Jf9_:b7_:b7_:b7_:b7
_:b7_:b7_:b7_:b7^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6
^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^:R3^:R3^:R3^:R3
^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3
]jN2^:R3^:R3^:R3^JV4^JV4^JV4^JV4^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3]jN2]jN2]jN2]jN2
]jN2]jN2]jN2]jN2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2^:V2
_:b1^J^1^:V2]jV5]ZZ8/JJ8ZYn3YIYoTi9mTi9nTi9nTY:0Ti>3U9>5Ti>7Ti:8TIB5TIB5TIB5TIB5
TYF6TYF6TiJ7TiJ7T9>4T9>4TIB5TYF6TYF6TiJ7U9N8U9N8Uij?SYF8=3/^SYB9XjVNG65HCeA;cM7;
MWehKWI_/[VbQHf3AT]2XjNLZ:bPYj^OFFMS0@l94alI?TU1DEY@@Ta0@DXm7bPK8BXPGVILYjZQ`<>j
Z:fTS9F;9SH[2a`AF5aAVJ6F[;JZNhMk@de19R`QGf1Fb<Jlc/Jo[;6XWJjS:SX_:BhUXYnGf]_B]l2f
]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/]KJ//;:V/;:V/K>W/K>W/K>W/;:V/;:V[k6U][N]][N]]kR^^;V_
^;V_^KZ`^KZ`^KZ`^;V_^;V_^KZ`^KZ`^KZ`^[^a^[^a^[^a^[^a^[^a^kbb^kbb_;fc_;fc_;fc_;fc
_Kjd_Kjd_Kjd_Kjd_[ne_[ne_l2f_l2f`/:fa<Bh`/:d_K^Y][6H]Z^;_Jf3aK62_Zf6_Zf6_Zf6_Zf6
_Zf6_Zf6_Zf6_Zf6_jf4_jf4_jf4_jf4_jf4_jf4_jf4_jf4_jf4_jf4_jf4`:j5`:j5`:j5`Jn6`Jn6
_jf4_jf4_jf4_jf4_jf4_jf4_jf4_jf4_Zb3_Zb3_Zb3_jf4_jf4_jf4`:j5`:j5_Zb3_Zb3_Zb3_jf4
_jf4_jf4`:j5`:j5`[6:`K29`K29`:n8_jj7_jj7_jj7_jj7_Jb5_Zf6_jj7`:n8`K29`:n8_jj7_Zf6
_Zf6_Zf6_Zf6_Zf6_Zf6_Zf60031]:C1]:C1]:C1]:C1]:C1]:C1]:C1]:C0/ZK0/ZK0/ZK0/ZK0/ZK0
/ZK0/ZK0/ZK1/jO1/jO1/jO1/jO1/jO1/jO1/jO1/jNn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJn/ZJo/Z:o
/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/JFo/JFo/JFo/JFo/JFo
/JFo/JFo/JFm/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:m/j:o/Z:o
/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:l/Z6l/Z6l/Z6l/Z6l/Z6l/Z6l/Z6l/Z6o/Z:o/Z:o/Z:o/Z:o/Z:o
/Z:o/Z:o/Z:n/Z2n/Z2n/Z2o/j6o/j6o/j70]:;0]::o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o/j6o
/j6o/j6o/j6o/j6o/j6o/j6o/j6m/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inn/Z2n/Z2n/Z2n/Z2n/Z2n
/Z2n/Z2n/Z2n/inn/inn/inn/inn/inn/inn/inn/inm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm
/Yjm/Yjm/Yjm/Yjm/Yjm/Yjm/Yjk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bi[YZg[9Rh[IVk/9bn
/ino]:2n/ini/9bk/Ini/YnaZIROV8N5OVmZI5MKEDQ@BSe;ACQ2?c4i>2Xb=BH^<b@]=2D_=RL`?CDa
?SHd@SLgACXjB3`kBS`kBS`kBS`[?B`[?B`[?B`[?B`[?B`/?Rd/?Rd/?RdY?2LY?2LX>bPW>BPW>BPV
=bTV=bTU=RTP<R4S<b8U=B@Y=RH]>2P_>RXb?2`c?Bd/;alc=RI0@C5?C3eNFDY]IUMiL6:3N6ZFSgjQ
VXV]YIB`ZIJ_YY:aYY:g[9Jn/ifeZXnfZi2g[96i[Y>j[iBj[iBj[iBj[iBg[96g[96g[96g[96g[96g
[96g[96g[96i[Y>i[Y>i[Y>i[Y>i[Y>i[Y>i[Y>i[Y>h[I6h[I6h[I6i[I6k[I6k[I6m[96m[96j[Y:i
[I6h[92h[92h[92h[92i[I6j[Y:j[i6j[i6i[Y2i[Y2i[Y2h[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh
[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hnh[Hni[Y2j[i6j[i6i[Y2h[Hnh[Hni[Y2i
[Y2i[Y2i[Y2i[Y2i[Y2i[Y2i[Y2j[i6j[i6i[Y2i[Y2i[Y2h[Hnh[Hnh[Hni[Y2i[Y2i[Y2i[Y2i[Y2i
[Y2i[Y2i[Y2g[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jkZhjkZhjkZhjkZhjkZhjkZhjkZhjkZhjjZh^j
Zh^jZh^jZh^k[8bk[8bk[8bl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfl[Hfk[8bk[8bk[8bk[8bjZh^j
Zh^jZh^jZh^k[8bk[8bk[8bk[8bk[8bk[8bk[8bk[8biZXZiZXZiZXZiZXZiZXZiZXZiZXZiZXZk[HVk
[HVk[HVk[HVk[HVk[HVk[HVk[HVkZhNkZhNkZhNkZhNkZhNkZhNkZhNkZhNhZXJiZhNiZhNiZhNj[8Rj
[8Rj[8Rj[8RkZhNkZhNkZhNkZhNkZhNkZhNkZhNkZhNiZhNiZhNiZhNiZhNiZhNiZhNiZhNiZhNl[8Rl
[8RkZhNjZXJjZXJkZhNl[8Rl[8RkZhJkZhJkZhJkZhJkZhJkZhJkZhJkZhJjZXFjZXFjZXFjZXFjZXFj
ZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFjZXFiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBi
ZHBiZHBiZHBiZHBiZHBiZHBiZHBhZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>h
Z8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>gYh:gYh:gYh:hZ8>hZ8>iZHBiZHBiZHBhZ8>h
Z8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:hZH:hZH:hZH:hZH:hZH:h
ZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:hZH:iZh6hZX2hZH:gZXBfZXRfZHVaYXR_Y8JOVh:I
UGbDT7RBSW^ETh6HUHJEU8JBT8F@ThB@ThBAU8FAU8FBUHJBUHJBUHJBUHJ?TX>@ThBAU8FBUHJCUXNE
V8VFVHZFVHYoQWN5S7mHGe:W[J:DVXmIGUE>DdZUZJ=/MF]JHUR5SH9cNVe3BSfDVHZf^JZZ[IeePG/E
8A/]>324ShO2bl6g`KF?Uh`c>c0T;B>CVi7=d<Nk_[FQY9^NYYaDHUL<7151AcbMYI[GhMFX]:Q;EDTR
:1e]KVCMg=;>a[n[/:NM[Z<c@cPZ;bJJUhoJfm:g`;Je]Zbe]Zbe]Zbe]Zbe]Zbe]Zbe]Zbe]Zbc]JVb
]:Ra/jN`/ZJ_/JF_/JF_/JF`/ZJc]:Ze]Zbg^:jh^Jni^[2i^[2h^Jnh^Jnh^Jnh^Jni^[2i^[2i^[2j
^k6j^k6j^k6j^k6j^k6k_;:k_;:l_K>l_K>l_K>l_K>m_[Bm_[Bm_[Bm_[Bn_kFn_kFo`;Jo`;K1_kC3
`kO4a;S1_Znl]j:j/9:l[8Nm[86m[8Fm[8Fm[8Fm[8Fm[8Fm[8Fm[8Fm[8Fn[8>n[8>n[8>n[8>n[8>n
[8>n[8>n[8>n[8>n[8>o[HBo[HBo[HC0[XG0[XG0[XFn[8>n[8>n[8>n[8>n[8>n[8>n[8>n[8>mZh:n
[8>n[8>n[8>o[HBo[HBo[HBo[HBn[8>n[8>n[8>o[HBo[HBo[HC0[XG0[XG1/8W1/8W0[hS0[hRo[XNo
[XNo[XNo[XNn[HJn[HJo[XO0[hS0[hRo[XNn[HJm[8Fn[HJn[HJn[HJn[HJn[HJn[HH00<6dY<6dY<6d
Y<6dY<6dY<6dY<6dY<6dY<2bY/2bY/2bY/2bY/2bY/2bY/2bY/2bY/6cYl6cYl6cYl6cYl6cYl6cYl6c
Yl6cYkjbY[jbY[jbY[jbY[jbY[jbY[jbY[jbY[jaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKja
XKjaXKjaXKjaXKjaXKjaXKj`Y;j`Y;j`Y;j`Y;j`Y;j`Y;j`Y;j`Y;bbXKbbXKbbXKbbXKbbXKbbXKbb
XKbbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKbbXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXK^aX;^aX;^a
X;^aX;^aX;^aX;^aX;^aX;jaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKfaWkfaWkjbX;jbX;ncXKncXKnc
XKncXKjbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;jbX;faWkfaWkfa
WkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfbW[fbW[fbW[fbW[fbW[fbW[fb
W[fbW[baWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWK^`W;^`W;^`
W;^`W;^`W;^`W;^`W;^`W;V^V[V^V[R]VKN/V;J[UkN/V;Z_VkbaWK^_Ukb`V;bbV[fbW;baWKV^V[JZ
V;BXUXj3MHMlKWU`HVYSE5YEATm:>dI3=4=0<C`o<3Xm;SLj:cDh:C<f9c<f9S@g9c@g9c0g:30g:30g
:34h:C8i:S8i:S<j:c<j:bH_6bL`72P`7bXa8R`c92he:30g:S4g;3<g93Hj9cm1;TM9=U9B@5aJB6=Q
CfUUDi:;MiN@O:6HQ:^PS;>UT[Z[V;n`WLFdXKjcWK^`V[R^U[Z^U[b^Uk^]U[VYT[FUS[FZSkJ[T;N/
TKR]T[R]T[R]T[N/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKV^TkV^TkV^TkV^TkV^TkV^TkV^
TkV^TkN/T;N/T;N/T;R/T;Z/T;Z/T;b[T;b[T;V]TKV]TKR/T;N[SkN[SkR/T;V]TKV]TKV^T;V^T;V^
T;V^T;R]SkR]SkN/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[N/
S[N/S[N/S[R]SkV^T;V^T;V^T;V^T;R]SkN/S[R]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkV^T;V^T;V^
T;R]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkR]SkJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[
SKJ[SKZZSKZZSKZZSKZZSKZZSKZZSKZZSKZZSKVZR[VZR[Z[RkZ[RkZ[Rk^/S;^/S;^/S;^/S;^/S;^/
S;^/S;^/S;^/S;^/S;^/S;b]SK^/S;^/S;Z[RkZ[RkVZR[VZR[VZR[Z[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[
RkZ[RkVZR[VZR[VZR[VZR[VZR[VZR[VZR[VZR[Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;Z/R;^[Qk^[Qk^[
Qk^[Qk^[Qk^[Qk^[Qk^[QkRZQ[RZQ[RZQ[V[QkV[QkZ/R;Z/R;Z/R;^[Qk^[Qk^[Qk^[Qk^[Qk^[Qk^[
Qk^[QkV[QkV[QkV[QkV[QkV[QkV[QkV[QkV[Qkb/R;^[Qk^[QkZZQ[ZZQ[^[Qk^[Qkb/R;^[Q[^[Q[^[
Q[^[Q[^[Q[^[Q[^[Q[^[Q[ZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZ
QKZZQKVYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;RXPkRXPkRX
PkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRX
PkRXPkNWP[NWP[NWP[NWP[RXPkRXPkVYQ;VYQ;RXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkNWP[NWP[NW
P[NWP[NWP[NWP[NWP[NWP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RYP[RY
P[RYP[V[PKRZP;NXPKNWP[JXQ;NXQkNXQkNXR:^SQJFMP9bENYNANYNBOIJBP9BAPYBAPi2CQ92CQ92C
Q96DQI6DQI6DQI:EQY:EQY2CQ92CQ96DQI6DQI:EQY>FQi>FQi>FQi:GR8Z>PW5eJEUMDSe1=Sm2>HB7
OYnQVj:[WVmhJfA[GW9iJX26MJFXV:ncX:FYUY:JTdaDCADM5S4j<:J_YLkGcJ:ZX3]3>A`U6ijVW=CG
c[Zk/ZNXWjjcZXVBR3i9?a8J46=/H[[5^k[8_FA_IBTa9fMZHMCBb/o7`:^`Yij_Y3e=@R/`9i2=QM_L
dkO0][Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Jh[;BfZ[:dZ;2bYZnaYJnaYK2bY[2bY[6bZ;>dZ[Jg
[KVj/;Zk/KVj/;Nh[[Jg[KRi[kRi[kVj/;Vj/;Vj/;Zk/KZk/KZk/KZk/KZk/K^l/[^l/[bm/kbm/kbm
/kbm/kfn];fn];fn];fn];jo]Kjo]Ko0][o0][nm/l;0]/C3^L?2]<2lZKjeV[Z^S;ZXPkf/QKf/QKf/
QKf/QKf/QKf/QKf/QKf/QKj/Pkj/Pkj/Pkj/Pkj/Pkj/Pkj/Pkj/Pkf[P[f[P[j/Pkj/Pkj/Pkn]Q;n]
Q;n]Q;j/Pkj/Pkj/Pkj/Pkj/Pkj/Pkj/Pkj/Pkf[P[f[P[f[P[j/Pkj/Pkn]Q;n]Q;n]Q;j/Pkj/Pkj/
Pkn]Q;n]Q;n]Q<2^QL2^QKn^Qkn^Ql2_R<2_R<2_R;n^Qkn^Qkj]Q[j]Q[n^Qkn^Qkn^Qkj]Q[j]Q[f/
QKf/QKf/QKf/QKf/QKj]Q[j]Q[j]QP00`;>S`;>S`;>S`;>S`;>S`;>S`;>S`;>S`;:V`;:V`;:V`;:V
`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V_K6U_K6U_K6U_K6U_K6U_K6U_K6U_K6U
_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[2T_[2T_[2T_[2T
_[2T_[2T_[2T_[2T_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q_;:Q
_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q_[6Q^k6P^k6P^k6P^k6P^k6P^k6P^k6P^k6P_[6Q_[6Q_[6Q_[6Q
_[6Q_[6Q_[6Q_[6Q_K6O_K6O_K6O_[:P_[:P_[:P_k>Q_k>Q_[:P_[:P_[:P_[:P_[:P_[:P_[:P_[:P
_[:P_[:P_[:P_[:P_[:P_[:P_[:P_[:P_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O
_K6O_K6O_K6O_K6O_K:N_K:N_K:N_K:N_K:N_K:N_K:N_K:N_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M
_;6M_;6M_;6M_;6M_;6M_;6M_;6M_;6M^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^ZnK_;6M_[>O_K:N
^ZnK^JjJ^ZnK_;6M_K:F_;6F^k2E^ZjF_:jG_JnI_k2M`;6N_ZnO^jbL]:NG[Z6AY9Z9W9:1UH]jShMf
P7]VNgIQLfeJJfEBI5i;GeU6GEM4GEM4DTLiDTLiDdPjDdPjE4TkE4TkEDXlEDXlHEM5HeU7JEm>KfED
MV]MOG5UPWIZQGU]XiF2YIN4ZIZ7[Yn<]JBA_:RF`:bJ`ZjL/ZB=]:J?^JVB^JVB]ZJ?]J><]::;]::;
^JjB/jR</:B8/jJ<_JjD`k:H`:nE^jZ@]Z^@]jbA^:fB^:fB^:fB^:fB]jbA]jbA]jbA]jbA]jbA]jbA
]jbA]jbA]jbA]jbA^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB]jb@]jb@]jb@^:b@^Zb@^Zb@_:^@_:^@
^JfA^:b@]j^?]j^?]j^?]j^?^:b@^JfA^Jj@^Jj@^:f?^:f?^:f?]jb>]jb>]jb>]jb>]jb>]jb>]jb>
]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>^:f?^Jj@^Jj@^:f?]jb>]jb>
^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?^:f?
^:f?^:f?^:f?^:f?]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=
^JZ:^JZ:^JZ:^JZ:^Z^;^Z^;^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jb<^jb<^Z^;
^JZ:^JZ:^:V9^:V9^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:
^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^Zb8^j^7^j^7^j^7^j^7^j^7^j^7^j^7^j^7]jV5^:Z6^:Z6^:Z6
^J^7^J^7^J^7^Zb8^j^7^j^7^j^7^j^7^j^7^j^7^j^7^j^7^J^7^J^7^J^7^J^7^J^7^J^7^J^7^J^7
^j^7^j^7^ZZ6^ZZ6^ZZ6^ZZ6^j^7^j^7^j^6^j^6^j^6^j^6^j^6^j^6^j^6^j^6^JV4^JV4^JV4^JV4
^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^JV4^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3
^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2
]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]ZJ1]ZJ1]jN2]jN2]jN2^:R3^:R3^:R3
]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]jR1]jR1]jR1]jR1
]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1]jR1^J^1^:V2]jR1]ZN0]JF0]JF0^:F2^JJ3
]:J2/JF3Zj20XYYmVI5jU8ikU91nUi:3Si:3Si:3T9>4T9>4TIB5TIB5TIB5TIB5TIB5TIB5TIB5T9>4
Si:3Si:3SY62SY62Ri21VIfATIF9TIF:W:2ESY68TYF<W9jH[KBWZ:nRVJ2CWjBE^Kb/ZJbLX::?[[2M
/KV_Ti^A@DTo3QH<GVIL^/6jaLg6De]D6B@JSYJ<c<o6_;fd/K:Y[k:YYjbSOHIl82LP<CTbPHj6amC<
R9F=8BTRDE==fm_Ed/[3Zk2WWZnTB5Q=:RlVQ85ig=gD^L:h]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/
][R/]KN[/[BX/;:V[k6U[k6U/;:V/K>W[k2V/K:X]KJ/]kR^^KZ`^;V_]kR^][N]^;V_^;V_^KZ`^KZ`
^KZ`^[^a^[^a^[^a^[^a^[^a^kbb^kbb_;fc_;fc_;fc_;fc_Kjd_Kjd_Kjd_Kjd_[ne_[ne_l2f_l2f
`Kbc`Kne`l:haL>ha/6b`[ZS_;6C^:V8_Jb5_Jb5_Jb5_Jb5_Jb5_Jb5_Jb5_Jb5_Zb3_Zb3_Zb3_Zb3
_Zb3_Zb3_Zb3_Zb3_:Z1_:Z1_J^2_J^2_J^2_Zb3_Zb3_Zb3_Zb3_Zb3_Zb3_Zb3_Zb3_Zb3_Zb3_Zb3
_:Z1_J^2_J^2_J^2_Zb3_Zb3_Zb3_jf4_Zb3_Zb3_Zb3_jf4_jf4_jf4`:j5`:j5_Jb5_Zf6_jj7`:n8
`:n8`:n8_Zf6_Zf6_jj7_jj7_Zf6_Zf6_Jb5_Jb5_Jb5_Jb5_:^4_Jb5_Jb5_Zf6_Zf6_jj70030/j?0
/j?0/j?0/j?0/j?0/j?0/j?0/j?0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0/ZK0
/ZK0/ZK0/ZJm/JFm/JFm/JFm/JFm/JFm/JFm/JFm/JFm/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m
/:2m/:2m/:2m/:2m/:2m/:2m/:2m[j>m[j>m[j>m[j>m[j>m[j>m[j>m[j>k/J2k/J2k/J2k/J2k/J2k
/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2k/J2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2j/9nj
/9nj/9nj/9nj/9nj/9nj/9nj/9nm/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2l/9jm/Inm/Inm/Inn/Z2n
/Z2n/Z2n/Z2m/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm/Inm
/Inm/Inm/Inm/Inm/Inm/Inm/Inl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/Ifl/Ifl/Ifl/Ifl/Ifl
/Ifl/Ifl/Ifk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bj[i^j
[i^j[i^j[i^j[i^j[i^j[i^j[i^eZYJh[IVl/Ifm/Yjl/Ifk/9bk/9bl/Ifd[8nh[iBm]9W2]Yk1/ibl
[YRgYY>bXHjk[IZm[ibo/Ik1/j31/j30/Ynm[ibl[Y^m]9Vk/YNg[Y>cZI6aYY2`YHnaYY:bYi>eWhfe
WhffX8jfX8jfX8jfX8jfX8jgXHncWXRdWhVfXHbjY9:mYiG0ZIW3[9c4[IjnZI>nZI?0ZI?1ZYC2ZYC4
ZIC5ZYG5ZYFdYH^hZHnm[YC0/IO1/YS2/iW4]I_6]ifeZhfj/9:o/iNm/9Jl[I>n[9G3/I[9]j2h[I:i
[Y>j[iBj[iBk/9Fj[iBj[iBi[Y>g[96g[96g[96g[96g[96g[96g[96g[96h[I:h[I:h[I:h[I:h[I:h
[I:h[I:h[I:fZhnfZhnfZhngZhniZhniZhnkZXnkZXnh[92h[92gZhnfZXjfZXjgZhnh[92h[92h[Hnh
[Hnh[Hnh[Hng[8jg[8jg[8jfZhffZhffZhffZhffZhffZhffZhffZhffZhffZhffZhffZhffZhffZhff
ZhffZhffZhffZhfg[8jh[Hnh[Hnh[Hnh[Hng[8jfZhfg[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jfZhfg
[8jg[8jg[8jh[Hnh[Hnh[Hnh[Hng[8jg[8jg[8jg[8jg[8jg[8jg[8jg[8jeZXbeZXbeZXbeZXbeZXbe
ZXbeZXbeZXbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbhZHVhZHViZXZiZXZiZXZjZh^jZh^jZh^jZh^j
Zh^jZh^jZh^jZh^jZh^jZh^jZh^jZh^jZh^jZh^iZXZiZXZiZXZiZXZiZXZiZXZiZXZiZXZiZXZiZXZi
ZXZiZXZiZXZhZHVhZHVhZHVhZHVhZHVhZHVhZHVhZHViZhNiZhNiZhNiZhNiZhNiZhNiZhNiZhNjZXJj
ZXJjZXJjZXJjZXJjZXJjZXJjZXJgZHFgZHFgZHFhZXJhZXJiZhNiZhNiZhNjZXJjZXJjZXJjZXJjZXJj
ZXJjZXJjZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJkZhNjZXJjZXJiZHFiZHFjZXJjZXJkZhNjZXFj
ZXFjZXFjZXFjZXFjZXFjZXFjZXFiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBi
ZHBiZHBiZHBhZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>gYh:g
Yh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:g
Yh:gYh:gYh:fYX6fYX6fYX6fYX6gYh:gYh:hZ8>hZ8>gYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:fYX6f
YX6fYX6fYX6fYX6fYX6fYX6fYX6gZ86gZ86gZ86gZ86gZ86gZ86gZ86gZ86gZ86gZ86gZ86gZ86gZ86g
Z86gZ86gZ86eZH6fZX:hZH:fYh2eY7feXWbgY7jiYX2iYgjjZH:fZ8B/XH6PUgbITGZFT7fGTh6?TX>?
TX>?TX>@ThB@ThBAU8FAU8FAU8FBUHJAU8F@ThB?TX>>TH:=T86<Sh2;SWn<Sh2AThN9Rgn][ZB4QG^L
WIBMWYFg]k6EVY6k`;O3akbRY9Ra/jNXZ9ZTY9Jg]jNNXYNEVHijP7De>S4L8aafOGK@em9MI5lO:R1m
QWc<clJo_KFf]:b/ZZ:Z[JBSZ9mQJF8E81PY=RjDXi^?W9@P:24m@C_Lg=KEcLJ[/:NN[jA@H5DX;BAh
MFgNgmJlaK^e]Zbe]Zbe]Zbe]Zbe]Zbe]Zbe]Zbe]Zbd]ZZd]ZZc]JVa/jNa/jNa/jNa/jNa/jN_/:J`
/JNc]:Ze]Zbg^:jg^:jg^:jg^:jh^Jnh^Jni^[2i^[2i^[2j^k6j^k6j^k6j^k6j^k6k_;:k_;:l_K>l
_K>l_K>l_K>m_[Bm_[Bm_[Bm_[Bn_kFn_kFo`;Jo`;K2_KC0_KG0_[K3`[S6`kG4_Z^n]9bh[HnlZhBl
ZhBlZhBlZhBlZhBlZhBlZhBlZhBmZh:mZh:mZh:mZh:mZh:mZh:mZh:mZh:kZH2kZH2lZX6lZX6mZh:m
Zh:mZh:mZh:mZh:mZh:mZh:mZh:mZh:mZh:mZh:mZh:lZX6lZX6lZX6mZh:mZh:n[8>n[8>n[8>n[8>n
[8>n[8>o[HBo[HBo[HC0[XG0[XFkZX>m[8Fo[XO0[hS1/8W0[hRn[HJm[8G0[hRo[XNn[HJm[8FlZhBl
ZhBlZhBlZhBlZhBlZhBm[8Fm[8Fn[HJo[XL00;nbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX/2bY/2bY/2b
Y/2bY/2bY/2bY/2bY/2bY[naYKnaYKnaYKnaYKnaYKnaYKnaYKnaYKb`Y;b`Y;b`Y;b`Y;b`Y;b`Y;b`
Y;b`Y;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f_Xkf_Xkf_
Xkf_Xkf_Xkf_Xkf_Xkf_Xk^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;^aX;^a
X;^aX;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;Z`WkZ`WkZ`WkZ`WkZ`WkZ`WkZ`WkZ`Wkf`X;f`X;f`
X;f`X;f`X;f`X;f`X;f`X;b`W[b`W[faWkfaWkfaWkjbX;jbX;jbX;faWkfaWkfaWkfaWkfaWkfaWkfa
WkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkfaWkb`W[b`W[b`
W[b`W[b`W[b`W[b`W[b`W[baWKbaWKbaWKbaWKbaWKbaWKbaWKbaWK^`W;^`W;^`W;^`W;^`W;^`W;^`
W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;Z_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkBYUKFZU[FZ
U[N/V;V^V[V^V[V^V[R]VKnkWkVdVk:[TZjSSK6TS[Z[V<JeX/fkZ[2USk6VT;FXT[NZU;NZU;R[UKRZ
U;RZU;>XR;BYRKFZS;N[SkZ]Tkf_V;naV/2bW;n`U[j_UKj_UKj_UKj_UKj_UKf^U;f^U;j`Tkf_Tkb^
T[^/T[Z[TKVYT[RWT[NVTKNZT;NZT;NZT;Z[TKf/T[f/T/2/Tl2/TkJXTKNYT[RZTkJZT[>WSk2TS;2T
S;6USK2XR[J^TKfbU[V^Tk6SS;2OR[BST;^ZUkN/TKN/TKV^TkZ_U;Z_U;Z_U;Z_U;V^TkN/TKN/TKN/
TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKJ[SkJ[SkJ[SkN[SkV[SkV[Sk^Z
Sk^ZSkR/T;N[SkN[SkJZS[JZS[N[SkN[SkR/T;R]SkR]SkR]SkN/S[N/S[N/S[J[SKJ[SKJ[SKJ[SKJ[
SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKJ[SKN/S[N/S[R]SkR]SkN/S[N/
S[J[SKN/S[N/S[N/S[N/S[N/S[N/S[N/S[N/S[J[SKJ[SKJ[SKN/S[N/S[R]SkR]SkV^T;N/S[N/S[N/
S[N/S[N/S[N/S[N/S[N/S[FZS;FZS;FZS;FZS;FZS;FZS;FZS;FZS;VYS;VYS;VYS;VYS;VYS;VYS;VY
S;VYS;RYRKRYRKRYRKVZR[VZR[VZR[Z[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkRYRKRYRKRY
RKVZR[VZR[VZR[VZR[VZR[VZR[VZR[VZR[VZR[VZR[VZR[VZR[VZR[RYRKRYRKRYRKRYRKRYRKRYRKRY
RKRYRKV[QkV[QkV[QkV[QkV[QkV[QkV[QkV[QkZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[NYQKNYQKNY
QKRZQ[RZQ[RZQ[V[QkV[QkZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[RZQ[RZQ[RZQ[RZQ[RZQ[RZQ[RZ
Q[RZQ[^[QkZZQ[VYQKVYQKVYQKVYQKZZQ[^[QkZZQKZZQKZZQKZZQKZZQKZZQKZZQKZZQKVYQ;VYQ;VY
Q;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;VYQ;NWP[NWP[NWP[NWP[NWP[NWP[NW
P[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[JVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJV
PKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKFUP;FUP;JVPKJVPKNWP[NWP[NW
P[NWP[JVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKFUP;FUP;FUP;FUP;FUP;FUP;FUP;FUP;JWP;JWP;JW
P;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;JWP;:VO[BXP;RYP[VXPKNUO;RTNkZV
OKjXOk^WN;^XOKVXPKBUQ:bPQ:BJPYbEPYVBPHnBPhnBPhnBPhnBPi2CQ92CQ92CQ96DQI6DQI6DQI2C
Q92CQ8nBPhjAPXjAPXf@PH^>OiNISJRZW]?DbY^LTZBUW9nPUlC4_ZRYYJj`Z/g?bJJWWZFSVj^ZX:n]
XZRVVk2bYZ>UVIbPUFEZHADL5Ble<:B[YW5hMA`W7GAmLm[Me;^i/K:_Yjn/Y:NXWjjaZ9nVXD1:A0hL
5TYJDfIdKR`f<4U?B]3AcMWAbZbaZ9f^XeIVFbH[8Vm/I>3Qf;o8_[Ff[;Ff[;Ff[;Ff[;Ff[;Ff[;Ff
[;Ff[;:dZ;:dZ;>eZK>eZK>eZK:dZ;:dZ;6cYjn`Y[2aYk6bZ;>dZ[Ff[;Jg[KNh[[Ri[kRi[kRi[kVj
/;Vj/;Vj/;Zk/KZk/KZk/KZk/KZk/K^l/[^l/[bm/kbm/kbm/kbm/kfn];fn];fn];fn];jo]Kjo]Ko0
][o0]/>n]Knl];jl]<6o]lG3^<K2/<6iX[fbUkb[Q;b[Q;b[Q;b[Q;b[Q;b[Q;b[Q;b[Q;f[P[f[P[f[
P[f[P[f[P[f[P[f[P[f[P[^YP;^YP;^YP;^YP;bZPKbZPKf[P[f[P[f[P[f[P[f[P[f[P[f[P[f[P[f[
P[f[P[bZPKbZPKbZPKf[P[f[P[f[P[j/Pkj/Pkj/Pkj/Pkj/Pkn]Q;n]Q;n]Q<2^QL2^QKZYP[b[Q;j]
Q/2_R<6`RL2_R;j]Q[f/QL6`RL2_R;j]Q[b[Q;^ZPk^ZPk^ZPkb[Q;^ZPkb[Q;b[Q;f/QKj]Q[n^Q`00
_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R`;:V`;:V`;:V`;:V`;:V`;:V`;:V`;:V_k6U_k6U_k6U_k6U
_k6U_k6U_k6U_k6U_;2T_;2T_;2T_;2T_;2T_;2T_;2T_;2T_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P
_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_JnS_JnS_JnS_JnS_JnS_JnS_JnS_JnS^k6P^k6P^k6P^k6P
^k6P^k6P^k6P^k6P^k6P^k6P^k6P^k6P^k6P^k6P^k6P^k6P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P
^[2O^[2O^[2O^[2O^[2O^[2O^[2O^[2O_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_;2N_;2N_;2N_K6O
_K6O_K6O_[:P_[:P_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O
_K6O_K6O_K6O_K6O_K6O_K6O_K6O_K6O_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;6M_;6M_;6M_;6M
_;6M_;6M_;6M_;6M^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L
^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK_K:N^JjJ]Z^G]Z^G^:fI^JjJ^JjJ]jbH/:bC/jnF^K>L_[JO
_kBP_JnM^JVH]jBE^[:K^k2J^JjH^:fG^ZfG^jjH_[2J_k6K_kJA_kFC_kBD_[>E_K6E^jjD^J^D^:ZC
]k:C][6B][6B]K2A]K2A]:n@]:n@/jj?/:^:/Jb;/Zf</jj?]:jA]JnB]ZnD]k2E/k6C/k6C/k6C];2C
][2C][2C^;2C^;2C]JVA]ZZB]ZbD]ZbD/jbC/jbC]JjE]K2G]:jA/jf@]JbA^JfE_:nI_ZnL_JfL_ZbK
/jR=]:V>]JZ?]Z^@]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA
]jbA]jbA]jbA]jbA]Z^?]Z^?]Z^?]j^?^J^?^J^?^jZ?^jZ?^:b@]j^?]j^?]ZZ>]ZZ>]j^?]j^?^:b@
^:f?^:f?]jb>]jb>]jb>]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=]Z^=
]Z^=]Z^=]Z^=]Z^=]Z^=]jb>]jb>^:f?^:f?]jb>]jb>]Z^=]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>
]JZ<]JZ<]Z^=]jb>]jb>^:f?^:f?^Jj@]jb>]jb>]jb>]jb>]jb>]jb>]jb>]jb>]JZ<]JZ<]JZ<]JZ<
]JZ<]JZ<]JZ<]JZ<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^:V9^:V9^:V9^:V9^JZ:^JZ:^Z^;^Z^;
^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;^Z^;]jR8]jR8^:V9^:V9^JZ:^Z^;^Z^;^Z^;^JZ:^JZ:^JZ:^JZ:
^JZ:^JZ:^JZ:^JZ:^:V9^:V9^:V9^:V9^:V9^:V9^:V9^:V9^J^7^J^7^J^7^J^7^J^7^J^7^J^7^J^7
^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6^ZZ6]ZR4]jV5]jV5]jV5^:Z6^:Z6^:Z6^J^7^ZZ6^ZZ6^ZZ6^ZZ6
^ZZ6^ZZ6^ZZ6^ZZ6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^:Z6^j^7^ZZ6^JV5^JV5^JV5^JV5^ZZ6^j^7
^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^ZZ5^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3
^:R3^:R3^:R3^:R3]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2
]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1
]ZJ1]ZJ1]ZJ1]ZJ1]JF0]JF0]ZJ1]ZJ1]ZJ1]jN2]jN2]jN2]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1
]JF0]JF0]JF0]JF0]JF0]JF0]JF0]JF0]ZN0]ZN0]ZN0]ZN0]ZN0]ZN0]ZN0]ZN0]ZN0]ZN0]ZN0]ZN0
]ZN0]ZN0]ZN0]ZN0[j=k/jMo^:V2^ZV2^JMn^ZIm_ZQn`:Z0_JMg^ZIg]jEl]jN3/jR:[J>;X9V5V99o
SY62Si:3Si:3Si:3T9>4T9>4T9>4T9>4T9>4T9>4T9>4TIB5TIB5TIB5TIB5TIB5Ti>5U9B8LW9VOgid
^KR^MG=[De59b/O2QhR6J6UW^[Ve^;NcZZNR[Z^S]kB/YJ:JYZJH[JfQZ:VOUYV@CU9<00D0<cXg<CXg
3Q`AL7U_i^WP]K>[[JZR^;F]ZjVQ/;6XY:jXOHV3=D<m5bLP8BlY6R@NBe5<_;fifm?<[;6XWJjSFFUN
9BXQJVMOhN;I`L[0]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/]KJ/]KJ//;:V/K>W/kFY];JZ];JZ];JZ/[BX/K>W
[k2V/;6W/;6W/K:X/kBZ][N]^;V_^KZ`^;V_^;V_^KZ`^KZ`^KZ`^[^a^[^a^[^a^[^a^[^a^kbb^kbb
_;fc_;fc_;fc_;fc_Kjd_Kjd_Kjd_Kjd_[ne_[ne_l2f_l2fal2g`K^d_;Vd_kbgaL>ib<>d`kbX_[BL
_:^4_:^4_:^4_:^4_:^4_:^4_:^4_:^4_J^2_J^2_J^2_J^2_J^2_J^2_J^2_J^2^ZQo^ZQo^jV0^jV0
_:Z1_:Z1_:Z1_:Z1_J^2_J^2_J^2_J^2_J^2_J^2_J^2_J^2^jV0_:Z1_:Z1_:Z1_J^2_J^2_J^2_Zb3
_Zb3_Zb3_Zb3_jf4_jf4_jf4`:j5`:j5^JR1^jZ3_Zf6`:n8`K29`:n8_Zf6_Jb5`K29`:n8_Jb5^jZ3
^ZV2^ZV2^jZ3_:^4^jZ3_:^4_:^4_Jb5_Zf6_jj70033]:C3]:C2/j?2/j?1/Z;0/J70/J70/J6o/Z:o
/Z:o/Z:o/Z:o/Z:o/Z:o/Z:o/Z:n/:Bn/:Bn/:Bn/:Bn/:Bn/:Bn/:Bn/:Bn/J6n/J6n/J6n/J6n/J6n
/J6n/J6n/J6o/Z:n/J6m/:2l[inl[inl[inm/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2m
/:2m/:2m/:2m/:2m/:2m/:2m/:2k[Yjk[Yjk[Yjl[inl[inm/:2m/:2m/:2l[inl[inl[inl[inl[inl
[inl[inl[inl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jk[ifk
[ifk[ifl/9jl/9jm/Inm/Inm/Inl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl
/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl
/Ifl/Ifl/Ifl/Ifl/Ifl/Ifl/Ifj[i^j[i^k/9bl/Ifl/Ifk/9bj[i^j[i^j[i^j[i^j[i^k/9bk/9bk
/9bl/Ifl/Ifj[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^i[9Ji
[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Jk[YRk[YRk[YRk[YRk[YRk[YRk[YRk[YRk[YRk[YRk[YRk[YRk[YRk
[YRk[YRk[YRk/9Fk/9Fk/9Fk/9Fk/9Fk/9Fk/9Fk/9Fh[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h
[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:gZY2gZY2gZY2gZY2gZY2g
ZY2gZY2gZY2g[96h[I:i[Y>i[Y>i[Y>i[Y>h[I:g[96g[96g[96g[96g[96g[96g[96g[96g[96gZY2g
ZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2fZXjfZXjfZXjfZXjfZXjf
ZXjfZXjfZXjjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfiZHbi
ZHbiZHbiZHbiZHbiZHbiZHbiZHbeZXbeZXbeZXbeZXbeZXbeZXbeZXbeZXbiZHbiZHbiZHbiZHbiZHbi
ZHbiZHbiZHbiZHbiZHbiZHbjZXfjZXfkZhjkZhjkZhjjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZh^j
Zh^jZh^jZh^jZh^jZh^jZh^jZh^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZHVhZHVhZHVhZHVhZHVh
ZHVhZHVhZHVhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZXJhZHVh
ZHVhZHVhZHVhZHVhZHVhZHVhZHVjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJjZXJj
ZXJjZXJjZXJgZHFgZHFgZHFhZXJhZXJhZXJiZhNiZhNiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFjZXJj
ZXJjZXJjZXJjZXJjZXJjZXJjZXJiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFi
ZHFiZHFiZHFiZHBiZHBiZHBiZHBiZHBiZHBiZHBiZHBkZHBkZHBkZHBkZHBkZHBkZHBkZHBkZHBiZHBi
ZHBiZHBiZHBiZHBiZHBiZHBiZHBgYh:gYh:gYh:gYh:gYh:gYh:gYh:gYh:iYh:iYh:hYX6gYH2gYH2h
YX6iYh:iYh:hYh2hYh2hYh2hYh2hYh2hYh2hYh2hYh2gYH2gYH2gYH2gYH2gYH2gYH2gYH2gYH2hYX6h
YX6hYX6hYX6hYX6hYX6hYX6hYX6gYH2gYH2gYH2gYH2gYH2gYH2gYH2gYH2iZ86iZ86hYh2hYh2gYWnf
YGjfYGjfYGjgYH2gYH2gYH2gYH2gYH2gYH2gYH2gYH2gYWngYWngYWngYWngYWngYWngYWngYWngYWng
YWngYWngYWngYWngYWngYWngYWnfYGjfYGjgYWngYWngYWnhYh2hYh2hYh2gYWngYWngYWngYWngYWng
YWngYWngYWnjZH:iZ86hYh2gYWnfYGjfYGjfYGjgYWnKU7^IU7nCTh>@TXJ?THFBTX:GTWfITWV>TH6>
TH6?TX:>TWn>TWn=TGj;T7^:SgZ2R7FGWHanPg@f>RmXJf8b<bmADU3@d=24S8E?Ee3<e<fma;g;clW4
b<:QXifTYZ2^[:6VYYZQXiNTZij7TH@c@3814P@I:Q`R9aQOHeOOh]Vg]k6f/jj_[JFa[jBYZ9Z^[Z:W
ZimbO6lB8A<B8A<Z=2M0A3S2`[KEem6a/jfWZJ=gNG</;RQEEe7]knVn`;Zd]J^d]J^d]J^d]J^c]:Zc
]:Zc]:Zc]:Zb]:Rc]JVc]JVc]JVd]ZZd]ZZd]ZZe]j^`/JNa/ZRb/jVa/ZRa/ZRb/jVe]Zbg^:jh^Jnh
^Jng^:jf]jfg^:jh^Jnj^k6k_;:j^k6j^k6k_;:k_;:l_K>l_K>l_K>l_K>k_;:l_K>l_K>l_K>m_[Bm
_[Bm_[Bn_kFn_kFn_kFn_kFn_kFn_kFn_kFn_kFn_kFk[i>fYhNhYH31Zh;5[X6nZGbkZ7flZh2lZX6l
ZX6lZX6lZX6lZX6lZX6lZX6lZX6jZ7njZ7njZ7njZ7njZ7njZ7njZ7njZ7nmZh:mZh:mZh:lZX6kZH2k
ZH2jZ7njZ7nlYWfmYgjnZ7noZH30ZX6oZH2oZH2oZH2lZX6lZX6lZX6lZX6kZH2kZH2kZH2kZH2m[H>o
[hG1/HO1/HNo[hFl[8:l[8:l[8:lZX6lZX6lZX6lZX6lZX6lZX6lZX6lZX6lZX6lZX6lZX6mZh:mZh:m
Zh800<>dY<:cXl:cXl6bX/6bX/2aXL2aXL2aXKnbX[nbX[nbX[nbX[nbX[nbX[nbX[nbX[j`Y;j`Y;j`
Y;j`Y;j`Y;j`Y;j`Y;j`Y;jaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKf`X;f`X;b_Wkb_Wkb_Wkf`
X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;f`X;^^W[^^W[^^
W[b_Wkb_Wkb_Wkf`X;f`X;b_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb`W[b`W[b`W[b`W[b`W[b`W[b`
W[b`W[b`W[b`W[b`W[b`W[b`W[b`W[b`W[b`W[^_WK^_WK^_WKb`W[b`W[b`W[faWkfaWkbaWKbaWKba
WKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKba
WKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKbaWKZ_VkZ_Vk^`
W;baWKbaWK^`W;Z_VkZ_VkZ_VkZ_VkZ_VkZ_Vk^`W;^`W;baWKbaWKZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_
VkZ_Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^Vkb^VkV/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[Z]UkZ]UkZ]
UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ_U;Z_U;Z_U;Z_U;Z_U;Z_U;Z_
U;Z_U;R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]
T[R]T[R]T[R]T[R]T[R]T[NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;N/TKR]T[V^TkV^TkV^TkV^TkR]
T[N/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKNZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZ
T;NZT;NZT;NZT;NZT;NZT;JZS[JZS[JZS[JZS[JZS[JZS[JZS[JZS[ZZSKZZSKZZSKZZSKZZSKZZSKZZ
SKZZSKZZSKZZSKZZSKZZSKZZSKZZSKZZSKZZSKVYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;FZS;FZS;FZ
S;FZS;FZS;FZS;FZS;FZS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;NWR[NWR[RXRkRXRkVYS;VYS;VY
S;VYS;ZZSKZZSKZZSKZZSKZZSKZZSKZZSKZZSKZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkZ[RkRXRkRXRkRX
RkRXRkRXRkRXRkRXRkRXRkRYRKRYRKRYRKRYRKRYRKRYRKRYRKRYRKRZQ[RZQ[RZQ[RZQ[RZQ[RZQ[RZ
Q[RZQ[RZQ[RZQ[RZQ[RZQ[RZQ[RZQ[RZQ[RZQ[RYRKRYRKRYRKRYRKRYRKRYRKRYRKRYRKZZQ[ZZQ[ZZ
Q[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[JXQ;NYQKNYQKNYQKRZQ[RZQ[RZ
Q[V[QkRXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[ZZQ[RXQ;RXQ;RX
Q;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXPkRXPkRXPkRXPkRXPkRXPkRX
PkRXPkZXPkZXPkZXPkZXPkZXPkZXPkZXPkZXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkRXPkNWP[NWP[NW
P[NWP[NWP[NWP[NWP[NWP[VWP[VWP[RVPKNUP;NUP;RVPKVWP[VWP[RWP;RWP;RWP;RWP;RWP;RWP;RW
P;RWP;NUP;NUP;NUP;NUP;NUP;NUP;NUP;NUP;RVPKRVPKRVPKRVPKRVPKRVPKRVPKRVPKNUP;NUP;NU
P;NUP;NUP;NUP;NUP;NUP;RWP;RWP;RWP;NVOkNVOkJUO[JUO[JUO[NUP;NUP;NUP;NUP;NUP;NUP;NU
P;NUP;NVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkJUO[JUO[JU
O[NVOkNVOkRWP;RWP;RWP;NVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkVXPKVXPKNVOkJUO[JUO[JUO[JU
O[NVOjNLOZ>JOi^FPI>CPi6APi:BPYNCP9ZEP8jAPHjAPHnBPXnCP8jBOhfAOXb@OH^?O8nEPXbBPH:7
N5eQEHJ9P6e^JXj?SJb]ZhJ?QA/T6V1XGUEMDhN<PkBg[ZV/Xj:UW:NUVZFUVJBVVZN^XIVRUF5^H2<b
90HG2B<X6F9VF]kQf;Ng/JfZYJJTW;6_Y;>bY:RZWZb`Y9NQU4UFB2@a8aHP4cDi;L;4^=?FcKVl/jV/
XfiaJ1hQ63i1>=OJdLc?a[BeZkBeZkBeZk>dZ[>dZ[>dZ[>dZ[>dZ[:dZ;>eZK>eZK>eZKBfZ[BfZ[Bf
Z[FgZk6bZ;>dZ[Ff[;Ff[;BeZk>dZ[Ff[;Nh[[Ri[kNh[[Jg[KJg[KNh[[Ri[kZk/K^l/[Zk/KZk/K^l
/[^l/[bm/kbm/kbm/kbm/k^l/[bm/kbm/kbm/kfn];fn];fn];jo]Kjo]Kjo]Kjo]Kjo]Kjo]Kjo]Kjo
]Kjo]L6fVkV[S[VVPkjZPL:]P<2[O[fZOkf/PK^YP;^YP;^YP;^YP;^YP;^YP;^YP;^YP;ZXOkZXOkZX
OkZXOkZXOkZXOkZXOkZXOkf[P[f[P[bZPKbZPK^YP;^YP;ZXOkZXOkbVOKfWO[jXOknYP;nYP;nYP;nY
P;jXOk^YP;^YP;^YP;^YP;^YP;bZPKbZPKbZPK^[PKf]Pkn_QKn_QKf]Pk^[PKZZP;^[PK^YP;^YP;^Y
P;^YP;^YP;^YP;^YP;^YP;^YP;bZPKbZPKbZPKf[P[f[PP00`[>S`[>S`K:R`K:R`K:R`;6Q`;6Q`;6Q
_k:R_k:R_k:R_k:R_k:R_k:R_k:R_k:R_[2T_[2T_[2T_[2T_[2T_[2T_[2T_[2T_[6Q_[6Q_[6Q_[6Q
_[6Q_[6Q_[6Q_[6Q_K2P_K2P_:nO_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P
_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P^ZfM^jjN^jjN^jjN_:nO_:nO_:nO_:nO^jjN^jjN^jjN^jjN
^jjN^jjN^jjN^jjN^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM
^ZjL^jnM^jnM^jnM_;2N_;2N_;2N_;2N^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L
^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L
^k2L^k2L^k2L^k2L^k2L^k2L^k2L^k2L^JjJ^ZnK^k2L^k2L^k2L^k2L^ZnK^JjJ^JjJ^JjJ^ZnK^ZnK
^k2L^k2L^k2L^k2L^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ
^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG
^ZfG^ZfG^ZfG^ZfG^ZnD^ZnD^ZnD^ZnD^ZnD^ZnD^ZnD^ZnD^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB
^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB]jZ@]jZ@]jZ@]jZ@
]jZ@]jZ@]jZ@]jZ@]jbA]jbA^:fB^JjC^JjC^:fB]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA]jbA
]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]JV=]JV=]JV=]JV=
]JV=]JV=]JV=]JV=^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<
^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=^ZZ=]:V;]:V;]:V;]:V;]:V;]:V;]:V;]:V;^:R;^:R;^:R;^:R;
^:R;^:R;^:R;^:R;]ZJ9]ZJ9]ZJ9]jN:]jN:^:R;^:R;^:R;^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<
^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:^JZ:]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jR8]jR8]jR8]jR8
]jR8]jR8]jR8]jR8]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5]jV5
]jR8]jR8]jR8]jR8]jR8]jR8]jR8]jR8^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5
^JV5^JV5^JV5^JV5]ZR4]ZR4]jV5]jV5]jV5^:Z6^:Z6^:Z6^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4
^JV5^JV5^JV5^JV5^JV5^JV5^JV5^JV5^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4
^:R4^:R4^:R4^:R4^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3^ZR3^ZR3^ZR3^ZR3^ZR3^ZR3^ZR3^ZR3
^:R3^:R3^:R3^:R3^:R3^:R3^:R3^:R3]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2^JN2^:J1]jF0]jF0
]jF0]jF0^:J1^JN2^:N0^:N0^:N0^:N0^:N0^:N0^:N0^:N0]jF0]jF0]jF0]jF0]jF0]jF0]jF0]jF0
^:J1^:J1^:J1^:J1^:J1^:J1^:J1^:J1]jF0]jF0]jF0]jF0]jF0]jF0]jF0]jF0^:N0]jIo]jIo]jIo
]ZEn]ZEn]ZEn]ZEn]jF0]jF0]jF0]jF0]jF0]jF0]jF0]jF0]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo
]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]ZEn]ZEn]ZEn]ZEn]jIo]jIo^:N0^:N0]jIo]jIo]jIo]jIo
]jIo]jIo]jIo]jIo^JR1^:N0]jIo]ZEn]ZEn]ZEn]ZEn]jIo]JF1[J20Y9^0VYF0U9:0U9:0UYB2V9J4
T99oT99oTI>0TI>0T99oT99oSY1mSY1mRHmlQ8YiS962Kg=WGf=HH69L^;VeYJJRPX^1C5A:][jd/KJ]
YjbS[k:Y/K:Y[k2WY:BHY:BHYZRLYj^OY:fPUInBEfAF3a`>2a01DUI:d=?:_[jh]K:]YjFM[ZbQ[ZfO
YZRLYJVM[KJYPH]nBE=68BXM?40d^K^_al[1^KbcZ:^RNgie?T4hCE17`LBkb<_2/kBZ/kBZ/kBZ/kBZ
/kBZ/kBZ/kBZ/kBZ/[BX/kFY/kFY/kFY];JZ];JZ];JZ]KN[[ZnU/;6W/[>Y/[>Y/;6W/;6W/K:X/kBZ
][N]][N]][N]][N]]kR^^;V_^[^a^kbb^[^a^[^a^kbb^kbb_;fc_;fc_;fc_;fc^kbb_;fc_;fc_;fc
_Kjd_Kjd_Kjd_[ne_[ne_[ne_[ne_[ne_[ne_[ne_[ne_[neb;fW_[6G^:V9^jR2_jb1_jb1_jb1_Zb3
^jV0^jV0^jV0^jV0^jV0^jV0^jV0^jV0^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo_:Z1_:Z1_:Z1^jV0
^jV0^jV0^ZQo^ZQo_:Im_JMn_ZQo_jV0_jV0_jV0_ZQo_ZQo^JMn^ZQo^ZQo^jV0^jV0_:Z1_:Z1_J^2
^ZZ0_:b2_Jf3_Jf3^j^1^JUo^JUo^ZZ0^jV0^jV0^jV0^jV0^jV0^jV0^jV0^jV0^jV0^jV0_:Z1_:Z1
_:Z1_J^20031/Z;1/Z;1/Z;0/J70/J70/J70/J70/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6n/J6m[j>m
[j>m[j>m[j>m[j>m[j>m[j>m[j>m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2k[Yjk[Yjl[inm/:2m/:2m
/:2l[inl[inl[inl[inl[inl[inl[inl[inl[inl[inl[inl[inl[inl[inl[inl[inl[inl[inj[Ifj
[Ifj[Ifk[Yjk[Yjl[inl[inl[ink[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[ifk[ifk[ifk[ifk[ifk
[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifj[Ybj[Ybj[Ybk[ifk[ifl/9jl/9jl/9jk/9bk
/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk
/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bk/9bi[YZi
[YZj[i^k/9bk/9bj[i^i[YZi[YZi[YZi[YZi[YZj[i^j[i^j[i^k/9bk/9bj[i^j[i^j[i^j[i^j[i^j
[i^j[i^j[i^k[IZk[IZk[IZk[IZk[IZk[IZk[IZk[IZi[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Jj[INj
[INj[INj[INj[INj[INj[INj[INj[INj[INj[INj[INj[INj[INj[INj[INj[iBj[iBj[iBj[iBj[iBj
[iBj[iBj[iBh[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:g[96g[96g[96g[96g[96g[96g[96g[96g[96g
[96g[96g[96g[96g[96g[96g[96gZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2fZi2g[96h[I:h[I:h[I:h
[I:g[96fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHnf
ZHnfZHnfZHnfZHnfZHnfZHnfZHneZHfeZHfeZHfeZHfeZHfeZHfeZHfeZHfiZHbiZHbiZHbiZHbiZHbi
ZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbjZXfjZXfjZXfjZXfjZXfjZXfjZXfjZXfdZH^d
ZH^dZH^dZH^dZH^dZH^dZH^dZH^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^fYXVfYXVgYhZgYhZgYhZh
Z8^hZ8^hZ8^iZHbiZHbiZHbiZHbiZHbiZHbiZHbiZHbhZHVhZHVhZHVhZHVhZHVhZHVhZHVhZHVgYhZg
YhZgYhZgYhZgYhZgYhZgYhZgYhZgZ8RgZ8RgZ8RgZ8RgZ8RgZ8RgZ8RgZ8RgZHFgZHFgZHFgZHFgZHFg
ZHFgZHFgZHFgZHFgZHFgZHFgZHFgZHFgZHFgZHFgZHFgZ8RgZ8RgZ8RgZ8RgZ8RgZ8RgZ8RgZ8RiZHFi
ZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFfZ8BfZ8BfZ8BgZHFgZHFg
ZHFhZXJhZXJhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BiZHFiZHFiZHFiZHFiZHFiZHFiZHFiZHFhZ8Bh
Z8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8BhZ8>hZ8>hZ8>hZ8>hZ8>h
Z8>hZ8>hZ8>jZ8>jZ8>jZ8>jZ8>jZ8>jZ8>jZ8>jZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>hZ8>gYh:g
Yh:gYh:gYh:gYh:gYh:gYh:gYh:hYX6hYX6gYH2fY7nfY7ngYH2hYX6hYX6gYWngYWngYWngYWngYWng
YWngYWngYWnfY7nfY7nfY7nfY7nfY7nfY7nfY7nfY7ngYH2gYH2gYH2gYH2gYH2gYH2gYH2gYH2fY7nf
Y7nfY7nfY7nfY7nfY7nfY7nfY7ngYWngYWnfYGjfYGjfYGjfYGjfYGjfYGjfY7nfY7nfY7nfY7nfY7nf
Y7nfY7nfY7nfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjeY7fe
Y7ffYGjfYGjfYGjgYWngYWngYWnfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjhYh2gYWnfYGjeY7feY7ff
YGjfYGjgYWnkYgjfY7n^WgjUVWjLUWnHU86CTh>DU8B?TGf@TWjATh2ATh2ATh2@TH6?T82?T823QWJ:
SGfAU8EgNFe2@cU2@cVg^:nUYYf7ShA9DDJEVi2IWiBDV8fZZj6g^:jYZZ2VYYZSXiNVZ9bRYYZPYiZZ
/jJ9TXE2C3lY;QmMHEFo`[Vj^[Be/Zf[ZJ6^[:6XYiV//:BLX9BZ/JBQZ9^0QgYPIeYYKF6//:Bh^Jnb
/jVWZ9jQXYR:Rh6:Rh6h^Jnd]J^b/jVb/jVb/jVb/jVc]:Zc]:Zc]:Zc]:Zb]:Rc]JVc]JVc]JVd]ZZd
]ZZd]ZZe]j^a/ZRb/jVa/ZR_/:J][ZB^[jFa/ZRc]:Ze]Zbe]Zbe]Zbf]jfg^:ji^[2j^k6j^k6j^k6j
^k6k_;:k_;:l_K>l_K>l_K>l_K>k_;:l_K>l_K>l_K>m_[Bm_[Bm_[Bn_kFn_kFn_kFn_kFn_kFn_kFn
_kFn_kFn_kG9`k2o]j2iZhjiYX>jZ7nnZh2m[86mZh:kZH2kZH2kZH2kZH2kZH2kZH2kZH2kZH2jZ7nj
Z7njZ7njZ7njZ7njZ7njZ7njZ7nkZH2kZH2kZH2kZH2kZH2jZ7njZ7njZ7nkYGblYWfmYgjnZ7noZH2n
Z7nnZ7nnZ7nhYWfhYWfiYgjjZ7nkZH2lZX6mZh:mZh:jZX2l[8:m[H>l[8:kZh6iZGnjZX2l[8:kZH2k
ZH2kZH2kZH2kZH2kZH2kZH2kZH2kZH2kZH2kZH2lZX6lZX6lZX400<2aXL2aXL2aXL2aXL2aXL2aXL2a
XL2aXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKjaXKf_Xkf_Xkf_Xkf_Xkf_Xkf_Xkf_Xkf_Xkf`X;f`X;f`
X;f`X;f`X;f`X;f`X;f`X;V/W;Z]WK^^W[f`X;f`X;f`X;b_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_
Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_WkV/W;Z]WKZ]WKZ]WK^^W[^^W[^^W[b_Wk^^W[^^W[^^
W[^^W[^^W[^^W[^^W[^^W[^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_
WK^_WKV]VkZ^W;Z^W;Z^W;^_WK^_WK^_WKb`W[^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`
W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`
W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;^`W;R]VKV^V[Z_VkZ_VkZ_VkZ_VkV^V[R]VKR]VKR]VKV^
V[V^V[Z_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/
VKZ/VKV/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/
U[V/U[V/U[V/U[V/U[V/U[V^TkV^TkV^TkV^TkV^TkV^TkV^TkV^TkR]T[R]T[R]T[R]T[R]T[R]T[R]
T[R]T[N/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKN/TKNZT;NZT;NZ
T;NZT;NZT;NZT;NZT;NZT;J[T;J[T;N/TKR]T[R]T[N/TKJ[T;J[T;J[T;J[T;J[T;J[T;J[T;J[T;J[
T;J[T;JYSkJYSkJYSkJYSkJYSkJYSkJYSkJYSkJYSkJYSkJYSkJYSkJYSkJYSkJYSkJYSkFYSKFYSKFY
SKFYSKFYSKFYSKFYSKFYSKVYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VY
S;VYS;ZZSKZZSKZZSKZZSKZZSKZZSKZZSKZZSK>XR[>XR[>XR[>XR[>XR[>XR[>XR[>XR[NWR[NWR[NW
R[NWR[NWR[NWR[NWR[NWR[NWR[NWR[RXRkRXRkRXRkVYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VYS;VY
S;VYS;NXR;NXR;NXR;NXR;NXR;NXR;NXR;NXR;JVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJWQkJWQkJW
QkJWQkJWQkJWQkJWQkJWQkJXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JXQ;JX
Q;JXQ;JWQkJWQkJWQkJWQkJWQkJWQkJWQkJWQkRXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RX
Q;RXQ;RXQ;RXQ;RXQ;RXQ;FWPkFWPkJXQ;JXQ;JXQ;NYQKNYQKNYQKNWPkNWPkNWPkNWPkNWPkNWPkNW
PkNWPkRXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;RXQ;NWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNW
PkNWPkNWPkNWPkNWPkNWPkNWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[VWP[VWP[VWP[VWP[VWP[VWP[VW
P[VWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[NWP[JVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKRVPKNUP;JT
OkJTOkJTOkJTOkNUP;RVPKNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkJTOkJTOkJTOkJTOkJTOkJTOkJT
OkJTOkNUP;NUP;NUP;NUP;NUP;NUP;NUP;NUP;JTOkJTOkJTOkJTOkJTOkJTOkJTOkJTOkFTOKFTOKJU
O[JUO[JUO[JUO[JUO[JUO[JTOkJTOkJTOkJTOkJTOkJTOkJTOkJTOkJUO[JUO[JUO[JUO[JUO[JUO[JU
O[JUO[JUO[JUO[JUO[JUO[JUO[JUO[JUO[JUO[FTOKFTOKFTOKJUO[JUO[JUO[NVOkNVOkJUO[JUO[JU
O[JUO[JUO[JUO[JUO[JUO[JUO[JUO[FTOKFTOKFTOKJUO[JUO[NVOkRTNkRTNkFSOZnPOjNLP9fGP9NC
P92@P92BO96COI:COi>CPI>CPi:APi:APi6?Q8n@P9JGQh^;OH^;OGIfJVATF:FUVHn>Q8fCR457?55G
C5IJCemPEXF6O:FTVYBCRIjNTYZLT:JXW:NYWIbPU:R/X:>ZWH68NhJ;O8nCQk>f[JVYXjNTWjRVW[6_
Y:^ZW;2dZ:2TV:Z/X:naYJ^]XJBVVYjRUZb`Y;2_YK6`YZ^ZX;Zi[kNf[;:aYkBcZJj]Xk6bZ;6bZ;6b
Z;:cZK:cZK>dZ[>dZ[BeZk:dZ;>eZK>eZK>eZKBfZ[BfZ[BfZ[FgZkRi[kNh[[Ff[;6bZ:n`Y[2aYkBe
ZkNh[[>dZ[BeZkFf[;Jg[KRi[kVj/;Vj/;Zk/KZk/KZk/K^l/[^l/[bm/kbm/kbm/kbm/k^l/[bm/kbm
/kbm/kfn];fn];fn];jo]Kjo]Kjo]Kjo]Kjo]Kjo]Kjo]Kjo]Kjo]LG2]<2jYkV`UKJWQ[NVOkZXOkbZ
PK^[PKZXOkZXOkZXOkZXOkZXOkZXOkZXOkZXOkVWO[VWO[VWO[VWO[VWO[VWO[VWO[VWO[ZXOkZXOkZX
OkZXOkZXOkZXOkZXOkZXOk^UO;bVOKfWO[jXOkjXOkjXOkfWO[fWO[NUO;RVOKVWO[ZXOk^YP;bZPKbZ
PKf[P[^[PKb/P[f]Pkf]Pk^[PK^[PKb/P[j^Q;ZXOkZXOkZXOkZXOkZXOkZXOkZXOkZXOkZXOkZXOk^Y
P;^YP;^YP;bZP@00_ZnO_k2P_k2P_k2P`;6Q`;6Q`;6Q`;6Q_K2P_K2P_K2P_K2P_K2P_K2P_K2P_K2P
_:jR_:jR_:jR_:jR_:jR_:jR_:jR_:jR_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO]jZJ^JbL^jjN_K2P
_[6Q_K2P_:nO^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN
^JbL^JbL^JbL^ZfM^ZfM^jjN^jjN^jjN^ZfM^ZfM^ZfM^ZfM^ZfM^ZfM^ZfM^ZfM^ZjL^ZjL^ZjL^ZjL
^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^JfK^JfK^JfK^ZjL^ZjL^jnM^jnM^jnM
^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK
^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK
^:fI^JjJ^JjJ^ZnK^ZnK^JjJ^JjJ^:fI^:fI^:fI^:fI^JjJ^JjJ^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK^ZnK
^ZnK^ZnK^ZnK^ZnK^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF
^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JjC^JjC^JjC^JjC
^JjC^JjC^JjC^JjC^:fB^:fB^:fB^:fB^:fB^:fB^:fB^:fB]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@
]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]Z^@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]JZ?]Z^@]jbA]jbA
]jbA]jbA]Z^@]JZ?]JZ?]JZ?]JZ?]JZ?]JZ?]JZ?]JZ?]JZ?]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>
]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]:R<]:R<]:R<]:R<]:R<]:R<]:R<]:R<^:R;^:R;^:R;^:R;
^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;^JV<^JV<^JV<^JV<^JV<^JV<^JV<^JV<
/jR:/jR:/jR:/jR:/jR:/jR:/jR:/jR:]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jN:^:R;^:R;
^JV<^JV<^JV<^JV<^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7
]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZR4]ZR4]ZR4]ZR4
]ZR4]ZR4]ZR4]ZR4]ZR4]ZR4]ZR4]ZR4]ZR4]ZR4]ZR4]ZR4]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7
^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4]JN3]JN3]JN3]ZR4
]ZR4]ZR4]jV5]jV5]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3^:R4^:R4^:R4^:R4^:R4^:R4^:R4^:R4
]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN2]jN2]jN2]jN2
]jN2]jN2]jN2]jN2^JN2^JN2^JN2^JN2^JN2^JN2^JN2^JN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2]jN2
]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]jF0]jF0]ZAo]J=n]J=n]ZAo]jF0]jF0]ZEn]ZEn]ZEn]ZEn
]ZEn]ZEn]ZEn]ZEn]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]ZAo]ZAo]ZAo]ZAo]ZAo]ZAo]ZAo]ZAo
]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]:=l]JAm]JAm]JAm]ZEn]ZEn]ZEn]ZEn]J=n]J=n]J=n]J=n
]J=n]J=n]J=n]J=n]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm
]:=l]:=l]JAm]JAm]ZEn]ZEn]ZEn]ZEn]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]:=l]:=l
]JAm]JAm]jIo]jIo]:5k]J9l]jAn]jAn/Z9nZ9eoWYMnV9=nT9=jTIAkTYAnTi>1Ti>3Ti:4TY25TY26
TI63VIV;QXIhT922UIF7P81bTi>5SHeoRY64Nh9eU9R<VifAQ8IjPh=gUYJ:Shf2SY24TYB8XZBHZZbP
XjFIXZBHZ:ZNYjVM[K:SXZJJYjZQYZJPZ:FPZjVQ/[2UYZFGXZVLYj^O[JfQ[ZbQ/[2U][JZ/;BXZk:U
[jnS];BX/;2T^[Z^[JfQ/K6U[jnS^KV]/;6W/;6W/K:X/K:X/[>Y/kBZ/kBZ];F[/[BX/kFY/kFY/kFY
];JZ];JZ];JZ]KN[]KJ/]KJ/];F[/[>Y[k2V[ZnU[k2V/[>Y/K:X/[>Y];F[][N]^;V_^KZ`^KZ`^KZ`
^[^a^[^a^kbb^kbb_;fc_;fc_;fc_;fc^kbb_;fc_;fc_;fc_Kjd_Kjd_Kjd_[ne_[ne_[ne_[ne_[ne
_[ne_[ne_[ne_[ne_;fc`;f__kNP]jb>]JF0]jIo^ZZ0^ZZ0^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo
^JMn^JMn^JMn^JMn^JMn^JMn^JMn^JMn^JMn^JMn^JMn^JMn^ZQo^ZQo^ZQo^jV0^jEl^jEl_:Im_JMn
_ZQo_ZQo_JMn_JMn^:Im^:Im^JMn^JMn^ZQo^jV0^jV0^jV0^j^1_:b2_Jf3_:b2^j^1^j^1_Jf3`;26
^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^ZQo^jV0^jV0^jV0002n[inn[inn[ino/:2o/:30
/J70/J71/Z:m/:2m/:2m/:2m/:2m/:2m/:2m/:2m/:2l[Z:l[Z:l[Z:l[Z:l[Z:l[Z:l[Z:l[Z:l[inl
[inl[inl[inl[inl[inl[inl[infZIVhZi^j[Ifm/:2n/J6m/:2l[ink[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk
[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yjk[Yji[9bi[9bi[9bj[Ifj[Ifj[Ifk[Yjk[Yjj[Ifj
[Ifj[Ifj[Ifj[Ifj[Ifj[Ifj[Ifj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj
[Ybj[Ybj[Ybi[I^i[I^i[I^j[Ybj[Ybj[Ybk[ifk[ifj[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j
[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j
[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^h[IVh[IVi[YZj[i^j[i^i[YZh[IVh[IVh[IVh
[IVh[IVh[IVi[YZi[YZi[YZj[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^j[i^iZiRiZiRiZiRiZiRiZiRi
ZiRiZiRiZiRi[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9JhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFh
ZiFhZiFhZiFhZiFhZiFhZiFhZiFh[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h[I:h
[I:h[I:h[I:fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2fZi2gZY2g
ZY2gZY2gZY2gZY2gZY2gZY2gZY2eZXnfZi2fZi2g[96g[96fZi2fZi2eZXneZXneZXneZXneZXneZXne
ZXneZXneZXneZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jdZ8bd
Z8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bhZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^h
Z8^hZ8^hZ8^gYhZgYhZgYhZgYhZgYhZgYhZgYhZgYhZcZ8ZcZ8ZcZ8ZcZ8ZcZ8ZcZ8ZcZ8ZcZ8ZgYhZg
YhZgYhZgYhZgYhZgYhZgYhZgYhZfYXVfYXVfYXVgYhZgYhZgYhZhZ8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^h
Z8^hZ8^hZ8^fYhNfYhNfYhNfYhNfYhNfYhNfYhNfYhNeYHReYHReYHReYHReYHReYHReYHReYHReYXJe
YXJeYXJeYXJeYXJeYXJeYXJeYXJeYh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>eYh>e
Yh>eYh>eYh>eYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJgYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>g
Yh>gYh>gYh>gYh>gYh>gYh>gYh>dYX:eYh>eYh>eYh>fZ8BfZ8BfZ8BgZHFfYX:fYX:fYX:fYX:fYX:f
YX:fYX:fYX:gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:f
YX:fYX:fYX:fYX:fYX:fYX:fYX:fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6hYX6hYX6hYX6hYX6hYX6h
YX6hYX6hYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6eYH2eYH2eYH2eYH2eYH2eYH2eYH2eYH2gYH2f
Y7nfY7neXgjeXgjfY7nfY7ngYH2fYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjeXgjeXgjeXgjeXgjeXgje
XgjeXgjeXgjfY7nfY7nfY7nfY7nfY7nfY7nfY7nfY7neXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjdXgbd
XgbdXgbeY7feY7ffYGjfYGjfYGjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeXgjeY7feY7feY7feY7feY7fe
Y7feY7feY7feY7feY7feY7feY7feY7feY7feY7feY7fdXgbdXgbdXgbeY7feY7ffYGjfYGjfYGjeY7fe
Y7feY7feY7feY7feY7feY7feY7feY7fdXgbdXgbdXgbdXgbeY7fgYWngYWncXgnfY7njYWflYWbiYGba
XGfYWX2TVh2BTgVCTg^DTgjEU82FThBFTXNET8NET8N<RgfDThF@Sh6=SGf8R7R5QGF;Rg^FUXJ<T8B;
Sh>7RgnKWI6QXIFLW92PWY>BT8F;SH6AThNEUh^NX9BZZYjVYYZSXiN][J6RYiRLX9BOXYV`/:Z_[:N/
ZZ:`[Z>TXiFKXYF]/JF[ZIjZYY^a[J:]Zj2Y[J6Z/JB_[J:d/ZNb/:Fh]Z^RX9Fd/ZN`[Z>k^Jj_/:J_
/:J`/JNa/ZRb/jVc]:Zc]:Zd]J^b]:Rc]JVc]JVc]JVd]ZZd]ZZd]ZZe]j^`/JNd]J^i^[2i^[2f]jfa
/ZR][ZB[[::`/JNa/ZRd]J^f]jfh^Jni^[2i^[2i^[2j^k6j^k6k_;:k_;:l_K>l_K>l_K>l_K>k_;:l
_K>l_K>l_K>m_[Bm_[Bm_[Bn_kFn_kFn_kFn_kFn_kFn_kFn_kFn_kFn_kFf^;;0`;C5_jbm/YJeYh>g
YWnjZX2l[8:iYgjiYgjiYgjiYgjiYgjiYgjiYgjiYgjhYWfhYWfhYWfhYWfhYWfhYWfhYWfhYWfhYWfh
YWfiYgjiYgjjZ7njZ7nkZH2kZH2jY7^kYGblYWfmYgjmYgjmYgjmYgjlYWfiYgjiYgjiYgjiYgjiYgjj
Z7njZ7njZ7njZX2kZh6kZh6jZX2iZGniZGnl[8:o[hFiYgjiYgjiYgjiYgjiYgjiYgjiYgjiYgjiYgjj
Z7njZ7njZ7nkZH2kZH000;f^W[f^W[j_Wkn`X;n`X<2aXL2aXL6bX[f`X;f`X;f`X;f`X;f`X;f`X;f`
X;f`X;b^X[b^X[b^X[b^X[b^X[b^X[b^X[b^X[b_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_Wkb_WkFXV;NZV[Z]
WKf`X;jaXKf`X;b_Wk^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^W[^^
W[^^W[R[VkV/W;V/W;V/W;Z]WKZ]WKZ]WK^^W[Z]WKZ]WKZ]WKZ]WKZ]WKZ]WKZ]WKZ]WKZ^W;Z^W;Z^
W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;R/V[V]VkV]VkV]VkZ^W;Z^W;Z^
W;^_WKZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_
VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_VkZ_
VkZ_VkN/V;R]VKV^V[V^V[V^V[V^V[R]VKN/V;N/V;R]VKR]VKR]VKV^V[V^V[V^V[V^V[Z_VkZ_VkZ_
VkZ_VkZ_VkZ_VkZ_VkZ_VkV[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V/U[V/U[V/U[V/U[V/U[V/U[V/
U[V/U[R[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKR]T[R]T[R]
T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[R]T[J[T;J[T;J[T;J[T;J[T;J[T;J[
T;J[T;J[T;J[T;J[T;J[T;J[T;J[T;J[T;J[T;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;FZSkJ[T;J[
T;N/TKN/TKJ[T;J[T;FZSkFZSkFZSkFZSkFZSkFZSkFZSkFZSkFZSkFXS[FXS[FXS[FXS[FXS[FXS[FX
S[FXS[FXS[FXS[FXS[FXS[FXS[FXS[FXS[FXS[BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;RXRkRXRkRX
RkRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkJVRKJVRKJVRKJVRKJVRKJVRKJV
RKJVRK:WRK:WRK:WRK:WRK:WRK:WRK:WRK:WRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKBTQkBTQkFU
R;FUR;FUR;JVRKJVRKJVRKRXRkRXRkRXRkRXRkRXRkRXRkRXRkRXRkFVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FV
Q[FVQ[FUR;FUR;FUR;FUR;FUR;FUR;FUR;FUR;FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FWPkFWPkFW
PkFWPkFWPkFWPkFWPkFWPkFWPkFWPkFWPkFWPkFWPkFWPkFWPkFWPkFVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FV
Q[FVQ[NWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkBVP[BVP[FW
PkFWPkFWPkJXQ;JXQ;JXQ;JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[NWPkNWPkNWPkNWPkNWPkNWPkNW
PkNWPkJVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVPKJVPKJV
PKJVPKJVPKJVPKJVPKJVPKRVPKRVPKRVPKRVPKRVPKRVPKRVPKRVPKJVPKJVPKJVPKJVPKJVPKJVPKJV
PKJVPKFUP;FUP;FUP;FUP;FUP;FUP;FUP;FUP;NUP;JTOkJTOkFSO[FSO[JTOkJTOkNUP;JUO[JUO[JU
O[JUO[JUO[JUO[JUO[JUO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[JTOkJTOkJTOkJTOkJTOkJTOkJT
OkJTOkFSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[>RNk>RNkBSO;BSO;FTOKJUO[JUO[JUO[FSO[FSO[FS
O[FSO[FSO[FSO[FSO[FSO[FTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFT
OKFTOKBSO;BSO;BSO;FTOKFTOKFTOKJUO[JUO[FTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKBSO;BSO;>R
Nk>RNkBSO;FTOKNVOkNVOk:UQKJVP[ZVOKfVNKfVNKVUO;BTP;2SPi:CNI>DNYBCOYFDP9JCQ9JBQiJA
R9F?R8n>P8f<OYZIRiJFQXf=OIZJR8n?OHJ6M8R=OYBIRX64MHnBPiJFR8n>P9BCQI6@PY6CQiFGRhR:
OXb>PZVYWJ^[Wj6OU:VWW:baXZJZWZ:UW;6aZjNTWj>QVK6_Y:n^X:2YW;Bh[:RVVjfWW;^eZZj/XJJZ
WZ^dYjb[WJb[WJn^X;bk[JZYVlG4][BcYK2_XJj_YJn`Y[2aYk6bZ;:cZK>dZ[>dZ[BeZk:dZ;>eZK>e
ZK>eZKBfZ[BfZ[BfZ[FgZkFf[;bm/lG6_<W:`<K7_Kfn];BeZjj_YJn`Y[6bZ;BeZkJg[KRi[kVj/;Vj
/;Vj/;Zk/KZk/K^l/[^l/[bm/kbm/kbm/kbm/k^l/[bm/kbm/kbm/kfn];fn];fn];jo]Kjo]Kjo]Kjo
]Kjo]Kjo]Kjo]Kjo]Kjo]K6e/<31]lW5/l>hWKRYR;RWP;^ZPkf]PkVWO[VWO[VWO[VWO[VWO[VWO[VW
O[VWO[RVOKRVOKRVOKRVOKRVOKRVOKRVOKRVOKNUO;RVOKRVOKVWO[VWO[ZXOk^YP;^YP;ZTNk^UO;bV
OKfWO[fWO[fWO[fWO[bVOKZXOkZXOkVWO[VWO[VWO[VWO[VWO[VWO[RXO[VYOkVYOkRXO[NWOKRXO[^[
PKj^Q;VWO[VWO[VWO[VWO[VWO[VWO[VWO[VWO[VWO[VWO[ZXOkZXOkZXOk^YP000_[2N_[2N_[2N_[2N
_[2N_[2N_[2N_[2N_k2P_k2P_k2P_k2P_k2P_k2P_k2P_k2P_:nO_:nO_:nO_:nO_:nO_:nO_:nO_:nO
_;2N_;2N_;2N_;2N_;2N_;2N_;2N_;2N^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM^ZjL^ZjL^ZjL^jnM
^jnM^jnM_;2N_;2N^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL
^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL
^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK
_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK^ZbI^ZbI^ZbI^ZbI
^jfJ^jfJ^jfJ_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK_:jK^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ
^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jjH^jjH^jjH^jjH^jjH^jjH^jjH^jjH^J^H^J^H^J^H^J^H
^J^H^J^H^J^H^J^H^JbF^JbF^JbF^JbF^JbF^JbF^JbF^JbF^:^E^:^E^:^E^:^E^:^E^:^E^:^E^:^E
^ZfG^ZfG^JbF^JbF^:^E]jZD]jZD]jZD^JbB^JbB^JbB^JbB^JbB^JbB^JbB^JbB^:^A^:^A^:^A^:^A
^:^A^:^A^:^A^:^A]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]j^?]j^?]j^?]j^?]j^?]j^?]j^?]j^?
]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]:R<]JV=]JV=]ZZ>]ZZ>]j^?]j^?^:b@]ZV?]ZV?]ZV?]ZV?
]ZV?]ZV?]ZV?]ZV?]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=
^JV<^JV<^JV<^:R;]jN:]jN:]ZJ9]ZJ9^:R;^:R;^:R;^:R;^:R;^:R;^:R;^:R;]jN:]jN:]jN:]jN:
]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jR8]jR8]jR8]jR8]jR8]jR8]jR8]jR8
]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]jR8]ZN7]JJ6]:F5]:F5]JJ6]ZN7]jR8]JJ6]JJ6]JJ6]JJ6
]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5
]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2
]ZJ2]ZJ2]ZJ2]ZJ2]JF1]JF1]ZJ2]ZJ2]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3
]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]:B0]JF1]ZJ2]jN3
^:R4]jN3]jN3]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2]ZJ2^JV5]ZJ2]:B0]:B0]ZJ2]jN3]jN3]ZJ2
]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1]ZJ1^:J1^:J1]jF0]ZAo]ZAo]jF0^:J1^:J1]jIo]jIo]jIo]jIo
]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]jIo]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn
]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]:=l]:=l]:=l]JAm
]JAm]ZEn]ZEn]ZEn]:=l]:=l]:=l]JAm]JAm]ZEn]ZEn]ZEn]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l
]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l
]:=l]:=l]:=l]:=l]:=l]:=l]:=l]J9l]j9l]j9l^J9l^J9l]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j
]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j]J=j
]J=j]J=j]J=j]J=j[:=nYiilX9QjUi=jTI1lSI21SI27SI6;Si65Si65Si65T922T922TI61T920T920
RhYlS8]mSHanSXeoT8n1TI22TY63Ti:4TIB5T9>4T9>4Si:3TIB5UiZ;Wj:CYZVJYZRLYZRLYjVMZ:ZN
ZJ^OZZbPZjfQZjfQYJbMXJRK[kJY[;2UYj^P[ZnV[ZnV`/:l^l6l[kF``/S3`LO2_/Boalg8_L>n^l6l
dLk:d<g9gmkJa/G1d]??emSDdMG@_/:m];B^][>^][:]^;:]]K6//[:/[K6[Z[:[^<VndMoDd=S>d]G<
k>[R`;jf[k2W^Kbc[k6U[k6U/;:V/[BX];JZ][R/^K^_^[b`^;V_^;V_^KZ`^[^a^[^a^[^a^KZ`^;V_
_;fc_;fc_;fc_;fc_Kjd_Kjd_Kjd_[ne_[ne_l2f_l2f_l2f_[ne_Kjd_;fc^kbb_;Va`Kjf`l6g`Kb]
^k>L]ZV9^:Im_JIh]J=j]ZAk^:Im^JMn^JMn^:Im]ZAk]J=j_:Mj_:Mj_:Mj_:Mj_:Mj_:Mj_:Mj_:Mj
^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^JUk^JUk^JUk^JUk
^JUk^JUk^JUk^JUk^JMn^ZQo^jV0^ZQo^JMn^jV0_Zb3`Jn6_J^2^jV0^JMn]jEl]ZAk^:Im^ZQo^jV0
`[27_jf4_:Z1^JMn]jEl]jEl002n/9jn/9jn/9jn/9jn/9jn/9jn/9jn/9jo/:2o/:2o/:2o/:2o/:2o
/:2o/:2o/:2l[inl[inl[inl[inl[inl[inl[inl[inl/9jl/9jl/9jl/9jl/9jl/9jl/9jl/9jk[ifk
[ifk[ifk[ifk[ifk[ifk[ifk[ifj[Ybj[Ybj[Ybj[Ybk[ifk[ifl/9jl/9jj[Ybj[Ybj[Ybj[Ybj[Ybj
[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj
[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj[Ybj
[Ybj[Ybj[Ybl[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l
[Y^l[Y^l[Y^l[Y^l[Y^l[Y^l[Y^iZiRj[9Vj[9Vj[9Vk[IZk[IZk[IZk[IZl[Y^l[Y^l[Y^l[Y^l[Y^l
[Y^l[Y^l[Y^j[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[INj
[INj[INj[INj[INj[INj[INj[INiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRi[9Ji[9Ji[9Ji[9Ji[9Ji
[9Ji[9Ji[9JhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFj[INi[9Ji[9JhZiFhZiFgZYBgZYBgZYBi[9:i
[9:i[9:i[9:i[9:i[9:i[9:i[9:hZi6hZi6hZi6hZi6hZi6hZi6hZi6hZi6gZY2gZY2gZY2gZY2gZY2g
ZY2gZY2gZY2gZhngZhngZhngZhngZhngZhngZhngZhnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHndZ8be
ZHfeZHfeZHffZXjgZhngZhngZhnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHneZHfeZHfeZHfeZHfeZHfe
ZHfeZHfeZHfeZHfeZHfeZHfeZHfeZHfeZHfeZHfeZHfiZHbiZHbhZ8^hZ8^gYhZgYhZfYXVfYXVhZ8^h
Z8^hZ8^hZ8^hZ8^hZ8^hZ8^hZ8^fYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVf
YXVfYXVfYXVfYhNfYhNfYhNfYhNfYhNfYhNfYhNfYhNeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJgZ8Rf
YhNeYXJdYHFdYHFeYXJfYhNgZ8ReYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJeYXJe
YXJeYXJeYXJdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFfYX:f
YX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:eYH6eYH6fYX:fYX:fYX:g
Yh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>gYh>fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:fYX:f
YX:fYX:fYX:fYX:fYX:fYX:fYX:dY82eYH6fYX:gYh>gYh>gYh>gYh>fYX:fYX:fYX:fYX:fYX:fYX:f
YX:fYX:fYX:hZ8BfYX:dY82dY82fYX:gYh>gYh>fYX:fYX6fYX6fYX6fYX6fYX6fYX6fYX6fYX6hYX6g
YH2gYH2fY7nfY7ngYH2gYH2hYX6gYWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWngYWng
YWngYWngYWnfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjeY7fe
Y7feY7feY7feY7feY7feY7feY7fdXgbdXgbdXgbeY7feY7feY7ffYGjfYGjdXgbdXgbdXgbeY7feY7fe
Y7ffYGjfYGjdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbd
XgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbeXWbgXWbg
XWbiXWbiXWbeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZe
XgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZeXgZ`Y7b/XG^TVgVLUWVGTg^C
TGnATH>AThNBTXBATH>ATH>ATH>@T8:ATH6ATH6@T82<Rgf<Rgf=S7j?SX2@Sh6AT8:BTH>CTXB@ThB@
ThB@ThB?TX>AU8FEV8VLWi2RYIJXZYjXZYjWZIfWZIfWZIfXZYjZ[:2[[J6`]jRSZYfX[:2PY9VSYibb
]Jbf]jk7al7Gg]W?e]7;d/g4blK3b/G;d/g?e]7FgMS0a;nm`Kc4b<>]/Jbc];2n_k_Mg][>cl^d]Jbe
/j^f/j^h/Z^e/ZZa/ZV]/ZVZ/jUVMfaRL6EPJ5j6RH3KfM7;bL6b/jZ]/:N_/JF`/ZJ`/ZJa/jNc]JVf
^:bh^Zji^jnh^Jni^[2j^k6j^k6k_;:j^k6j^k6i^[2k_;:l_K>l_K>l_K>m_[Bm_[Bm_[Bm_[Bn_kFn
_kFo`;Jo`;Jn_kFm_[Bl_K>k_;:m^[:o_KG1_kG0_Jnl]J6h[HniZ86jYGReXgZfY7^hYWfiYgjiYgjh
YWffY7^eXgZlYgZlYgZlYgZlYgZlYgZlYgZlYgZlYgZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7Zh
Z7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZiZG^iZG^iZG^iZG^iZG^iZG^iZG^iZG^iYgjjZ7nkZH2jZ7niYgjk
ZH2n[8?1[hJmZh:kZH2iYgjgYGbfY7^hYWfiYgjkZH30[XFn[8>kZH2hYWfgYGbgYG`00;f_WKf_WKf_
WKf_WKf_WKf_WKf_WKf_WKn`X;n`X;n`X;n`X;n`X;n`X;n`X;n`X;^^W[^^W[^^W[^^W[^^W[^^W[^^
W[^^W[^_WK^_WK^_WK^_WK^_WK^_WK^_WK^_WKZ^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^W;V]VkV]VkZ^
W;Z^W;^_WK^_WK^_WK^_WKV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]
VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]
VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkV]Vk^]V[^]V[^]V[^]V[^]V[^]V[^]
V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[V[V;V[V;V[
V;Z/VKZ/VK^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[^]V[Z/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/
VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkZ]UkV[V;V[V;V[
V;V[V;V[V;V[V;V[V;V[V;V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[R[UKR[UKR[UKR[UKR[UKR[UKR[
UKR[UKV/U[V/U[R[UKR[UKR[UKNZU;NZU;NZU;V/T[V/T[V/T[V/T[V/T[V/T[V/T[V/T[R[TKR[TKR[
TKR[TKR[TKR[TKR[TKR[TKNZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;N[SkN[SkN[SkN[SkN[SkN[SkN[
SkN[SkFXS[FXS[FXS[FXS[FXS[FXS[FXS[FXS[BXS;FYSKFYSKFYSKJZS[JZS[JZS[JZS[FXS[FXS[FX
S[FXS[FXS[FXS[FXS[FXS[BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BXS;BX
S;BXS;RXRkRXRkRXRkNWR[NWR[NWR[JVRKJVRKNWR[NWR[NWR[NWR[NWR[NWR[NWR[NWR[JVRKJVRKJV
RKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKJWQkJWQkJWQkJWQkJWQkJWQkJW
QkJWQkFVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[JWQkFVQ[FVQ[BUQKBUQKFVQ[FVQ[JWQkFVQ[FVQ[FV
Q[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[BUQKBUQKBUQKBUQKBUQKBUQKBU
QKBUQKBUQKBUQKBUQKBUQKBUQKBUQKBUQKBUQKJVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JV
P[JVP[JVP[JVP[JVP[JVP[FUPKFUPKFUPKJVP[JVP[JVP[NWPkNWPkNWPkNWPkNWPkNWPkNWPkNWPkNW
PkNWPkJVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[BTP;FUPKJV
P[NWPkNWPkNWPkJVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[RXQ;JVP[BTP;BTP;JVP[NWPkNW
PkFUPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKJVPKRVPKNUP;JTOkJTOkJTOkJTOkNUP;RVPKNVOkNVOkNV
OkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkNVOkJUO[JUO[JUO[JUO[JUO[JUO[JU
O[JUO[JUO[JUO[JUO[JUO[JUO[JUO[JUO[JUO[BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;>RNkBSO;BS
O;BSO;FTOKFTOKFTOKFTOK>RNkBSO;BSO;BSO;FTOKFTOKFTOKFTOK>RNk>RNk>RNk>RNk>RNk>RNk>R
Nk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>R
Nk>RNk>RNk>RNk>RNk>RNk>SNK>SNK>SNKBRNKJRNKJRNKRRNKRRNKBRNKBRNKBRNKBRNKBRNKBRNKBR
NKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBRNKBR
NKBRNKBRNKBRNKBRNKBRNKJVN;>SN:bPN:RLNZ2HNifFOIVDOiNCP9>CPi>CPi:BPY:BPY:BPY6API6A
PI6APHf<OXf<OXj=Ohn>P92?PI6@PY:APi>BQ8jAPXnBPi2CQ92CQ96DQI>FQiRKS9bOT:NYWJNYWJNY
WJNYWJRZWZRZWZV[WjV[WjjcY:>WVjb`Y:R/XJ^_Y:R[XXF8OgIhLV=^IVYeKEQSFe9MEE1KDd=>AT=>
AT=>ASI3>cA1>CM2>SDm=T55?fQZI<c<a/_;aK>dZkFcZkFbZ[NaZ[FbZ[6bZJfbZJZcZCU:?aTW71XR
65ULDmSFc]KDc;Jg[ZZ]Y;2bY[2bY[2bY[6cYk>eZKFgZkNi[KRj[[Ri[kVj/;Zk/K^l/[bm/k^l/[^l
/[Zk/K^l/[^l/[^l/[bm/kbm/kfn];fn];fn];fn];jo]Kjo]Kjo]Kjo]Kfn];bm/k^l/[bk/Kfl/[fl
/[jm[l2jYkjcUkZZQ[JSOKJTNkNUO;NUO;RVOKRVOKNUO;NUO;JTNkbWN[bWN[bWN[bWN[bWN[bWN[bW
N[bWN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[RXN[VYNkVYNkVY
NkVYNkVYNkVYNkVYNkVYNkVWO[ZXOk^YP;^YP;ZXOkZXOkf[P[n]Q;bZPK^YP;VWO[NUO;NUO;NUO;VW
O[ZXOkf[P[^YP;VWO[RVOKNUO;RVO@00_JnM_JnM_JnM_JnM_JnM_JnM_JnM_JnM_ZnO_ZnO_ZnO_ZnO
_ZnO_ZnO_ZnO_ZnO^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jjN^jnM^jnM^jnM^jnM^jnM^jnM^jnM^jnM
^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^JfK^JfK^JfK^ZjL^ZjL^ZjL^jnM^jnM^JfK^JfK^JfK^JfK
^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK
^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK
^JfK^JfK^JfK^JfK^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ
^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ^J^H^J^H^J^H^J^H^ZbI^ZbI^jfJ^jfJ^jfJ^jfJ^jfJ^jfJ
^jfJ^jfJ^jfJ^jfJ^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI^ZbI
^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^ZfG^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^JbF^JbF^JbF^JbF
^JbF^JbF^JbF^JbF]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD^:^E^:^E^:^E]jZD]jZD]jZD]jZD]jZD
^:^A^:^A^:^A^:^A^:^A^:^A^:^A^:^A]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]ZV?]ZV?]ZV?]ZV?
]ZV?]ZV?]ZV?]ZV?]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>
]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JV=]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]:R<]:R<]:R<]:R<
]:R<]:R<]:R<]:R<]:R<]:R<]:R<]:R<]:R<]:R<]:R<]:R<]jN:]jN:]jN:]jN:]jN:]jN:]ZJ9]ZJ9
]jN:]jN:]jN:]jN:]jN:]jN:]jN:]jN:]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9]ZJ9
]ZJ9]ZJ9]ZJ9]ZJ9]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]ZN7]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6
]JJ6]JJ6]:F5]:F5]:F5]:F5]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6]JJ6
]JJ6]JJ6]JJ6]JJ6/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4
]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1]:B0]:B0]JF1]JF1
]ZJ2]ZJ2]ZJ2]ZJ2]jN3]jN3]jN3]jN3]jN3]jN3]jN3]jN3]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1
]JF1]JF1]JF1]JF1]JF1]JF1]JF1]JF1/j=o]:B0]JF1]ZJ2]jN3]ZJ2]ZJ2]JF1]JF1]JF1]JF1]JF1
]JF1]JF1]JF1]JF1^:R4]JF1/j=o]:B0]JF1]jN3]ZJ2]JF1]JF0]JF0]JF0]JF0]JF0]JF0]JF0]JF0
]jF0]jF0]ZAo]J=n]J=n]ZAo]jF0]jF0]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn]ZEn
]ZEn]ZEn]ZEn]ZEn]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm
]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l/j9k/j9k/j9k]:=l]:=l]JAm]JAm]JAm/j9k/j9k/j9k]:=l
]:=l]JAm]JAm]JAm/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k
/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j=i/j=i/j=i]:9i
]Z9i]Z9i^:9i^:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i
]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i]:9i^ZIf]jEf]:=h/J1i
ZieiYIYjXYMkXIIkUi>0UI>1UI>1U9:0TY:2TY:2T922T922SXeoSXeoShj0T8n1T8n1TI22TY63TY63
SI21Si:3T9>4TIB5T9>4TIB5U9N8UYV:Wj6EXJ>GYJNKZ:ZNZZbPZZbPZJ^OZ:ZNZZfNY:JJ/[BX/KFZ
/KFZUibCCE996alI21D=62DM2AH>3Q/C5R<K2QL?3AXB31TA3b<G3AhC21P=41/A5QhDB4]2e]C<f]S@
/[>Y];>Y]K>Y]k:Y];:X/K:X[K>XZ[BX?4e241hC7BDKF5]BgM_Ce=;:]KJ]]KR_/K>W/K>W/K>W/K>W
/[BX];JZ]KN[][R/^;V_^KZ`^[^a^kbb_;fc_;fc_;fc^kbb^kbb^kbb^kbb^kbb_;fc_;fc_Kjd_Kjd
_;fc_Kjd_Kjd_[ne_[ne_Kjd_;fc^kbb_Kbb^kZ`^KZ`_Kfa`[f^`KVR^jf@]JB3]jEl]jEl]jEl]jEl
]jEl]jEl]jEl]jEl^jIi^jIi^jIi^jIi^jIi^jIi^jIi^jIi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi
]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Qj^:Im^ZQo^jV0^jV0
^ZQo^ZQo_:Z1_Zb3^jV0^ZQo^:Im]jEl]jEl]jEl^:Im^JMn^ZQo^JMn^:Im]jEl]jEl^:Im002m[ifm
[ifm[ifm[ifm[ifm[ifm[ifm[ifn[inn[inn[inn[inn[inn[inn[inn[ink[Yjk[Yjk[Yjk[Yjk[Yjk
[Yjk[Yjk[Yjk[ifk[ifk[ifk[ifk[ifk[ifk[ifk[ifi[I^i[I^i[I^i[I^i[I^i[I^i[I^i[I^h[9Zh
[9Zi[I^i[I^j[Ybj[Ybj[Ybj[Ybh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh
[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh
[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zj[9Vj[9Vj[9Vj[9Vj[9Vj
[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9VhZYNh
ZYNiZiRiZiRiZiRj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9Vj[9ViZiRiZiRiZiRiZiRiZiRi
ZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRi[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9Ji[9JhZYNh
ZYNhZYNhZYNhZYNhZYNhZYNhZYNhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFgZYBgZYBgZYBgZYBgZYBg
ZYBgZYBgZYBgZYBgZYBgZYBgZYBgZYBgZYBgZYBgZYBhZi6hZi6hZi6hZi6hZi6hZi6hZi6hZi6gZY2g
ZY2gZY2gZY2gZY2gZY2gZY2gZY2fZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHnfZXjfZXjfZXjfZXjfZXjf
ZXjfZXjfZXjeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZHfeZHfeZHfeZHfdZ8bdZ8bdZ8bdZ8beZ8je
Z8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jcYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^cYh^c
Yh^cYh^cYh^fYXVfYXVfYXVfYXVfYXVfYXVgYhZgYhZfYXVfYXVfYXVfYXVfYXVfYXVfYXVfYXVeYHRe
YHReYHReYHReYHReYHReYHReYHReYHReYHReYHReYHReYHReYHReYHReYHReYXJeYXJeYXJeYXJeYXJe
YXJeYXJeYXJdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFd
YHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFcY8BcY8BcY8BcY8BcY8Bc
Y8BcY8BcY8BcY8BcY8BcY8BcY8BcY8BcY8BcY8BcY8BeYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6e
YH6eYH6eYH6eYH6eYH6eYH6eYH6dY82dY82dY82eYH6eYH6eYH6fYX:fYX:fYX:fYX:fYX:fYX:fYX:f
YX:fYX:fYX:eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6cXgnd
Y82eYH6fYX:fYX:fYX:eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6gYh>eYH6cXgncXgneYH6f
YX:fYX:eYH6eYH2eYH2eYH2eYH2eYH2eYH2eYH2eYH2gYH2fY7neXgjeXgjeXgjeXgjfY7ngYH2fYGjf
YGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjfYGjeY7feY7feY7feY7feY7fe
Y7feY7feY7feY7feY7feY7feY7feY7feY7feY7feY7fdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbbXGZc
XW^cXW^cXW^dXgbdXgbdXgbeY7fbXGZcXW^cXW^cXW^dXgbdXgbdXgbeY7fbXGZbXGZbXGZbXGZbXGZb
XGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZb
XGZbXGZbXGZbXGZbXGZbXGZbXGZbXWNbXWNbXWNcXWNeXWNeXWNgXGNgXGNcXGRcXGRcXGRcXGRcXGRc
XGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRcXGRc
XGRcXGRcXGRcXGRcXGRcXGRcXGRkYW>iYGFgYGJdXgRbXGZ^WWZYVWVXVGVJUH2JUH2GTh2GTh2ETh6B
TX:ATH>ATH>?SX2?SX2@Sh6@Sh6AT8:AT8:BTH>BTH><Sh2?TX>AU8FAU8F@ThB@ThBAU8FCUXNCUHVI
VhnQXiNXZYj/[Z:/[Z:Z[:2WZIfc/jFYZIf/[Z:VZYn//:FIWYE:DTP?5Pl950XA718<5`d=60h?6Q0>
6@lG8QPL9ad=814=7Q0?7Q0L9QTM91M0@SJn_[:m^k2a/ZRc/ZRd/ZRf/JRd/ZRa/ZR]/jRZ]:PlCD87
5@XM9A]>DDSIelo@c/Jc]:^j_KBb]:Ra/jNa/jNa/jNa/jNc]JVd]ZZe]j^g^:jh^Jni^[2k_;:l_K>l
_K>l_K>l_K>j^k6j^k6k_;:k_;:k_;:l_K>l_K>l_K>k_;:l_K>l_K>m_[Bm_[Bm_[Bl_K>l_K>m_K6h
^Zjg^:jk_;;0_k72^jZk/9ZdYhfgYGbgYGbgYGbgYGbgYGbgYGbgYGbgYGbkYWVkYWVkYWVkYWVkYWVk
YWVkYWVkYWVgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYgVhZ7Zh
Z7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhZ7ZhYWfjZ7nkZH2kZH2jZ7niYgjjZ7nlZX6jZ7niYgjhYWfgYGbgYGbg
YGbgYGbgYGbgYGbgYGbgYGbgYGbgYGbhYWd00;b^W;b^W;b^W;b^W;b^W;b^W;b^W;b^W;f^W[f^W[f^
W[f^W[f^W[f^W[f^W[f^W[Z]WKZ]WKZ]WKZ]WKZ]WKZ]WKZ]WKZ]WKZ^W;Z^W;Z^W;Z^W;Z^W;Z^W;Z^
W;Z^W;V]VkV]VkV]VkV]VkV]VkV]VkV]VkV]VkR/V[R/V[R/V[V]VkV]VkZ^W;Z^W;Z^W;R/V[R/V[R/
V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/
V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/V[R/
V[R/V[R/V[R/V[R/V[R/V[Z/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/
VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKZ/VKRZUkRZUkRZUkRZUkV[V;V[V;Z/VKZ/VKZ/VKZ/VKZ/
VKZ/VKZ/VKZ/VKZ/VKZ/VKV[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[V;V[
V;V[V;V/U[V/U[V/U[V/U[V/U[V/U[V/U[V/U[RZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkR[UKR[UKR[
UKR[UKR[UKR[UKR[UKR[UKJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkFXT[JYTkJYTkJYTkNZU;NZU;NZ
U;NZU;NZT;NZT;NZT;NZT;NZT;NZT;NZT;NZT;JYSkJYSkJYSkJYSkJYSkJYSkJYSkJYSkFXS[FXS[FX
S[FXS[FXS[FXS[FXS[FXS[FYSKFYSKFYSKFYSKFYSKFYSKFYSKFYSKBWSKBWSKBWSKBWSKBWSKBWSKBW
SKBWSKFYSKFYSKFYSKBXS;BXS;BXS;>WRk>WRkBWSKBWSKBWSKBWSKBWSKBWSKBWSKBWSK>WRk>WRk>W
Rk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRkFUR;FUR;FUR;JVRKJVRKJVRKNW
R[NWR[JVRKJVRKJVRKJVRKJVRKJVRKJVRKJVRKFUR;FUR;FUR;FUR;FUR;FUR;FUR;FUR;FUR;FUR;FU
R;FUR;FUR;FUR;FUR;FUR;FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[FVQ[BUQKBUQKBUQKBUQKBUQKBUQKBU
QKBUQK>TQ;>TQ;BUQKFVQ[FVQ[BUQK>TQ;>TQ;BUQKBUQKBUQKBUQKBUQKBUQKBUQKBUQKBUQKBUQKBU
QKBUQKBUQKBUQKBUQKBUQK:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPk:S
Pk:SPkBTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;>SOkBTP;BT
P;BTP;FUPKFUPKFUPKFUPKJVP[JVP[JVP[JVP[JVP[JVP[JVP[JVP[BTP;BTP;BTP;BTP;BTP;BTP;BT
P;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;:RO[>SOkBTP;FUPKJVP[FUPKFUPKBTP;BTP;BTP;BT
P;BTP;BTP;BTP;BTP;BTP;NWPkFUPK:RO[>SOkBTP;JVP[FUPKBTP;BTOkBTOkBTOkBTOkBTOkBTOkBT
OkBTOkJTOkJTOkFSO[BROKBROKFSO[JTOkJTOkFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFT
OKFTOKFTOKFTOKFTOKFTOKBSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;BS
O;BSO;>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk:QN[:QN[:QN[>RNk>RNkBSO;BSO;BSO;:QN[:QN[:Q
N[>RNk>RNkBSO;BSO;BSO;:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:Q
N[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:RMk:RMk:R
Mk>RMkFRMkFRMkNQMkNQMk>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>Q
N;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;RTM;RTM;JT
MKJSN;>QN;6PNK2NNJnLNIfFOIfFOI^EOYNCP9FCPI>CPi6APhnAQI2?PI2?PI2?PI6@PY6@PY:APi:A
Pi:APhf@PHnBPi2CQ92CQ8nBPhnBPi6DQI>FQhj@Q9>ERI^MTJBVVZV[Wj^]XJZ/X:V[Wk:aXjZXWJf]
XJJWWJbbYj6YWe9KDA8J4`P@1A<K44I>@diFBci6>d18?Ca4>D59?UIQDEQSDfMaHG1gJ79eIWalK/G4
][RgZK2bY[:bY[>aY[FaY[BbYk6cYjfdYj^eZ4UJC`8@1ADM4c/n=MOEcMKDc;Be[;>f[K:dZ;:dZ;6c
Yk6cYk6cYk6cYk:dZ;>eZKFf[;Jg[KRi[kVj/;^l/[^l/[^l/[^l/[Zk/KZk/KZk/KZk/K^l/[^l/[bm
/kbm/kZk/K^l/[bm/kfn];fn];fn];bm/kbm/kfm[kRj[[Jj[kRk/[jo]L2m[kbdXkR]VKRVOKNUO;NU
O;JTNkJTNkNUO;NUO;RVOKZUN;ZUN;ZUN;ZUN;ZUN;ZUN;ZUN;ZUN;JVN;JVN;JVN;JVN;JVN;JVN;JV
N;JVN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;JVN;NWNKNWNKNWNKNWNKNWNKNWNKNWNKNWNKNUO;ZXOkbZ
PKbZPKZXOkVWO[VWO[ZXOkRVOKRVOKRVOKRVOKNUO;NUO;NUO;JTNkJTNkJTNkJTNkNUO;NUO;NUO000
_:jL_:jL_:jL_:jL_:jL_:jL_:jL_:jL_JjN_JjN_JjN_JjN_JjN_JjN_JjN_JjN^ZfM^ZfM^ZfM^ZfM
^ZfM^ZfM^ZfM^ZfM^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^ZjL^JfK^JfK^JfK^JfK^JfK^JfK^JfK^JfK
^:bJ^:bJ^:bJ^:bJ^JfK^JfK^JfK^ZjL]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I
]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I
]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I]j^I^J^H^J^H^J^H^J^H
^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H
]jVF]jVF^:ZG^:ZG^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^J^H^:ZG^:ZG^:ZG^:ZG
^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:^E^:^E^:^E^:^E^:^E^:^E^:^E^:^E
]jVF]jVF]jVF]jVF]jVF]jVF]jVF]jVF]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]ZVC]ZVC]ZVC]ZVC
]ZVC]ZVC]ZVC]ZVC]JRB]JRB]JRB]ZVC]ZVC]jZD]jZD^:^E]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@]jZ@
]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]ZV?]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JR>]JV=]JV=]JV=]JV=
]JV=]JV=]JV=]JV=]:N=]:N=]:N=]:N=]:N=]:N=]:N=]:N=]JV=]JV=]JV=]:R</jN;/jN;/jN;/ZJ:
]:N=]:N=]:N=]:N=]:N=]:N=]:N=]:N=/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;/jN;
/jN;/jN;/jN;/jN;]:B7]:B7]JF8]JF8]ZJ9]ZJ9]jN:]jN:]JF8]JF8]JF8]JF8]JF8]JF8]JF8]JF8
]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:F5]:F5]:F5]:F5
]:F5]:F5]:F5]:F5/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/Z>3/jB4]:F5]JJ6]JJ6]:F5/jB4/Z>3
/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4/Z>3/Z>3/Z>3/Z>3
/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0
]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0/j=o/j=o]:B0]:B0]:B0]JF1]JF1]JF1]JF1]JF1]JF1]JF1
]JF1]JF1]JF1]JF1]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0
/Z9n/j=o]:B0]JF1]JF1]JF1]JF1]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]ZJ2]:B0/Z9n/Z9n
]:B0]JF1]JF1]:B0]:Ao]:Ao]:Ao]:Ao]:Ao]:Ao]:Ao]:Ao]ZAo]J=n]J=n]:9m]:9m]J=n]J=n]ZAo
]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]JAm]:=l]:=l]:=l]:=l
]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k
/Z5j/Z5j/Z5j/j9k/j9k/j9k]:=l]:=l/Z5j/Z5j/Z5j/j9k/j9k/j9k]:=l]:=l/Z5j/Z5j/Z5j/Z5j
/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j
/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z=e/Z=e/Z=e/j=e]J9e]J9e]j9e]j9e/j5h/j5h/j5h/j5h
/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h
/j5h/j5h/j5h/j5h/j5h/j5h/j5h/j5h]J=d]J=d]:5d/Z5f/j5h/Z5j/Z1k/YmlX9MlWiIkWIImVYF0
UI>1Ti>3TY:4Si65TI22TI22TI22TI22TI22TY63TY63TY63SY62Si:3T9>4Si:3SY62Si:3TYF6UIR9
TI>7TiF9UYR<VifAXJ>GYZRLZZbP[:jR[:VKZjNL/[:VZjbR/;J[Y:bRCeY@2A@<4AD:;30U/;BYcM76
[K6V^KfbZjnT][Z_][NW/;6Q_Kj^/[>S/K:RZ:RH^KVYZJVI[k6U/K6U/[2U]K6V];:W/K>W[KBWZkFX
FV]P2QP=6b<I<3<Zdm79fmWA][N^[k:Y/kFY/[BX/K>W/K>W/;:V/;:V/K>W/[BX/kBZ];F[][N]^;V_
^KZ`^[^a^[^a^[^a^KZ`^KZ`^[^a^[^a^kbb^kbb^kbb^kbb^KZ`^[^a^kbb_;fc_Kjd_Kjd_;fc_;fc
_;f]^Kb]]k^`][Zd^[fd_[bb_KNZ_;>U^JMn^:Im]ZAk]J=j]J=j]ZAk^:Im^JMn^ZEh^ZEh^ZEh^ZEh
^ZEh^ZEh^ZEh^ZEh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh]ZIh
]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jMi]jEl^JMn_:Z1_:Z1^ZQo^:Im^:Im^JMn^:Im^:Im^:Im^:Im
]jEl]jEl]ZAk]J=j]ZAk]ZAk]ZAk]jEl]jEl]ZAk002l[Ybl[Ybl[Ybl[Ybl[Ybl[Ybl[Ybl[Ybm[Yjm
[Yjm[Yjm[Yjm[Yjm[Yjm[Yjm[Yjj[Ifj[Ifj[Ifj[Ifj[Ifj[Ifj[Ifj[Ifj[Ybj[Ybj[Ybj[Ybj[Ybj
[Ybj[Ybj[Ybh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9Zh[9ZgZiVh[9Zh[9Zh[9Zi[I^i[I^i[I^i[I^gZiVg
ZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVg
ZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVgZiVg
ZiVgZiVgZiVgZiVgZiVgZiVgZiViZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRi
ZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRiZiRgZIJgZIJhZYNhZYNhZYNiZiRiZiRiZiRiZiRi
ZiRiZiRiZiRiZiRiZiRiZiRiZiRhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNh
ZYNhZYNhZYNhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZIJgZYBg
ZYBgZYBgZYBgZYBgZYBgZYBgZYBfZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>dYi6dYi6eZ9:fZI>fZI>g
ZYBgZYBhZiFgZY2gZY2gZY2gZY2gZY2gZY2gZY2gZY2fZHnfZHnfZHnfZHnfZHnfZHnfZHnfZHneZ8je
Z8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZHfeZHfeZHfeZHfeZHfeZHfeZHfeZHfdYhfdYhfdYhfdYhfdYhfd
YhfdYhfdYhfeZHfeZHfdZ8bdZ8bcYh^cYh^bYXZbYXZdYhfdYhfdYhfdYhfdYhfdYhfdYhfdYhfbYXZb
YXZbYXZbYXZbYXZbYXZbYXZbYXZbYXZbYXZbYXZbYXZbYXZbYXZbYXZbYXZdY8NdY8NdY8NeYHRfYXVf
YXVgYhZgYhZeYHReYHReYHReYHReYHReYHReYHReYHRdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8Nd
Y8NdY8NdY8NdY8NdY8NdY8NdY8NdYHFdYHFdYHFdYHFdYHFdYHFdYHFdYHFcY8BcY8BcY8BcY8BcY8Bc
Y8BcY8BcY8BaXX:bXh>dYHFeYXJeYXJdYHFbXh>aXX:cY8BcY8BcY8BcY8BcY8BcY8BcY8BcY8BcY8Bc
Y8BcY8BcY8BcY8BcY8BcY8BcY8BbXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>b
Xh>bXh>bXh>dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82cXgnc
XgncXgndY82dY82dY82eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6eYH6dY82dY82dY82dY82dY82d
Y82dY82dY82dY82dY82dY82dY82dY82dY82dY82dY82bXWjcXgndY82eYH6eYH6eYH6dY82dY82dY82d
Y82dY82dY82dY82dY82dY82dY82fYX:dY82bXWjbXWjdY82eYH6eYH6dY82dY7ndY7ndY7ndY7ndY7nd
Y7ndY7ndY7nfY7neXgjdXWfdXWfdXWfdXWfeXgjfY7neY7feY7feY7feY7feY7feY7feY7feY7feY7fe
Y7feY7feY7feY7feY7feY7feY7fdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbd
XgbdXgbdXgbcXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^aX7VbXGZbXGZbXGZcXW^cXW^cXW^dXgbaX7Vb
XGZbXGZbXGZcXW^cXW^cXW^dXgbaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7Va
X7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaXWBa
XWBaXWBbXWBdXGBdXGBfXGBfXGBbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7Nb
X7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NbXWBb
XWBaX7FaWgJaX7VbX7^dXWfeXWnRUg^PUgbMUWfJUH2HU86CTh>BTXB@TXJAT8:AT8:AT8:AT8:BTH>B
TH>BTH>BTH>?TX>@ThB@ThB?TX>>TH:@ThBCUXNFVHZFV8bDUXZCUHVEUh^IVhnQXiNYZin^/:BaZij]
ZIja[jBTYI^Y[jBS[:9HHeTE8QX@3`DW9Qc;b/3Mg=:RXIN`[jFPWiFd/jVg/:6YY9Fi]:FWY9Fh]JJe
]JFf]ZJa/Z:^/J:a/J>b/J>e/ZBc/ZBa]:F]]:F[]ZIDIEX95``O9adY;2?9akoDd/Zf]jjd]jjc]JVc
]JVa/jN`/ZJ`/ZJ`/ZJ`/ZJa/jNb/jVc]:Ze]Zbg^:jh^Jni^[2i^[2i^[2i^[2i^[2j^k6j^k6j^k6k
_;:k_;:k_;:i^[2i^[2k_;:l_K>m_[Bm_[Bl_K>l_K>l_Jfj_Jje^k2f^[Bi^kFl^[:m^Jjo]jZiYgjh
YWffY7^eXgZeXgZfY7^hYWfiYgjjYGRjYGRjYGRjYGRjYGRjYGRjYGRjYGRfYWRfYWRfYWRfYWRfYWRf
YWRfYWRfYWRfYWRfYWRfYWRfYWRfYWRfYWRfYWRfYWRgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYgVgYGbi
YgjlZX6lZX6jZ7nhYWfhYWfhYWfgYGbgYGbhYWfhYWfhYWfgYGbfY7^eXgZfY7^fY7^gYGbgYGbfY7^e
XgX00;b^W;b^W;b^W;b^W;b^W;b^W;b^W;b^W;V[VKZ/V[Z/V[Z/V[^]Vk^]Vk^]Vkb^W;b^W;b^W;b^
W;b^W;b^W;b^W;b^W;b^W;^]Vk^]Vk^]Vk^]Vk^]Vk^]Vk^]Vk^]VkZ/V[Z/V[V[VKRZV;RZV;V[VKZ/
V[Z/V[V[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKRZV;RZV;RZ
V;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;NYUkNYUkRZV;RZV;V[VKV[VKV[
VKV[VKRZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZUkRZ
UkRZUkRZUkRZUkRZUkRZUkR[UKR[UKR[UKR[UKR[UKR[UKR[UKR[UKNZU;NZU;R[UKR[UKV/U[V/U[V/
U[V/U[RZU;RZU;V[UKV[UKZ/U[Z/U[Z/U[Z/U[NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZU;NZ
U;NZU;NZU;NZU;NZU;NZU;JYTkJYTkNZU;NZU;NZU;R[UKR[UKR[UKRZU;RZU;RZU;RZU;RZU;RZU;RZ
U;RZU;NYTkNYTkNYTkNYTkNYTkNYTkNYTkNYTkNYTkNYTkNYTkNYTkNYTkNYTkNYTkNYTkJXT[JXT[JX
T[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JZS[JZS[JZS[JZS[JZS[JZS[JZ
S[JZS[ZYS[ZYS[ZYS[ZYS[ZYS[ZYS[ZYS[ZYS[VXSKVXSKVXSKVXSKVXSKVXSKVXSKVXSKRWS;RWS;RW
S;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;NVRkNVRkJUR[JUR[JUR[JUR[NV
RkNVRk>WRk>WRk>WRk>WRk>WRk>WRk>WRk>WRkNVRkNVRkNVRkNVRkNVRkNVRkNVRkNVRkFTRKFTRKFT
RKFTRKFTRKFTRKFTRKFTRKFUR;FUR;FVQ[FVQ[FVQKFVQKFWPkFWPkBUQKBUQKBUQKBUQKBUQKBUQKBU
QKBUQKJTQKJTQKJTQKJTQKJTQKJTQKJTQKJTQK:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPkFSQ;FSQ;FS
Q;FSQ;FSQ;FSQ;FSQ;FSQ;BRPkBRPkFSQ;FSQ;FSQ;JTQKJTQKJTQKFSQ;FSQ;FSQ;FSQ;FSQ;FSQ;FS
Q;FSQ;BRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBR
PkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPk>SOk>SOk>SOk>SOk>SOk>SOk>S
Ok>SOk>SO[>SO[BTOkBTOkBTOkFUP;FUP;FUP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;BTP;FSO[FSO[FS
O[FSO[FSO[FSO[FSO[FSO[FUP;BTOkBTOk>SO[>SO[:ROK:ROK6QO;JSP;JSP;JSP;JSP;JSP;JSP;JS
P;JSP;FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FSO[FS
O[FSO[FSO[FSO[FSO[FSO[FTOKFTOKFTOKFTOKFTOKFTOKFTOKFTOKFSO[FSO[FSO[FSO[FSO[FSO[FS
O[FSO[>RNk>RNk>RNkBSO;BSO;BSO;FTOKFTOKBSO;BSO;BSO;BSO;BSO;BSO;BSO;BSO;>RNk>RNk>R
Nk>RNk>RNk>RNk>RNk>RNk>SNK>SNK>SNK>SNK>SNK>SNK>SNK>SNK>SNK>SNK>SNK>SNK>SNK>SNK>S
NK>SNK:RN;:RN;:RN;:RN;6QMk6QMk6QMk6QMk>QN;>QN;>QN;>QN;>QN;>QN;>QN;>QN;:RN;:RN;:R
N;:RN;:RN;:RN;:RN;:RN;6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6O
M[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6Q
Lk6QLk6QLk6QLk6QLk6QLk6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[2NMK2NMK6OM[:PMk>Q
N;>QN;6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[FTOK2PNjVJ
NJ2EMi^ANIZAOIVBPI^DQIRGPiJEPIBBP9:@OY6?OI6API>CPiBDQ9>BQ9>BQ9>BQ9:APi:APi:APi:A
Pi:APiJIRYNJRiNJRiFHRIBGR9NJRinRTjFXVK2`Y:R[W:FXV:V_W:BZVJ>ZWGYoMPX@2`4B1aHW6Zfn
/L?Ba:FdYZ:_WjZfY9fYUj^YW[Zh[K2^Xjj/XK2^Xk6_Y;Vg[:NUVZf_Xjf_Xjf_Xjj`Y:j`Y:j`Y:na
YJnaYF5bI`lM4R8Z82@W7/G3^mOEcKJg[[:e[;>dZ[>dZ[6bZ;2aYk2aYk2aYk6bZ;6bZ;2aYk:cZKBe
ZkJg[KRi[kVj/;Zk/KZk/KZk/KZk/KVj/;Vj/;Zk/K^l/[bm/kbm/kVj/;Zk/K^l/[bm/kfn];bm/kbm
/kbm/k^l/[^l/[^l/[Zk/KZk/KZk/KVj/;Vj/;biY;6WSk6NOKfSNl:WNkZSM[:QM[6UNk^VNK^VNKZU
N;VTMkRSM[RSM[NRMKNRMKVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVTMkVT
MkVTMkBTM[BTM[BTM[FUMkFUMkFUMkJVN;JVN;bWN[bWN[bWN[^VNK^VNK^VNK^VNK^VNKRXN[NWNKNW
NKJVN;JVN;FUMkFUMkBTM[FSN[FSN[FSN[FSN[FSN[FSNP00_:jL_:jL_:jL_:jL_:jL_:jL_:jL_:jL
^J^I^ZbJ^ZbJ^ZbJ^jfK^jfK^jfK_:jL_:jL_:jL_:jL_:jL_:jL_:jL_:jL_:jL^ZbJ^ZbJ^ZbJ^ZbJ
^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^J^I^:ZH^:ZH^J^I^ZbJ^ZbJ^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I
^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH
^:ZH^:ZH^:ZH^:ZH]jVG]jVG^:ZH^:ZH^:ZH^J^I^J^I^J^I^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH
^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:ZG^:^E^:^E^:^E^:^E
^:^E^:^E^:^E^:^E]jZD]jZD^:^E^:^E^:^E^JbF^JbF^JbF^:ZD^:ZD^J^E^J^E^J^E^ZbF^ZbF^ZbF
]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]ZVC]ZVC]ZVC]jZD
]jZD^:^E^:^E^:^E^:ZD^:ZD^:ZD^:ZD^:ZD^:ZD^:ZD^:ZD]jVC]jVC]jVC]jVC]jVC]jVC]jVC]jVC
]jVC]jVC]jVC]jVC]jVC]jVC]jVC]jVC]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB
]ZRB]ZRB]ZRB]ZRB]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>]ZZ>^ZV>^ZV>^ZV>^ZV>^ZV>^ZV>^ZV>^ZV>
^JR=^JR=^JR=^JR=^JR=^JR=^JR=^JR=^:N<^:N<^:N<^:N<^:N<^:N<^:N<^:N<^:N<^:N<^:N<^:N<
^:N<^:N<^:N<^:N<]jJ;]jJ;]ZF:]ZF:]ZF:]ZF:]jJ;]jJ;/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:/ZJ:
]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JF8]JF8]JJ6]JJ6
]JJ5]JJ5]JN3]JN3]:F5]:F5]:F5]:F5]:F5]:F5]:F5]:F5]ZB5]ZB5]ZB5]ZB5]ZB5]ZB5]ZB5]ZB5
/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3]J>4]J>4]J>4]J>4]J>4]J>4]J>4]J>4]::3]::3]::3]J>4
]J>4]ZB5]ZB5]ZB5]J>4]J>4]J>4]J>4]J>4]J>4]J>4]J>4]::3]::3]::3]::3]::3]::3]::3]::3
]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3]::3
]::3]::3]::3]::3/j=o/j=o/j=o/j=o/j=o/j=o/j=o/j=o/j=n/j=n/j=n]:Ao]:Ao]:Ao]JF0]JF0
]:B0]:B0]:B0]:B0]:B0]:B0]:B0]:B0]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]:Ao]:Ao]:Ao/j=n
/Z9m/Z9m/Z9m/J5l]Z>0]Z>0]Z>0]Z>0]Z>0]Z>0]Z>0]Z>0]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n
]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n]JAm]JAm]JAm]JAm
]JAm]JAm]JAm]JAm]J=n]J=n]J=n]J=n]J=n]J=n]J=n]J=n/j9k/j9k/j9k/j9k]:=l]:=l]JAm]JAm
]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j=i/j=i/j=i/j=i
/j=i/j=i/j=i/j=i/j=i/j=i/j=i/j=i/j=i/j=i/j=i/j=i/Z9h/Z9h/Z9h/J5g/J5g/J5g/J5g/J5g
/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/Z1g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/Imf/Imf/Imf/Imf
/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf
/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c/J5c/Imf/Imf/Imf/Imf
/Imf/Imf/Imf/Imf/Imf/Imf/9ie/9ie/Imf/Imf/j5h/j5h/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf
/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Z9h[j1iZieiYiYjXYMkWIImVI9nVI9oUiB5UY>4U962TI61
TI61T961TI:2TY>3Ti:4Ti:4Ti:4Ti:4Ti:4Ti:4Ti:4Ti:4TIB5TYF6TiJ7TIB5T9>4TiJ7V9^<WJ2A
YjNKY:NHYjZJ[;:OXjVHX:NJNWmf3Q@?3A@=6R4J[[>Ze]W@^knd[[2T/K>W/;2T]K>X]kFZYJ>H[:ZO
/k6V[jfR]kFZ/:jS[JnS[JnS[JnS[[2T[[2T[[2T[k6U[k6UJGY_4R0E7BDK7b8I_[bdf=K>^KZa];N^
/kBZ/kBZ/[>Y/[>Y/K:X/;6W/;6W[k2V/K:X/K:X/[>Y];F[][N]]kR^^KZ`^[^a^[^a^[^a^KZ`^KZ`
^KZ`^[^a^kbb_;fc^KZ`^[^a^kbb_;fc_;fc_;fc_;fc^kbb^kbb^kbb^kbb^[^a^[^a^[^a^KZ`^KZ`
_;^W]JjE]::3^J9l_JAj^jAg]JAi/jIj^:=f^:=f^:=f^JAg^JAg^JAg^JAg^JAg^JAg^JAg^JAg^JAg
^JAg^JAg^JAg^JAg^JAg^JAg^JAg^JAg^JAg^JAg^JAg^JAg]:Af]:Af]:Af]:Af]JEg]JEg]ZIh]ZIh
^jIi^jIi^jIi^jIi^jIi^jIi^ZEh^ZEh]jMi]jMi]jMi]ZIh]JEg]JEg]JEg]:Af]J=j]J=j]J=j]J=j
]J=j]J=j002k[I^k[I^k[I^k[I^k[I^k[I^k[I^k[I^iZiVj[9Zj[9Zj[9Zk[I^k[I^k[I^l[Ybk[I^k
[I^k[I^k[I^k[I^k[I^k[I^k[I^j[9Zj[9Zj[9Zj[9Zj[9Zj[9Zj[9Zj[9Zj[9ZiZiViZiVhZYRhZYRi
ZiViZiVj[9ZiZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiViZiVhZYRh
ZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRgZINgZINgZINhZYRhZYRh
ZYRiZiViZiVhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNhZYNh
ZYNhZYNhZYNhZYNhZYNhZYNhZYNhZiFhZiFhZiFhZiFhZiFhZiFhZiFhZiFgZYBgZYBgZYBhZiFhZiFh
ZiFi[9Ji[9JhZYBhZYBhZYBiZiFiZiFiZiFj[9Jj[9JgZYBgZYBgZYBgZYBgZYBgZYBgZYBgZYBgZYBg
ZYBgZYBgZYBgZYBgZYBgZYBgZYBfZI>fZI>fZI>fZI>gZYBgZYBhZiFhZiFhZYBhZYBhZYBhZYBhZYBh
ZYBhZYBhZYBgZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>gZI>fZ9:f
Z9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eZHfeZHfeZHfeZHfeZHfe
ZHfeZHfeZHfiZ8fiZ8fiZ8fiZ8fiZ8fiZ8fiZ8fiZ8fhYhbhYhbhYhbhYhbhYhbhYhbhYhbhYhbgYX^g
YX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^fYHZfYHZfYHZf
YHZgYX^gYX^bYXZbYXZbYXZbYXZbYXZbYXZbYXZbYXZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZeY8Ve
Y8VeY8VeY8VeY8VeY8VeY8VeY8VeYHReYHReYXJeYXJeYXFeYXFeYh>eYh>dYHFdYHFdYHFdYHFdYHFd
YHFdYHFdYHFfY8FfY8FfY8FfY8FfY8FfY8FfY8FfY8FbXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>eXhBe
XhBeXhBeXhBeXhBeXhBeXhBeXhBdXX>dXX>dXX>dXX>eXhBeXhBfY8FfY8FeXhBeXhBeXhBeXhBeXhBe
XhBeXhBeXhBdXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>d
XX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>dXX>cXgncXgncXgncXgncXgnc
XgncXgncXgncXgjcXgjcXgjcXgjdY7ndY7ndY7neYH2dY82dY82dY82dY82dY82dY82dY82dY82dXWfd
XWfdXWfdXWfdXWfdXWfdXWfdXWfcXgjcXgjcXgjcXgjbXWfbXWfbXWfaXGbfXh2fXh2fXh2fXh2fXh2f
Xh2fXh2fXh2dXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfdXWfd
XWfdXWfdXWfdXWfdXWfdXWfdXWfdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXgbdXWfdXWfdXWfdXWfdXWfd
XWfdXWfdXWfbXGZbXGZcXW^cXW^dXgbdXgbdXgbdXgbcXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^bXGZb
XGZbXGZbXGZbXGZbXGZbXGZbXGZbXWRbXWRbXWRbXWRbXWRbXWRbXWRbXWRbXWRbXWRbXWRbXWRbXWRb
XWRbXWRbXWRaXGNaXGNaXGNaXGNaXGNaXGNaXGNaXGNbX7NbX7NbX7NbX7NbX7NbX7NbX7NbX7NaXGNa
XGNaXGNaXGNaXGNaXGNaXGNaXGNaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJa
WgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>aXG>a
XG>aXG>aXG>aXG>aXG>aXG>aXG>aWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJ`WWF`WWF`WWF`WWFa
WgJbX7NcXGRaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJ^Wg6`
X7F`XWR]XWbYWgfTVWbNUWVITWNFTXNFTXNCTHJBTXBBTXB?TX:?TX:=Th:DThFDThFDThFDThFDThFD
ThFDThFDThF?TX>@ThBAU8FAU8F@ThBAU8FDUhRFVHZKVhnNXI:VZIV]/j2RZ9NOYYUlPGPD6QD=2@PH
51>QWY[PfmSGdLc:a;g>a[oBbl;@c/?;bKj^[:6b/:Fi]jb/ZYn`[Z>a[jB][j>][j>][j>^/:B^/:B^
/:B_/JF_/JEdQGXE8aPG7aDJ7ABd/Z[Ielnl_KBc]Zfc]:Zc]:Zd]J^d]J^c]:Za/ZR_/:J][ZBa/ZR`
/JN`/JNa/ZRb/jVe]Zbg^:ji^[2j^k6i^[2i^[2i^[2i^[2j^k6k_;:l_K>i^[2j^k6k_;:l_K>l_K>l
_K>k_;:k_;:k_;:k_;:k_;:j^k6j^k6j^k6i^[2i^[2m^jVk]:2gZHfcWgbeWgJjY7ZhYgbaY7RfXGBf
XGBgXWFhXgJiY7NjYGRjYGRkYWVhXgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJhXgJh
XgJhXgJhXgJcXgFcXgFdY7JdY7JeYGNeYGNeYGNeYGNjYGRjYGRjYGRjYGRjYGRjYGRjYGRjYGRfYWRf
YWRfYWRfYWReYGNeYGNeYGNdY7JeXgZeXgZeXgZeXgZeXgZeXgX00;^]Vk^]Vk^]Vk^]Vk^]Vk^]Vk^]
Vk^]VkV[VKZ/V[Z/V[Z/V[^]Vk^]Vk^]Vkb^W;^]Vk^]Vk^]Vk^]Vk^]Vk^]Vk^]Vk^]VkZ/V[Z/V[Z/
V[Z/V[Z/V[Z/V[Z/V[Z/V[V[VKV[VKRZV;RZV;RZV;RZV;V[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[
VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNY
UkNYUkNYUkNYUkNYUkNYUkJXU[JXU[NYUkNYUkRZV;RZV;RZV;RZV;NYUkNYUkNYUkNYUkNYUkNYUkNY
UkNYUkNYU[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NYU[NZU;NZU;NZ
U;NZU;NZU;NZU;NZU;NZU;JYTkJYTkNZU;NZU;R[UKR[UKR[UKR[UKNYTkNYTkRZU;RZU;V[UKV[UKV[
UKV[UKJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkFXT[FXT[JY
TkJYTkJYTkNZU;NZU;NZU;NYTkNYTkNYTkNYTkNYTkNYTkNYTkNYTkJXT[JXT[JXT[JXT[JXT[JXT[JX
T[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[FWTKFWTKFW
TKFWTKFWTKFWTKFWTKFWTKFYSKFYSKFYSKFYSKFYSKFYSKFYSKFYSKVXSKVXSKVXSKVXSKVXSKVXSKVX
SKVXSKRWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;NVRkNVRkNVRkNVRkNVRkNVRkNVRkNVRkNVRkNVRkNV
RkNVRkNVRkNVRkNVRkNVRkNVRkNVRkJUR[JUR[JUR[JUR[NVRkNVRk:VR[:VR[:VR[:VR[:VR[:VR[:V
R[:VR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[FTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFUR;FUR;FV
Q[FVQ[FVQKFVQKFWPkFWPk>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;FSQ;FSQ;FSQ;FSQ;FSQ;FSQ;FS
Q;FSQ;:SPk:SPk:SPk:SPk:SPk:SPk:SPk:SPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPk>QP[>QP[BR
PkBRPkBRPkFSQ;FSQ;FSQ;BRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPk>QP[>QP[>QP[>QP[>QP[>QP[>Q
P[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[>Q
P[>QP[>QP[>QP[>QP[>QP[>SOk>SOk>SOk>SOk>SOk>SOk>SOk>SOk:ROK:ROK>SO[>SO[>SO[BTOkBT
OkBTOk>SOk>SOk>SOk>SOk>SOk>SOk>SOk>SOkBROKBROKBROKBROKBROKBROKBROKBROK:ROK:ROK:R
OK:ROK:ROK:ROK:ROK:ROKFROkFROkFROkFROkFROkFROkFROkFROkBROKBROKBROKBROKBROKBROKBR
OKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBROKBSO;BSO;BS
O;BSO;BSO;BSO;BSO;BSO;BROKBROKBROKBROKBROKBROKBROKBROK:QN[:QN[:QN[>RNk>RNk>RNkBS
O;BSO;>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk:QN[:QN[:QN[:QN[:QN[:QN[:QN[:QN[:RN;:RN;:R
N;:RN;:RN;:RN;:RN;:RN;:RN;:RN;:RN;:RN;:RN;:RN;:RN;:RN;2PM[2PM[2PM[2PM[6QMk6QMk6Q
Mk6QMk:PMk:PMk:PMk:PMk:PMk:PMk:PMk:PMk6QMk6QMk6QMk6QMk6QMk6QMk6QMk6QMk6OM[6OM[6O
M[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6O
M[6OM[6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6QLk6OM[6OM[6O
M[6OM[6OM[6OM[6OM[6OM[2NMK2NMK2NMJnMM;2NMK6OM[:PMk>QN;6OM[6OM[6OM[6OM[6OM[6OM[6O
M[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OMZjPKk2RL[2SMK6SNJjRNZVMNJ>IMj6GMINAQYJBQiJB
QiFDQY6DQHjDPhfCPXZBPIBCQIBCQIFDQYFDQYFDQYFDQYJEQiJEQi:EQY>FQiBGR9BGR9BGR9BGR9BG
R9BGR9FERINJRj2STjV_W:>YV:>ZWGn4NaHL5a8D51XL78J6Q/W:b<k=bMKCcmWFdMODclg;`=WGc;bj
[k:`YKRfZjf[X:j/XJn]XZf_Xjf_Xjf_Xjj`Y:j`Y:j`Y:naYJnaYGf>PaLU6Q<K4ATL4jZXX=cJd[jo
][2cZ[:cZK>dZ[Ff[;Jg[KBeZk:cZJj_YJb]Xk6bZ;2aYjj_YJj_YJn`Y[:cZKJg[KRi[kVj/;Vj/;Ri
[kRi[kVj/;Zk/K^l/[^l/[Ri[kVj/;Zk/K^l/[bm/k^l/[^l/[^l/[^l/[^l/[^l/[Zk/KZk/KZk/KVj
/;Vj/;^kZkjjYk^_Uk2NPJjJMkRTNkRXN[6RM;NRMKNRMKNRMKRSM[RSM[VTMkVTMkVTMkRSM[RSM[RS
M[RSM[RSM[RSM[RSM[RSM[RSM[RSM[RSM[RSM[RSM[RSM[RSM[RSM[>SMK>SMK>SMKBTM[BTM[BTM[FU
MkFUMkVTMkVTMkVTMkVTMkVTMkZUN;ZUN;ZUN;FUMkFUMkFUMkFUMkFUMkFUMkFUMkFUMkFSN[FSN[FS
N[FSN[FSN[FSNP00^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^J^I^ZbJ^ZbJ^ZbJ^jfK^jfK^jfK_:jL
^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^ZbJ^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^:ZH^:ZH]jVG
]jVG^:ZH^:ZH^J^I^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH
]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]ZRF]ZRF]ZRF]jVG
]jVG]jVG^:ZH^:ZH]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVF]jVF]jVF]jVF]jVF]jVF]jVF]jVF
]jVF]jVF]jVF]jVF]jVF]jVF]jVF]jVF]jZD]jZD]jZD]jZD]jZD]jZD]jZD]jZD]ZVC]ZVC]ZVC]jZD
]jZD]jZD^:^E^:^E]jVC]jVC]jVC^:ZD^:ZD^:ZD^J^E^J^E]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC
]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]JRB]JRB]JRB]ZVC]ZVC]ZVC]jZD]jZD]jVC]jVC]jVC]jVC
]jVC]jVC]jVC]jVC]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB
]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JV=]JV=]JV=]JV=
]JV=]JV=]JV=]JV=^JR=^JR=^JR=^JR=^JR=^JR=^JR=^JR=]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;]jJ;
]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]jJ;]jJ;]ZF:]ZF:
]ZF:]ZF:]jJ;]jJ;/JF9/JF9/JF9/JF9/JF9/JF9/JF9/JF9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9
]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:B7]:B7]:F5]:F5]:F4]:F4]:J2]:J2/jB4/jB4/jB4/jB4
/jB4/jB4/jB4/jB4]J>4]J>4]J>4]J>4]J>4]J>4]J>4]J>4/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3
]::3]::3]::3]::3]::3]::3]::3]::3/j62/j62/j62]::3]::3]::3]J>4]J>4]::3]::3]::3]::3
]::3]::3]::3]::3/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62
/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j62/j=o/j=o/j=o/j=o
/j=o/j=o/j=o/j=o/Z9m/Z9m/Z9m/Z9m/j=n/j=n]:Ao]:Ao/j=o/j=o/j=o/j=o/j=o/j=o/j=o/j=o
]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m/J5l/J5l/J5l/J5l/Z9m/Z9m/Z9m/Z9m]J9o]J9o]J9o]J9o
]J9o]J9o]J9o]J9o]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m
]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:9m]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:=l]:9m]:9m]:9m]:9m
]:9m]:9m]:9m]:9m/J1i/J1i/Z5j/Z5j/j9k/j9k/j9k/j9k/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j
/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g/J5g
/J5g/J5g/J5g/J5g[ime[ime[ime/:1f/:1f/J5g/J5g/Z9h/Imf/Imf/Imf/Imf/Imf/Imf/Imf/Imf
/:1f/:1f/:1f/:1f/:1f/:1f/:1f/:1f/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie
/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/:1b/:1b/:1b/:1b/:1b/:1b/:1b/:1b
/:1b/:1b/:1b/:1b/:1b/:1b/:1b/:1b/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie[ied[ied
[ied/9ie/Imf/Z1g/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie
/Z=b/J=c/J=c/:5c[Z1f[IigZYifZYegViB1Vi>2ViB3UiF3UIF5TIB4SY>4Ri:3U9>5U9>5U9>5UIB6
UIB6UYF7UYF7UYF7TiJ7U9N8U9N8UIR9UYV:UYV:U9N8TiJ7UIF9TYF6UYV9XZREXZRGYjjQPhQo5Q`G
0Q0>00P67bd[=TA09c<];c/e:cH^6B@LXZ2EdLo4_kfbZ:JK[jfR/:jS/k6V/JnT[JnS[JnS[JnS[[2T
[[2T[[2T[k6U[k6UPiB96BLL4AT?6ahEXInGgM_C_l2g[:nV/[>Y/kBZ]KJ/][N]]KJ//kBZ[k2V[JjT
/K:X[k2V[ZnU[JjT[ZnU/K:X];F[][N]^KZ`^;V_^;V_^;V_^;V_^KZ`^[^a^kbb^;V_^KZ`^[^a^kbb
^kbb^kbb^[^a^[^a^kbb^kbb^kbb^[^a^[^a^[^a^KZ`^KZ`]kZ[_[^/^[>P[Z29[9Yk/j9k]ZIh/J5b
^JAg^JAg^:=f^:=f]j9e]j9e]Z5d]Z5d]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e]j9e
]j9e]j9e]j9e]j9e/Z9d/Z9d/j=e/j=e]:Af]:Af]:Af]:Af]j9e]j9e]j9e^:=f^JAg^JAg^JAg^ZEh
]:Af]:Af]:Af]:Af]JEg]JEg]JEg]JEg]J=j]J=j]J=j]J=j]J=j]J=j002j[9Zj[9Zj[9Zj[9Zj[9Zj
[9Zj[9Zj[9ZiZiVj[9Zj[9Zj[9Zk[I^k[I^k[I^l[Ybj[9Zj[9Zj[9Zj[9Zj[9Zj[9Zj[9Zj[9ZiZiVi
ZiViZiViZiViZiViZiViZiViZiViZiVhZYRgZINgZINgZINgZINhZYRiZiVhZYRhZYRhZYRhZYRhZYRh
ZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9Jf
Z9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JeYiFfZ9JfZ9JfZ9JgZINgZINgZINgZINfZ9JfZ9JfZ9JfZ9JfZ9Jf
Z9JfZ9JfZ9JfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZI>f
ZI>fZI>fZI>fZI>fZI>fZI>fZI>eZ9:fZI>fZI>fZI>gZYBgZYBgZYBgZYBfZ9:gZI>gZI>gZI>hZYBh
ZYBhZYBhZYBeZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:dYi6d
Yi6eZ9:eZ9:fZI>fZI>fZI>fZI>fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:eYi6eYi6eYi6eYi6eYi6e
Yi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:dYY2d
YY2dYY2dYY2dYY2dYY2dYY2dYY2dZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bdZ8bhYhbhYhbhYhbhYhbhYhbh
YhbhYhbhYhbgYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^fYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZf
YHZfYHZfYHZfYHZfYHZfYHZfYHZgYX^gYX^fYHZfYHZfYHZfYHZgYX^gYX^aYHVaYHVaYHVaYHVaYHVa
YHVaYHVaYHVeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdY8Nd
Y8NdYHFdYHFdYHBdYHBdYX:dYX:bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>dXX>dXX>dXX>dXX>dXX>d
XX>dXX>dXX>bXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:bX86b
X86cXH:cXH:dXX>dXX>dXX>dXX>cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:bX86bX86bX86bX86bX86b
X86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86b
X86bX86bX86bX86bX86bX86bX86cXgncXgncXgncXgncXgncXgncXgncXgnaXGbaXGbbXWfbXWfbXWfc
XgjcXgjcXgjbXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGb`X7^`
X7^aXGbaXGbaXGbbXWfbXWfbXWfdXGjdXGjdXGjdXGjdXGjdXGjdXGjdXGjcXGbcXGbcXGbcXGbcXGbc
XGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXW^c
XW^cXW^cXW^cXW^cXW^cXW^cXW^cXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbaX7VaX7VaX7VbXGZbXGZc
XW^cXW^cXW^bXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZaX7VaX7VaX7VaX7VaX7VaX7VaX7VaX7VaXGNa
XGNaXGNaXGNaXGNaXGNaXGNaXGNaXGNaXGNaXGNaXGNaXGNaXGNaXGNaXGN^WWB^WWB_WgF_WgF`X7Ja
XGNaXGNbXWRaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJ`X7J`X7J`X7J`X7J`X7J`X7J`X7J`X7J`WWF`
WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`
WWF`WWF`WWF`X7:`X7:`X7:`X7:`X7:`X7:`X7:`X7:`X7:`X7:`X7:`X7:`X7:`X7:`X7:`X7:`WWF`
WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF_WGB_WGB^W7>_WGB`WWFaWgJbX7N`WWF`WWF`WWF`WWF`WWF`
WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWF`WWFcXgBaXG>`X7:^WG:^WG:_WGBaWWRbWgVTVG^R
V7ZPUgbKUGjHU86DU8BCThF@TXJBTH>BTH>CTXBDThFEU8JEU8JFUHNFUHNCUXNBUHJAU8FCUXNEV8VE
V8VCUXNAU8FGUh^@ThB@Th>JX8fMXi:V[J25RX4I7aX04@`020<02`<46A403@@F9a`N;b@C9AR;RGk@
c/?4`[NUXiR^[:6a[jBa[jB]Zj2][j>][j>][j>^/:B^/:B^/:B_/JF_/JF8VHhL:Ql@60hL7aJETh_K
fM70`KR/[jJb/jVc]:Zd]J^e]Zbe]Zbc]:Zb/jVa/ZR`/JN_/:J_/:J^[jF_/:Ja/ZRc]:Zd]J^h^Jnh
^Jng^:jg^:jh^Jni^[2j^k6j^k6h^Jnh^Jni^[2j^k6k_;:k_;:j^k6j^k6k_;:k_;:k_;:j^k6j^k6j
^k6i^[2i^[2e^Jfk^jnk]ZNdZYR^XHNaXGfcXgFdXg2iY7NiY7NhXgJgXWFfXGBfXGBeX7>eX7>gXWFg
XWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFbXWBbXWBbXWBcXgFcXgFd
Y7JdY7JdY7JeX7>fXGBfXGBgXWFhXgJiY7NiY7NiY7NcXgFcXgFdY7JdY7JdY7JeYGNeYGNeYGNeXgZe
XgZeXgZeXgZeXgZeXgX00;V[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKZ/V[Z/V[Z/V[^]Vk^]Vk^]
Vkb^W;V[VKV[VKV[VKV[VKV[VKV[VKV[VKV[VKRZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;NY
UkJXU[JXU[NYUkRZV;RZV;NYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNYUkNY
UkNYUkJXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[FWUKFWUKJX
U[JXU[JXU[NYUkNYUkNYUkJXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXUKJXUKJXUKJXUKJXUKJXUKJX
UKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkFXT[FXT[JY
TkJYTkJYTkNZU;NZU;NZU;JXT[JXT[NYTkNYTkNYTkRZU;RZU;RZU;FXT[FXT[FXT[FXT[FXT[FXT[FX
T[FXT[FXT[FXT[FXT[FXT[FXT[FXT[FXT[FXT[BWTKBWTKBWTKFXT[FXT[JYTkJYTkJYTkJXT[JXT[JX
T[JXT[JXT[JXT[JXT[JXT[FWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFW
TKFWTKJXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BXS;BXS;BX
S;BXS;BXS;BXS;BXS;BXS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;RWS;NVRkNVRkNVRkNVRkNVRkNVRkNV
RkNVRkFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKNVRkNVRkJU
R[JUR[JUR[JUR[NVRkNVRk2TR;2TR;2TR;2TR;2TR;2TR;2TR;2TR;BSR;BSR;BSR;BSR;BSR;BSR;BS
R;BSR;>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>SQ[>SQ[>TQ;>TQ;>TPk>TPk>UPK>UPK:SPk:SPk:S
Pk:SPk:SPk:SPk:SPk:SPkBRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPk:SPk:SPk:SPk:SPk:SPk:SPk:S
Pk:SPk>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[:PPK:PPK:PPK>QP[>QP[BRPkBRPkBRPk>QP[>QP[>Q
P[>QP[>QP[>QP[>QP[>QP[:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:P
PK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK:PPK>SOk>SOk>S
Ok>SOk>SOk>SOk>SOk>SOk6QO;6QO;6QO;:ROK:ROK:ROK>SO[>SO[:RO[:RO[:RO[:RO[:RO[:RO[:R
O[:RO[>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO:nON[2PNk2PNk2PNk6QO;:ROK:ROK:ROKBQO[BQO[BQ
O[BQO[BQO[BQO[BQO[BQO[>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>Q
O;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk>QO;>QO;>Q
O;>QO;>QO;>QO;>QO;>QO;6PNK6PNK6PNK6PNK:QN[:QN[:QN[>RNk:QN[:QN[:QN[:QN[:QN[:QN[:Q
N[:QN[2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2PM[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2PM[2P
M[2PM[2PM[2PM[2PM[2PMZfMLjfMLjjNM:nOMK2PM[6QMk6QMk:RN;2NMK2NMK2NMK2NMK2NMK2NMK2N
MK2NMJnOMJnOMJnOMJnOMJnOMJnOMJnOMJnOMJnMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nM
M:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nOLJnOLJnOLJnOLJnOLJnOLJnO
LJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:jL
LjjLLjjLLjnMM;6OM[6OMZnMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nM
M:nMM;2OM;2OM:nNLk2LLk2LLk6LM[>NN;BONJfNL:ZLLZFIMJ2FN9bDOIVBPiNCR9FBRY6@PY6@PY:A
Pi>BQ9BCQIBCQIFDQYJEQi>FQi6DQHnBPi6DQIBGR9FHRIBGR9:EQYRHS96DQHnBPYJLRIFKRZ2WVXF:
PAlU80HG3P<B2P0?11TW700>0PLD1PPB1@D?0XZ8OLg;`;nm/ZJTVKBbYk2^XjZXWJf[X:f_Xjf_Xjf_
Xjj`Y:j`Y:j`Y:naYJnaYHnPUB0^8`lG3AXM58N5OMOEcL;3^[2cZ[:cZK:cZK>dZ[>dZ[BeZkBeZkBe
ZkBeZjn`YZn`Y[2aYk2aYk6bZ;:cZK:cZK>dZ[Ri[kRi[kNh[[Nh[[Nh[[Ri[kVj/;Zk/KNh[[Ri[kVj
/;Zk/KZk/KZk/KZk/KVj/;^l/[^l/[^l/[Zk/KZk/KZk/KVj/;Vj/;Jj[kRi[k^i[[ffYkR/U;2QP;>P
LkVVLkNRMKNRMKNRMKNRMKJQM;JQM;JQM;JQM;NRMKNRMKNRMKNRMKNRMKNRMKNRMKNRMKNRMKNRMKNR
MKNRMKNRMKNRMKNRMKNRMK:RM;:RM;:RM;:RM;>SMK>SMK>SMKBTM[BOL[FPLkFPLkJQM;NRMKRSM[VT
MkVTMk:RM;>SMK>SMK>SMKBTM[FUMkFUMkFUMkFSN[FSN[FSN[FSN[FSN[FSNP00^J^I^J^I^J^I^J^I
^J^I^J^I^J^I^J^I^J^I^ZbJ^ZbJ^ZbJ^jfK^jfK^jfK_:jL^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I
^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH]jVG]jVG]ZRF]ZRF]jVG]jVG^:ZH]jVG]jVG]jVG]jVG
]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF
]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]JNE]JNE]JNE]ZRF]ZRF]ZRF]jVG]jVG]ZRF]ZRF]ZRF]ZRF
]ZRF]ZRF]ZRF]ZRF]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE
]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]JRB]JRB]JRB]ZVC]ZVC]ZVC]jZD]jZD]ZRB]ZRB]ZRB]jVC
]jVC]jVC^:ZD^:ZD]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB]JRB
]:NA]:NA]:NA]JRB]JRB]JRB]ZVC]ZVC]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]JNA]JNA]JNA]JNA
]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB]ZRB
]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:R<]:R<]:R<]:R<]:R<]:R<]:R<]:R<^:N<^:N<^:N<^:N<
^:N<^:N<^:N<^:N<]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9
]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]jJ;]jJ;]ZF:]ZF:]ZF:]ZF:]jJ;]jJ;/:B8/:B8/:B8/:B8
/:B8/:B8/:B8/:B8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7
/j>6/j>6/jB4/jB4/jB3/jB3/jF1/jF1/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3]::3]::3]::3]::3
]::3]::3]::3]::3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/Z>3/j62/j62/j62/j62/j62/j62/j62/j62
/Z21/Z21/Z21/j62/j62/j62]::3]::3/j62/j62/j62/j62/j62/j62/j62/j62/Z21/Z21/Z21/Z21
/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21
/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21/j=o/j=o/j=o/j=o/j=o/j=o/j=o/j=o/J5l/J5l/J5l/J5l
/Z9m/Z9m/j=n/j=n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l
[imj[imj/:1k/:1k/J5l/J5l/Z9m/Z9m]:5n]:5n]:5n]:5n]:5n]:5n]:5n]:5n/j5l/j5l/j5l/j5l
/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l
/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j9k/j5l/j5l/j5l/j5l/j5l/j5l/j5l/j5l/9mh/J1i/J1i/J1i
/Z5j/Z5j/Z5j/Z5j/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh
/:1f/:1f/:1f/:1f/:1f/:1f/:1f/:1f/:1f/:1f/:1f/:1f/:1f/:1f/:1f/:1f[9ab[Iec[Yid[ime
/:1f/J5g/J5g/Z9h/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie[ime[ime[ime[ime[ime[ime[ime[ime
[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied
[ied[ied[ied[ied[ima[ima[ima[ima[ima[ima[ima[ima[ima[ima[ima[ima[ima[ima[ima[ima
[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[Yac[Yac[Yac[ied/9ie/Imf[ied[ied[ied[ied
[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[ied[I]b[Yac/Ied/Iaf/Yeg]9eg]9eg]9eg
/Z9][Ym^Z9]_XYIdWI=kVY:1VI:9VI>>T8n1T8n1TI22TY63Ti:4U9>5UIB6UIB6UYV:TYF6T9>4TIB5
UIR9UiZ;UiZ;UIR9UiN;TiJ7TYF5UI^8SiF4VJ2CQ8V09B/V0PX04QX?;S@YLgM[J6aPJ6]LJ6]KMGIV
P7ic^[R]ZjVNX9jC^;J[[jfRZ:JK]K>X[JnS[JnS[JnS[[2T[[2T[[2T[k6U[k6UU:FJ8c4V3aL=61/B
OWade=;:a<Fl]KR_/[>Y/[>Y/[>Y/[>Y/kBZ];F[][N]]kR^[k2V/;6W/K:X/[>Y/[>Y/[>Y/[>Y/[>Y
^;V_]kR^]kR^]kR^]kR^^;V_^KZ`^[^a]kR^^;V_^KZ`^[^a^[^a^[^a^[^a^KZ`^kbb^kbb^kbb^[^a
^[^a^[^a^KZ`^KZ`][ba][V`_Kbba;ja_[>M/J:1/j1c_ZUe]9mb]J1c]J1c]Z5d]j9e^:=f^:=f^:=f
]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d/J5c/Z9d/Z9d/Z9d
/j=e/j=e/j=e/j=e]9mb]9mb]J1c]Z5d]j9e^:=f^JAg^JAg/Z9d/Z9d/j=e/j=e]:Af]:Af]JEg]JEg
]J=j]J=j]J=j]J=j]J=j]J=j002iZYNiZYNiZYNiZYNiZYNiZYNiZYNiZYNhZYRiZiVj[9Zj[9Zj[9Zj
[9ZiZiVhZYRiZiViZiViZiViZiViZiViZiViZiViZiVhZYRhZYRhZYRhZYRhZYRhZYRhZYRhZYRiZiVi
ZiVhZYRhZYRgZINfZ9JfZ9JfZ9JgZINgZINgZINgZINgZINgZINgZINgZINfZ9JfZ9JfZ9JfZ9JfZ9Jf
Z9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9Jf
Z9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9Ff
Z9FfZ9FfZ9FdYY>eYiBeYiBfZ9FfZ9FgZIJgZIJhZYNfZI>fZI>fZI>fZI>fZI>fZI>fZI>fZI>fZ9:f
Z9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:eYi6eYi6eYi6eYi6eYi6e
Yi6eYi6eYi6fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:fZ9:eYi6e
Yi6eYi6eYi6eYi6eYi6eYi6eYi6eZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeYi6eYi6eYi6eYi6eYi6e
Yi6eYi6eYi6eZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jeZ8jdYhfdYhfdYhfdYhfdYhfdYhfdYhfdYhfgYX^g
YX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^gYX^g
YX^gYX^gYX^eY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8Ve
Y8VeY8VeY8VeY8VeY8VeY8VeY8VdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdY8NdY8NdY8NdY8NdY8Nd
Y8NdY8NdY8NcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcY8BcY8BcY8BcY8BcY8BcY8BcY8BcY8BdXX>d
XX>dXX>dXX>dXX>dXX>dXX>dXX>cXgncXgncXgncXgncXgncXgncXgncXgnbXWjcXgncXgndY82dY82c
XgncXgnbXWjbX86bX86bX86bX86bX86bX86bX86bX86bXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjbXWjb
XWjbXWjbXWjbXWjbXWjbXWjbXWjaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfa
XGfaXGfaXGfaXGbaXGbaXGbaXGbaXGbaXGbaXGbaXGbaXGfaXGfaXGfaXGfaXGf`X7b`X7b`X7bcX7nc
X7ncX7ncX7ncX7nbWgjbWgjbWgjcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbaXGbaXGbaXGbaXGbaXGba
XGbaXGbaXGbcXW^cXW^cXW^cXW^cXW^cXW^cXW^cXW^cXGbcXGbcXGbcXGbcXGbcXGbcXGbcXGbcXW^c
XW^cXW^cXW^cXW^cXW^cXW^cXW^bXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZcXW^cXW^cXW^cXW^cXW^c
XW^cXW^cXW^bXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZ`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`
WgR`WgR`WgR`WgR`WgR`WgR`WgRaXGNaXGNbXWRcXgVcXgVbXWRaXGNaXGNaWgJaWgJaWgJaWgJaWgJa
WgJaWgJaWgJ`WWF`WWFaWgJaWgJbX7NbX7NcXGRcXGR^WWB^WWB^WWB^WWB^WWB^WWB^WWB^WWB`WWF`
WWF`WWF`WWF`WWF`WWF`WWF`WWF^WWB^WWB_WgF_WgF`X7J`X7J`X7J`X7JbX7NbX7NbX7NbX7NbX7Nb
X7NbX7NbX7N_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:^W7>^
W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>_WGB`WWF`WWFaWgJaWgJ^WW2^WW2^WW2^WW2^WW2^
WW2^WW2^WW2]WFn]WFn^WW2^WW2^WW2_Wg6_Wg6_Wg6^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^
WW2^WW2^WW2^WW2^WW2^WW2^WW2_Wg6^WW2^WW2]WFn]WFn^WW2^WW2_Wg6_Wg6_Wg6_Wg6_Wg6_Wg6_
Wg6_Wg6_Wg6`X7:`X7:_Wg6^WW2^WW2_Wg6`X7:`X7:]WVf/WVj[WW:VVgFRVGRLUGZITgbGTGjDUX:C
UH:@U86?TX:?TX>@TXJBThVAUHZEU8JEU8JFUHNGUXRHUhVHUhVIV8ZIV8ZHV8JCTh6KW8bBTh>FVHZF
Vhb:SX8W:al030P020EAEe;9bL>m^[:b[JB[ZIjVYYRUYIF`/:2YZIV][Yja/Z:VYiNVZIVZ[If][Yje
]ZJ[Zi^a/::g/jRZYY^_ZZ6j/jZOZZ8Z=BdD7A<@5@aWJf3Mgm?<c<2`[j6l_ZRWZ9Ba/j2c]:Bc]ZNe
]Zbf]jjg^:nb]:Ra/jN_/JF^/:B^/:B_/JFa/jNb]:Rc]JVd]ZZf^:bg^Jfh^Zjh^Zjf^:bf^:bf]jfg
^:jh^Jni^[2i^[2i^[2h^Jnh^Jnj^k6j^k6i^[2i^[2i^[2i^[2i^[2h^Jo0^Zfl^k6i^kFg^kFf^JZd
/9B`Y7b]VFVgW72jY7BeYg>ZXfbYXV^`YG>fXgJdWWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFeX7>e
X7>eX7>eX7>eX7>eX7>eX7>eX7>gXgBgXgBgXgBgXgBgXgBgXgBgXgBgXgBfXGBfXGBgXWFhXgJhXgJg
XWFfXGBfXGBgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXWFgXGRgXGRgXGRhXWVhXWVhXWT00;VZUkVZUkVZ
UkVZUkVZUkVZUkVZUkVZUkRZV;V[VKZ/V[Z/V[Z/V[Z/V[V[VKRZV;V[VKV[VKV[VKV[VKV[VKV[VKV[
VKV[VKRZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;NYUkNYUkJXU[JXU[JXU[NYUkNYUkNY
UkNYUkNYUkNYUkNYUkNYUkJXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JX
U[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXUKJXUKJX
UKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKFWU;FWU;JXUKJXUKJXUKJXUKJX
UKNYU[JYTkJYTkJYTkJYTkJYTkJYTkJYTkJYTkJXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JX
T[JXT[JXT[JXT[JXT[JXT[FWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKJXT[JXT[JXT[JXT[JXT[JXT[JX
T[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[JXT[FWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFXS[FXS[FX
S[FXS[FXS[FXS[FXS[FXS[FWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFXS[FXS[FXS[FXS[FXS[FXS[FX
S[FXS[BWSKBWSKBWSKBWSKBWSKBWSKBWSKBWSKJUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JU
R[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[JUR[FTRKFTRKFTRKFTRKFTRKFTRKFT
RKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKBSR;BSR;BS
R;BSR;BSR;BSR;BSR;BSR;BTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQk>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>S
Q[>SQ[>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;>TQ;BRPkBRPkBRPkBRPkBRPkBRPkBRPkBRPk>SOk>SOk>S
Ok>SOk>SOk>SOk>SOk>SOk:RO[:RO[>SOkBTP;BTP;>SOk:RO[:RO[:PPK:PPK:PPK:PPK:PPK:PPK:P
PK:PPK:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[6QOK6QOK6Q
OK6QOK6QOK6QOK6QOK6QOK6QOK6QOK6QOK6QOK6QOK6QOK6QOK6QOK6QO;6QO;6QO;6QO;6QO;6QO;6Q
O;6QO;6QOK6QOK6QOK6QOK2PO;2PO;2PO;2PO;>POK>POK>POK>POK:OO;:OO;:OO;:OO;>QO;>QO;>Q
O;>QO;>QO;>QO;>QO;>QO;6QO;6QO;6QO;6QO;6QO;6QO;6QO;6QO;>RNk>RNk>RNk>RNk>RNk>RNk>R
Nk>RNk>QO;>QO;>QO;>QO;>QO;>QO;>QO;>QO;>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk6PNK6PNK6P
NK6PNK6PNK6PNK6PNK6PNK>RNk>RNk>RNk>RNk>RNk>RNk>RNk>RNk6PNK6PNK6PNK6PNK6PNK6PNK6P
NK6PNK2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2PM[6QMk:R
N;:RN;:RN;:RN;6QMk2PM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[6OM[2NMK2NMK2NMK6OM[:PMk:PMk:P
Mk>QN:jNM:jNM:jNM:jNM:jNM:jNM:jNM:jNM;2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMJjNM:jNM:nO
MJnOMJnOMK2PM[2PM[2PM[2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMJnMM:nMM:nMM:nMM:nMM:nMM:nM
M:nMM:fKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjfKLZfKLZfK
LZfKLZjLLjjLLjjLLjjLLjjNL:jNL:jNL:jNL:jNL:jNL:jNL:jNL:fMKjfMKjfMKjjNL:jNL:jNL:nO
LJnOLJjNL:jNL:jNL:jNL:jNL:jNL:jNL:jNL:jNL:jNL:jNL:jNL:jNL:jNL:jNL:jNL:nOLJjNL:jN
L:fMKjfMKjjNL:jNL:nOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLJnOLK2PLZnOLJnOLJjNL:jNL:nOLJnO
LK2PL[2OKZjNKjfMLZVMMJJJMZ6HMijFNI^EN9:DOY:COi:DP9>EPY>DQ96DQI6CQi6BR9FDQYFDQYJE
QiJEQiNFR9RGRIVHRYVHRYRHQY>CPI^LS9:CPiJIRYJKS8^?Pb/_8`HD40/E3deAC=KCc/Bn]jbWWZRV
VjNUVZVYWJ^[WjJVVZZZWZj^XZb^X[>eZK:dZ:>TU:VZVZJUUjj]WkBbYjf[XKB_Y[fh[j2ZY2hh<Q8I
510G455DBlc=a<?2^:b[XKJfZ;6aXkjn/;Vi[Jf_Xk6bZ;:cZJf^Y;>eZK:dZ;6cYk2bY[2bY[6cYk:d
Z;>eZK:dZ;>eZKFgZkNi[KRj[[Rj[[Ni[KJh[;Jg[KNh[[Ri[kVj/;Vj/;Vj/;Ri[kRi[kZk/KVj/;Vj
/;Vj/;Vj/;Vj/;Vj/;Vj/<6k[[^j/;Nj/KNl/kVl[KRdVk:WPJfMKkNNL[VUM[FXM:bUKZ^SK[:TLkFR
MK>MM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;JQM;FPLkFPLkFPLkFPLkFPLkFPLkFPLkFPLkJRLkJRLkJR
LkJRLkJRLkJRLkJRLkJRLkFPLkJQM;NRMKNRMKNRMKNRMKJQM;FPLkJQM;JQM;JQM;JQM;JQM;JQM;JQ
M;JQM;FOM[FOM[JPMkJPMkJPMkNQN000^JZG^JZG^JZG^JZG^JZG^JZG^JZG^JZG^:ZH^J^I^J^I^ZbJ
^ZbJ^J^I^J^I^:ZH^J^I^J^I^J^I^J^I^J^I^J^I^J^I^J^I^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH^:ZH
^:ZH]jVG]jVG]jVG]ZRF]ZRF]ZRF]ZRF]jVG]jVG]jVG]jVG]jVG]jVG]jVG]jVG]ZRF]ZRF]ZRF]ZRF
]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF
]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE
]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]JND]JND]JND]JND]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC]ZVC
]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]:J@]:J@]:J@]:J@
]:J@]:J@]:J@]:J@]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA]JNA
]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:N=]:N=]:N=]:N=]:N=]:N=]:N=]:N=]:J@]:J@]:J@]:J@
]:J@]:J@]:J@]:J@]:N=]:N=]:N=]:N=]:N=]:N=]:N=]:N=/jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ<
]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:]ZF:
]ZF:]ZF:]ZF:]ZF:]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9
]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:B7]:B7]:B7]:B7
]:B7]:B7]:B7]:B7/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/jB4/jB4/jB4/jB4/jB4/jB4/jB4/jB4
]::3]::3]::3]::3]::3]::3]::3]::3/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/J5m/Z9n/j=o/j=o
/j=o/j=o/Z9n/J5m/In0/In0/In0/In0/In0/In0/In0/In0/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m
/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l
/:1l/:1l/:1l/:1l/:1k/:1k/:1k/:1k/:1k/:1k/:1k/:1k/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l
/Yml/Yml/Yml/Yml/Yml/Yml/Yml/Yml/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k/:1k/:1k/:1k/:1k
/:1k/:1k/:1k/:1k/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k/Z1k
/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/Z5j/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/Z5j/Z5j/Z5j/Z5j
/Z5j/Z5j/Z5j/Z5j/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh
/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/:1f/J5g/J5g/Z9h/Z9h/J5g/J5g/:1f/Imf/Imf/Imf/Imf
/Imf/Imf/Imf/Imf/9ie/9ie/9ie/Imf/Imf/Imf/Z1g/Z1g[Yid[Yid[Yid[Yid[Yid[Yid[Yid[Yid
/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie[Yid[Yid[Yid[ime[ime[ime/:1f/:1f[Yac[Yac[Yac[Yac
[Yac[Yac[Yac[Yac[ied[ied[ied[ied[ied[ied[ied[ied[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b
[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[I]b[I]b[I]b[9Ya[9Ya[9Ya[9Ya[9Ya[Yi`[Yi`[Yi`[Yi`
[Yi`[Yi`[Yi`[Yi`[Ie_[Ie_[Ie_[Ie_[Yi`[Yi`[Yi`[ima[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`
[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[Yi`[ima[Yi`[Ie_[Ie_[Ie_[Ie_[Yi`[ima[ima[ima[ima[ima
[ima[ima[ima[ima/:1b[ima[Yi`[Yi`[Yi`[Yi`[ima/:1b/Ye`/iia/Iia[iicZiecZ9adY9YbXiUa
U9=iUIAjUIEmUYF1UIF3U9F5Ti>5TI>7U9>5U9>5UIB6UYF7UiJ8UiJ8V9N9V9N9V9R6TY:0VY^;TiB4
UYV:U9V:SI65<CDY00X42Q0;=SH`fMG@c<BmZjBK[JRO[J^Q/K:YZ:VPZJZQZJZQY:FLZ:VPZ:VPW9fD
][NW/K6S[jnQ/;2T/K6U[JbRZZRP[:ZRVjJT;CDd3QDB9BXXEEUDf]cFc/k8/ZnZ[JfW][J`_kni_l2g
[JjU];F[^kbb][N]];JZ/kFY/kFY/[BX/[BX/kFY/kFY];JZ/;:V/K>W/kFY]KN[]kV]]kV]^;Z^^;Z^
][N]]kR^^;V_^KZ`^KZ`^KZ`^;V_^;V_^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ``Kj`^k^_]KR_][^b
_[j`_[ZR]jb</:1k]Z1g]jAg]:Ie[jA`[jA`]:Ed]J9e/iec]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d
]J1c]J1c]J1c]J1c]J1c]J1c]J1c]J1c]Z9c]Z9c]Z9c]Z9c]Z9c]Z9c]Z9c]Z9c]J1c]Z5d]Z5d]j9e
]j9e]Z5d]Z5d]J1c]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]Z5d]9id]9id]9id]9id]Ime]Ime002hZIJh
ZIJhZIJhZIJhZIJhZIJhZIJhZIJhZYRhZYRiZiViZiViZiViZiVhZYRhZYRiZiViZiViZiViZiViZiVi
ZiViZiViZiVgZINgZINgZINgZINgZINgZINgZINgZINgZINgZINfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9Jf
Z9JfZ9JfZ9JfZ9JfZ9JfZ9JfZ9JeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFe
YiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiBe
YiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBgZIJfZ9FfZ9FeYiBeYiBd
YY>dYY>dYY>eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eZ9:eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6e
Yi6eYi6eYi6eYi6eYi6eYi6eYi6dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2eYi6eYi6eYi6eYi6eYi6e
Yi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6eYi6dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYhfd
YhfdYhfdYhfdYhfdYhfdYhfdYhfdYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYhfdYhfdYhfdYhfdYhfd
YhfdYhfdYhfcYXbcYXbcYXbcYXbcYXbcYXbcYXbcYXbfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZf
YHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZfYHZeY8VeY8VeY8VeY8VeY8Ve
Y8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VcXXNc
XXNcXXNcXXNcXXNcXXNcXXNcXXNcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJbXXFbXXFbXXFbXXFbXXFb
XXFbXXFbXXFbXh>bXh>bXh>bXh>bXh>bXh>bXh>bXh>cXH:cXH:cXH:cXH:cXH:cXH:cXH:cXH:bXWjb
XWjbXWjbXWjbXWjbXWjbXWjbXWjaXGfbXWjbXWjcXgncXgnbXWjbXWjaXGfaWh2aWh2aWh2aWh2aWh2a
Wh2aWh2aWh2aXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGf`X7b`
X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7^`X7^`X7^`X7^`X7^`
X7^`X7^`X7^_Wg^_Wg^_Wg^`X7b`X7b`X7b`X7b`X7baWgZaWgZaWgZbX7^bX7^bX7^bX7^bX7^bX7^b
X7^bX7^bX7^bX7^bX7^bX7^bX7^`X7^`X7^`X7^`X7^`X7^`X7^`X7^`X7^bXGZbXGZbXGZbXGZbXGZb
XGZbXGZbXGZbX7^bX7^bX7^bX7^bX7^bX7^bX7^bX7^bXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZaX7Va
X7VaX7VaX7VaX7VaX7VaX7VaX7VbXGZbXGZbXGZbXGZbXGZbXGZbXGZbXGZaX7VaX7VaX7VaX7VaX7Va
X7VaX7VaX7V`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`X7J`
X7JaXGNbXWRbXWRaXGN`X7J`X7JaWgJaWgJaWgJaWgJaWgJaWgJaWgJaWgJ`WWF`WWF`WWF`WWFaWgJa
WgJaWgJaWgJ^WWB^WWB^WWB^WWB^WWB^WWB^WWB^WWB_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB]WG>]
WG>^WWB^WWB_WgF_WgF_WgF_WgF_WGB_WGB_WGB_WGB_WGB_WGB_WGB_WGB^W7>^W7>^W7>^W7>^W7>^
W7>^W7>^W7>]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:^W7>^
W7>]Vg:]Vg:/VW6[VG2[VG2[VG2]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn/W6j/W6j]WFn]WFn]WFn^
WW2^WW2^WW2]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn]WFn^WW2^
WW2]WFn/W6j/W6j]WFn^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2^WW2_Wg6_Wg6^WW2]WFn]WFn^
WW2_Wg6_Wg6eWG>eWW6cWW6aWW6_Wg2^WVn/WVj[WFbLUgRKUGRIUGVGTg^FTgjETh6DU8BDU8JCTXBC
TXBDThFEU8JFUHNFUHNGUXRGUXRGUhFATGnJVh^CU8BEV8VCV8V@U8Pi?C4840TC5a4V9R3IdlcBc<F/
YYn^Zj>YYinX[ZVNY9na]K2g^kJf]k>o`;bk_;Re];2_[j6PX9:XZYj`/ZJk_kC<clK;c/G;c/G9eMM5
Cdl00@493`h`<c7=c/cOg][Cd/kHf]_Ff=SBdm7Qh]k4a;je]Zbd]ZZd]:Rc]JVc]JVc]JVc]JVc]JVc
]JVc]JVc]JV_/JF`/ZJa/jNc]JVe]j^g^Jfh^Zjh^Zjf]jfg^:jh^Jni^[2i^[2i^[2h^Jnh^Jnh^Jni
^[2i^[2i^[2i^[2j^k6j^k6j^k70_k6k^jnf]jjg^[70`;C2_Z^l/YZcZ8ZaWWRaWgJ`XG>`XW6cYG6f
YGBgXWFdWWBfXGBfXGBfXGBfXGBfXGBfXGBfXGBfXGBeX7>eX7>eX7>eX7>eX7>eX7>eX7>eX7>fXW>f
XW>fXW>fXW>fXW>fXW>fXW>fXW>eX7>eX7>fXGBgXWFgXWFfXGBeX7>eX7>fXGBfXGBfXGBfXGBfXGBf
XGBfXGBfXGBdWWBdWWBdWWBeWgFeWgFeWgD00;RYU[RYU[RYU[RYU[RYU[RYU[RYU[RYU[NYUkRZV;RZ
V;V[VKV[VKRZV;RZV;NYUkRZV;RZV;RZV;RZV;RZV;RZV;RZV;RZV;NYUkNYUkNYUkNYUkNYUkNYUkNY
UkNYUkFWUKFWUKJXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[FWUKFWUKFW
UKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFW
UKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKFWU;FWU;FWU;FWU;FWU;FWU;FWU;FWU;FWU;FWU;FW
U;FWU;FWU;FWU;FWU;FWU;JXUKJXUKJXUKFWU;BVTkBVTk>UT[>UT[FXT[FXT[FXT[FXT[FXT[FXT[FX
T[FXT[FWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTK>USk>USk>U
Sk>USk>USk>USk>USk>USkFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFWTKFW
TKFWTK>USk>USk>USk>USk>USk>USk>USk>USk>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;>USk>USk>U
Sk>USk>USk>USk>USk>USk>VS;>VS;>VS;>VS;>VS;>VS;>VS;>VS;:URk:URk:URk:URk:URk:URk:U
Rk:URkFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFTRKFT
RKFTRKFTRKFTRKFTRKFTRKBSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BS
R;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>SQ[>SQ[>S
Q[>SQ[>SQ[>SQ[>SQ[>SQ[:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:SPk:SPk:SPk:SPk:SPk:SPk:S
Pk:SPk>QP[>QP[>QP[>QP[>QP[>QP[>QP[>QP[:RO[:RO[:RO[:RO[:RO[:RO[:RO[:RO[6QOK6QOK:R
O[:RO[:RO[:RO[6QOK6QOK2NOk2NOk2NOk2NOk2NOk2NOk2NOk2NOk2PO;2PO;2PO;2PO;2PO;2PO;2P
O;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO:nONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnO
NjnONjnONjnONjnONjnONjnONZnONZnONZnONZnONZnONZnONZnONZjNNZjNNZjNNZnONk2PO;2PO;2P
O;6QOK2NNK2NNK2NNK6ON[:PNk:PNk:PNk>QO;6ON[6ON[6ON[6ON[6ON[6ON[6ON[6ONZnONZnONZnO
NZnONZnONZnONZnONZnON[6PNK6PNK6PNK6PNK6PNK6PNK6PNK6PNK6ON[6ON[6ON[6ON[6ON[6ON[6O
N[6ON[6PNK6PNK6PNK6PNK6PNK6PNK6PNK6PNK2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;6PNK6PNK6P
NK6PNK6PNK6PNK6PNK6PNK2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON;2O
N;2ON:nNMjnNMjnNMjnNMjnNMjnNMjnNMjnNMjnOMK2PM[6QMk6QMk6QMk6QMk2PMZnOMK2NMK2NMK2N
MK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMK2NMJjNM:jNM:jNM:jNM:jNM:jNM:jN
M:jNM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:fMLjfMLjfMLjjNM:jNM:jNM:nOMJnOMK2NMK2NMK2N
MK2NMK2NMK2NMK2NMK2NMJjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjfKLZfKLZfKLZfKLZfKLZfKLZfK
LZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZnMM:nMM:jLLjjLLjfKLZbJLJbJLJbJLJfMKjfMKjfM
KjfMKjfMKjfMKjfMKjfMKjbLKZbLKZbLKZbLKZfMKjfMKjjNL:jNL:fMKjfMKjfMKjfMKjfMKjfMKjfM
KjfMKjfMKjfMKjfMKjfMKjfMKjfMKjfMKjfMKjjNL:fMKjbLKZbLKZbLKZbLKZfMKjjNL:jNL:jNL:jN
L:jNL:jNL:jNL:jNL:jNL:nOLJjNL:fMKjfMKjfMKjfMKjjNL:nOLKBLL[BLL[>NLK>OL;6PKk2OKZnN
JjfOJjFLMj:HMYfDLiNAM9B@N9B@OIJDPYNGQi:APi>BQ9>BQ9BCQIFDQYFDQYJEQiJEQiNGQI2@OYZK
RiBEQIBGR96FQi:FRT55>@`E2aLO5BPY8=?AbN[Wgm7>bMWKeM3Dc/oHeL7:amGLfM7Fe<[=bloBd<g>
c>3Qgm?Cak>eZKfo/kRl/KVn]M3Hc/S@bL?;a;g9beEQH@lI6AXR8BH[:J2SXJn`[:n^ZY^PXIFJVIBI
UmgQg<g?bKBeZjb/X;6aYK6cYk:dZ;:dZ;:dZ;:dZ;:dZ;:dZ;6cYjnaYJnaYK2bY[:dZ;BfZ[Jh[;Ni
[KRj[[Jg[KNh[[Ri[kVj/;Vj/;Vj/;Ri[kRi[kRi[kRi[kRi[kVj/;Vj/;Zk/KZk/K^l/[no/k^j/;Jg
[KZk/L71]L?0/[ngY[R_VjfONjbMMZbLLJnOL;BSL[NSLkJQM;JPM[FPLkFPLkFPLkFPLkFPLkFPLkFP
LkFPLkBOL[BOL[BOL[BOL[BOL[BOL[BOL[BOL[FQL[FQL[FQL[FQL[FQL[FQL[FQL[FQL[BOL[FPLkJQ
M;JQM;JQM;JQM;FPLkBOL[FPLkFPLkFPLkFPLkFPLkFPLkFPLkFPLkFPLkFPLkFPLkJQM;JQM;JQM000
]jRE]jRE]jRE]jRE]jRE]jRE]jRE]jRE]jVG]jVG^:ZH^J^I^J^I^:ZH]jVG]jVG^:ZH^:ZH^:ZH^:ZH
^:ZH^:ZH^:ZH^:ZH]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]ZRF]:JD]JNE]JNE]JNE]ZRF]ZRF]ZRF]ZRF
]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD
]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD
]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]JND]JND]JND]:JC
]:JC]:JC]:JC]:JC]:NA]:NA]:NA]:NA]:NA]:NA]:NA]:NA]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@
]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@/jF?/jF?/jF?/jF?/jF?/jF?/jF?/jF?]:J@]:J@]:J@]:J@
]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@/jF?/jF?/jF?/jF?/jF?/jF?/jF?/jF?
/jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jF?/jF?/jF?/jF?/jF?/jF?/jF?/jF?/jJ</jJ</jJ</jJ<
/jJ</jJ</jJ</jJ</ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9
]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9]:>8]:>8]:>8]:>8
]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8]:>8
/Z66/Z66/Z66/Z66/Z66/Z66/Z66/Z66/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/J64/J64/J64/J64
/J64/J64/J64/J64/J:2/J:2/J:2/J:2/J:2/J:2/J:2/J:2/Z21/Z21/Z21/Z21/Z21/Z21/Z21/Z21
/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/:1l/J5m/J5m/Z9n/Z9n/J5m/J5m/:1l/9io/9io/9io/9io
/9io/9io/9io/9io/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l
[imk[imk[imk[imk[imk[imk[imk[imk[imk[imk[imk[imk[imk[imk[imk[imk[imj[imj[imj[imj
[imj[imj[imj[imj[Iei[Iei[Yij[Yij[imk/:1l/J5m/J5m[iig[iig/9mh/9mh/J1i/Z5j/j9k/j9k
/Imj/Imj/Imj/Imj/Imj/Imj/Imj/Imj[imj[imj[imj[imj[imj[imj[imj[imj/J1i/J1i/J1i/J1i
/J1i/J1i/J1i/J1i/Imj/Imj/Imj/Imj/Imj/Imj/Imj/Imj/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i
/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/J1i/J1i/J1i/J1i/J1i/J1i/J1i/J1i/9mh/9mh/9mh/9mh
/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh/9mh[iig[iig[iig[iig[iig[iig[iig[iig
[ime[ime/:1f/J5g/J5g/:1f[ime[ime/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie/Imf/9ie/9ie/9ie
[ied[ied[ied[ied[Yid[Yid[Yid[Yid[Yid[Yid[Yid[Yid[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac
[9ab[Iec[Iec[Iec[Yid[Yid[Yid[Yid/9ie/9ie/9ie/9ie/9ie/9ie/9ie/9ie[I]b[I]b[I]b[I]b
[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya
[Yac[Yac[Yac[Yac[I]b[I]b[I]b[I]b[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^Zi]]Zi]][9a^[9a^
[9a^[Ie_[Ie_[Ie_[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^
[Ie_[Ie_[9a^Zi]]Zi]][9a^[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Ie_[Yi`[Yi`[Ie_[9a^
[9a^[Ie_[Yi`[Yi`[iaa[iaa/9e`/9e`/9i_/9i_[ii][Ye/[ImeZY]dXIEaVi9aUXmdUI5iUY9oUYB2
TI22TY63TY63Ti:4U9>5UIB6UIB6UIB6UiN5ShmmVIZ:U9F5TiJ7T9F6UIV=BDe10@l32aD961hCSI27
[k6[WJ6KZK2[WJNQVZZSS9ZDUZ:LQ8j8OHAoPHF0Rhb8d]??dM?7XjFIWj>HLgQ_BU=9CUUA>4Dm;SXd
9C<a2AHD00/84Q/H1`h9=C`e:blY;2hX7RTQ8RdU>D4j_LFkc<o6]kR^/K2V^KR^/K>W/K>W/[BX/kFY
/kFY/[BX/K>W/K>W[k6U[k6U/;:V/;:V/[BX];JZ][R/]kV]][N]]kR^^;V_^KZ`^KZ`^KZ`^;V_^;V_
]kR^]kR^^;V_^KZ`^[^a^[^a^kbb^kbb^kfa^KZ`^[V__;^a`;jd`[jc_[Z_^kFZ/:F5[9ijZi]a/9e`
]j5a]j5a]Z9c]j9e]J1c]J1c]J1c]J1c]J1c]J1c]J1c]J1c]9mb]9mb]9mb]9mb]9mb]9mb]9mb]9mb
]J5b]J5b]J5b]J5b]J5b]J5b]J5b]J5b]9mb]9mb]J1c]Z5d]Z5d]J1c]9mb]9mb]J1c]J1c]J1c]J1c
]J1c]J1c]J1c]J1c]J5b]J5b]J5b]Z9c]Z9c]j=d002gZ9FgZ9FgZ9FgZ9FgZ9FgZ9FgZ9FgZ9FfZ9Jg
ZINhZYRhZYRhZYRhZYRgZINfZ9JgZINgZINgZINgZINgZINgZINgZINgZINfZ9JfZ9JfZ9JfZ9JfZ9Jf
Z9JfZ9JfZ9JdYYBdYYBdYYBeYiFeYiFfZ9JfZ9JfZ9JeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFdYYBd
YYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBd
YYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>d
YY>dYY>dYY>dYY>dYY>dYY>dYY>cYI:cYI:cYI:dYY>dYY>dYY>dYY>dYY>dYi6dYi6dYi6dYi6dYi6d
Yi6dYi6dYi6dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2cYHnc
YHncYHncYHncYHncYHncYHncYHndYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2dYY2d
YY2dYY2dYY2cYHncYHncYHncYHncYHncYHncYHncYHncYXbcYXbcYXbcYXbcYXbcYXbcYXbcYXbcYHnc
YHncYHncYHncYHncYHncYHncYHncYXbcYXbcYXbcYXbcYXbcYXbcYXbcYXbaY8ZaY8ZaY8ZaY8ZaY8Za
Y8ZaY8ZaY8ZdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRdXhRd
XhRdXhRdXhRdXhRdXhRdXhRdXhRcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNc
XXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNbXHJbXHJbXHJbXHJbXHJbXHJbXHJbXHJbXXFb
XXFbXXFbXXFbXXFbXXFbXXFbXXFaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXX:aXX:aXX:aXX:aXX:a
XX:aXX:aXX:bX86bX86bX86bX86bX86bX86bX86bX86aXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGf`X7b`
X7baXGfbXWjbXWjaXGf`X7b`X7b`WWn`WWn`WWn`WWn`WWn`WWn`WWn`WWn`X7b`X7b`X7b`X7b`X7b`
X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^
WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWV^WWV^WWV^WWV^WWV^WWV^WWV^WWV/W7R/W7R]WGV^WWZ_Wg^`
X7baXGfaXGf^WGJ^WGJ_WWN`WgRaX7VbXGZcXW^cXW^`WWV`WWV`WWV`WWV`WWV`WWV`WWV`WWV^WWV^
WWV^WWV^WWV^WWV^WWV^WWV^WWV`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WWV`WWV`WWV`WWV`WWV`
WWV`WWV`WWV`WgR`WgR`WgR`WgR`WgR`WgR`WgR`WgR_WWN_WWN_WWN_WWN_WWN_WWN_WWN_WWN`WgR`
WgR`WgR`WgR`WgR`WgR`WgR`WgR_WWN_WWN_WWN_WWN_WWN_WWN_WWN_WWN`WgR`WgR`WgR`WgR`WgR`
WgR`WgR`WgR^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ^WWB_WgF`X7J`X7J`X7J`X7J_WgF^WWB_WGB_
WGB_WGB_WGB_WGB_WGB_WGB_WGBaWgJ`WWF`WWF`WWF_WGB^W7>^W7>^W7>^WWB^WWB^WWB^WWB^WWB^
WWB^WWB^WWB^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>/W7:/W7:]WG>]WG>]WG>^WWB^WWB^WWB^W7>^
W7>^W7>^W7>^W7>^W7>^W7>^W7>]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]
Vg:]Vg:]Vg:/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6[VG2/VW6/VW6/VW6/VW6/VW6]Vg:]Vg:/W6j/
W6j/W6j/W6j/W6j/W6j/W6j/W6j[Vff[Vff[Vff/W6j/W6j/W6j]WFn]WFn/W6j/W6j/W6j/W6j/W6j/
W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j]WFn/W6j[Vff[Vff[Vff[Vff/W6j]WFn]WFn]
WFn]WFn]WFn]WFn]WFn]WFn]WFn^WW2]WFn]WFn/W6j/W6j]WFn]WFn^WW2ZVff[W6j/W76/W76]W76]
W76/VW6/VW6`WVn]W76XVG:RUWBKTgJFTGRDSW^BSWbAT8:AT8:BTH>BTH>CTXBDThFDThFEU8JGUhF?
SgfIVXZEUXJCUXN?U8FGVhm?DdL35PL140854@DS;28d?3DG8adM;BH?81`>8AP:7A@J:b8<6A4H81TN
9Ahk?cVk_KO?d<JRXiVPYY]OIedJ9AdH9Ad85Q096A875a065Pl44P`54PX740HF7Q@F714Y;b@?8A0M
;A`_?2bnak[9d<>i^[2b/JNd/ZRb]:Rb]:Rd]ZZe]j^e]j^d]ZZb]:Rb]:Ra/jN`/ZJ_/JF_/JF`/ZJb
]:Rd]ZZe]j^f]jfg^:jh^Jni^[2i^[2i^[2h^Jnh^Jng^:jg^:jh^Jni^[2j^k6k_;:k_;:l_K>i^[2j
_;2m_K6n_;:n_;:m^[:n^[Fn^[Fi/I>aYH>^WGJcWW6hX7:gX72fWg6gXWFdWg:dWg:dWg:dWg:dWg:d
Wg:dWg:dWg:cWW6cWW6cWW6cWW6cWW6cWW6cWW6cWW6dX76dX76dX76dX76dX76dX76dX76dX76cWW6d
Wg:eX7>eX7>eX7>eX7>dWg:cWW6dWg:dWg:dWg:dWg:dWg:dWg:dWg:dWg:dX76dX76dX76dX76eXG:e
XG800;NXUKNXUKNXUKNXUKNXUKNXUKNXUKNXUKJXU[NYUkNYUkRZV;RZV;NYUkNYUkJXU[NYUkNYUkNY
UkNYUkNYUkNYUkNYUkNYUkJXU[JXU[JXU[JXU[JXU[JXU[JXU[JXU[>UTk>UTkBVU;BVU;FWUKJXU[JX
U[JXU[FWUKFWUKFWUKFWUKFWUKFWUKFWUKFWUKBVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BV
U;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BV
U;BVU;BVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTk:TTK:TTK>U
T[>UT[BVTkFWU;FWU;FWU;BWTKBWTKBWTKBWTKBWTKBWTKBWTKBWTKBVT;BVT;BVT;BVT;BVT;BVT;BV
T;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;:TS[:TS[:TS[:TS[:TS[:TS[:TS[:TS[BVT;BVT;BV
T;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;BVT;:TS[:TS[:TS[:TS[:TS[:TS[:T
S[:TS[:URk:URk:URk:URk:URk:URk:URk:URk:TS[:TS[:TS[:TS[:TS[:TS[:TS[:TS[:URk:URk:U
Rk:URk:URk:URk:URk:URk6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[BSR;BSR;BSR;BSR;BSR;BSR;BS
R;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;>RQk>RQk>R
Qk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>RQk>R
Qk>RQk:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK6QQ;6QQ;6Q
Q;6QQ;6QQ;6QQ;6QQ;6QQ;6RP[6RP[6RP[6RP[6RP[6RP[6RP[6RP[:PPK:PPK:PPK:PPK:PPK:PPK:P
PK:PPK6QOK6QOK6QOK6QOK6QOK6QOK6QOK6QOK2PO;2PO;6QOK:RO[:RO[6QOK2PO;2PO:nMOZnMOZnM
OZnMOZnMOZnMOZnMOZnMOZnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnO
NjnONjjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNJjNNJjN
NJjNNJjNNJjNNJjNNJjNNJbLN:bLN:fMNJjNNZnONk2PO;6QOK6QOJjNM:jNM:nOMK2PM[6QMk:RN;>S
NK>SNK2NNK2NNK2NNK2NNK2NNK2NNK2NNK2NNJjNNJjNNJjNNJjNNJjNNJjNNJjNNJjNNK2ON;2ON;2O
N;2ON;2ON;2ON;2ON;2ON;2NNK2NNK2NNK2NNK2NNK2NNK2NNK2NNK2ON;2ON;2ON;2ON;2ON;2ON;2O
N;2ON:nNMjnNMjnNMjnNMjnNMjnNMjnNMjnNMk2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON:nNMjnNMjnN
MjnNMjnNMjnNMjnNMjnNMk2ON;2ON;2ON;2ON;2ON;2ON;2ON;2ON:jMMZjMMZjMMZjMMZjMMZjMMZjM
MZjMMZjNM:nOMK2PM[2PM[2PM[2PMZnOMJjNM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM;6OM[2NMK2N
MJnMM:nMM:jLLjjLLjfKLZjNM:jNM:jNM:jNM:jNM:jNM:jNM:jNM:jLLjjLLjjLLjjLLjjLLjjLLjjL
LjjLLjbLLZbLLZbLLZfMLjfMLjfMLjjNM:jNM:fKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfK
LZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZfKLZbJLJbJLJbJLJbJLJbJLJbJLJbJ
LJbJLJVGKZVGKZZHKjZHKj^IL:^IL:bJLJbJLJbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZ^KKJ^KKJ^K
KJ^KKJbLKZbLKZfMKjfMKjbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbLKZbL
KZbLKZfMKjbLKZ^KKJ^KKJ^KKJ^KKJbLKZfMKjfMKjfMKjfMKjfMKjfMKjfMKjfMKjfMKjjNL:fMKjbL
KZbLKZbLKZbLKZfMKjjNL:FKK:JLKJVLL:VKLJbKM:^JLj^IM:^HLjnKJjjLKJbLLZRJMZ6GNIRAN96<
Mhb8MI2?PI6@PY6@PY:APi>BQ9>BQ9BCQIBCQIJFQ8j>O9VJRYFFQY:EQXjCQ9RLT5=GB`0E0`0?00XH
300800hK4`0<1@`P6`HL5`@J3PLM4ATZ7`@D2@dH3PP@1R4V7Kbo]/g>a:>WW:^`YemXGPXE3@LE3`4A
2P`N5`<F3@TJ4@@D2@4?11PT61PQ50lF2AdT5A<X3bHj8bln:K:n[;W0/KBeZkBbZ[FbZ[>eZKBfZ[Fg
ZkNi[KNi[KFgZkBfZ[>eZK6cYk6cYjnaYJnaYK2bY[6cYk>eZKBfZ[Jg[KNh[[Ri[kVj/;Vj/;Vj/;Ri
[kRi[kJg[KNh[[Ri[kVj/;Zk/K^l/[^l/[bm/kJj[kZl/;jn/[jl/Kbj/;^g/[fj][nm_<6kW[J[Rk6O
N[NOMK^QLkJOKkFNL;BQM;BOL[BOL[BOL[BOL[BOL[BOL[BOL[BOL[>NLK>NLK>NLK>NLK>NLK>NLK>N
LK>NLKBPLKBPLKBPLKBPLKBPLKBPLKBPLKBPLK>NLKBOL[FPLkFPLkFPLkFPLkBOL[>NLKBOL[BOL[BO
L[BOL[BOL[BOL[BOL[BOL[:NKk:NKk:NKk>OL;>OL;BPL@00]jRE]jRE]jRE]jRE]jRE]jRE]jRE]jRE
]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]ZRE]JNE]JNE]JNE]JNE
]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]JNE]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD
]ZRE]JND]JND]:JC]:JC/jFB/ZBA/ZBA]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JC]:JC]:JC]:JC
]:JC]:JC]:JC]:JC/jBA/jBA]:FB]JJC]JJC]ZND]ZND]ZND]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC
]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@/jF?/jF?]:J@]JNA
]JNA]:J@/jF?/jF?]:J@]:J@]:J@]:J@]:J@]:J@]:J@]:J@/jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ<
/jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ<
/jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ<
/jJ</jJ</jJ</jJ</jJ</jJ</jJ</jJ</JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:]JB9]JB9]JB9]JB9
]JB9]JB9]JB9]JB9]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7]:B7
/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6
/j>6/j>6/j>6/j>6/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5
/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/j64/j64/j64/j64/j64/j64/j64/j64[j:2[j:2/J:2/J:2
/j62]J62]J62]J62/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/Z9n/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m
/J5m/J5m/J5m/J5m/J5m/J5m/J5m/J5m/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l[Iei[Yij[Yij[Yij
[imk[imk[imk/:1l[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Iei[9ah[9ah[Iei[Yij[Yij
[Ieh[Ieh[Ieh[Ieh[Ieh[Ieh[Ieh[Ieh[imk[imk[Yij[Yij[Iei[9ah[9ah[9ah[9ag[9ag[Ieh[Ieh
[Yii[Yii[Yii[Yii/9ii/9ii[ieh[Yag[Yag[ieh/9ii/9ii[Iae[Yef[iig/9mh/J1i/9mh/9mh[iig
[Yef[Yef[iig[iig/9mh/9mh/9mh/9mh/Z5j[iig[Iae[Yef/J1i/Z5j/9mh[Iae[iig[iig[iig[iig
[iig[iig[iig[iig[Yef[iig/9mh/9mh/9mh/9mh[iig[Yef[Yef[iig/9mh/9mh/9mh/9mh[iig[Yef
[Yef[Yef[iig[iig/9mh/9mh/9mh/9mh[iig[iig[iig[iig[iig[iig[iig[iig[Yef[Yef[Yef[Yef
[Yef[Yef[Yef[Yef[ied[ied[ied[ied[ied[ied[ied[ied[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac
/9ie/9ie[ied[Yac[Yac[I]b[I]b[9Ya[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac
[Yac[Yac[Yac[Yac[I]b[Yac[Yac[ied[ied[Yac[Yac[I]b[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya
[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]bZiU`ZiU`ZiU`[9Ya
[9Ya[9Ya[I]b[I]b[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya
[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^Zi]]Zi]]Zi]]Zi]]
Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]][9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^
Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]][9a^[9a^[9a^[9a^[9a^[9a^[9a^[9a^Zi]]Zi]]Zi]][9a^
[9a^[9a^[Ie_[Ie_/9e`[ia_[Iaa[Iec[9idZ9adXIM_WI9/Shj0S8n0RI21QY:0Qi>1S99oTI5oUY:0
SXeoTI22TI22TY63WIb>XJ2BSHanLW5S21<32aH63QT941/;4A`<4ah>5R4A6B@D:S0I6R095Q/69BXE
9BTF6Qd=BD`lVYf>];JZ/;:VWZ2DNgeaEUQ<@dDiB4XnE5I:H5iCHf5FJFMLL6iSN7I[OgebQH=hR8Ik
TY25VYR=YZBI[jfR];:W]K>X];:W];:W]K>X][BY]kFZ^;J[^[R]^kV^_;Z__K^`/;>T/;>T/;>T/KBU
/KBU/[FV/[FV/[FV][N]]kR^^;V_^KZ`^KZ`^KZ`^KZ`^KZ`]kR^]kR^]kR^^;V_^;V_^KZ`^KZ`^KZ`
^[^a^[^a^[^a^[^a^[^a^[^a^[^a^[^a_K^`][2M[Z:6[ieh]Z5d^jAf^:=f/j1c/Ye`/Ye`/Ye`/iia
]9mb]Z5d]j9e^:=f/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/iia/iia/iia/iia/iia/iia/iia/iia
]9e_]9e_]Ii`]Ii`]Ii`]Yma]Yma]Yma]Ymb]Ymb]Ymb]Ymb]Ymb]Ymb]Ymb]Ymb]:1a]:1a]J5b]Z9c
]j=d]j=d002gZ9FgZ9FgZ9FgZ9FgZ9FgZ9FgZ9FgZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9Ff
Z9FfZ9FfZ9FfZ9FfZ9FfZ9FfZ9FeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFeYiFe
YiFeYiFeYiFdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBeYiBeYiBdYY>dYY>cYI:cYI:bY96bY96dYYBd
YYBdYYBdYYBdYYBdYYBdYYBdYYBdYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYI:dYI:dYI:eYY>eYY>e
YY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>dYY2d
YY2dYY2dYY2dYY2dYY2dYY2dYY2cYHncYHndYY2eYi6eYi6dYY2cYHncYHndYY2dYY2dYY2dYY2dYY2d
YY2dYY2dYY2bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^b
YH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^b
YH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^bYH^aY8Za
Y8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZeY8VeY8VeY8VeY8VeY8VeY8VeY8VeY8VdY8NdY8NdY8NdY8NdY8Nd
Y8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NdY8NcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJc
XhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJbXXFbXXFbXXFbXXFbXXFb
XXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFcXHBc
XHBcXHBcXHBcXHBcXHBcXHBcXHB_XX:_XX:aXX:aXX:cXH:eXH:eXH:eXH:bXWjbXWjbXWjbXWjbXWjb
XWjbXWjbXWjaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGfaXGf_Wg^_
Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^]WGV]WGV^WWZ^WWZ^WWZ_Wg^_Wg^_Wg^^WWZ^WWZ^WWZ^WWZ^WWZ^
WWZ^WWZ^WWZ^WWZ^WWZ]WGV/W7R/W7R]WGV^WWZ^WWZ]WGR]WGR]WGR]WGR]WGR]WGR]WGR]WGR_Wg^^
WWZ^WWZ]WGV]WGV/W7R/W7R/W7R/W7N/W7N]WGR]WGR]WGR^WWV^WWV^WWV`WWV`WWV_WGR^W7N^W7N_
WGR`WWV`WWV]W7F^WGJ_WWN`WgR`WgR`WgR`WgR_WWN^WGJ^WGJ_WWN_WWN_WWN`WgR`WgR`WgRaX7V_
WWN]W7F^WGJ`WgRaX7V`WgR]W7F_WWN_WWN_WWN_WWN_WWN_WWN_WWN_WWN^WGJ_WWN`WgR`WgR`WgR`
WgR_WWN^WGJ^WGJ_WWN`WgR`WgR`WgR`WgR_WWN^WGJ^WGJ^WGJ_WWN_WWN_WWN`WgR`WgR`WgR_WWN_
WWN_WWN_WWN_WWN_WWN_WWN_WWN^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ_WGB_WGB_WGB_WGB_WGB_
WGB_WGB_WGB^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>_WGB_WGB_WGB^W7>^W7>]Vg:]Vg:/VW6^W7>^
W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>]Vg:^W7>^W7>_WGB_WGB^
W7>^W7>]Vg:/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6]Vg:]
Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:[VG2[VG2[VG2[VG2/VW6/VW6]Vg:]Vg:/VW6/VW6/VW6/VW6/VW6/
VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j/
W6j/W6j/W6j/W6j/W6j/W6j/W6j[Vff[Vff[Vff[Vff[Vff[Vff[Vff[VffZVVbZVVbZVVbZVVbZVVbZ
VVbZVVbZVVb/W6j/W6j/W6j/W6j/W6j/W6j/W6j/W6j[Vff[Vff[Vff[Vff[Vff[Vff[Vff[Vff/W6j/
W6j/W6j/W6j/W6j/W6j/W6j/W6j[Vff[Vff[Vff[Vff/W6j/W6j]WFn]WFn_W6n^Vfj/Vg2]WG:/WWBX
W7BTV72OUFfCSGZ?SWZ;T7^7T7b7TWj<TX6BTh>DU8B=S7jDThFEU8JBTH>GUXRLVhfDThF4PgEKHU=L
HeAMI5EPIeQRJEYUK5eVKEiWKUmaMf1jOfZ5RWFCUhBFVXN7RWZ?TX>a]:FVZ9bXZYjXZYjSYIVNX9BQ
XiN][j>h^ZjUXiRVY9VXYY^[ZIj^[:6`[Z>b/:Fc/JJVY9V[ZIj`[Z>c/JJd/ZNc/JJd/ZNe/jRe/jRf
]:Vg]JZh]Z^i]jbk^Jjl^Znl^Zna]:Fa]:Fa]:Fa]:Fa]:Fa]:Fa]:Fa]:Fe]Zbf]jfg^:jh^Jni^[2i
^[2i^[2i^[2g^:jg^:jg^:jh^Jnh^Jni^[2i^[2i^[2j^k6j^k6j^k6j^k6j^k6j^k6j^k6j^k74`[Nm
]ZFaYX^ZVWJZUfb^VFbaW6n`WG2iY7NhXgJgXWFeX7>dWg:cWW6cWW6bWG2bWG2bWG2bWG2bWG2bWG2b
WG2bWG2bWG2cWW6cWW6cWW6cWW6cWW6cWW6cWW6cWW6dWFndWFndWFneWW2eWW2fWg6fWg6fWg6fWg:f
Wg:fWg:fWg:fWg:fWg:fWg:fWg:cWg2cWg2eXG:eXG:fXW>fXW<00;NXUKNXUKNXUKNXUKNXUKNXUKNX
UKNXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKJXUKBVU;BVU;BV
U;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;BVU;>UTk>UTk>UTk>UTk>UTk>UTk>U
Tk>UTkBVTkBVTkBVTkBVTk>UT[>UT[>UT[:TTK>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UT[>UT[>U
T[>UT[>UT[>UT[>UT[>UT[FVTkFVTkFVTkBUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BU
T[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[>USk>USk>USk>USk>USk>USk>USk>USk:TS[>USkBV
T;BVT;BVT;BVT;>USk:TS[>USk>USk>USk>USk>USk>USk>USk>USk:URk:URk:URk:URk:URk:URk:U
Rk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:U
Rk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:URk:U
Rk:URk:URk:URk:URk:URk:URk:URk:URk:URk6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[FTRKFTRKFT
RKFTRKFTRKFTRKFTRKFTRKBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBTQkBT
QkBTQk>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>SQ[>S
Q[>SQ[>SQ[>SQ[>SQ[>SQ[:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:R
QK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPjjQPJjQPK2Q
PK2QPK:PPKBPPKBPPKBPPK6QOK6QOK6QOK6QOK6QOK6QOK6QOK6QOK2PO;2PO;2PO;2PO;2PO;2PO;2P
O;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO;2PO:nONjnONjnONjnONjnONjnONjnONjnONjfMNJfMNJfM
NJjNNZjNNZnONjnONjnONjjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZfMNJbLN:bLN:bLN:bLN:fM
NJjNNZfMN:fMN:fMN:fMN:fMN:fMN:fMN:fMN:jNNZjNNZfMNJfMNJfMNJbLN:bLN:bLN:bLMjbLMjbL
MjfMN:fMN:fMN:jNNJjNNK2NNJnMN:jLMjjLMjjLMjjLMjnMN;2NNJfLMJjMMZnNMk2ON;2ON;2ON:nN
MjnNMjjMMZjMMZjMMZnNMjnNMjnNMk2ON;2ON;2ON:nNMjfLMJjMM[2ON;2ON:nNMjjMMZnNMjnNMjnN
MjnNMjnNMjnNMjnNMjnNMjjMMZjMMZnNMk2ON;2ON:nNMjjMMZjMMZjMMZjMMZnNMk2ON;2ON:nNMjjM
MZjMMZjMMZjMMZjMMZnNMjnNMjnNMk2ON;2ON:nNMjnNMjnNMjnNMjnNMjnNMjnNMjnNMjjMMZjMMZjM
MZjMMZjMMZjMMZjMMZjMMZnMM:nMM:nMM:nMM:nMM:nMM:nMM:nMM:jLLjjLLjjLLjjLLjjLLjjLLjjL
LjjLLjnMM:jLLjjLLjjLLjfKLZfKLZfKLZfKLZjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLjjL
LjjLLjjLLjjLLjjLLjjLLjfKLZfKLZjLLjnMM:nMM:jLLjfKLZfKLZbJLJbJLJbJLJbJLJbJLJbJLJbJ
LJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJZHKjZHKj^I
L:^IL:bJLJbJLJbJLJbJLJ^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^I
L:^IL:^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJZJK:ZJK:ZJ
K:ZJK:ZJK:ZJK:ZJK:ZJK:VIJjVIJjVIJjVIJjVIJjVIJjVIJjVIJj^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^K
KJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^KKJZJK:ZJK:^K
KJ^KKJbLKZbLKZbLKZbLKZfKK:bIK:^KKJbKL:fMLj^MLjRILZFFKiZ@LYN?LY:?Lhb?MX^@NhbBPHjC
Q92DR8f<OYJEQiRGRI6@PY2?PINFR9ZIRiNFR9NJRiBGR9>FQiJIRY^NSijQTYfPTI^NSiBIQ:FZUJR/
VJJZUjnbXZnbXjNZVjR[W:j`Y:b^XZ^]XJZ/X:Z/X:Z/X:V[WjRZW[FcZ;FcZ;BbYkBbYk>aY[:`YK:`
YK6_Y;FcZ;JdZKJdZKBbYk:`YK>aY[FcZ;RfZkFcZ;JdZKNeZ[RfZkVg[;Zh[K^i[[^i[[>fYk>fYk>f
Yk:eY[6dYK6dYK2cY;2cY;BeZkFf[;Jg[KRi[kVj/;Vj/;Vj/;Ri[kNh[[Nh[[Nh[[Ri[kRi[kVj/;Vj
/;Vj/;Zk/KZk/KZk/KZk/KZk/KZk/KZk/KZk/L;0]L2lZ[bbV[JWQk2ON;6NLkJSM[^XNk6LKk6LKk6L
Kk:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;:ML;>NLK>NLK>NLK>NLK>NLK>NLK>N
LK>NLKBMKkBMKkBMKkBMKkFNL;FNL;JOLKJOLKFNLKFNLKFNLKFNLKFNLKFNLKFNLKFNLK6MK[:NKk>O
L;BPLKBPLKBPL@00]ZND]ZND]ZND]ZND]ZND]ZND]ZND]ZND]JND]JND]JND]JND]JND]JND]JND]JND
]JND]JND]JND]JND]JND]JND]JND]JND]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD]:JD
]:JD]:JD]:JD]:JD/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFB/jFB/jFB/jFB/jFB/jFB/jFB/jFB
/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFB/jFB/jFB/jFB/jFB/jFB/jFB/jFB]JJC]JJC]JJC]:FB
]:FB/jBA/jBA/Z>@]:FB]:FB]:FB]:FB]:FB]:FB]:FB]:FB]:FB]:FB]:FB]:FB]:FB]:FB]:FB]:FB
/jF?/jF?/jF?/jF?/jF?/jF?/jF?/jF?/ZB>/ZB>/jF?]:J@]:J@/jF?/ZB>/ZB>/jF?/jF?/jF?/jF?
/jF?/jF?/jF?/jF?/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;
/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;
/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;/ZF;
/JB:/JB:/JB:/JB:/JB:/JB:/JB:/JB:]JB9]JB9]JB9]JB9]JB9]JB9]JB9]JB9/j>6/j>6/j>6/j>6
/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/j>6/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5
/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5
/Z:5/Z:5/Z:5/Z:5/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64
/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23[Z61[Z61/:61/:61/Z21]:21]:21]:21/J5m/J5m/J5m/J5m
/J5m/J5m/J5m/J5m/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l
[imk[imk[imk[imk[imk[imk[imk[imk[9ah[Iei[Iei[Iei[Yij[Yij[Yij[imk[Yij[Yij[Yij[Yij
[Yij[Yij[Yij[Yij[Iei[Iei[9ahZi]gZi]g[9ah[Iei[Iei[9ag[9ag[9ag[9ag[9ag[9ag[9ag[9ag
[Iei[Iei[Iei[9ah[9ah[9ah[9ah[9ahZi]fZi]f[9ag[9ag[Ieh[Ieh[Ieh[Ieh[ieh[ieh[Yag[I]f
[I]f[Yag[ieh[ieh[9]d[Iae[Yef[iig/9mh[iig[iig[Yef[Iae[Iae[Yef[Yef[iig[iig[iig[iig
[iig[Yef[Yef[Yef[iig[iig[Yef[Yef[Yef[Yef[Yef[Yef[Yef[Yef[Yef[Yef[Iae[Yef[iig[iig
[iig[iig[Yef[Iae[Iae[Yef[iig[iig[iig[iig[Yef[Iae[Iae[Iae[Yef[Yef[iig[iig[iig[iig
[Yef[Yef[Yef[Yef[Yef[Yef[Yef[Yef[Iae[Iae[Iae[Iae[Iae[Iae[Iae[Iae[Yac[Yac[Yac[Yac
[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[Yac[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b
[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[9Ya[I]b[Yac[Yac
[Yac[Yac[I]b[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya
[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9YaZYQ_ZYQ_ZYQ_ZiU`ZiU`ZiU`[9Ya[9YaZiU`ZiU`ZiU`ZiU`
ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]
Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/Z9QZZ9QZZ9QZZ9QZ
Z9QZZ9QZZ9QZZ9QZZi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]
Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]ZYY/ZYY/ZYY/Zi]]Zi]]Zi]][9a^[9a^ZYY[ZIUZZIU[Zi]]
[Iaa[YacZi]aZ9Q^YIE[X9=]VY5_ThmbShmgS91mS962S9>6SXeoUIB6UiJ8TI22SXeoUIB6ViZ<W9^=
WIb>VIR:UYF7VIR:X9nAXj:DXJ2BW9^=VIj9XjNDVYj;TIB4WZ6BZJbMYjVMYZRLZJ^OZ:ZNZ:ZNZJ^O
ZZbPZ:ZNY:JJX::F[ZbQ[ZbQ[ZbQ[ZbQ[ZbQ[jfR[jfR[jfR];:W];:W];:W/k6V/[2U/k6V]kFZ^[R]
]K>X][BY][BY]kFZ^;J[^KN/^[R]^[R]]KRY]KRY];NX/kJW/KBU/;>T[k:S[k:S/[>Y/kBZ]KJ/]kR^
^;V_^;V_^;V_^;V_]kR^]kR^]kR^^;V_^;V_^KZ`^KZ`^KZ`^[^a^[^a^[^a^[^a^[^a^[^a^[^a^[^a
]K>X_;NX_KJR^:fA[YmnZIQaZiY_/Iia/Ia_/Ia_/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`
/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/ia^/ia^]9e_]9e_]9e_]Ii`]Ii`]Ii`
]9e`]9e`]9e`]9e`]9e`]9e`]9e`]9e`/9a]/Ie^/Yi_/im`/im`/im`002fYiBfYiBfYiBfYiBfYiBf
YiBfYiBfYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBeYiBdYYBd
YYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBdYYBbY9:bY9:bY9:bY9:bY9:b
Y9:bY9:bY9:bY96bY96bY96bY96bY96cYI:cYI:cYI:bY9:bY9:bY9:bY9:bY9:bY9:bY9:bY9:bY96b
Y96bY96bY96bY96bY96bY96bY96eYY>eYY>dYI:dYI:cY96bXi2bXi2bXi2cY96cY96cY96cY96cY96c
Y96cY96cY96cY96cY96cY96cY96cY96cY96cY96cY96bY8jbY8jbY8jbY8jbY8jbY8jbY8jbY8jaXhfb
Y8jcYHncYHncYHncYHnbY8jaXhfbY8jbY8jbY8jbY8jbY8jbY8jbY8jbY8jaY8ZaY8ZaY8ZaY8ZaY8Za
Y8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8Za
Y8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8Za
Y8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8ZaY8Z`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhVdXhRd
XhRdXhRdXhRdXhRdXhRdXhRdXhRcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJcXhJc
XhJcXhJcXhJbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFb
XXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFaXHBaXHBaXHBaXHBaXHBa
XHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBbX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>^XH6^
XH6`XH6`XH6bX86dX86dX86dX86`X7b`X7b`X7b`X7b`X7b`X7b`X7b`X7b_Wg^_Wg^_Wg^_Wg^_Wg^_
Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ/W7R/
W7R/W7R]WGV]WGV^WWZ^WWZ^WWZ]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV/W7R[VgN[VgN[VgN[
VgN/W7R]WGV/W7N/W7N/W7N/W7N/W7N/W7N/W7N/W7N/W7R/W7R/W7R/W7R/W7R/W7R/W7R/W7R[VgJ[
VgJ[VgJ/W7N/W7N/W7N]WGR]WGR_WGR^W7N]VgJ]VgJ]VgJ]VgJ^W7N_WGR/VgB]W7F^WGJ_WWN_WWN_
WWN^WGJ^WGJ]W7F]W7F]W7F^WGJ^WGJ^WGJ_WWN_WWN]W7F^WGJ^WGJ^WGJ^WGJ]W7F^WGJ^WGJ^WGJ^
WGJ^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ]W7F]W7F^WGJ_WWN_WWN^WGJ]W7F]W7F]W7F]W7F^WGJ_WWN_WWN^
WGJ]W7F]W7F]W7F]W7F]W7F^WGJ^WGJ^WGJ_WWN_WWN^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ^WGJ]W7F]
W7F]W7F]W7F]W7F]W7F]W7F]W7F^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>^
W7>^W7>^W7>/VW6/VW6/VW6]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]
Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:/VW6/VW6]Vg:^W7>^W7>]Vg:/VW6/VW6/VW6/VW6/VW6/VW6/VW6/
VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6YUfjY
UfjZV6nZV6n[VG2[VG2[VG2[VG2ZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nZ
V6nZV6nZV6nZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbYVF^Y
VF^YVF^YVF^YVF^YVF^YVF^YVF^XV6ZXV6ZXV6ZXV6ZXV6ZXV6ZXV6ZXV6ZZVVbZVVbZVVbZVVbZVVbZ
VVbZVVbZVVb[Vff[Vff[Vff[Vff[Vff[Vff[Vff[VffZVVbZVVbZVVbZVVbZVVbZVVbZVVbZVVbYVF^Y
VF^ZVVbZVVb[Vff[Vff[Vff[VffYVVVXVFRXV6VZVVb^Vfj_W76^Vg2/V6n/VfZYVF^TUVbLTW2FT7>?
SWV;Sgb8Sh2@Sh6BTH>BTH>@Sh6BTH>FUHNGUXRFUHNMVXbIUXRFThFIUXRPWHnSX9:QWY2LVH^EVHJM
XHjKWXjLWhnWZY^XZYjUYi^[[::TYYZXZYj/[Z:^/:B_/JF`/ZJb]:Rd]ZZ^[:6_[J:`[Z>b/:Fd/ZNe
/jRg]JZh]Z^`[Z>b/:Fe/jRe/jRd/ZNd/ZNf]:Vh]Z^f]:Vf]:Vf]:Vg]JZh]Z^h]Z^i]jbi]jbg^Z^f
^JZe^:Vc]ZNb]JJ`/jB_/Z>_/Z>a/ZRb/jVd]J^f]jfg^:jh^Jnh^Jnh^Jng^:jg^:jg^:jh^Jnh^Jni
^[2i^[2i^[2j^k6j^k6j^k6j^k6j^k6j^k6j^k6j^k6n_;72_k71_J^h/Y^]XXJWVGFZVW2aWW6gXWFh
XgJhXgJgXWFeX7>cWW6aW6n_VVfbWG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2bWG2b
WG2bWG2bWG2cW6jcW6jcW6jdWFndWFndWFneWW2eWW2dWG2dWG2dWG2dWG2dWG2dWG2dWG2dWG2`W6f`
W6faWFjbWVncWg2cWg000;FVTkFVTkFVTkFVTkFVTkFVTkFVTkFVTkBVTkBVTkBVTkBVTkBVTkBVTkBV
TkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTkBVTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>UTk>U
Tk>UTk>UTk>UTk>UTk>UTk:TT[:TT[:TT[:TT[:TT[:TT[:TT[:TT[6ST;6ST;6ST;:TTK:TTK:TTK>U
T[>UT[:TT[:TT[:TT[:TT[:TT[:TT[:TT[:TT[:TTK:TTK:TTK:TTK:TTK:TTK:TTK:TTKBUT[>TTK>T
TK>TTK>TTK>TTK:ST;:ST;>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>T
TK>TTK:TS[:TS[:TS[:TS[:TS[:TS[:TS[:TS[6SSK6SSK:TS[>USk>USk:TS[6SSK6SSK:TS[:TS[:T
S[:TS[:TS[:TS[:TS[:TS[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6T
R[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6T
R[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6TR[6T
R[6TR[2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRKBSR;BSR;BSR;BSR;BSR;BSR;BSR;BSR;:RQK:RQK:R
QK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK:RQK6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6Q
Q;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;6QQ;:RQK:RQK:R
QK:RQK:RQK:RQK:RQK:RQK2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2P
Pk2PPk6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OPZfPP:fPP:nPP:nPP;6OP;>OP;>OP;>OP;2PO;2PO;2P
O;2PO;2PO;2PO;2PO;2PO:nONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnONjnO
NjnONjjNNZjNNZjNNZjNNZjNNZjNNZjNNZjNNZbLN:bLN:bLN:bLN:fMNJfMNJfMNJjNNZfMNJfMNJfM
NJfMNJfMNJfMNJfMNJfMNJbLN:bLN:^KMjZJMZZJMZ^KMjbLN:bLN:^KMZ^KMZ^KMZ^KMZ^KMZ^KMZ^K
MZ^KMZZJMZ^KMj^KMj^KMjbLN:bLN:bLN:bLN:ZJMJ^KMZ^KMZ^KMZbLMjbLMjbLMjbLMjjLMjjLMjfK
MZbJMJbJMJfKMZjLMjjLMj^JLjbKM:fLMJjMMZnNMjjMMZjMMZfLMJbKM:fLMJfLMJfLMJjMMZjMMZjM
MZjMMZbKM:jMMZnNMjjMMZfLMJbKM:fLMJnNMjfLMJfLMJfLMJfLMJfLMJfLMJfLMJfLMJbKM:fLMJjM
MZjMMZjMMZjMMZfLMJbKM:bKM:fLMJjMMZjMMZjMMZjMMZfLMJbKM:bKM:fLMJfLMJfLMJjMMZjMMZjM
MZjMMZfLMJfLMJfLMJfLMJfLMJfLMJfLMJfLMJbKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:fKLZfKLZfK
LZfKLZfKLZfKLZfKLZfKLZjLLjjLLjjLLjjLLjjLLjjLLjjLLjjLLj^IL:^IL:bJLJbJLJbJLJfKLZfK
LZfKLZbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJ^IL:bJLJfK
LZfKLZfKLZfKLZbJLJ^IL:bJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJ
LJbJLJ^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:VGKZVGKZVGKZZHKjZHKj^IL:^IL:^IL:ZHKjZHKjZH
KjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJ
K:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:VIJjVIJjVIJjVIJjVIJjVIJjVIJjVIJjVIJjVIJjVI
JjVIJjVIJjVIJjVIJjVIJjZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:^KKJ^KKJ^KKJ^KKJ^KKJ^KKJ^K
KJ^KKJZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:VIJjVIJjVIJjZJK:ZJK:^KKJ^KKJ^KKJZKJZRIJ:NH
Ij^IJZnJKK2KK[:JL;2HKZnLJJnKJjbIK:RGL:2CLiN@MHn?MhV?N92?PHn>P8j=Oi6@PYFDQYNFR9BC
QI2?PI^JS9VHRYRGRI^JS:2OTJ>RU::QTinNT9JIRI^NSYRKRiZMSYnQUIZLT9^LTZb]XjV[Wjf_Xjna
YJ^]XJBVVZ2RUZ>UVJNYWJ^YWZbZWjf[X:j/XK2^Xk6_Y;:`YK>aY[BbYkJdZKVg[;Vg[;NeZ[FcZ;Bb
YkBbYkJdZKJdZKJdZKNeZ[NeZ[RfZkRfZkRfZkNjZkJiZ[FhZKBgZ;:eY[6dYK2cY:nbXjn`Y[6bZ;:c
ZKFf[;Jg[KNh[[Nh[[Nh[[Nh[[Nh[[Nh[[Ri[kRi[kVj/;Vj/;Vj/;Zk/KZk/KZk/KZk/KZk/KZk/KZk
/KZk/KFcZ;>aYZf/WZRTTZ:MQ:JKNk6PNKRUN:NBIJVDIjfHJk2KK[>NLKFPLkFPLkFPLk:ML;:ML;:M
L;:ML;:ML;:ML;:ML;:ML;6LKk6LKk6LKk6LKk6LKk6LKk6LKk6LKk:KKK:KKK>LK[>LK[BMKkBMKkBM
KkBMKk>LKk>LKk>LKk>LKk>LKk>LKk>LKk>LKk2LKK6MK[:NKk>OL;>OL;>OL000]JJC]JJC]JJC]JJC
]JJC]JJC]JJC]JJC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC]:JC
/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/jFC/ZBB/ZBB/ZBB/ZBB
/ZBB/ZBB/ZBB/ZBB/::?/::?/J>@/J>@/ZBA/ZBA/jFB/jFB/ZBB/ZBB/ZBB/ZBB/ZBB/ZBB/ZBB/ZBB
/ZBA/ZBA/ZBA/ZBA/ZBA/ZBA/ZBA/ZBA/Z>@/Z>@/Z>@/Z>@/jBA/jBA/jBA/jBA/jBA/jBA/jBA/jBA
/jBA/jBA/jBA/jBA/jBA/jBA/jBA/jBA/jBA/jBA/jBA/jBA/J>=/J>=/J>=/J>=/J>=/J>=/J>=/J>=
/::</J>=/ZB>/ZB>/ZB>/ZB>/J>=/::</J>=/J>=/J>=/J>=/J>=/J>=/J>=/J>=/:>9/:>9/:>9/:>9
/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9
/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9
/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9[j:8[j:8[j:8[j:8[j:8[j:8[j:8[j:8
/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5
/Z:5/Z:5/Z:5/Z:5/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64/J64
/J64/J64/J64/J64/J64/J64/J64/J64/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/Z:5/:23/:23/:23/:23
/:23/:23/:23/:23/:23/:23/:23/:23/:23/:23/:23/:23/In2/In2/In2/In2/In2/In2/In2/In2
[J20[J20[j20[j20/In0/in0/in0/in0/:1l/:1l/:1l/:1l/:1l/:1l/:1l/:1l[Yij[Yij[Yij[Yij
[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Yij[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei
Zi]gZi]g[9ah[9ah[9ah[Iei[Iei[Iei[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ahZi]gZi]gZYYf
ZYYfZi]gZi]g[9ahZi]fZi]fZi]fZi]fZi]fZi]fZi]fZi]fZYYfZYYfZYYfZi]gZi]g[9ah[9ah[Iei
ZYYeZYYeZi]fZi]fZi]f[9ag[9ag[9ag[Yag[I]f[I]f[9Ye[9Ye[I]f[I]f[YagZiYc[9]d[Iae[Yef
[Yef[Yef[Yef[Iae[9]d[9]d[Iae[Iae[Iae[Yef[Yef[YefZiYc[Yef[iig[Yef[9]dZiYc[Iae[iig
[Iae[Iae[Iae[Iae[Iae[Iae[Iae[Iae[9]d[Iae[Iae[Yef[Yef[Iae[Iae[9]d[9]d[Iae[Iae[Yef
[Yef[Iae[Iae[9]d[9]d[9]d[Iae[Iae[Iae[Yef[Yef[Yef[Iae[Iae[Iae[Iae[Iae[Iae[Iae[Iae
[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[I]b[I]b[I]b[I]b[I]b[I]b[I]b[I]b[Yac[Yac[Yac[Yac
[Yac[Yac[Yac[YacZYQ_ZiU`ZiU`[9Ya[9Ya[I]b[I]b[I]b[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya
[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9YaZiU`ZiU`[9Ya[I]b[I]b[9YaZiU`ZiU`[9Ya[9Ya[9Ya[9Ya
[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9Ya[9YaZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`
ZIM^ZIM^ZIM^ZIM^ZYQ_ZYQ_ZYQ_ZiU`ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_
ZYQ_ZYQ_ZYQ_ZYQ_ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/
Z9QZZ9QZZ9QZZ9QZZ9QZZ9QZZ9QZZ9QZZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/
ZYY/ZYY/ZYY/ZYY/Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]Zi]]ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/ZYY/
ZIU[ZIU[ZIU[ZIU[ZYY/ZYY/ZYY/Zi]]ZYeYZI]WYiQWZYUX[YY[/IY]/YU]/IQ^[9]X[Ia[/9]^/9Ya
ZIMbWiAdUI9cSY1bSXeoSHanSXeoTY63UIB6UIB6U9>5U9>5U9B6UIF7UYJ8VIV;Vi^=WIf?WinAX:2B
XZFEZ:^KX:>DV9Z>VifAVibBWj2F[ZnVXZBHYZRLZZbPZjfQZZbPZZbP[JnS/K>W/:jS/JnT/[2U/k6V
];:W]K>X][BY][BY][BY]kFZ^KN/^;J[][BY];:W];:W]K>X][BY][BY][BY][BY]kFZ]kFZ]kFZ]kFZ
][VZ][VZ]KRY];NX/kJW/[FV/KBU/KBU[ZnU[k2V/[>Y];F[][N]]kR^]kR^]kR^]kR^]kR^]kR^^;V_
^;V_^KZ`^KZ`^KZ`^[^a^[^a^[^a^[^a^[^a^[^a^[^a^[^aXInDWIfAVYZ>ViZ<XIb7YYanZ9UbZIIY
W8MJX8]NYY5T[9MZ/Ia_]J1c]j9e]j9e/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ye`/Ia_/Ia_/Ia_/Ia_
/Ia_/Ia_/Ia_/Ia_/Y]]/Y]]/Y]]/ia^/ia^]9e_]9e_]9e_/Y]^/Y]^/Y]^/Y]^/Y]^/Y]^/Y]^/Y]^
/Ie^/Ie^/Yi_/im`]:1a]:1a002eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>dYY>dYY>dYY>dYY>dYY>d
YY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>dYY>cYI>cYI>cYI>cYI>cYI>cYI>cYI>cYI>cYI>c
YI>cYI>cYI>cYI>cYI>cYI>cYI>aXi6aXi6aXi6aXi6aXi6aXi6aXi6aXi6`XXn`XXn`XXnaXi2bY96b
Y96cYI:cYI:aXi6aXi6aXi6aXi6aXi6aXi6aXi6aXi6aXi2aXi2aXi2aXi2aXi2aXi2aXi2aXi2aXXna
XXnaXXnbXi2cY96cY96dYI:dYI:bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2b
Xi2bXi2bXi2aXhfaXhfaXhfaXhfaXhfaXhfaXhfaXhf`XXbaXhfbY8jbY8jbY8jbY8jaXhf`XXbaXhfa
XhfaXhfaXhfaXhfaXhfaXhfaXhf`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`
XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`
XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`
XhV`XhV`XhV_XXR_XXR_XXR_XXR_XXR_XXR_XXR_XXRcXXNcXXNcXXNcXXNcXXNcXXNcXXNcXXNbXXFb
XXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFbXXFaXHBaXHBaXHBaXHBaXHBa
XHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBaXHBbXXFb
XXFbXXFbXXFbXXFbXXFbXXFbXXF`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>`
X8>`X8>`X8>aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:]X82]X82_X82_X82aWh2cWh2cWh2cWh2_Wg^_
Wg^_Wg^_Wg^_Wg^_Wg^_Wg^_Wg^^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^WWZ^
WWZ^WWZ^WWZ]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV[VgN[VgN[VgN/W7R/W7R]WGV]WGV]WGV/W7R/
W7R/W7R/W7R/W7R/W7R/W7R/W7R/W7R[VgN[VgNZVWJZVWJ[VgN[VgN/W7R[VgJ[VgJ[VgJ[VgJ[VgJ[
VgJ[VgJ[VgJYVGFYVGFZVWJ[VgN[VgN/W7R/W7R]WGVZVWFZVWFZVWF[VgJ[VgJ[VgJ/W7N/W7N^W7N]
VgJ]VgJ/VWF/VWF]VgJ]VgJ^W7N[VW>/VgB]W7F^WGJ^WGJ^WGJ]W7F]W7F/VgB/VgB/VgB]W7F]W7F]
W7F^WGJ^WGJ[VW>]W7F`WgR^WGJ[VW>ZVG:/VgB_WWN]W7F]W7F]W7F]W7F]W7F]W7F]W7F]W7F/VgB]
W7F]W7F^WGJ^WGJ]W7F]W7F/VgB/VgB]W7F]W7F^WGJ^WGJ]W7F]W7F/VgB/VgB/VgB/VgB]W7F]W7F]
W7F^WGJ^WGJ]W7F]W7F]W7F]W7F]W7F]W7F]W7F]W7F/VgB/VgB/VgB/VgB/VgB/VgB/VgB/VgB]Vg:]
Vg:]Vg:]Vg:]Vg:]Vg:]Vg:]Vg:^W7>^W7>^W7>^W7>^W7>^W7>^W7>^W7>ZV6nZV6n[VG2[VG2/VW6]
Vg:]Vg:]Vg:/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6[VG2[
VG2/VW6]Vg:]Vg:/VW6[VG2[VG2/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/VW6/
VW6/VW6/VW6[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2XUVfYUfjYUfjYUfjZV6nZV6nZV6nZV6nYUfjY
UfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYVF^YVF^YVF^YVF^YVF^Y
VF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^XV6ZXV6ZXV6ZXV6ZXV6ZXV6ZXV6ZXV6Z[Vff[
Vff[Vff[Vff[Vff[Vff[Vff[VffYVF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^[Vff[Vff[Vff[Vff[Vff[
Vff[Vff[VffYVF^YVF^YVF^YVF^YVF^YVF^YVF^YVF^XV6ZYVF^YVF^YVF^ZVVbZVVbZVVbZVVbZWFVY
VfNWV6NZVFR_V6ZbVFfaV6bbUf^WVFF[VVV`W6fdW7:_VWBVV7BKUG:DTg6<Rgf=S7j?SX2CTXBCTXBC
TXBFUHNKVXb?TX>BUHJEV8VGVX^HVhbJWHjMX96PXiBGVXZZ[IjY[9fOXIFSY9ZTYI^MWYFLWIBRY9RS
YIVVZ9bYZinZ[:2Z[:2YZinYZin/ZYn]Zj2^[:6`[Z>b/:Fd/ZNe/jRf]:Vc/JJd/ZNd/ZNc/JJb/:Fc
/JJf]:Vh]Z^f]:Vf]:Vf]:Vf]:Vf]:Vg]JZg]JZg]JZf^JZe^:Ve^:Vd]jRc]ZNb]JJb]JJa]:F^[jF_
/:Ja/ZRc]:Ze]Zbf]jfg^:jg^:jg^:jg^:jg^:jh^Jnh^Jni^[2i^[2i^[2j^k6j^k6j^k6j^k6j^k6j
^k6j^k6j^k6n_;6l_;2k_;;1`KG6`Zo0^9^cXgjWU6N`VfjaW6ncWW6eX7>eX7>cWW6aW6n_VVfbWG2b
WG2bWG2bWG2bWG2bWG2bWG2bWG2aW6naW6naW6naW6naW6naW6naW6naW6nbVffbVffbVffcW6jcW6jc
W6jdWFndWFnbVfjbVfjbVfjbVfjbVfjbVfjbVfjbVfjaWFjbWVncWg2dX76dX76dX7400;JWU;FVTkBU
T[BUT[BUT[BUT[FVTkJWU;JWU;JWU;JWU;JWU;JWU;JWU;JWU;JWU;FVTkFVTkFVTkFVTkFVTkFVTkFV
TkFVTkBUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>T
TK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK6RSk6RSk6RSk6RSk6RSk6RSk6R
Sk6RSk>TTK>TTK>TTK>TTK>TTK>TTK>TTK>TTK:TS[:TS[6SSK2RS;2RS;6SSK:TS[:TS[6RSk6RSk6R
Sk6RSk6RSk6RSk6RSk6RSk6SSK6SSK6SSK6SSK6SSK6SSK6SSK6SSK6RSk6RSk6SSK6SSK6SS;6SS;6T
R[6TR[2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRKFTR[FTR[FTR[FTR[FTR[FTR[FTR[FTR[BSRKBSRKBS
RKBSRKBSRKBSRKBSRKBSRK6TR[6TR[2SRJnRR:nRR:jQQjjQQjfPQ[BSRKBSRKBSRKBSRKBSRKBSRKBS
RKBSRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRJnRR:nRR:nRR:nRR:nRR:nRR:nRR:nRR;:QQk>RR;BS
RKBSRKBSRKBSRK>RR;:QQjjQQjjQQjjQQjjQQjjQQjjQQjjQQjjQQk>RQk>RQk>RQk>RQk>RQk>RQk>R
Qk>RQkBSR;>RQk6PQK2OQ;2OQ;6PQK>RQkBSR;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;BRQKBRQKBR
QKBRQKBRQKBRQKBRQKBRQK>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>Q
Q;>QQ;:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk>QQ;:PPk6O
P[6OP[6OP[6OP[:PPk>QQ;:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk2NPK2NPK6OP[:PPk:PPk6OP[2N
PK2NPJbNPJbNPJjOOjjOOk2OO[:OO[:OO;:OO:bLN:jNNZnONjjNNZbLN:bLN:fMNJnONjfMNJfMNJfM
NJfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJfMNJjLMjjLMjjLMjjLMjjLMjjLMjjL
MjjLMjfKMZfKMZfKMZfKMZfKMZfKMZfKMZfKMZbLMj^KMZ^KMZZJMJZJMJ^KMZ^KMZbLMjbJMJbJMJbJ
MJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJRHLjRHLjRHLjVIM:VIM:VIM:ZJ
MJZJMJZJMJZJMJZJMJZJMJZJMJZJMJZJMJZJMJbKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:fLMJfLMJfL
MJfLMJfLMJfLMJfLMJfLMJbKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:fLMJfLMJjMMZjMMZfLMJfL
MJbKM:^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLjbKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bK
M:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bK
M:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^IL:^IL:^I
L:bJLJbJLJbJLJfKLZfKLZbJLJbJLJbJLJbJLJbJLJbJLJbJLJbJLJjLLjfKLZ^IL:ZHKjZHKj^IL:fK
LZjLLjZHKjZHKj^IL:bJLJbJLJ^IL:ZHKjZHKj^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:ZHKjZHKjZH
KjZHKjZHKjZHKjZHKjZHKjVGKZVGKZVGKZVGKZZHKjZHKjZHKj^IL:ZHKjZHKjZHKjZHKjZHKjZHKjZH
KjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKj^IL:ZHKjVGKZVGKZVGKZVGKZZHKj^IL:RFKJRFKJRF
KJRFKJRFKJRFKJRFKJRFKJbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZjIK:jIK:jIK:jIK:fHJjfHJjfH
JjfHJjjIK:jIK:fHJjfHJjbGJZbGJZ^FJJ^FJJfHJjfHJjbGJZbGJZ^FJJZEJ:ZEJ:ZEJ:^FJJbGJZbG
JZbGJZfHJjfHJjfHJjjIK:fGKZfGKZfGKZfGKZjHKjjHKjjHKjnIL:ZJK:ZJK:ZJK:ZJK:ZJK:ZJK:ZJ
K:ZJK:jIK:jIK:jIK:jIK:jIK:jIK:jIK:jIK:bGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZfH
JjjIK:nJKJnJKJjIK:jIK:6?LY^>M9B=NY2=OXj>P8n@P9:COiNEOI>AQYBBQiJDRIRGRIZIRi^KRi^K
Ri^KRijMSj6PTZBSUJBSUJ:QTinNT9fLSYfLSYbNTYjPU::TV:JXW:V[WjZ/X:^]XJ^]XJ^YWZbZWjf[
X:j/XJn]X[2^Xk6_Y;:`YK:bX[>cXk>bY;>bY;>aY[BbZ;JdZ[NeZlflZL>gYKB]W:f]WKZj[/O5^l:i
]K:VX[RgX[VhY;VhY;RfY;BdY;>bY;>cYKBdZ;JdZK6_Y:j/XJn]X[BbYkNeZ[NeZ[FcZ;Nh[[Nh[[Jg
[KJg[KJg[KNh[[Ri[kRi[kNh[[Nh[[Ri[kVj/;Zk/KZk/K^l/[^l//2m[kZl/;>l[kBn/Kg3//6nZKVZ
T:^ENKNQLK2LK:jKK[6NLk:OM;6KLK>LKkNNL[6LKk6LKk6LKk6LKk6LKk6LKk6LKk6LKk:KKK:KKK:K
KK:KKK:KKK:KKK:KKK:KKKBMKkBMKkBMKkBMKkBMKkBMKkBMKkBMKk:KKK>LK[>LK[BMKkBMKk>LK[>L
K[:KKK>LKk>LKk>LKk>LKk>LKk>LK`00]ZND]JJC]:FB]:FB]:FB]:FB]JJC]ZND]ZND]ZND]ZND]ZND
]ZND]ZND]ZND]ZND]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC]:FB]:FB]:FB]:FB]:FB]:FB]:FB]:FB
/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@
/Z>@/Z>@/Z>@/Z>@/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@
/ZB>/ZB>/J>=/::</::</J>=/ZB>/ZB>/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J>=/J>=/J>=/J>=
/J>=/J>=/J>=/J>=/J:?/J:?/J>=/J>=/J></J></JB:/JB:/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9
]JB:]JB:]JB:]JB:]JB:]JB:]JB:]JB:]:>9]:>9]:>9]:>9]:>9]:>9]:>9]:>9/JB:/:>9/:>9[j:8
[j:8[Z67[Z67[Z67]:>9]:>9]:>9]:>9]:>9]:>9]:>9]:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9
[j:8[j:8[j:8[j:8[j:8[j:8[j:8[j:8/Z67/j:8/j:8]:>9]:>9/j:8/j:8/Z67[Z67[Z67[Z67[Z67
[Z67[Z67[Z67[Z67/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/j:7/J25/9n4/9n4/J25/j:7/j:7
/j64/j64/j64/j64/j64/j64/j64/j64]::5]::5]::5]::5]::5]::5]::5]::5/j64/j64/j64/j64
/j64/j64/j64/j64/j64/j64/j64/j64/j64/j64/j64/j64/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23
/:23/:23/:23/:23/:23/:23/:23/:23/j64/Z23/In2/In2/In2/In2/Z23/j64/Z23/Z23/Z23/Z23
/Z23/Z23/Z23/Z23/9j1/9j1/In2/Z23/Z23/In2/9j1/9j1Zif0Zif0[Iin[Iin[iim/Iim/Iik/Iik
[9ah[Yij[imk[Yij[9ah[9ah[Iei[imk[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei[Iei
[Iei[Iei[Iei[Iei[Yag[Yag[Yag[Yag[Yag[Yag[Yag[Yag[I]f[I]f[I]f[I]f[I]f[I]f[I]f[I]f
[9agZi]fZi]fZYYeZYYeZi]fZi]f[9ag[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye
[9Ye[9Ye[9Ye[9YeZ9QcZ9QcZ9QcZIUdZIUdZIUdZYYeZYYeZYYeZYYeZYYeZYYeZYYeZYYeZYYeZYYe
[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[Iae[Iae[Iae[Iae[Iae[Iae[Iae[Iae[9]d[9]d[9]d[9]d
[9]d[9]d[9]d[9]d[9]d[Iae[Iae[Yef[Yef[Iae[Iae[9]dZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYc
[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d
[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]d
ZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiU`ZiU`ZiU`ZiU`[9Ya[9Ya[I]b[I]b[9Ya[9Ya[9Ya[9Ya
[9Ya[9Ya[9Ya[9Ya[I]b[9YaZiU`ZYQ_ZYQ_ZiU`[9Ya[I]bZYQ_ZYQ_ZiU`[9Ya[9YaZiU`ZYQ_ZYQ_
ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZiU`ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^Z9I]ZIM^ZIM^ZIM^
ZYQ_ZYQ_ZYQ_ZYQ_ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^
ZYQ_ZYQ_ZIM^Z9I]Z9I]ZIM^ZYQ_ZYQ_Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I][9MZ[9MZ[9MZ[9MZ
[9MZ[9MZ[9MZ[9MZ[YU/[YU/[YU/[IQ[[IQ[[IQ[[IQ[[IQ[[YU/[IQ[[IQ[[IQ[[9MZZiIYZiIYZiIY
[9MZ[9MZ[9MZZiIYZiIYZiIYZiIYZiIYZiIYZiIY[9MZ[9MZ[9MZ[IQ[[IQ[[IQ[[9I][IM^[IM^[IM^
[YQ_[YQ_[YQ_[YQ_ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[ZIU[[IQ[[IQ[[IQ[[IQ[[IQ[[IQ[[IQ[[IQ[
[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZZiIY[9MZ[IQ[[YU/[iY][YU/[YU/[IQ[YY5aX91cVHmgTXil
ShmoSi20TI9nU9=nTi:4U9>5UYF7V9N9VYV;Vi^;Vi^;Vi^;VYV;WYf?XZ6CXj:DXZ6CX9nAX9nAX9nA
WInCWZ2DXJ>GY:JJYjVMZJ^OZZbPZjfQ[J^P[J^P[J^P[ZbQ[jfR/:jS/JnT/[2U/k>S];BT]KBV];>U
/JnT/:jT/JnU/[2V/ZFG]jjP^KJX_[jbbL[1f]KAh=ODflo=_;b/]KFU[ZjN[jjP];>U][FW/K2RZjVN
]K>X/k6V/JnT/JnT/k6V]K>X]kFZ]kFZ]kR^][N]][N]][N]][N]]kR^^;V_^;V_]kR^]kR^^;V_^KZ`
^[^a^[^a^kbb^kbb_[f_^[b`/kb_];f`_<:a`[j[^jfF/Ib1/Im`[I]/[9U//9eb/Iic/I]a/Y]^]Iia
/Ia_/Ia_/Ia_/Ia_/Ia_/Ia_/Ia_/Ia_/Y]]/Y]]/Y]]/Y]]/Y]]/Y]]/Y]]/Y]]/ia^/ia^/ia^/ia^
/ia^/ia^/ia^/ia^/Y]]/Y]]/ia^]9e_]9e_/ia^/Y]]/Y]]/ia_/ia_/ia_/ia_/ia_/ia_002eYY>e
YY>dYI:cY96cY96dYI:eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>eYY>dYI:dYI:dYI:dYI:dYI:d
YI:dYI:dYI:cY96cY96cY96cY96cY96cY96cY96cY96bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2b
Xi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2aXXnaXXnaXXnaXXnaXXna
XXnaXXnaXXnbXi2bXi2bXi2bXi2bXi2bXi2bXi2bXi2bY8jaXhfaXhf`XXb`XXbaXhfaXhfbY8jaXXna
XXnaXXnaXXnaXXnaXXnaXXnaXXnaXhfaXhfaXhfaXhfaXhfaXhfaXhfaXhfaXXnaXXnaXhfaXhfaXhba
XhbaY8ZaY8Z`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhVeY8ZeY8ZeY8ZeY8ZeY8ZeY8ZeY8ZeY8ZdXhVd
XhVdXhVdXhVdXhVdXhVdXhVdXhV`XhV`XhV`XhV_XXR_XXR_XXR^XHN^XHNdXhVdXhVdXhVdXhVdXhVd
XhVdXhVdXhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV`XhV_XXR_XXR_XXR_XXR_XXR_XXR_XXR_XXRbXHNb
XHNcXXRdXhVdXhVcXXRbXHNbXHN^XHN^XHN^XHN^XHN^XHN^XHN^XHN^XHNcXXNcXXNcXXNcXXNcXXNc
XXNcXXNcXXNcXXNbXHJaX8FaX8FaX8FaX8FbXHJcXXNcXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBdXXFd
XXFdXXFdXXFdXXFdXXFdXXFdXXFbX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>b
X8>bX8>bX8>aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>bX8>b
X8>aWh:`WX6`WX6aWh:bX8>bX8>aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:_WH2`WX6aWh:aWh:aWh:a
Wh:`WX6_WH2[WH2[WH2]WWj]WWj_WWfaWWfaWW^aWW^/W7R^WWZ_Wg^^WWZ/W7R/W7R]WGV_Wg^]WGV]
WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV]WGV^W7N^W7N^W7N^W7N^W7N^
W7N^W7N^W7N]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ/W7N[VgJZVWFZVWFZVWFZVWF[VgJ/W7N/VWF/
VWF/VWF/VWF/VWF/VWF/VWF/VWF[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGBXV7>XV7>XV7>YVGBYVGBY
VGBZVWFZVWFYVGBYVGBYVGBYVGBYVGBYVGBYVGBYVGB[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>]W7F]
W7F]W7F]W7F]W7F]W7F]W7F]W7F[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>/VgB/VgB]W7F^WGJ^WGJ]
W7F/VgB/VgB[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[
VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[
VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZV6nZ
V6n[VG2[VG2/VW6/VW6/VW6/VW6[VG2[VG2[VG2[VG2[VG2[VG2[VG2[VG2/VW6/VW6[VG2ZV6nZV6n[
VG2/VW6/VW6YUfjZV6n[VG2[VG2[VG2[VG2ZV6nYUfjZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nYUfjY
UfjYUfjYUfjYUfjYUfjYUfjYUfjXUVfXUVfXUVfYUfjYUfjZV6nZV6nZV6nYUfjYUfjYUfjYUfjYUfjY
UfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjZV6nYUfjYUfjXUVfXUVfYUfjYUfjZV6nXUVfX
UVfXUVfXUVfXUVfXUVfXUVfXUVf/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ]V6^]V6^]V6^]V6^]V6^]
V6^]V6^]V6^]V6^]V6^/UfZ/UfZ/UfZ[UVV[UVV[UVV[UVV[UVV[UVV[UVV[UVV/UfZ/UfZ/UfZ[UVV[
UVV[UVV/UfZ/UfZ]V6^]V6^]V6^/UVb/UVb/UVb]Uff]Uff^V6j^V6j^V6jYVF^YVF^YVF^YVF^YVF^Y
VF^YVF^YVF^]V6^]V6^]V6^]V6^]V6^]V6^]V6^]V6^/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ[UVV/
UfZ]V6^^VFb^VFb^VFb^VFb]V6^[UFbWU6nOTW:HTGRCSgb?Sgf?TGj@TWnCTh>DU8BFUXJHV8RIVHVJ
VXZKVh^KVh^GUXRJVH^OWY2QX9:QX9:QX9:RXI>TXiFNX9BOXIFPXYJRY9RTYYZWZIfYZinZ[:2`[Z>_
[J:^[:6]Zj2^[:6`[Z>a[jBc/JJc/j>e]JFf]JNd/jF`[Z>^[::`[ZBc/JNl]:g3_KK:b<3@d<[FeM7L
emCLe=CJd=3Gf<o?d<O4`kVf]J^^[:6^[:6e/jRn^jfd/ZNd/ZNd/ZNc/JJa[jBb/:Fe/jRh]Z^e]Zbe
]Zbf]jff]jfg^:jg^:jg^:jh^Jng^:jg^:jh^Jni^[2j^k6j^k6k_;:k_;:m_:jj_Jjd^jjc_:nk`;74
`:k1]9jhYhf]WG:YV6fXV6Z_W6ncWW6`VfjaVFncVg6`Vfj`Vfj`Vfj`Vfj`Vfj`Vfj`Vfj`VfjaVVba
VVbaVVbaVVbaVVbaVVbaVVbaVVbbVffbVffbVffbVffbVffbVffbVffbVffaVVbbVffcW6jcW6jcW6jc
W6jbVffaVVbbVfjbVfjbVfjbVfjbVfjbVfh00;FVTkBUT[>TTK>TTK>TTK>TTKBUT[FVTkFVTkFVTkFV
TkFVTkFVTkFVTkFVTkFVTkBUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[>TTK>TTK>TTK>TTK>TTK>TTK>T
TK>TTK:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:ST;:S
T;:ST;:ST;:ST;:ST;:ST;6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk:ST;:ST;:ST;:ST;:ST;:ST;:S
T;:ST;6SSK6SSK2RS;2RS;2RS;2RS;6SSK6SSK6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6SSK6SSK6S
SK6SSK6SSK6SSK6SSK6SSK6RSk6RSk6SSK6SSK6SS;6SS;6TR[6TR[2SRK2SRK2SRK2SRK2SRK2SRK2S
RK2SRKFTR[FTR[FTR[FTR[FTR[FTR[FTR[FTR[>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR:nRR:nRR:nR
R:nRR:nRR:nRR:nRR:nRR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR:nRR:nRR:nRR:nRR:nRR:nRR:nR
R:nRR:jQQjjQQjjQQjjQQjjQQjjQQjjQQjjQQk6PQ[:QQk>RR;>RR;>RR;>RR;:QQk6PQZjQQjjQQjjQ
QjjQQjjQQjjQQjjQQjjQQk:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[6PQK6PQK6PQK6PQK6PQK6PQK6P
QK6PQK>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;:PPk:PPk:P
Pk:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk6OP[6OP[6OP[6OP[6OP[6OP[6O
P[6OP[2PPk2PPk2PPk2PPk2PPk2PPk2PPk2PPk:PPk6OP[2NPK2NPK2NPK2NPK6OP[:PPk6OP[6OP[6O
P[6OP[6OP[6OP[6OP[6OPZnMP:nMP;2NPK6OP[6OP[2NPJnMP:nMP:^MP:^MP:fNOZfNOZnNOK6NOK6N
Nk6NNjbLN:jNNZnONjjNNZbLN:bLN:fMNJnONjbLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bLN:bL
N:bLN:bLN:bLN:bLN:bLN:fKMZfKMZfKMZfKMZfKMZfKMZfKMZfKMZbJMJbJMJbJMJbJMJbJMJbJMJbJ
MJbJMJ^KMZ^KMZZJMJVIM:VIM:ZJMJ^KMZ^KMZbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJ^IM:^IM:^I
M:^IM:^IM:^IM:^IM:^IM:RHLjRHLjRHLjVIM:VIM:VIM:ZJMJZJMJVIM:VIM:VIM:VIM:VIM:VIM:VI
M:VIM:^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLjbKM:bKM:bKM:bKM:bKM:bKM:bKM:bKM:^JLj^JLj^J
Lj^JLj^JLj^JLj^JLj^JLj^JLjbKM:fLMJfLMJfLMJfLMJbKM:^JLj^JLj^JLj^JLj^JLj^JLj^JLj^J
Lj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^J
Lj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLj^J
Lj^JLjZILZZILZZILZZILZZILZZILZZILZZILZZHKjZHKjZHKj^IL:^IL:^IL:bJLJbJLJ^IL:^IL:^I
L:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:^IL:VGKZVGKZZHKj^IL:^IL:ZHKjVG
KZVGKZZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZRFKJRFKJRF
KJRFKJVGKZVGKZZHKjZHKjVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZVG
KZVGKZZHKjVGKZRFKJRFKJRFKJRFKJVGKZZHKjRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJbGJZbGJZbG
JZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZfHJjfHJjfHJjfHJjbGJZbGJZbGJZbGJZ^FJJ^FJJ^F
JJ^FJJZEJ:ZEJ:ZEJ:^FJJbGJZbGJZfHJjfHJjZEJ:^FJJ^FJJ^FJJbGJZbGJZbGJZfHJjbFK:bFK:bF
K:bFK:fGKJfGKJjHKZjHKZVIJjVIJjVIJjVIJjVIJjVIJjVIJjVIJjfHJjfHJjfHJjfHJjfHJjfHJjfH
JjfHJjbGJZbGJZbGJZbGJZbGJZbGJZbGJZbGJZ^FJJ^FJJbGJZfHJjjIK:jIK:fHJjfHJk2HJZbGJZJE
KYfBLYRAMY>@Ni2@OXn@P9:COi>CPIFEPiNGQIVIRIZJRYZIRiZIRiJEQiVHRYfLSYnNT:2OTJ2OTJ:Q
TjBSUInQUInQUInQUInQUJ6SUjBVVZNYWJV[Wk2^Xjn]XZj/XJf[X:f[X:n]X[6_Y;>aY[>cXkBdY;Bc
YK:aXk6_Y;>aYkZh[/2n]<k:bM7=c=SEdN3Kf>7LfN3Ge=c@c][>b]WFd][Gdm_Hdm_Hd=GBb/W4^kVe
ZZjZWk:`YKBbYkFcZ;>aYZn]XZj/XK:`YKNeZ[BeZkBeZkFf[;Jg[KNh[[Nh[[Nh[[Nh[[Nh[[Nh[[Ri
[kVj/;Zk/KZk/K^l/[^l/[bm[KZm[[Fl[kBj[kbn//?0/L:kYkjaVjZONJFILJNFJjnJKKBMKk:KKZnI
Kk2JLK2KK[2KK[2KK[2KK[2KK[2KK[2KK[2KK[6JK;6JK;6JK;6JK;6JK;6JK;6JK;6JK;6JK;6JK;6J
K;6JK;6JK;6JK;6JK;6JK;6JK;:KKK:KKK>LK[>LK[:KKK:KKK6JK;:KK[:KK[:KK[:KK[:KK[:KKP00
]:FB]:FB/jBA/Z>@/Z>@/jBA]:FB]:FB]JJC]JJC]JJC]JJC]JJC]JJC]JJC]JJC/jBA/jBA/jBA/jBA
/jBA/jBA/jBA/jBA/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?
/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/:6>/:6>/:6>/:6>
/:6>/:6>/:6>/:6>/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J>=/::</::<[j6;[j6;/::</::</J>=
/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>/::</::</::</::</::</::</::</::</:6>/:6>/::</::<
/::;/::;/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9/:>9]:>9]:>9]:>9]:>9]:>9]:>9]:>9]:>9
/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8[j:8[j:8[j:8[j:8[j:8[j:8[j:8[j:8/j:8/j:8/j:8/j:8
/j:8/j:8/j:8/j:8[j:8[j:8[j:8[j:8[j:8[j:8[j:8[j:8[Z67[Z67[Z67[Z67[Z67[Z67[Z67[Z67
/J26/J26/Z67/j:8/j:8/Z67/J26/J26[Z67[Z67[Z67[Z67[Z67[Z67[Z67[Z67/Z66/Z66/Z66/Z66
/Z66/Z66/Z66/Z66/9n4/9n4/J25/J25/J25/J25/9n4/9n4/j64/j64/j64/j64/j64/j64/j64/j64
/j64/j64/j64/j64/j64/j64/j64/j64/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23
/Z23/Z23/Z23/Z23/9j1/9j1/9j1/9j1/9j1/9j1/9j1/9j1/:23/:23/:23/:23/:23/:23/:23/:23
/In2/In2/9j1[if0[if0/9j1/In2/In2/9j1/9j1/9j1/9j1/9j1/9j1/9j1/9j1[Yao[if0/9j1/9j1
/9j1/9j1[if0[YaoZYaoZYao[9em[9em[Yel/9el/9ej/9ej[9ah[Yij[imk[Yij[9ah[9ah[Iei[imk
[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ah[9ah[I]f[I]f[I]f[I]f
[I]f[I]f[I]f[I]f[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9YeZi]fZYYeZIUdZIUdZIUdZIUdZYYeZi]f
[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9YeZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZ9QcZ9QcZ9QcZIUd
ZIUdZIUdZYYeZYYeZIUdZIUdZIUdZIUdZIUdZIUdZIUdZIUdZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYc
[9]d[9]d[9]d[9]d[9]d[9]d[9]d[9]dZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYc[9]d[Iae
[Iae[9]dZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYc
ZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYc
ZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYcZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQa
ZIM^ZIM^ZYQ_ZYQ_ZiU`ZiU`ZiU`ZiU`ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZiU`ZiU`
ZiU`ZiU`ZYQ_ZYQ_Z9I]ZIM^ZYQ_ZYQ_ZYQ_ZYQ_ZIM^Z9I]ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^
Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]YiE/YiE/Z9I]Z9I]Z9I]ZIM^ZIM^ZIM^Z9I]Z9I]Z9I]Z9I]
Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]ZIM^ZIM^Z9I]YiE/YiE/Z9I]ZIM^ZIM^
YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/ZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIY[9MZ
[9MZ[IQ[[IQ[[YU/ZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIYZYEXZYEXZYEXZiIY[9MZ[9MZ[IQ[[IQ[
ZYEXZYEXZYEXZiIYZiIY[9MZ[9MZ[9MZZiIYZiIY[9MZ[9MZ[9MZ[IQ[[IQ[[IQ[Z9QZZ9QZZ9QZZ9QZ
Z9QZZ9QZZ9QZZ9QZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ
ZYEXZiIY[9MZ[IQ[[IQ[[IQ[[IQ[[9MZ/9UW[YQXZIIYYYE^WI=aVI9gU95lTi9nTYAnTiEoUIJ2UiR4
VIV7VYZ:VYV;VYV;V9N9VYV;WIb>WYf?WYf?WYf?X9nAXZ6CWj6EWj6EWZ2DWZ2DX::FXZBHYJNKYZRL
[ZbQ[J^P[J^P[:ZO[J^P[jfR/JnT/[2U/k>S/K6Q/:nQ/K2R]kFZ`Knec<[0dm77dLg<f=?@iMcIj=cH
gLg6d/6hfLJnj=K;jn3LgmC@elc8fM7:hm_Dgm[Ac/W0^kJ]/[2U];:W];:W/JnT[J^P[:ZO/:jS];:W
/[>Y/kBZ]KJ/][N]]kR^]kR^]kR^]kR^]kR^]kR^^;V_^KZ`^[^a^[^a^kbb^kbb^Kb/^Kj_^;b`][Z_
^[^a`L2b`kn]`;VU[JJ5YYehZ9Q^[i]/]9e]/Y]][YQ^[IQb/9]^/9]^/9]^/9]^/9]^/9]^/9]^/9]^
/9U[/9U[/9U[/9U[/9U[/9U[/9U[/9U[/9U[/9U[/9U[/9U[/9U[/9U[/9U[/9U[/IY//IY//Y]]/Y]]
/Y]]/Y]]/IY//IY//Y]^/Y]^/Y]^/Y]^/Y]^/Y]^002dYI:cY96cY96bXi2bXi2cY96cY96dYI:dYI:d
YI:dYI:dYI:dYI:dYI:dYI:dYI:cY96cY96cY96cY96cY96cY96cY96cY96bXi2bXi2bXi2bXi2bXi2b
Xi2bXi2bXi2aXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXna
XXnaXXnaXXnaXXnaXXnaXXnaXXn`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHjaXXnaXXnaXXnaXXnaXXna
XXnaXXnaXXnaXhf`XXb_XH^_XH^_XH^_XH^`XXbaXhf`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XHj`XXb`
XXb`XXb`XXb`XXb`XXb`XXb`XXb`XHj`XHj`XXb`XXb`XX^`XX^`XhV`XhV`XhV`XhV`XhV`XhV`XhV`
XhV`XhV`XhVdXhVdXhVdXhVdXhVdXhVdXhVdXhVdXhVbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHN^XHN^
XHN_XXR_XXR_XXR`XhV`XhV`XhVbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHN^XHN^XHN^XHN^XHN^XHN^
XHN^XHN^XHN]X8J]X8J]X8J]X8J]X8J]X8J]X8J]X8J`WhFaX8JbXHNbXHNbXHNbXHNaX8J`WhF^XHN^
XHN^XHN^XHN^XHN^XHN^XHN^XHNaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8F_WX>`WhBaX8FaX8FaX8Fa
X8F`WhB_WX>cXHBcXHBcXHBcXHBcXHBcXHBcXHBcXHBbX8>bX8>bX8>bX8>bX8>bX8>bX8>bX8>aWh:a
Wh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:`WX6`WX6`WX6`WX6`WX6`
WX6`WX6`WX6`X8>`X8>`X8>`X8>`X8>`X8>`X8>`X8>aWh:`WX6`WX6_WH2_WH2`WX6`WX6aWh:`WX6`
WX6`WX6`WX6`WX6`WX6`WX6`WX6^W7n^W7n_WH2`WX6`WX6_WH2^W7n^W7nZW7nZW7n/WGf/WGf^WGb`
WGb`WGZ`WGZ/W7R^WWZ_Wg^^WWZ/W7R/W7R]WGV_Wg^[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN[
VgN[VgN[VgN[VgN[VgN[VgN[VgN/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF[VGB[VGB[VGB[VGB[VGB[
VGB[VGB[VGBZVWFZVWFYVGBXV7>XV7>YVGBZVWFZVWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWFZV7>Z
V7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>XV7>XV7>XV7>YVGBYVGBYVGBZVWFZVWFXV7>XV7>XV7>XV7>XV7>X
V7>XV7>XV7>ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:[VW>[VW>[VW>[VW>[VW>[VW>[VW>[VW>ZVG:Z
VG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:[VW>/VgB/VgB/VgB/VgB[VW>ZVG:[VW>[VW>[VW>[VW>[VW>[
VW>[VW>[VW>ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:Z
VG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:Z
VG:ZVG:ZVG:YV76YV76YV76YV76YV76YV76YV76YV76YUfjYUfjYUfjZV6nZV6n[VG2[VG2[VG2ZV6nZ
V6nZV6nZV6nZV6nZV6nZV6nZV6nYUfjZV6nZV6n[VG2[VG2ZV6nZV6nYUfjXUVfXUVfYUfjZV6nZV6nY
UfjXUVfXUVfYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfWUFbW
UFbWUFbWUFbXUVfXUVfYUfjYUfjXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfX
UVfXUVfXUVfYUfjXUVfWUFbWUFbWUFbWUFbXUVfYUfjWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFb[UVV[
UVV[UVV[UVV[UVV[UVV[UVV[UVVZUFRZUFR[UVV[UVV/UfZ]V6^]V6^^VFbZUFRZUFRZUFRZUFR[UVV[
UVV[UVV/UfZ[UVV[UVV[UVV[UVV[UVV/UfZ/UfZ/UfZZUFRZUFRZUFRZUFR[UVV[UVV[UVV/UfZ[UfR[
UfR[UfR[UfR/V6V/V6V]VFZ]VFZXV6ZXV6ZXV6ZXV6ZXV6ZXV6ZXV6ZXV6Z/UfZ/UfZ/UfZ/UfZ/UfZ/
UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZ/UfZZUFRZUFR/UfZ/UfZ]V6^]V6^/UfZ/UfZ[VVV/
V6R[UfNYUfRVUVbQUG>MUGRIU7^AU7ZBUG^DUgjFUh>HV8JIVHVIV8ZIUhbIV8ZKVXbMW8jMW8jLVhfL
VhfNWHnPWi6NX9BNX9BNX9BNX9BOXIFPXYJRY9RRY9RYYibZZ9f[ZIj/ZYn^[:6_[J:_[J:`[Z>c/j>_
[in^[Ind/jG2`;G@c/CIelgMfm7SgMKXg=KYf<oF_[:YSgn;KEbEN6>bUWkNaK_UclCZeloWf<oNdl_I
dL[KeLkOfmJe/jRe/jRc/JJa[jB^[:6]Zj2_[J:a[jB`/JNb/jVd]J^f]jfh^Jnh^Jng^:jf]jfg^:jg
^:jh^Jni^[2j^k6j^k6k_;:k_;:f_:Vi_Znj_[:i^[6k^K6o_k?0`;2o_J^d/IF[Y8>YVW>_VfbfW6fb
VVb^V6j[V7:_VVf_VVf_VVf_VVf_VVf_VVf_VVf_VVf`VF^`VF^`VF^`VF^`VF^`VF^`VF^`VF^aVVba
VVbaVVbaVVbaVVbaVVbaVVbaVVb`VF^aVVbaVVbbVffbVffaVVbaVVb`VF^aVVfaVVfaVVfaVVfaVVfa
VVd00;BUT[>TTK:ST;:ST;:ST;:ST;>TTKBUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[BUT[>TTK>TTK>T
TK>TTK>TTK>TTK>TTK>TTK6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk2QS[2QS[2QS[2QS[2QS[2QS[2Q
S[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QSZnPSJnPSJnP
SJnPSJnPSJnPSJnPSJnPSK2QS[2QS[2QS[2QS[2QS[2QS[2QS[2QS[2RS;2RS:nQRjjPRZjPRZnQRk2R
S;2RS:nPSJnPSJnPSJnPSJnPSJnPSJnPSJnPSJnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnPSJnPSJnQ
RjnQRjnQRZnQRZnRR:nRR;2SRK2SRK2SRK2SRK2SRK2SRK2SRK2SRK>RR;>RR;>RR;>RR;>RR;>RR;>R
R;>RR;:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQjjQQjjQQjjQQjnRR:nRR;2SRK2SRK6TR[:QQk:QQk:Q
Qk:QQk:QQk:QQk:QQk:QQjjQQjjQQjjQQjjQQjjQQjjQQjjQQjjQQjfPQZfPQZfPQZfPQZfPQZfPQZfP
QZfPQ[2OQK6PQ[6PQ[:QQk:QQk6PQ[6PQ[2OQJjQQjjQQjjQQjjQQjjQQjjQQjjQQjjQQk6PQK6PQK6P
QK6PQK6PQK6PQK6PQK6PQJjMPZnNPk2OQ;6PQK6PQK2OQ:nNPjjMP[>QQ;>QQ;>QQ;>QQ;>QQ;>QQ;>Q
Q;>QQ;:PPk:PPk:PPk:PPk:PPk:PPk:PPk:PPk6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OP[6OP[6O
P[6OP[6OP[6OP[6OP[6OP[2NPK2NPK2NPK2NPK2NPK2NPK2NPK2NPK2PPk2PPk2PPk2PPk2PPk2PPk2P
Pk2PPk6OP[2NPJnMP:nMP:nMP:nMP;2NPK6OP[2NPK2NPK2NPK2NPK2NPK2NPK2NPK2NPJfKOZjLOjnM
P:nMP:nMP:nMP:jLOjfKOZVKOZVKOZ^LO:^LO:fLNjnLNjnLNJnLNJbLN:jNNZnONjjNNZbLN:bLN:fM
NJnONj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMjbJMJbJMJbJ
MJbJMJbJMJbJMJbJMJbJMJ^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:ZJMJVIM:RHLjRHLjRHLjRHLjVI
M:ZJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjRHLjRHLjRH
LjVIM:VIM:VIM:ZJMJZJMJRHLjRHLjRHLjRHLjRHLjRHLjRHLjRHLjZILZZILZZILZZILZZILZZILZZI
LZZILZ^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLjZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZ^J
LjbKM:bKM:^JLjZILZZILZ^JLj^JLj^JLj^JLj^JLj^JLj^JLj^JLjZILZZILZZILZZILZZILZZILZZI
LZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZI
LZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZZILZVHLJVHLJVHLJVHLJVHLJVHLJVH
LJVHLJVGKZVGKZVGKZVGKZZHKjZHKjZHKj^IL:ZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjRFKJVGKZZH
Kj^IL:^IL:ZHKjVGKZRFKJNEK:RFKJVGKZVGKZVGKZVGKZRFKJNEK:RFKJRFKJRFKJRFKJRFKJRFKJRF
KJRFKJNEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:JDJjJDJjNEK:NEK:RFKJRFKJRFKJRFKJNEK:NEK:NE
K:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:RFKJRFKJNEK:JDJjJDJjNEK:RF
KJRFKJJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:VDIjVDIjZE
J:^FJJbGJZfHJjfHJjjIK:VDIjVDIjVDIjZEJ:^FJJ^FJJ^FJJbGJZbGJZbGJZbGJZ^FJJ^FJJ^FJJ^F
JJ^FJJVDIjVDIjZEJ:ZEJ:ZEJ:^FJJ^FJJ^FJJZFIjZFIj^GJ:^GJ:bHJJbHJJbHJJbHJJNGJJNGJJNG
JJNGJJNGJJNGJJNGJJNGJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJbGJZbGJZbGJZbGJZbGJZbGJZbG
JZbGJZVDIjZEJ:^FJJbGJZfHJjbGJZbGJZ^FJJFHJZNGJ:^HIJfHIJbHJ:VGKZFGLj:GMi6EN9:FNIBG
OIJHPYRHQYVIRIVHRYVGS9RGRIVHRY^JS9^JS9^JS9bKSInNT:6PTYbNTYfOTijPU9nQUInQUInQUInQ
UInQUJ>QUZJTVJVWW:bZWjj/XJn]XZj/XJj/XK>cXjn_Wjn^X;^j[<k<`M_IcmgKdM[Hc]kBa/RgZ[2F
QYAcH758<E0X2e8[2fQ287mLB:N6LmJiZ_3Hc>cKd]gCc=?>bmCAcKZh[KNeZ[>aY[6_Y;6_Y;:`YK6_
Y;2^Xjn`Y[6bZ;BeZkNh[[Ri[kRi[kNh[[Jg[KNh[[Nh[[Ri[kVj/;Zk/KZk/K^l/[^l/[>lZ;[0[kjo
]KZk/[Zh/;fl/[jn/[Zm[KblY;:/SjfNMk6JK;FLJ[:KJjnIL:^IM:nJKJnJKJnJKJnJKJnJKJnJKJnJ
KJnJKK2IJk2IJk2IJk2IJk2IJk2IJk2IJk2IJk6JK;6JK;6JK;6JK;6JK;6JK;6JK;6JK;2IJk2IJk6J
K;:KKK:KKK6JK;2IJk2IJk6JKK6JKK6JKK6JKK6JKK6JK@00/jBA/jBA/Z>@/J:?/J:?/Z>@/jBA/jBA
]:FB]:FB]:FB]:FB]:FB]:FB]:FB]:FB/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/Z>@/J:?/J:?/J:?/J:?
/J:?/J:?/J:?/J:?/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>
/:6>/:6>/:6>/:6>/:6>/:6>/:6>/:6>[j2=[j2=[j2=[j2=[j2=[j2=[j2=[j2=/:6>/:6>/:6>/:6>
/:6>/:6>/:6>/:6>/::<[j6;[j6;[Z2:[Z2:[j6;[j6;/::<[j2=[j2=[j2=[j2=[j2=[j2=[j2=[j2=
[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j2=[j2=[j6;[j6;[j6:[j6:[j:8[j:8/:>9/:>9/:>9/:>9
/:>9/:>9/:>9/:>9/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/Z67/Z67/Z67/Z67/Z67/Z67/Z67/Z67
[J26[Z67[Z67[j:8[j:8/:>9/JB:/JB:/Z67/Z67/Z67/Z67/Z67/Z67/Z67/Z67[Z67[Z67[Z67[Z67
[Z67[Z67[Z67[Z67[J26[J26[J26[J26[J26[J26[J26[J26/9n5/9n5/J26/Z67/Z67/J26/9n5/9n5
[Z67[Z67[Z67[Z67[Z67[Z67[Z67[Z67/J25/J25/J25/J25/J25/J25/J25/J25[Yf2[ij3/9n4/J25
/J25/9n4[ij3[Yf2/j64/j64/j64/j64/j64/j64/j64/j64/Z23/Z23/Z23/Z23/Z23/Z23/Z23/Z23
/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2/In2[if0[if0[if0[if0
[if0[if0[if0[if0/:23/:23/:23/:23/:23/:23/:23/:23/9j1/9j1[if0[Yao[Yao[if0/9j1/9j1
[if0[if0[if0[if0[if0[if0[if0[if0[I]n[Yao[if0[if0[if0[if0[Yao[I]nZI]nZI]nZialZial
[Iak[iak[iai[iai[9ah[Yij[imk[Yij[9ah[9ah[Iei[imkZi]gZi]gZi]gZi]gZi]gZi]gZi]gZi]g
Zi]gZi]gZi]gZi]gZi]gZi]gZi]gZi]g[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9YeZiUdZiUdZiUdZiUd
ZiUdZiUdZiUdZiUdZYYeZIUdZ9QcZ9QcZ9QcZ9QcZIUdZYYe[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye
ZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZ9QcZ9QcZ9QcZIUdZIUdZIUdZYYeZYYeZ9QcZ9QcZ9QcZ9Qc
Z9QcZ9QcZ9QcZ9QcZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZiYcZiYcZiYcZiYcZiYcZiYcZiYcZiYc
ZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZiYc[9]d[9]dZiYcZYUbZYUbZiYcZiYcZiYcZiYc
ZiYcZiYcZiYcZiYcZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUb
ZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUbZYUb
ZYUbZYUbZYUbZYUbZ9M`Z9M`Z9M`Z9M`Z9M`Z9M`Z9M`Z9M`Z9I]ZIM^ZIM^ZIM^ZYQ_ZYQ_ZYQ_ZYQ_
ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^Z9I]ZIM^ZYQ_ZiU`ZiU`ZYQ_ZIM^Z9I]YiE/Z9I]ZIM^ZIM^
ZIM^ZIM^Z9I]YiE/Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/
YYA[YYA[YiE/YiE/YiE/Z9I]Z9I]Z9I]YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/
YiE/YiE/YiE/YiE/Z9I]Z9I]YiE/YYA[YYA[YiE/Z9I]Z9I]YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[
ZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZ9=VZIAWZYEXZiIY[9MZ[IQ[[IQ[[YU/Z9=VZIAWZIAWZYEX
ZYEXZiIYZiIY[9MZ[IQ[[IQ[[9MZ[9MZZiIYZYEXZYEXZYEXZIAWZIAWZIAWZYEXZYEXZiIYZiIYZiIY
ZYIWZYIWZiMXZiMXZiMX[9QY[9QY[9QYYiMYYiMYYiMYYiMYYiMYYiMYYiMYYiMYZiIYZiIYZiIYZiIY
ZiIYZiIYZiIYZiIY[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZ[9MZZIAWZYEXZiIY[9MZ[9MZ[9MZ[9MZZiIY
X9M[Y9QXZIQU[YQT[iQV[YY[ZiQbZIUeTIIgTYIiU9MmUYR2V9V5VIV9VIR:VIN<UYF7V9N9VYV;VYV;
ViZ<W9^=X9nAXj:DVifAW9jBWZ2DX::FX::FWj6EWZ2DWInCX9jCXj6FZ:JK[:ZO[jfR[jfR[ZbQ[:ZO
/k>S[jnO/[6S`L2be]C9hMoEg=[@dm77[9b;OFMEESLRE2/BFbd>FBT5FB/2Gc@9Eb`AF2lHJ4DaT7IV
`[2UhmOAiN3Mg=[I_kfb^[R]];:W/k6V]K>X]K>X/k6V/:jS[ZnU/;6W];F[]kR^^;V_^;V_]kR^][N]
]kR^]kR^^;V_^KZ`^[^a^[^a^kbb^kbb/kbX^l6`_l2f_;Zb^[Nb_;Zb^kfa]kb]`<:^]K6E[Z9j/Ya/
]IaZ/Y][[iU`[9Ye[iY][iY][iY][iY][iY][iY][iY][iY][iQZ[iQZ[iQZ[iQZ[iQZ[iQZ[iQZ[iQZ
/Y]]/Y]]/Y]]/Y]]/Y]]/Y]]/Y]]/Y]]/9U[/9U[/IY//Y]]/Y]]/IY//9U[/9U[/IY]/IY]/IY]/IY]
/IY]/IY]002gY8ngY8ngY8ngY8ngY8ngY8ngY8ngY8ncYHncYHncYHncYHncYHncYHncYHncYHnaXXna
XXnaXXnaXXnaXXnaXXnaXXnaXXnaXhfaXhfaXhfaXhfaXhfaXhfaXhfaXhf`XXb`XXb`XXb`XXb`XXb`
XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb_XH^_
XH^_XH^_XH^_XH^_XH^_XH^_XH^`XXb`XXb`XXb`XXb`XXb`XXb`XXb`XXb^X8Z_XH^`XXb`XXb`XXb`
XXb_XH^^X8Z_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^cXXRc
XXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRcXXRbXHNbXHNbXHNbXHNbXHNb
XHNbXHNbXHN^XXJ^XXJ^XXJ^XXJ^XXJ^XXJ^XXJ^XXJbXHJbXHJbXHJbXHJbXHJbXHJbXHJbXHJdXhRd
XhRcXXNbXHJbXHJaX8FaX8F`WhBaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8Fa
X8FaX8FaX8F`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB_WX>_WX>_WX>`WhB`WhB`WhBaX8FaX8F`WhB`
WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhBdXXFcXHBcXHBbX8>bX8>a
Wh:`WX6`WX6bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86bX86aWh2`WWn`WWn_WGj_WGjaWh2a
Wh2aWh2aWh2aWh2aWh2aWh2aWh2`WWn`WWn`WWn`WWn`WWn`WWn`WWn`WWn_WGj_WGj_WGj_WGj`WWn`
WWn`WWnaWh2`WWn`WWn`WWn`WWn`WWn`WWn`WWn`WWn`WWn_WGj_WGj_WGj^W7f^W7f^W7f]Vgb]Vgb]
Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN^W7N^W7N^W7N^W7N^W7N^
W7N^W7N^W7N]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/
VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWFZV7>ZV7>ZV7>ZV7>ZV7>Z
V7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>[VGB[VGB[VGB/VWF/VWFZV7>Z
V7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:WUVnXUg2XUg2XUg2YV76Y
V76YV76ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:ZVG:YV76YV76YV76YV76YV76YV76YV76YV76[V7:[
V7:[V7:[V7:[V7:[V7:[V7:[V7:[VW>[VW>[VW>ZVG:YV76YV76XUg2XUg2ZVG:ZVG:ZVG:ZVG:ZVG:Z
VG:ZVG:ZVG:ZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6n[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:[V7:[
V7:[V7:[V7:[V7:[V7:[V7:[V7:ZV6nYUfjXUVfXUVfXUVfYUfj[VG2/VW6XUVfXUVfXUVfXUVfXUVfX
UVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nXUVfX
UVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfZV6nZV6nYUfjYUfjXUVfX
UVfWUFbWUFb[UVV[UVV[UVV[UVV[UVV[UVV[UVV[UVVWUfVWUfVWUfVWUfVWUfVWUfVWUfVWUfVZUFRZ
UFRZUFRZUFRZUFRZUFRZUFRZUFRYU6NYU6NZUFRZUFRZUFR[UVV[UVV[UVVVU6^VU6^VU6^VU6^VU6^V
U6^VU6^VU6^VUVRVUVRVUVRVUVRVUVRVUVRVUVRVUVRYU6NYU6NZUFRZUFRZUFR[UVV[UVV[UVVZUFRZ
UFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRYUFJYUFJZUVNZUVNZUVN[
UfR[UfR[UfRYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJ/V6V/V6V[UfR[UfRZUVNYUFJYUFJYUFJZUVNZ
UVNZUVNZUVNZUVNZUVNZUVNZUVN[UVV[UVV[UVV[UVV[UVV[UVV[UVV[UVVZUFRZUFR[UVV[UVV/UfZ/
UfZ/UfZ/UfZ[UVV[UVV[UVV[UVV[UVV[UVV[UVV[UVVZUVNZUVNZUVNZUVNZUVNZUVNZUVNZUVNQUVZP
UfbNUW6KV7VFVGnDVhJBW8^BWHfIV8>IV8BGUhFGV8RHV8bHVHnGVY6HVYBLVXnMVi2OWI:PWY>RX9FR
X9FRX9FRX9FNWHnQX9:TXiFWYYRXYiVZZI^][9j`[j6[/IR]/:2][jW2_l7Pem[Nc/oYe/nPR7a/?QEZ
?A`g;a8bDCI[IeF=C4B;Ed]`OFM/DEA>C3Xm<11O9PbIGToDaKcDf/oVgM?Lf/o3`KJ`[Z>a[jBe/jRa
[jB_[J:c/JJ^/:B^/:B`/ZJb]:Rc]JVe]j^g^Jfg^Jfg^:jg^:jg^:jh^Jnh^Jni^[2i^[2i^[2i^[2i
^[2i^[2i^[2i^[2i^[2i^[2i^[2g]:no^Jjl/9R/W7RTTFJZUVJ]W6^YVVV_Vfb_Vfb_Vfb_Vfb_Vfb_
Vfb_Vfb_Vfb_V6Z_V6Z_V6Z_V6Z`VF^`VF^`VF^aVVb_V6Z_V6Z`VF^aVVbaVVb`VF^_V6Z_V6Z`VF^`
VF^`VF^`VF^`VF^`VF^`VF^`VF^_V6Z_V6Z_V6Z_V6Z`VF^`VF/00;JSS[JSS[JSS[JSS[JSS[JSS[JS
S[JSS[:TS[:TS[:TS[:TS[:TS[:TS[:TS[:TS[6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk6SSK6SSK6S
SK6SSK6SSK6SSK6SSK6SSK2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2R
S;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS:nQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRk2RS;2RS;2R
S;2RS;2RS;2RS;2RS;2RS:jPRZnQRk2RS;2RS;2RS;2RS:nQRjjPRZnQRjnQRjnQRjnQRjnQRjnQRjnQ
RjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRk>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>RR;>R
R;>RR;>RR;>RR;>RR;>RR;:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQjjRQZjRQZjRQZjRQZjRQZjRQZjR
QZjRQ[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[:QQ[>RQk>RQk>RQk:QQ[:QQ[6PQK6PQK2OQ;6PQK6PQK6P
QK6PQK6PQK6PQK6PQK6PQK6PQK6PQK6PQK6PQK6PQK6PQK6PQK6PQK2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2O
Q;2OQ:nNPjnNPjnNPjnNPk2OQ;2OQ;6PQK6PQK2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2O
Q;2OQ;2OQ;2OQ;2OQ;2OQ;>QQ;>QQ;:PPk:PPk6OP[6OP[2NPK2NPK:PPK:PPK:PPK:PPK:PPK:PPK:P
PK:PPK:PPK:PPK6OP;6OP;2NOk2NOjnMOZnMO[2NOk2NOk2NOk2NOk2NOk2NOk2NOk2NOjnMOZnMOZnM
OZnMOZnMOZnMOZnMOZnMOZjLOJnMOZnMOZnMO[2NOk2NOk2NOk2NOjjLOJjLOJjLOJjLOJjLOJjLOJjL
OJjLOJnMOZnMOZnMOZjLOJjLOJjLOJfKO:fKO:fKO:fKO:fKO:fKO:fKO:fKO:fKO:fKO:^KMj^KMj^K
Mj^KMj^KMj^KMj^KMj^KMjjLMjjLMjjLMjjLMjjLMjjLMjjLMjjLMjfKMZfKMZfKMZfKMZfKMZfKMZfK
MZfKMZbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJ
MJbJMJbJMJbJMJbJMJbJMJZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZH
LjZHLjZHLjZHLjZHLjZHLj^IM:^IM:bJMJbJMJZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZILZZILZZI
LZZILZZILZZILZZILZZILZNFKjRGL:RGL:RGL:VHLJVHLJVHLJZILZZILZZILZZILZZILZZILZZILZZI
LZZILZVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^JLj^JLjZI
LZZILZVHLJVHLJRGL:RGL:ZILZZILZZILZZILZZILZZILZZILZZILZZHKjZHKjZHKjZHKjZHKjZHKjZH
KjZHKj^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZ^HLZZHKjVGKZRF
KJRFKJRFKJVGKZ^IL:bJLJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRF
KJRFKJVGKZVGKZVGKZVGKZVGKZVGKZVGKZVGKZRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJRF
KJRFKJRFKJRFKJRFKJRFKJZHKjVGKZVGKZVGKZRFKJNEK:NEK:NEK:^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^F
JJ^FJJNGJJNGJJNGJJNGJJNGJJNGJJNGJJNGJJZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:VDIjVDIjVD
IjZEJ:ZEJ:^FJJ^FJJ^FJJJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJFJ:JFJ:JFJ:JFJ:JFJ:JFJ:JF
J:JFJ:VDIjVDIjVDIjZEJ:ZEJ:^FJJ^FJJ^FJJZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZE
J:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:VEIZVEIZVEIZZFIjZFIj^GJ:^GJ:^GJ:VEIZVEIZVEIZVEIZVEIZVEIZVE
IZVEIZ^GJ:^GJ:^GJ:ZFIjZFIjVEIZVEIZVEIZZFIjZFIjZFIjZFIjZFIjZFIjZFIjZFIj^FJJ^FJJ^F
JJ^FJJ^FJJ^FJJ^FJJ^FJJZEJ:ZEJ:^FJJ^FJJ^FJJbGJZbGJZbGJZ^FJJ^FJJ^FJJ^FJJ^FJJ^FJJ^F
JJ^FJJZFIjZFIjZFIjZFIjZFIjZFIjZFIjZFIjBDJJ>EJinFL9jGMYbIOIRJQ9NKR9FKRYRIQIRHQYRH
QYRIRIVIRiZJSY^JT9bKTIbJSifKT9nMTZ2NTj:PUJ:PUJ:PUJ:PUInNT:6PTZBSUJFTUZJUUjVXVZb[
WK2_XJR^UJb_Wk2aZ<O2`nGLgm[=blfj/fUCAeX`4ddh8W1kJk?4^L2ZYKn1PL2CSi:BQZRKXhNERVMY
DeX_76<^8JZJS/_<`^[Ne=WGc<?1][:`YKBbYkRfZkBbYk6_Y;BbYjj`Y:j`Y;2bY[6cYk>eZKFgZkJh
[;Ni[KNh[[Nh[[Nh[[Ri[kRi[kVj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Zg/[ni[[jc
WK>TPjVGKZREJ:VIJZ^KK:nKK:nKK:nKK:nKK:nKK:nKK:nKK:nKK:jGJJnHJZnHJZnHJ[2IJk2IJk2I
Jk2IJjjGJJnHJ[2IJk2IJk2IJk2IJjnHJZjGJJnHJZnHJZnHJZnHJZnHJZnHJZnHJZnHJZjGJJnHJZnH
JZnHJ[2IJk2IJ`00]Z>>]Z>>]Z>>]Z>>]Z>>]Z>>]Z>>]Z>>/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>/ZB>
/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J>=/J>=/J>=/J>=/J>=/J>=/J>=/J>=/::</::</::</::<
/::</::</::</::</::</::</::</::</::</::</::</::</::</::</::</::</::</::</::</::<
[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;/::</::</::</::</::</::</::</::<[Z2:[j6;/::</::<
/::</::<[j6;[Z2:[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;[j6;
/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/j:8/Z67/Z67/Z67/Z67
/Z67/Z67/Z67/Z67[Z:6[Z:6[Z:6[Z:6[Z:6[Z:6[Z:6[Z:6/Z66/Z66/Z66/Z66/Z66/Z66/Z66/Z66
/j:7/Z66/Z66/Z66/J25/J25/J25/J25/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4
/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4[Yf2[Yf2[ij3[ij3/9n4/9n4/9n4/9n4
[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3/Z23/Z23/Z23/Z23
/In2/In2/In2/9j1/In0/In0/In0/In0/In0/In0/In0/In0/In0/In0/In0/9io/9io/9io[ien[ien
/9io/9io/9io/9io/9io/9io/9io/9io[ien[ien[ien[ien[ien[ien[ien[ien[Yam[Yam[Yam[ien
[ien/9io/9io/9io[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l[ien[ien[ien[Yam[Yam[I]l[I]l[I]l
[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]lZi]gZi]gZi]gZi]gZi]gZi]gZi]gZi]g[Yag[Yag[Yag[Yag
[Yag[Yag[Yag[Yag[I]f[I]f[I]f[I]f[I]f[I]f[I]f[I]fZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUd
ZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUdZYQcZYQcZYQcZYQc
ZYQcZYQcZYQcZYQcZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZYQcZYQcZiUdZiUdZiUdZiUd
ZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaYiI_Z9M`Z9M`Z9M`
ZIQaZIQaZIQaZYUbZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQa
ZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYUbZYUbZYUbZIQaZIQaZIQaZ9M`Z9M`ZIQaZIQaZIQaZIQa
ZIQaZIQaZIQaZIQaZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYQ_ZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMa
ZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaZIM^ZIM^Z9I]Z9I]Z9I]ZIM^ZYQ_ZiU`Z9I]Z9I]Z9I]Z9I]
Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^ZIM^
Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]ZIM^ZIM^Z9I]Z9I]
Z9I]YiE/YiE/YiE/ZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIYYiMYYiMYYiMYYiMYYiMYYiMYYiMYYiMY
ZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZIAWZIAWZIAWZIAWZYEXZYEXZiIYZiIYYYA[YYA[YYA[YYA[
YYA[YYA[YYA[YYA[YYIXYYIXYYIXYYIXYYIXYYIXYYIXYYIXZIAWZIAWZIAWZIAWZYEXZYEXZiIYZiIY
ZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZIEVZIEVZIEVZIEV
ZYIWZYIWZiMXZiMXZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEVZiMXZYIWZYIWZYIWZIEVZIEVZIEVZIEV
ZYIWZYIWZYIWZYIWZYIWZYIWZYIWZYIWZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIYZYEXZYEXZYEXZiIY
ZiIYZiIY[9MZ[9MZZiIYZiIYZiIYZiIYZiIYZiIYZiIYZiIYZYIWZYIWZYIWZYIWZYIWZYIWZYIWZYIW
YiAWYYEZYII_XYIdWiMiWIQoW9V4VYV5UYV9V9V9VIZ:VYZ:Vi^;WIZ;WY^=WY^=ViV>WI^@WYbAX9jC
XInDXZ2EXZ2EXZ2EX9nAXJ2BXj:DXj:DY:>EYjJHZjZL[jjPZjjH[k2P[ZnU`Kflh][Jel_7]jJM?2TL
AB/MOIZAP[NjPXnMY7j:_8bB]9VLTHJ9U:6aSKJiSZZTOVMOEbTQUhIi`Kj`flJnd<k3_kfb/k6V]K>X
^;J[];:W/:jS/[2U[[2T[[2T/;:V/K>W/kFY];JZ]KN[][R/]kR^]kR^]kR^^;V_^;V_^KZ`^KZ`^KZ`
^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`_KZe_[Z_`;JT_;2D/J5mYIE[YYEZ[Ie_[YY[[YY[[YY[[YY[
[YY[[YY[[YY[[YY[[YMY[YMY[YMY[iQZ[iQZ/9U[/9U[/9U[[YMY[iQZ[iQZ/9U[/9U[[iQZ[iQZ[YMY
[iQZ[iQZ[iQZ[iQZ[iQZ[iQZ[iQZ[iQZ[YMY[YMY[YMY[iQZ[iQZ/9U[002fXhjfXhjfXhjfXhjfXhjf
XhjfXhjfXhjbY8jbY8jbY8jbY8jbY8jbY8jbY8jbY8jaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXhfa
XhfaXhfaXhfaXhfaXhfaXhfaXhf_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_
XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z_XH^_
XH^_XH^_XH^_XH^_XH^_XH^_XH^^X8Z_XH^`XXb`XXb`XXb`XXb_XH^^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^
X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8ZbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHNbXHNb
XHNbXHNbXHNbXHNbXHNbXHNbXHNaX8JaX8JaX8JaX8JaX8JaX8JaX8JaX8J]XHF]XHF]XHF]XHF]XHF]
XHF]XHF]XHFaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8FaX8F`WhB`
WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB`
WhB`WhB`WhB^WH:^WH:^WH:_WX>_WX>_WX>`WhB`WhB_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_
WX>_WX>_WX>_WX>_WX>_WX>_WX>aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh:aWh2aWh2aWh2aWh2aWh2a
Wh2aWh2aWh2`WWn`WWn`WWn`WWn`WWn`WWn_WGj_WGj_WGj_WGj_WGj_WGj_WGj_WGj_WGj_WGj_WGj_
WGj_WGj_WGj_WGj_WGj_WGj_WGj^W7f^W7f^W7f^W7f_WGj_WGj`WWn`WWn]Vgb]Vgb]Vgb]Vgb]Vgb]
Vgb]Vgb]Vgb_WGj^W7f^W7f^W7f]Vgb]Vgb]Vgb/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^[VgN[
VgN[VgN[VgN[VgN[VgN[VgN[VgN]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ]VgJ/VWF/VWF/VWF/VWF/VWF/
VWF/VWF/VWF[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGB[
VGB[VGB[VGB[VGB[VGB[VGB[VGBZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>YUg:YUg:YUg:YUg:YUg:Y
Ug:YUg:YUg:YUg:YUg:YUg:ZV7>ZV7>ZV7>[VGB[VGBYUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:YV76Y
V76YV76YV76YV76YV76YV76YV76WUVnXUg2XUg2XUg2YV76YV76YV76ZVG:YV76YV76YV76YV76YV76Y
V76YV76YV76YV76YV76YV76YV76YV76YV76YV76YV76ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6YV76Y
V76YV76YV76YV76YV76XUg2XUg2YV76YV76YV76YV76YV76YV76YV76YV76ZV6nZV6nZV6nZV6nZV6nZ
V6nZV6nZV6nZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6ZUg6XUVfX
UVfXUVfXUVfXUVfYUfjZV6nZV6nXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfX
UVfXUVfXUVfYUfjYUfjYUfjYUfjYUfjYUfjYUfjYUfjXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfX
UVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfWUFbWUFbWUFbWUFbZUFRZUFRZUFRZUFRZUFRZ
UFRZUFRZUFRVUVRVUVRVUVRVUVRVUVRVUVRVUVRVUVRYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NXTfJX
TfJYU6NYU6NYU6NZUFRZUFRZUFRUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUUFNUUFNUUFNUUFNUUFNU
UFNUUFNUUFNXTfJXTfJYU6NYU6NYU6NZUFRZUFRZUFRYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NY
U6NYU6NYU6NYU6NYU6NYU6NYU6NXU6FXU6FYUFJYUFJYUFJZUVNZUVNZUVNYUFJYUFJYUFJYUFJYUFJY
UFJYUFJYUFJZUVNZUVNYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJZUFRZ
UFRZUFRZUFRZUFRZUFRZUFRZUFRYU6NYU6NZUFRZUFR[UVV[UVV[UVV[UVVZUFRZUFRZUFRZUFRZUFRZ
UFRZUFRZUFRZUVNZUVNZUVNZUVNZUVNZUVNZUVNZUVN/U6J/UFRYUFbWUG2UUWFQUgVPUgbOV7nFVHVG
VXZIVXZKVh^NW8ZPW8ZPW8ZQVXVKVHjLVXnNW96OWI:QWiBQWiBQWiBQWiBPWi6QX9:RXI>RXI>RXI>T
XiFYZ9Z][9ja/ife]J>/[:2b[j[CcLS@a[ngZ9lm:b1CFUM]`lUHa=ajV[feUJjKPh]oNh2AR9F0XkM_
]<=m^/B3Q8Q69R2@OVg8`:oXc/O3`KJh]Z^a[jBd/ZNf]:Vb/:F^[:6^[:6^/:B_/JF`/ZJa/jNb]:Rc
]JVd]ZZe]j^g^:jg^:jg^:jh^Jnh^Jni^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2n_;Bk
^Jo1^ZW3^::gZHbVUW:STV^/VW6^VV^^VV^^VV^^VV^^VV^^VV^^VV^^VV^^UfV^UfV^UfV^UfV_V6Z_
V6Z`VF^`VF^^UfV^UfV_V6Z`VF^`VF^_V6Z^UfV^UfV_V6Z_V6Z_V6Z_V6Z_V6Z_V6Z_V6Z_V6Z^UfV^
UfV^UfV^UfV_V6Z_V6X00;FRSKFRSKFRSKFRSKFRSKFRSKFRSKFRSK6SSK6SSK6SSK6SSK6SSK6SSK6S
SK6SSK6RSk6RSk6RSk6RSk6RSk6RSk6RSk6RSk2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS:nQRjnQRjnQ
RjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQ
RjnQRjjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjjPRZnQRk2R
S;2RS;2RS;2RS:nQRjjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjP
RZjPR[:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQk:QQk6PQ[6PQ[6P
Q[6PQ[6PQ[6PQ[6PQ[6PQZfQQJfQQJfQQJfQQJfQQJfQQJfQQJfQQK6PQK6PQK6PQK6PQK6PQK6PQK6P
QK6PQK2OQ;2OQ;2OQ;6PQK6PQK6PQK6PQK6PQK2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2O
Q;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ:fLPJfLPJjMPZjMPZnNPjnNPjnN
PjnNPjjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMP[2NPK2NPK2N
PK2NPK2NPK6OP[6OP[6OP[2NOk2NOk2NOk2NOk2NOk2NOk2NOk2NOjnMOZnMOZnMOZnMOZnMOZnMO[2N
Ok2NOjjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJfKO:fKO:jL
OJjLOJjLOJnMOZnMOZnMOZjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJfKO:fKO:bJNjbJ
NjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNj^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMjfKMZfKMZfK
MZfKMZfKMZfKMZfKMZfKMZbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJ^IM:^IM:^IM:^IM:^IM:^IM:^I
M:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:ZHLjZHLjZH
LjZHLjZHLjZHLjZHLjZHLjRFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJVGLZVGLZZHLjZHLjZH
LjZHLjRFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJRGL:RGL:RGL:RGL:RGL:RGL:RGL:RGL:NFKjRGL:RG
L:RGL:VHLJVHLJVHLJZILZRGL:RGL:RGL:RGL:RGL:RGL:RGL:RGL:VHLJVHLJVHLJVHLJVHLJVHLJVH
LJVHLJVFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:RGL:RGL:RGL:RGL:RGL:RGL:VHLJVHLJRGL:RGL:RG
L:RGL:RGL:RGL:RGL:RGL:ZHKjZHKjZHKjZHKjZHKjZHKjZHKjZHKjVFL:VFL:VFL:VFL:VFL:VFL:VF
L:VFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:VFL:NEK:NEK:RFKJRFKJVGKZVGKZVGKZVGKZRFKJRFKJRF
KJRFKJRFKJRFKJRFKJRFKJNEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:RFKJRFKJRFKJRFKJRFKJRFKJRF
KJRFKJNEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NE
K:NEK:NEK:NEK:NEK:NEK:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:JFJ:JFJ:JFJ:JFJ:JFJ:JFJ:JF
J:JFJ:VDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjRCIZRCIZRCIZVDIjVDIjVDIjZEJ:ZEJ:FCJZFCJZFC
JZFCJZFCJZFCJZFCJZFCJZFEIjFEIjFEIjFEIjFEIjFEIjFEIjFEIjRCIZRCIZRCIZVDIjVDIjVDIjZE
J:ZEJ:VDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjRDIJRDIJRD
IJVEIZVEIZVEIZZFIjZFIjVEIZVEIZVEIZVEIZVEIZVEIZVEIZVEIZRDIJRDIJVEIZVEIZVEIZVEIZVE
IZVEIZVEIZVEIZVEIZVEIZVEIZVEIZVEIZVEIZZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:VDIjVDIjVD
IjZEJ:ZEJ:ZEJ:^FJJ^FJJZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZFIjZFIjZFIjZFIjZFIjZFIjZF
IjZFIjbEIJfEIjZEJ:VEK:NEL:BEM:>FMZ6FN9NHQ9RIQIZJR9fKRIjLRZ2LRYnKRInJRi^ISYbJSifK
T9nMTZ2NTj6OU:6OU:6OU9nNT:6PTZ:QTj6PTZ6PTZ:QTjJUUjVXV[2_VkFeXjb/WZZYWl;0]/Jm];fa
YeA3>SmYJ1NHYa:]e5bZeI:BZXn9RXfEUGn2T7RZ`5J`b6RneY2W]UE2>iJ8LKfcXMBl][Zh[KFcZ;:`
YKBbYkFcZ;:`YK2^Xjn]XZj`Y:naYJnaYK2bY[:dZ;>eZK>eZKBfZ[Nh[[Nh[[Nh[[Ri[kRi[kVj/;Vj
/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;bj/[Vh[[jk[L>lZkZ_VJVKOZ>CKjZGLZfIJZfIJZfI
JZfIJZfIJZfIJZfIJZfIJZfFJ:fFJ:jGJJjGJJjGJJnHJZnHJZnHJZfFJ:jGJJnHJZnHJZnHJZnHJZjG
JJfFJ:jGJJjGJJjGJJjGJJjGJJjGJJjGJJjGJJfFJ:fFJ:jGJJjGJJjGJJnHJP00]J:=]J:=]J:=]J:=
]J:=]J:=]J:=]J:=/J>=/J>=/J>=/J>=/J>=/J>=/J>=/J>=/J:?/J:?/J:?/J:?/J:?/J:?/J:?/J:?
/::</::</::</::</::</::</::</::<[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:
[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[In9[In9[In9[In9[In9[In9[In9[In9
[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[j6;/::</::</::</::<[j6;[Z2:[In9[In9[In9[In9
[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9/J26/J26/J26/J26/J26/J26/J26/J26
/J26/J26/J26/J26/J26/J26/J26/J26/9n5/9n5/9n5/9n5/9n5/9n5/9n5/9n5[:24[:24[:24[:24
[:24[:24[:24[:24/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4[ij3[ij3/9n4/9n4/9n4/J25/J25/J25
[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3/9n4/9n4/9n4/9n4
/9n4/9n4/9n4/9n4[Ib1[Ib1[Ib1[Yf2[Yf2[ij3[ij3[ij3[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2
[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[if0[if0[if0/9j1/9j1/9j1/In2/In2/9io/9io/9io/9io
/9io/9io/9io/9io[Yam[Yam[Yam[ien[ien[ien/9io/9io[I]l[I]l[I]l[I]l[I]l[I]l[I]l[I]l
[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[I]l[I]l[I]l[I]l[Yam[Yam[ien[ien[Yam[Yam[Yam[Yam
[Yam[Yam[Yam[Yam[Yam[I]l[I]l[I]l[9Yk[9Yk[9Yk[9YkZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUj
Zi]gZi]gZi]gZi]gZi]gZi]gZi]gZi]g[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9YeZiUdZiUdZiUdZiUd
ZiUdZiUdZiUdZiUdZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQc
ZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZ9IaZ9IaZ9IaZ9Ia
Z9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaZIMbZIMbZYQcZYQcZYQcZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9Ia
Z9M`Z9M`Z9M`Z9M`Z9M`Z9M`Z9M`Z9M`YiI_Z9M`Z9M`Z9M`ZIQaZIQaZIQaZYUbZ9M`Z9M`Z9M`Z9M`
Z9M`Z9M`Z9M`Z9M`ZIQaZIQaZIQaZIQaZIQaZIQaZIQaZIQaZII`ZII`ZII`ZII`ZII`ZII`ZII`ZII`
YiI_YiI_YiI_Z9M`Z9M`Z9M`ZIQaZIQaZ9M`Z9M`Z9M`Z9M`Z9M`Z9M`Z9M`Z9M`ZYQ_ZYQ_ZYQ_ZYQ_
ZYQ_ZYQ_ZYQ_ZYQ_ZII`ZII`ZII`ZII`ZII`ZII`ZII`ZII`ZII`ZII`ZII`ZII`ZII`ZII`ZII`ZII`
YYA[YYA[Z9I]ZIM^ZIM^ZIM^Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]YiE/YiE/YiE/YiE/
YiE/YiE/YiE/YiE/Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/
YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YYA[YYA[YYA[YYA[YiE/YiE/YiE/Z9I]ZIAWZIAWZIAWZIAW
ZIAWZIAWZIAWZIAWYIEWYIEWYIEWYIEWYIEWYIEWYIEWYIEWZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=V
Yi9UYi9UZ9=VZ9=VZIAWZIAWZIAWZIAWY99YY99YY99YY99YY99YY99YY99YY99YY9AVY9AVY9AVY9AV
Y9AVY9AVY9AVY9AVYi9UYi9UZ9=VZ9=VZIAWZIAWZIAWZIAWZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=V
Z9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VYi=TYi=TZ9AUZ9AUZIEVZIEVZIEVZIEVZIEVZIEVZIEVZIEV
ZIEVZIEVZIEVZIEVYi=TZ9AUZ9AUZ9AUZIEVZIEVZIEVZIEVZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AU
ZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZ9=VZIAWZIAWZIAWZYEXZYEXZYEXZYEXZIAWZIAWZIAWZIAW
ZIAWZIAWZIAWZIAWZYIWZYIWZYIWZYIWZYIWZYIWZYIWZYIW[9EUZiEUZYIWZ9EXYiE/Y9E^XYE_XiEa
ViImViMnWYZ2WYZ7WYb:WY^<ViZ<ViV>VYR=ViV>WI^@WifBX9jCX9jCX9jCX9jCWIb>X9nAXZ6CXZ6C
XJ2BXJ2BXj:DYJBFYZ:@/JnM[jnO[:bN^KRZ][2U_;:XIUM>Chb8>/?I1KOV8:3;NJ2^XIfBXIjFTibU
MJfnBK39EKoNV<7GKFAKZj24/JZF^ZNT][BY][BY][BY]kFZ]kFZ][BY]K>X]K>X[[2T[k6U[k6U/;:V
/K>W/[BX/[BX/kFY]kR^]kR^]kR^^;V_^;V_^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`^KZ`
^[R`^[R`_;^a_[ba_;FT/ZJ>ZIUlZ9Aa[IUZ[IUZ[IUZ[IUZ[IUZ[IUZ[IUZ[IUZ[IIX[IIX[IIX[IIX
[YMY[YMY[iQZ[iQZ[IIX[IIX[YMY[iQZ[iQZ[YMY[IIX[IIX[YMY[YMY[YMY[YMY[YMY[YMY[YMY[YMY
[IIX[IIX[IIX[IIX[YMY[YMY002dXHbdXHbdXHbdXHbdXHbdXHbdXHbdXHb`XXb`XXb`XXb`XXb`XXb`
XXb`XXb`XXbaXXnaXXnaXXnaXXnaXXnaXXnaXXnaXXn_XH^_XH^_XH^_XH^_XH^_XH^_XH^_XH^^X8Z^
X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^
X8Z^X8Z^X8Z]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z_
XH^`XXb`XXb`XXb`XXb_XH^^X8Z]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]
WhV]WhV]WhVaX8JaX8JaX8JaX8JaX8JaX8JaX8JaX8JaX8JaX8JaX8JaX8JaX8JaX8JaX8JaX8J`WhF`
WhF`WhF`WhF`WhF`WhF`WhF`WhF/X8B/X8B/X8B/X8B/X8B/X8B/X8B/X8B`WhB`WhB`WhB`WhB`WhB`
WhB`WhB`WhB^WH:_WX>_WX>`WhB`WhBaX8FaX8FaX8F_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_
WX>_WX>_WX>_WX>_WX>_WX>_WX>`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhB]W86]W86]W86]W86^WH:^
WH:^WH:_WX>^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^WH:^W7n^
W7n_WH2_WH2`WX6`WX6aWh:aWh:`WWn`WWn`WWn`WWn`WWn`WWn`WWn`WWn]Vgb]Vgb^W7f^W7f_WGj_
WGj`WWn`WWn/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb/VW^/
VW^]Vgb]Vgb^W7f^W7f^W7f^W7f]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb/VW^/VW^/
VW^[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VgN[VgN[VgN[VgN[VgN[VgN[VgN[VgN/VWF/
VWF/VWF/VWF/VWF/VWF/VWF/VWF[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGBZV7>ZV7>ZV7>ZV7>ZV7>Z
V7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>Z
V7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2XUW6XUW6XUW6XUW6YUg:Y
Ug:YUg:ZV7>WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUVnWUVnWUVnWUVnWUVnWUVnWUVnWUVnWUVnX
Ug2XUg2XUg2YV76YV76YV76ZVG:WUVnWUVnWUVnWUVnWUVnWUVnWUVnWUVnYV76YV76YV76YV76YV76Y
V76YV76YV76XUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnVUFjVUFjWUVnWUVnXUg2XUg2YV76YV76WUVnW
UVnWUVnWUVnWUVnWUVnWUVnWUVnZV6nZV6nZV6nZV6nZV6nZV6nZV6nZV6nXUFnXUFnXUFnXUFnXUFnX
UFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnUTfZVU6^WUFbYUfjYUfjYUfjXUVfWUFbXUVfX
UVfXUVfXUVfXUVfXUVfXUVfXUVfVU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^WUFbWUFbWUFbWUFbWUFbW
UFbWUFbWUFbVU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^UTfZU
TfZUTfZVU6^WUFbWUFbWUFbXUVfYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NUUFNUUFNUUFNUUFNUUFNU
UFNUUFNUUFNXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJWTVFWTVFWTVFXTfJXTfJYU6NYU6NYU6NTTVVT
TVVTTVVTTVVTTVVTTVVTTVVTTVVTU6JTU6JTU6JTU6JTU6JTU6JTU6JTU6JWTVFWTVFWTVFXTfJXTfJY
U6NYU6NYU6NXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJWTfBW
TfBWTfBXU6FXU6FYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJYUFJWTfBWTfBWTfBXU6FXU6FY
UFJYUFJYUFJXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NXTfJX
TfJYU6NYU6NYU6NZUFRZUFRZUFRYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NZUVNZUVNZUVNZUVNZUVNZ
UVNZUVNZUVN[UV>YUV>YUFFWUFJTUFNRUFVSUF^QUF^NU7:OUGNOV7fOVh>MVhVKVhnFVI2EUi6JV8fK
VHjLVXnNW96OWI:PWY>PWY>PWY>KVXbOWY2RXI>SXYBRXI>PWi6PWi6QX9:QVXV/Z9J/[9Z^[Ybe]JF^
Z9^o]J]jKFE5PGLm[/P0Vll<[M=c^;]WCSY58a=/LG24^/E?^m<k[m9bY[eFE4Z^ZHRh^:37^k^b/:Fe
/jRg]JZg]JZf]:Vg]JZh]Z^h]Z^_/JF_/JF_/JF`/ZJa/jNa/jNb]:Rb]:Rg^:jg^:jg^:jh^Jnh^Jni
^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^[2i^:jj^k:k^kFl^[:m^Jjn/Z2cXXNWTW>/V6V/
V6V/V6V/V6V/V6V/V6V/V6V/V6V/UFN/UFN]UVR]UVR^UfV^UfV^UfV^UfV/UFN]UVR^UfV^UfV^UfV^
UfV]UVR/UFN]UVR]UVR]UVR]UVR]UVR]UVR]UVR]UVR/UFN/UFN]UVR]UVR^UfV^UfT00;BQS;BQS;BQ
S;BQS;BQS;BQS;BQS;BQS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;2RS;6RSk6RSk6RSk6RSk6RSk6RSk6R
Sk6RSjnQRjnQRjnQRjnQRjnQRjnQRjnQRjnQRjjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjP
RZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZfORJfORJfORJfORJfORJfORJfO
RJfORJjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPRZnQRk2RS;2RS;2RS;2RS:nQRjjPRZfORJfORJfO
RJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORJfORK6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[6P
Q[6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[2OQK2OQK2OQK2OQK2OQK2OQK2OQK2OQJbPQ:bPQ:bP
Q:bPQ:bPQ:bPQ:bPQ:bPQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ;2OQ:jMPZjMPZnNPjnNPk2OQ;6PQK6P
QK6PQJnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPjnNPk2OQ;2OQ;2O
Q;2OQ;2OQ;2OQ;2OQ;2OQ:bKP:fLPJfLPJfLPJjMPZjMPZjMPZjMPZfLPJfLPJfLPJfLPJfLPJfLPJfL
PJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJjLOjjLOjjLOjnMP;2NPK2NPK6OP[6OPZnMOZnMOZnM
OZnMOZnMOZnMOZnMOZnMOZfKO:fKO:fKO:jLOJnMOZnMO[2NOk2NOjbJNjbJNjbJNjbJNjbJNjbJNjbJ
NjbJNjfKO:fKO:fKO:fKO:fKO:fKO:fKO:fKO:bJNjbJNjfKO:fKO:fKO:jLOJjLOJjLOJ^INZ^INZ^I
NZ^INZ^INZ^INZ^INZ^INZfKO:fKO:fKO:bJNjbJNj^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^I
NZ^INZ^KMj^KMj^KMj^KMj^KMj^KMj^KMj^KMjbJMJbJMJbJMJbJMJbJMJbJMJbJMJbJMJ^IM:^IM:^I
M:^IM:^IM:^IM:^IM:^IM:ZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZH
LjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjZHLjNEL:NEL:NE
L:NEL:NEL:NEL:NEL:NEL:NEL:RFLJRFLJRFLJVGLZVGLZVGLZVGLZNEL:NEL:NEL:NEL:NEL:NEL:NE
L:NEL:NFKjNFKjNFKjNFKjNFKjNFKjNFKjNFKjNFKjRGL:RGL:RGL:VHLJVHLJVHLJZILZNFKjNFKjNF
KjNFKjNFKjNFKjNFKjNFKjVHLJVHLJVHLJVHLJVHLJVHLJVHLJVHLJREKjREKjREKjREKjREKjREKjRE
KjREKjJEKZJEKZJEKZNFKjRGL:RGL:VHLJVHLJNFKjNFKjNFKjNFKjNFKjNFKjNFKjNFKjZHKjZHKjZH
KjZHKjZHKjZHKjZHKjZHKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjRE
KjREKjBBJJJDJjNEK:VGKZVGKZRFKJNEK:JDJjRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJJDJjJDJjJD
JjJDJjJDJjJDJjJDJjJDJjNEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:JDJjJDJjJDJjJDJjJDJjJDJjJD
JjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjBBJJFCJZFCJZJDJjJDJjNEK:NEK:RFKJVDIjVDIjVD
IjVDIjVDIjVDIjVDIjVDIjFEIjFEIjFEIjFEIjFEIjFEIjFEIjFEIjRCIZRCIZRCIZRCIZRCIZRCIZRC
IZRCIZNBIJNBIJNBIJRCIZRCIZRCIZVDIjVDIjBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBDIZBDIZBD
IZBDIZBDIZBDIZBDIZBDIZNBIJNBIJNBIJRCIZRCIZRCIZVDIjVDIjRCIZRCIZRCIZRCIZRCIZRCIZRC
IZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZNCI:NCI:NCI:RDIJRDIJRDIJVEIZVEIZVEIZVEIZVE
IZVEIZVEIZVEIZVEIZVEIZJBHjJBHjNCI:NCI:RDIJVEIZVEIZVEIZRDIJRDIJRDIJRDIJRDIJRDIJRD
IJRDIJVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjRCIZRCIZRCIZVDIjVDIjVDIjZEJ:ZEJ:VDIjVDIjVD
IjVDIjVDIjVDIjVDIjVDIjZFIjZFIjZFIjZFIjZFIjZFIjZFIjZFIjVFHjNFHjNFIJFFIJBFIZ:EIinD
J9nDJ:2CKJ2DL:6GNInIPYfKRIRISiBHTi2GU9ZHSI^ISYbJSijLTInMTZ2NTj2NTj2NTiZIRijMSj:Q
TjBSUJ>RU:2OTInNT9jMSj:JRJNSTJRVU:ZZV;6aWjVVV<Jm/i23Nd9dJ4FP^a2`iP6ceS:5OEd`5EhO
2d8l=FZNY4^hcSZbeW6Z`e]LD[FcT:b_UZVSY:j/XK:`YKJdZKBbYk>aY[FcZ;NeZ[RfZjnaYJnaYJna
YK2bY[2bY[6cYk6cYk6cYkNh[[Nh[[Nh[[Ri[kRi[kVj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj/;Vj
/;Vj/;Vh[[fn]K^m]kVi/kjl//FkZ[ZYSjNAMJbHJJbHJJbHJJbHJJbHJJbHJJbHJJbHJJbEIjbEIjfF
J:fFJ:fFJ:jGJJjGJJjGJJbEIjfFJ:jGJJjGJJjGJJjGJJfFJ:bEIjfFJ:fFJ:fFJ:fFJ:fFJ:fFJ:fF
J:fFJ:bEIjbEIjfFJ:fFJ:fFJ:jGJ@00]:6<]:6<]:6<]:6<]:6<]:6<]:6<]:6<[j:8[j:8[j6:[j6:
[j6;[j6;[j2=[j2=[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:/Yj</Yj</Yj</Yj</Yj</Yj</Yj</Yj<
[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[j6;[Z2:[9j8Zif7
Zif7[9j8[Z2:[j6;Zif7[9j8[In9[Z2:[Z2:[Z2:[In9[In9[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8
[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[In9[9j8[9j8[9j8[9j8
[9j8[9j8[9j8[9j8[9n5[9n5[9n5[9n5[9n5[9n5[9n5[9n5/9n4/9n4/9n4/9n4/9n4/9n4/9n4/9n4
/Z67/J26/J26/9n5/9n5[ij4[Yf3[Yf3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3
[ij3[ij3[ij3[ij3[Yf2[Yf2[Yf2[ij3[ij3[ij3/9n4/9n4[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3
[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2
[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[9ao[9ao[9ao[9ao[9ao[9ao[9ao[9ao
[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[I]l[I]l[I]l[I]l
[I]l[I]l[I]l[I]l[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk
[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9YkZIUeZYYfZYYfZi]g
Zi]g[9ah[9ah[IeiZIMhZIMhZIMhZYQiZYQiZiUjZiUjZiUj[9Uf[9Uf[9UfZiQeZYMdZYMdZIIcZIIc
[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9Ye[9YeYiYdZIUdZIUdZiUdZiUd[9Ud[9Ud[YQdZYQcZYQcZYQcZYQc
ZYQcZYQcZYQcZYQcZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQc
ZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbYiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`ZIMbZIMbZIMbZIMb
ZIMbZIMbZIMbZIMbYiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_
YiI_YiI_YiI_YiI_YiI_YiI_YiI_YiI_ZYMaZYMaZYMaZYMaZYMaZYMaZYMaZYMaYiA^Z9E_Z9E_Z9E_
ZII`ZII`ZII`ZYMaZ9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_
Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YiA^YiA^YiA^YiA^
YiA^YiA^YiA^YiA^Z9I]Z9I]Z9I]YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/
YYA[YYA[YiE/YiE/Z9I]Z9I]Z9I]Z9I]YiE/YiE/YiE/YiE/YiE/YiE/YiE/YiE/ZYEXZYEXZYEXZYEX
ZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZYEXZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAW
ZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=V
Z9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=V
Z9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VYY5TYY5TYi9UZ9=VZ9=VYi9UYY5TYY5TYi=TYi=TYi=TZ9AU
Z9AUZIEVZIEVZIEVYi=TZ9AUZ9AUZIEVZIEVZ9AUZ9AUYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=T
Yi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYY9SYY9SYY9SYi=TYi=TYi=TZ9AUZ9AUZ9AUYi=TYY9SYI5R
YI5RYi=TZ9AUZYIWZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AU
Z9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9=VZ9=VZIAWZIAWZIAWZYEXZYEXZYEXZiAVZiAVZiAVZiAV
ZiAVZiAVZiAVZiAVZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZ9AUZII[YYA[X99^W95eVI>0UYB9U9J@TiJD
WYN>W9R=W9R=ViZ<W9f=WJ6>X:F@X:NBX9jCX9jCX9jCX9jCX9jCX9jCX9jCX9jCXZ2>VIV7WIj>WIj>
[JbN`k^^[YnFVXMo?RhRLi6T>[GK<Z71CSY6RCDYF1H3FA4:HfITC[>lBKO?MGZ?G2lRXZ9j[kbRa:6[
];:W]K>X]K>X]K>X][BY][BY][BY]kFZ/kFY/K>W[[2T[:jR[:jR[JnS[k6U/;:V/K:X/[>Y]KJ/]kR^
^;V_^;V_^;V_]kR^^kV_^kV__;Z`_;Z`_;Z`_K^a_K^a_K^a]Kn_^Knd^[^i_;Nh_[Vh_kV/]K6HZJN5
Wi=_YII_Z9M/[YMY/I][]Im_/Ia_ZYM/[9EW[9EW[9EW[9EW[9EW[9EW[9EW[9EW[YMY[YMY[iQZ[iQZ
[YMY[IIX[9EWZiAV[iQZ[iQZ[YMY[YMY[IIX[9EW[9EW[9EWZiAVZiAVZiAV[9EW[9EW[IIX002dXHbd
XHbdXHbdXHbdXHbdXHbdXHbdXHb_XXR_XXR_XHZ_XHZ_XH^_XH^_X8f_X8f^X8Z^X8Z^X8Z^X8Z^X8Z^
X8Z^X8Z^X8ZbWXbbWXbbWXbbWXbbWXbbWXbbWXbbWXb]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]
WhV]WhV]WhV]WhV]WhV]WhV]WhV^X8Z]WhV/WXR[WHN[WHN/WXR]WhV^X8Z[WHN[WHN]WhV^X8Z^X8Z^
X8Z]WhV]WhV/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]WhV]
WhV]WhV]WhV]WhV]WhV]WhV]WhV/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WhF/WhF/WhF/WhF/WhF/
WhF/WhF/WhF`WhB`WhB`WhB`WhB`WhB`WhB`WhB`WhBaX8JaX8J`WhF`WhF_WXB_WXB^WH>^WH>_WX>_
WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>]W86^WH:^WH:^WH:_WX>_
WX>_WX>`WhB_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>_WX>]W86]
W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]
W86]W86]W86/W7n/W7n/W7n/W7n/W7n/W7n/W7n/W7n^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^W7f^
W7f^W7f^W7f^W7f^W7f^W7f^W7f]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb/VW^/VW^/VW^/VW^/VW^/
VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/
VW^/VW^/VW^/VW^/VW^/VW^/VW^ZVWJZVWJ[VgN[VgN[VgN[VgN[VgN/W7RYUgRYUgRYUgRZV7VZV7VZ
V7V[VGZ[VGZ/VGJ/VGJ/VGJ[V7F[V7F[V7F[V7F[V7F/VWF/VWF/VWF/VWF/VWF/VWF/VWF/VWFWVWBY
VGBYVGB[VGB[VGB/VGB/VGB^V7BZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>YUg:YUg:YUg:YUg:YUg:Y
Ug:YUg:YUg:ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>ZV7>XUW6XUW6XUW6XUW6XUW6XUW6XUW6XUW6WUG2W
UG2WUG2WUG2WUG2WUG2WUG2WUG2XUW6XUW6XUW6XUW6XUW6XUW6XUW6XUW6WUG2WUG2WUG2WUG2WUG2W
UG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUVnWUVnWUVnWUVnWUVnWUVnWUVnWUVnXUFnX
UFnXUFnXUFnXUFnXUFnXUFnXUFnWU6jWU6jXUFnXUFnXUFnYUW2YUW2YUW2XUFnXUFnXUFnXUFnXUFnX
UFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUVfXUVfXUVfXUVfXUVfXUVfXUVfXUVfVTffV
TffVTffVTffVTffVTffVTffVTffWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jXUVfWUFbWUFbWUFbWUFbW
UFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbVU6^VU6^WUFbWUFbWUFbXUVfXUVfXUVfWUFbW
UFbWUFbWUFbWUFbWUFbWUFbWUFbZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZUFRZ
UFRZUFRZUFRYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NXTfJX
TfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJX
TfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJVTFBV
TFBWTVFXTfJXTfJWTVFVTFBVTFBWTfBWTfBWTfBXU6FXU6FXU6FYUFJYUFJWTfBWTfBXU6FYUFJYUFJX
U6FWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBVTV>V
TV>VTV>VTV>WTfBWTfBXU6FXU6FWTfBVTV>UTF:UTF:UTF:WTfBXU6FYUFJXU6FXU6FXU6FXU6FXU6FX
U6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXU6FXTfJX
TfJXTfJYU6NYU6NYU6NZUFRZUFR[U6J[U6J[U6J[U6J[U6J[U6J[U6J[U6JYUFJYUFJYUFJYUFJYUFJY
UFJYUFJYUFJ`UF:ZTf6VTFBRT6^PTWFPUGnOV8NPVhbNWI>NWY:MWI6LW92LW8jJWHfKWXjKWXjNW96N
W96NW96NW96MVi2MVi2MVi2MVi2LVXRMWH^PXI6OX92NWHn`Z9^eYYfIQWhn9Q1EIF`mY;e9Z[hh8BEO
4P1D6`9R81Dn<BUV/;9HY[MIAUEM7A:UUG2g_JBnWZ>d/ZNd/ZNe/jRe/jRe/jRf]:Vf]:Vf]:Vd]ZZb
]:R_/JF][j>/[Z:][j>_/JF`/ZJa/ZRb/jVe]Zbg^:jh^Jnh^Jnh^Jng^:jk^Jnk^Jnk^Jnl^[2l^[2m
^k6m^k6m^k6c_Jff_;6h^KFk][Nn^KK2_;6k]ina[XnPUWBRUFnVU6^YUFJYTf>XTF>WTVFXUFZ/UFN/
UFN/UFN/UFN/UFN/UFN/UFN/UFN^UfV^UfV^UfV^UfV^UfV]UVR/UFN[U6J_V6Z^UfV^UfV]UVR]UVR/
UFN/UFN/UFN/UFN/UFN/UFN/UFN]UVR]UVP00;BQS;BQS;BQS;BQS;BQS;BQS;BQS;BQS:nRR:nRR:nQ
RZnQRZnQRjnQRjnPSJnPSJjPRZjPRZjPRZjPRZjPRZjPRZjPRZjPR[:OR[:OR[:OR[:OR[:OR[:OR[:O
R[:ORZbNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:fORJfORJbN
R:^MQj^MQjbNR:fORJfORJZLQZ^MQjbNR:fORJjPRZfORJfORJbNR:fORJfORJfORJfORJfORJfORJfO
RJfORJbNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:^MQj^MQj^M
Qj^MQj^MQj^MQj^MQj^MQj^NQ:^NQ:^NQ:^NQ:^NQ:^NQ:^NQ:^NQ:nNPjnNPjnNPjnNPjnNPjnNPjnN
PjnNPk2OQK2OQK2OQK2OQJnNQ:nNQ:nNQ:jMPjjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjM
PZjMPZjMPZjMPZjMPZjMPZfLPJfLPJjMPZjMPZjMPZnNPjnNPjnNPjjMPZjMPZjMPZjMPZjMPZjMPZjM
PZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfL
PJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJbLOjbLOjbLOjbLOjbLOjbLOjbL
OjbLOjjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJjLOJfKO:fKO:fK
O:fKO:fKO:fKO:fKO:fKO:bJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJ
NjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNjbJNj^KMj^KMj^K
Mj^KMjZJMZZJMZZJMZZJMZRFMjVGN:VGN:VGN:ZHNJZHNJZHNJZHNJ^HMJ^HMJbIMZbIMZbIMZbIMZfJ
MjfJMj^IM:^IM:^IM:^IM:^IM:^IM:^IM:^IM:JILjRHLjRHLjZHLjZHLj^HLj^HLjfGLjVGLZVGLZVG
LZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZVG
LZVGLZRFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJNEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:RFLJRFLJRF
LJRFLJRFLJRFLJRFLJRFLJNEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:NE
L:NEL:NFKjNFKjNFKjNFKjNFKjNFKjNFKjNFKjNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZND
KZREKjREKjVFL:VFL:VFL:REKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjREKjRE
KjREKjRFKJRFKJRFKJRFKJRFKJRFKJRFKJRFKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJNDKZNDKZND
KZNDKZNDKZNDKZNDKZNDKZNEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:NE
K:NEK:JDJjJDJjJDJjNEK:NEK:NEK:RFKJRFKJNEK:NEK:NEK:NEK:NEK:NEK:NEK:NEK:ZEJ:ZEJ:ZE
J:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:ZEJ:VDIjVDIjVDIjVDIjVDIjVDIjVD
IjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjVDIjRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZNBIJNBIJNB
IJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNB
IJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJF@HjJAI:NBIJNBIJNBIJNBIJJAI:F@HjJBHjNCI:NC
I:NCI:RDIJRDIJRDIJRDIJJBHjNCI:RDIJRDIJRDIJRDIJNCI:JBHjJBHjJBHjJBHjJBHjJBHjJBHjJB
HjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjFAHZFAHZJBHjJBHjNCI:NCI:NCI:NCI:JBHjJBHjFA
HZFAHZFAHZJBHjRDIJRDIJNCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NC
I:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:NCI:RCIZRCIZRCIZRCIZVDIjVDIjVDIjZEJ:^DIZ^DIZ^D
IZ^DIZ^DIZ^DIZ^DIZ^DIZZFIjZFIjZFIjZFIjZFIjZFIjZFIjZFIkFHGk:GGjfEHJZCIJJCKJJEM:JH
NjNJP9NKSiNKSiRLT9ZLT9ZLT9^KSiZJSYVISIfKT9fKT9bJSibJSi^ISYZHSIZHSIZHSINEPibLRYZK
RjNXV:2OTK6YW<Ff[HYgKdTN03h_9TN9SWNj_Dl[8eT=05HR15`L2T@S48V[XFV9SU4M96lG2IUdD[fi
X<:XZ;BbYkBbYkBbYkFcZ;FcZ;JdZKJdZKJdZKFgZk>eZK6cYjj`Y:f_Xjj`Y:j`Y:naYK6bZ;:cZKBe
ZkJg[KNh[[Ri[kRi[kNh[[^i[k^i[k^i[k^i[kbj/;bj/;fk/Kfk/K>jZkJj[kRh/[Ve];fi]<:n/l2m
Z;ZgVjVOPJ>GMJ:AJZNBIJF>H9n8FZ6<GjVFJjbEIjbEIjbEIjbEIjbEIjbEIjbEIjbEIjfFJ:fFJ:jG
JJjGJJjGJJfFJ:bEIj^DIZjGJJjGJJfFJ:fFJ:fFJ:bEIjbEIjbEIjjGJJfFJ:fFJ:fFJ:fFJ:fFJ000
/j2;/j2;/j2;/j2;/j2;/j2;/j2;/j2;[j:8[j:8[j6:[j6:[j6;[j6;[j2=[j2=[Z2:[Z2:[Z2:[Z2:
[Z2:[Z2:[Z2:[Z2:/Ij9/Ij9/Ij9/Ij9/Ij9/Ij9/Ij9/Ij9[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8
[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8ZYb6Zif7[9j8[In9
[In9[In9[9j8[9j8[In9[In9[In9[In9[In9[In9[In9[In9Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7
[9j8[9j8[9j8[9j8[9j8[9j8[9j8[9j8Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zij4Zij4Zij4Zij4
Zij4Zij4Zij4Zij4[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij3[ij4[ij4[ij4[ij4[ij4[ij4[ij4[ij4
[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Ib1[Ib1[Ib1[Yf2
[Yf2[Yf2[ij3[ij3[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2[Yf2
[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1[Ib1
[Ib1[Ib1[Ib1[Ib1[9ao[9ao[9ao[9ao[9ao[9ao[9ao[9ao[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam
[Yam[Yam[Yam[Yam[Yam[Yam[Yam[Yam[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9YkZiUjZiUjZiUjZiUj
ZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUj
ZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUj[9ahZi]gZi]gZYYfZYYfZIUeZIUeZIUeZ9IgZ9IgZ9IgZIMh
ZIMhZYQiZYQiZYQiZiQeZiQeZiQe[9Uf[IYg[IYg[Y]h[Y]hZiUdZiUdZiUdZiUdZiUdZiUdZiUdZiUd
YYUcZ9QcZ9QcZYQcZYQcZiQcZiQc[IMcZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMb
ZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9Ia
YiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`Z9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaYiE`YiE`YiE`YiE`
YiE`YiE`YiE`YiE`Z9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaZ9IaYiI_YiI_YiI_YiI_YiI_YiI_YiI_YiI_
YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^YY=]YiA^YiA^YiA^Z9E_Z9E_Z9E_ZII`Z9E_Z9E_Z9E_Z9E_
Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9E_Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]Z9I]
YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YYA[YYA[YYA[YYA[
YiE/YiE/YiE/YiE/YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YI=ZYI=ZYYA[YYA[YiE/YiE/YiE/YiE/
YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[ZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAWZIAW
ZIAWZIAWZIAWZIAWZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=V
Z9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9U
Yi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9U
YI1SYI1SYY5TYi9UYi9UYY5TYI1SYI1SYY9SYY9SYY9SYi=TYi=TZ9AUZ9AUZ9AUYY9SYi=TYi=TZ9AU
Z9AUYi=TYi=TYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9S
YI5RYI5RYI5RYY9SYY9SYY9SYi=TYi=TYI5RYI5RYI5RYI5RYY9SYY9SYi=TYi=TYi=TYi=TYi=TYi=T
Yi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=T
Yi9UYi9UZ9=VZ9=VZ9=VZIAWZIAWZIAWZY=UZY=UZY=UZY=UZY=UZY=UZY=UZY=UZIEVZIEVZIEVZIEV
ZIEVZIEVZIEVZIEVZI5MZI9PZI=SYI9WXI1YWhi]W8m_WHmbRY:1S9B3TYN8UIV=VY^AWI^CWY^CWYZE
WYbAWYbAWI^@W9Z?W9Z?ViV>VYR=VYR=W9Z8Vi^9Si20[JjNZJRJ]ZjQaKJ]He18K2T2BaH1AEM:NY>5
L3PWL246FbL9F1<0M48VShUfJUmGGQ@@N1L9LT0T/:>=^ZRQ/k6V];:W];:W];:W]K>X]K>X]K>X][BY
]KN[];JZ/[BX/;:V[k6U[k6U[k6U[k6U/K:X/[>Y/kBZ]KJ/][N]]kR^]kR^^;V_^[R^^[R^^kV_^kV_
^kV__;Z`_;Z`_;Z`][^/^K^_^;V`^;F`_;Va`knd`/2^_kfU]ZnDYYanX91/YI5XYi1SXX]NY8mR[iU_
ZiAVZiAVZiAVZiAVZiAVZiAVZiAVZiAV[9EW[9EW[IIX[IIX[IIX[IIX[9EWZiAV[IIX[IIX[IIX[9EW
[9EW[9EW[9EW[9EW[YMY[YMY[YMY[IIX[9EW[9EW002cX8^cX8^cX8^cX8^cX8^cX8^cX8^cX8^_XXR_
XXR_XHZ_XHZ_XH^_XH^_X8f_X8f^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8ZaWhRaWhRaWhRaWhRaWhRa
WhRaWhRaWhR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXR[WHN[
WHN/WXR/WXR/WXR/WXR[WHN[WHNYVhFZW8J[WHN/WXR]WhV/WXR/WXR/WXR]WhV]WhV]WhV]WhV]WhV]
WhV]WhV]WhVZW8JZW8JZW8JZW8JZW8JZW8JZW8JZW8J/WXR/WXR/WXR/WXR/WXR/WXR/WXR/WXRZW8JZ
W8JZW8JZW8JZW8JZW8JZW8JZW8JZWH>ZWH>ZWH>ZWH>ZWH>ZWH>ZWH>ZWH>^WH:^WH:^WH:^WH:^WH:^
WH:^WH:^WH:^WH>^WH>^WH>^WH>^WH>_WXB_WXB_WXB]W86]W86]W86]W86]W86]W86]W86]W86]W86]
W86]W86]W86]W86]W86]W86]W86/Vh2/Vh2]W86]W86]W86^WH:^WH:^WH:]W86]W86]W86]W86]W86]
W86]W86]W86]W86]W86]W86]W86]W86]W86]W86]W86/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/
Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2[Vgj[Vgj[Vgj[Vgj[Vgj[
Vgj[Vgj[Vgj]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb]Vgb/VW^/
VW^/VW^/VW^/VW^/VW^/VW^/VW^[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[
VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VgN[
VgN[VgNZVWJYVGFYVGFXV7BXV7BWUGJXUWNXUWNXUWNYUgRYUgRYUgRZV7VZUgBZUgB[V7F[V7F/VGJ]
VWN]VWN]VWN[VGB[VGB[VGB[VGB[VGB[VGB[VGB[VGBUV7:WUg:WUg:YUg:YUg:ZUg:ZUg:/UW:XUW6X
UW6XUW6XUW6XUW6XUW6XUW6XUW6YUg:YUg:YUg:YUg:YUg:YUg:YUg:YUg:XUW6XUW6XUW6XUW6XUW6X
UW6XUW6XUW6WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2VU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nWUG2W
UG2WUG2WUG2WUG2WUG2WUG2WUG2VU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nWUG2WUG2WUG2WUG2WUG2W
UG2WUG2WUG2VUFjVUFjVUFjVUFjVUFjVUFjVUFjVUFjXUFnXUFnXUFnXUFnXUFnXUFnXUFnXUFnVTffV
TffVTffWU6jWU6jXUFnXUFnXUFnWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jW
U6jWU6jWU6jWUFbWUFbWUFbWUFbWUFbWUFbWUFbWUFbVTffVTffVTffVTffVTffVTffVTffVTffVTffV
TffVTffVTffVTffVTffVTffVTffTTVVUTfZUTfZVU6^VU6^WUFbWUFbWUFbVU6^VU6^VU6^VU6^VU6^V
U6^VU6^VU6^UTfZUTfZUTfZVU6^VU6^VU6^WUFbWUFbVU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^YU6NY
U6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NYU6NXTfJXTfJXTfJXTfJXTfJX
TfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJWTVFW
TVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFW
TVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFTSf:UT6>VTFBVTFBVTFBVTFBUT6>TSf:UTF:V
TV>VTV>VTV>WTfBWTfBWTfBXU6FVTV>VTV>WTfBWTfBWTfBWTfBVTV>VTV>UTF:UTF:UTF:UTF:UTF:U
TF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:TT66TT66UTF:UTF:VTV>VTV>VTV>VTV>TT66T
T66UTF:VTV>VTV>VTV>VTV>VTV>WTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBW
TfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTVFWTVFWTVFWTVFXTfJXTfJYU6NYU6NZTfFZ
TfFZTfFZTfFZTfFZTfFZTfFZTfFWTfBWTfBWTfBWTfBWTfBWTfBWTfBWTfAkKD=oLd^6NE>7NeN4NEV0
MUQlLeQlLeQeNf9hOVMnP6b3Q7B7Qg^:R7j;Qh:<R8>OWI:OWI:NW96NW96MVi2MVi2MVi2LVXnPWXbL
W8Z>SgnYZYZQX9:XX9>iZZ5LBD5d:PIP4P0`6@<n<aeN5PAV605<6P1L4`1:4`139@`l6PYD301^6`aW
=B6iZYNcZijc/JJc/JJc/JJd/ZNd/ZNe/jRe/jRe/jRe]j^d]ZZc]JVb]:Ra/jN`/ZJ`/ZJ`/ZJb/jVb
/jVb/jVc]:Ze]Zbf]jfg^:jh^Jnj^:jj^:jj^:jk^Jnk^Jnk^Jnl^[2l^[2j_Jjm_K6k^[2g]Jfj^:jo
_K;0`;2n_:Zo^:B/XXZMT72RSfZYTfVZTfJ[TfV^V6j[U6J[U6J[U6J[U6J[U6J[U6J[U6J[U6J[U6J[
U6J/UFN]UVR]UVR/UFN/UFN[U6J/UFN/UFN/UFN/UFN/UFN/UFN/UFN/UFN]UVR]UVR]UVR/UFN[U6J[
U6H00;:OR[:OR[:OR[:OR[:OR[:OR[:OR[:ORZnRR:nRR:nQRZnQRZnQRjnQRjnPSJnPSJjPRZjPRZjP
RZjPRZjPRZjPRZjPRZjPR[2NQk2NQk2NQk2NQk2NQk2NQk2NQk2NQj^MQj^MQj^MQj^MQj^MQj^MQj^M
Qj^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQjZLQZ^MQj^MQjbNR:bNR:^MQj^MQjZLQZVKQJZLQZ^M
QjbNR:bNR:bNR:bNR:^MQjbNR:bNR:bNR:bNR:bNR:bNR:bNR:bNR:VKQJVKQJVKQJVKQJVKQJVKQJVK
QJVKQJ^MQj^MQj^MQj^MQj^MQj^MQj^MQj^MQjZLQZZLQZZLQZZLQZZLQZZLQZZLQZZLQZZMPjZMPjZM
PjZMPjZMPjZMPjZMPjZMPjjMPZjMPZjMPZjMPZjMPZjMPZjMPZjMPZfLPZfLPZfLPZjMPjjMPjjMPjnN
Q:nNQ:fLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJbKP:bKP:bK
P:fLPJfLPJfLPJjMPZjMPZfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfLPJfL
PJfLPJbKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:bK
P:bKP:bKP:bKP:bKP:bKP:^KOZ^KOZ^KOZ^KOZ^KOZ^KOZ^KOZ^KOZfKO:fKO:fKO:fKO:fKO:fKO:fK
O:fKO:fKO:fKO:fKO:fKO:fKO:fKO:fKO:fKO:^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZZHNJZHNJZH
NJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZH
NJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZJMZZJMZZJMZVIMJVIMJVIMJVIMJVIMJNEMZNEMZNE
MZRFMjRFMjVGN:VGN:VGN:ZGM:ZGM:ZGM:ZGM:^HMJ^HMJ^HMJ^HMJZHLjZHLjZHLjZHLjZHLjZHLjZH
LjZHLjFHLZNGLZNGLZVGLZVGLZZGLZZGLZbFLZRFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJVGLZVGLZVG
LZVGLZVGLZVGLZVGLZVGLZRFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJNEL:NEL:NEL:NEL:NEL:NEL:NE
L:NEL:JDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjNEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:JDKjJDKjJD
KjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJEKZJEKZJEKZJEKZJEKZJEKZJE
KZJEKZREKjREKjREKjREKjREKjREKjREKjREKjJCKJJCKJJCKJJCKJNDKZNDKZNDKZREKjNDKZNDKZND
KZNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZNEK:NEK:NEK:NEK:NEK:NEK:NE
K:NEK:JCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJFBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:>AJ:BBJJBB
JJFCJZJDJjNEK:NEK:NEK:FCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZBBJJFCJZFCJZFCJZJDJjJDJjJD
JjJDJjFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZRC
IZRCIZRCIZRCIZRCIZRCIZNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNB
IJNBIJRCIZRCIZRCIZRCIZRCIZRCIZRCIZRCIZJAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JA
I:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:JA
I:JAI:B?HZF@HjF@HjJAI:JAI:F@HjF@HjB?HZFAHZFAHZFAHZJBHjJBHjNCI:NCI:NCI:FAHZJBHjJB
HjNCI:NCI:JBHjJBHjFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZFA
HZFAHZB@HJB@HJB@HJFAHZFAHZJBHjJBHjJBHj>?H:B@HJFAHZJBHjJBHjJBHjFAHZFAHZJBHjJBHjJB
HjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJBHjJB
HjJBHjJAI:JAI:NBIJNBIJNBIJRCIZRCIZRCIZVBI:VBI:VBI:VBI:VBI:VBI:VBI:VBI:JBHjJBHjJB
HjJBHjJBHjJBHjJBHjJBHi28HiVAK:>JN:VPOZROOZJLOZFJOZFJOZ6NOj6OPJBQQJBQS:FRTjJRUjJS
VjJRWIbJSibJSifKT9fKT9fKT9fKT9fKT9fKT9FCPIRHQYFFQZBUUIJEQj>KS/6bZIJ3NfD_67hb7ddY
4CdW3V/V5fT[6d`Z4g0`7U`_6UDe7VM8<gU=?8aJCYMeJ=C7]k:bX;>aY[>aY[>aY[>aY[BbYkBbYkBb
YkFcZ;>eZK>eZK>eZK>eZK>eZK:dZ;:dZ;:dZ;:cZK:cZK:cZK:cZKBeZkFf[;Nh[[Ri[kVg[KVg[KZh
[[Zh[[^i[k^i[k^i[k^i[kfm[kno/kfm/KRh[;RfZkfk/;jl/K^j[;jjZ;2YUJ>GNj6>JjNAJ:jFK:jF
K:bDJZZCIJZCIJZCIJZCIJZCIJZCIJZCIJZCIJZCIJZCIJ^DIZbEIjfFJ:bEIjbEIj^DIZZCIJ^DIZ^D
IZ^DIZbEIjbEIjbEIjbEIj^DIZ^DIZ^DIZZCIJZCIJZCI@00/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:
[j:8[j:8[j6:[j6:[j6;[j6;[j2=[j2=[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:[Z2:/9n5/9n5/9n5/9n5
/9n5/9n5/9n5/9n5Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7
ZI^5ZYb6Zif7[9j8[9j8Zif7ZYb6ZI^5ZI^5ZI^5Zif7Zif7[9j8[9j8Zif7Zif7ZYb6ZYb6ZYb6ZYb6
ZYb6ZYb6ZYb6ZYb6ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5Zif7Zif7Zif7Zif7Zif7Zif7Zif7Zif7
ZYb6ZYb6ZYb6ZYb6ZYb6ZYb6ZYb6ZYb6ZYf3ZYf3ZYf3ZYf3ZYf3ZYf3ZYf3ZYf3[Yf2[Yf2[Yf2[Yf2
[Yf2[Yf2[Yf2[Yf2[9^1[9^1[Ib2[Ib2[Yf3[Yf3[ij4[ij4[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0
[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0ZiYo[9^0[9^0[9^0[Ib1[Ib1[Ib1[Yf2[9^0[9^0[9^0[9^0
[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0ZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYo
ZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZYYmZYYmZYYmZYYm
ZYYmZYYmZYYmZYYm[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk[9Yk
ZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQi
ZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQi
Z9QdZ9QdZ9QdZIUeZIUeZIUeZIUeZIUeYiEfYiEfYiEfZ9IgZ9IgZ9IgZIMhZIMhZYMdZYMdZYMdZIIc
ZIIcZIIcZIIcZIIcZYQcZYQcZYQcZYQcZYQcZYQcZYQcZYQcYIQbYiMbYiMbZIMbZIMbZYMbZYMb[9Ib
YiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`ZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbYiE`YiE`YiE`YiE`
YiE`YiE`YiE`YiE`YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^
YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^
YI=^YI=^YI=^YI=^YIA]YIA]YIA]YIA]YIA]YIA]YIA]YIA]YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^
YI9/YI9/YY=]YY=]YY=]YiA^YiA^YiA^YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]
YY=]YY=]YY=]YY=]YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]
YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/Xi5XXi5XY99YYI=ZYYA[YYA[YiE/Z9I]YI=ZYI=ZYI=ZYI=Z
YI=ZYI=ZYI=ZYI=ZY99YY99YYI=ZYI=ZYI=ZYYA[YYA[YYA[YI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=Z
Z9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VYi9UYi9UYi9UYi9U
Yi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UYi9UZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=V
YY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5T
YY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TY8mRY8mRYI1SYY5TYY5TYI1SY8mRY8mR
YI5RYI5RYI5RYY9SYY9SYY9SYi=TYi=TYI5RYI5RYY9SYi=TYi=TYY9SYI5RYI5RYI5RYI5RYI5RYI5R
YI5RYI5RYI5RYI5RYI5RYI5RYI5RYI5RYI5RYI5RYI5RYI5RY91QY91QY91QY91QYI5RYI5RYI5RYY9S
XXiOXhmPYI5RYY9SYY9SYY9SYI5RY91QYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9S
YY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY5TYY5TYY5TYi9UYi9UYi9UZ9=VZ9=V
ZI9TZI9TZI9TZI9TZI9TZI9TZI9TZI9TYi=TYi=TYi=TYi=TYi=TYi=TYi=TYi=TTHEKVHeSX9AZYIM]
YIE[Xi=YY9AZZ9I]X9A/WY=]W95aVY5fUi1lU962Ti66Ti69UYB9UiF:UiF:V9J;VIN<VYR=VYR=ViV>
Ti5oTI5oV9V9WIj>V9N9ZJ6D`K:Y_jbTZifAfJVMb;:I]JjEfJfPbJ^P/JZIdJVGaZZObK6Ob;ZS]K2K
]jjT^jfW`kZ`ZjnL/[2U/[2U/k6V/k6V/k6V];:W];:W];:W/[BX/[BX/kFY];JZ];JZ];JZ];JZ];JZ
/[>Y/[>Y/K:X/K:X/kBZ]KJ/]kR^^;V_^KN]^KN]^KN]^[R^^[R^^kV_^kV_^kV_^kV^_kj`_[f_^KRZ
]kNY^[Z^_;^a^[V_^[NY^kFR/ZN<Y9=bXXeW[IA/[iM]ZI1XZY=UZY=UZY=UZY=UZY=UZY=UZY=UZY=U
ZI9TZI9TZiAV[9EW[9EW[9EW[9EW[9EWZY=UZY=UZY=UZiAVZiAV[9EW[9EW[IIXZ95SZ95SZ95SZ95S
ZI9TZI9T002bWhZbWhZbWhZbWhZbWhZbWhZbWhZbWhZ_XXR_XXR_XHZ_XHZ_XH^_XH^_X8f_X8f^X8Z^
X8Z^X8Z^X8Z^X8Z^X8Z^X8Z^X8Z`WhF`WhF`WhF`WhF`WhF`WhF`WhF`WhF[WHN[WHN[WHN[WHN[WHN[
WHN[WHN[WHN[WHN[WHN[WHN[WHN[WHN[WHN[WHN[WHNYVhFZW8J[WHN/WXR/WXR[WHNZW8JYVhFYVhFY
VhFZW8J[WHN/WXR/WXR[WHN[WHNYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFXVXBXVXBXVXBXVXBXVXBX
VXBXVXBXVXB[WHN[WHN[WHN[WHN[WHN[WHN[WHN[WHNYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFYW8:Y
W8:YW8:YW8:YW8:YW8:YW8:YW8:]W86]W86]W86]W86]W86]W86]W86]W86/Vh6/Vh6/Vh6]W8:^WH>^
WH>_WXB_WXB/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2[VWn[
VWn/Vh2/Vh2/Vh2]W86]W86]W86/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/
Vh2/Vh2/Vh2[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[
VWn[VWn[VWn[VWn[VWn[VWn[VWnZVWfZVWfZVWfZVWfZVWfZVWfZVWfZVWf/VW^/VW^/VW^/VW^/VW^/
VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^/VW^[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZZV7VZ
V7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZ
V7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VZV7VWUg>WUg>XV7BXV7BYVGFZVWJZVWJZVWJVU7FW
UGJWUGJWUGJXUWNXUWNXUWNYUgRZUgBZUgBYUW>YUW>XUG:WU76WU76WU76ZV7>ZV7>ZV7>ZV7>ZV7>Z
V7>ZV7>ZV7>TUg6VUW6VUW6XUW6XUW6YUW6YUW6[UG6WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2YUg:Y
Ug:YUg:YUg:YUg:YUg:YUg:YUg:WUG2WUG2WUG2WUG2WUG2WUG2WUG2WUG2VU6nVU6nVU6nVU6nVU6nV
U6nVU6nVU6nUTfjUTfjUTfjUTfjUTfjUTfjUTfjUTfjVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nUTfjU
TfjUTfjUTfjUTfjUTfjUTfjUTfjTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfUU6fUU6fUU6fUU6fUU6fU
U6fUU6fUU6fUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbVTffVTffWU6jWU6jWU6jVTffV
TffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVU6^VU6^VU6^VU6^VU6^V
U6^VU6^VU6^VTffVTffVTffVTffVTffVTffVTffVTffUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbRT6NS
TFRSTFRTTVVUTfZVU6^WUFbXUVfUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZTTVVTTVVTTVVUTfZUTfZU
TfZVU6^VU6^UTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJX
TfJXTfJXTfJXTfJXTfJXTfJXTfJWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFWTVFW
TVFWTVFWTVFXTfJXTfJXTfJXTfJXTfJXTfJXTfJXTfJVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBV
TFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBV
TFBVTFBVTFBSSV6TSf:UT6>UT6>UT6>UT6>TSf:SSV6TT66UTF:UTF:UTF:VTV>VTV>VTV>WTfBUTF:U
TF:VTV>WTfBWTfBVTV>UTF:UTF:TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66T
T66TT66TT66SSf2TT66TT66TT66UTF:UTF:UTF:UTF:RSUnSSf2UTF:VTV>VTV>VTV>UTF:TT66VTV>V
TV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>VTV>V
TV>VTV>VTV>VTFBVTFBVTFBVTFBWTVFWTVFXTfJXTfJYTVBYTVBYTVBYTVBYTVBYTVBYTVBYTVBXU6FX
U6FXU6FXU6FXU6FXU6FXU6FXU6FSTUnYUV>/VFJ[UV>WTEfVSUZ[T5f_U66ZUFRVU6^STfjMTWBJTgZH
U8:FUHNEUXbAShBAShBBT8FDTXNEThRFU8VGUHZGUHZQWhfBTX2FUhNEUXJJVH^WWi:UUXf]VY:?XYn_
V92XY8bKY8ZcWI:WXIZK[YngXi:cXYnkZij^[IRH[INZ_[:][ZZNW9:f_JRb/:Fb/:Fb/:Fc/JJc/JJd
/ZNd/ZNd/ZNa/jNa/jNc]JVd]ZZe]j^e]j^e]j^e]j^b/jVb/jVa/ZRa/ZRb/jVd]J^g^:jh^Jni]jfi
]jfi]jfj^:jj^:jj^:jk^Jnk^Jnk]jbm_:jm_:ji^JVg]jVj^Zjl^k6h^K2g]J[4`:k2]Yj[VGZPRVJ[
TVZ`UfnZTFVZTfFZTfFZTfFZTfFZTfFZTfFZTfFZTfFXTF>YTVBZTfF/UFN/UFN/UFN/UFN/UFNYTVBY
TVBZTfF[U6J[U6J/UFN/UFN]UVRVSf6VSf6VSf6WT6:XTF>XTF<00;6PQ[6PQ[6PQ[6PQ[6PQ[6PQ[6P
Q[6PQ[:OR[:OR[:OR[:OR[:OR[:OR[:OR[:OR[2MR;6NRK6NRK:OR[:OR[6NRK6NRK2MR:nLQjnLQjnL
QjnLQjnLQjnLQjnLQjnLQjjKQZjKQZjKQZnLQjnLQjnLQk2MR;2MR:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJ
Q:RJQ:fJQJfJQJfJQJfJQJjKQZjKQZjKQZnLQjZLQZZLQZZLQZZLQZZLQZZLQZZLQZZLQZZLQZZLQZZL
QZZLQZZLQZZLQZZLQZZLQZRJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:jKQZjKQZjKQZjKQZjKQZjKQZjK
QZjKQZjMPjjMPjjMPjjMPjjMPjjMPjjMPjjMPjbKPJbKPJbKPJbKPJbKPJbKPJbKPJbKPJbKP:bKP:bK
P:bKP:bKP:bKP:bKP:bKP:^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^JOj^J
Oj^JOjZIOZZIOZ^JOj^JOjbKP:bKP:bKP:bKP:ZIOZ^JOjbKP:bKP:bKP:bKP:^JOjZIOZZJOJZJOJ^K
OZ^KOZbLOjbLOjbLOjbLOjVHOJZIOZ^JOj^JOj^JOj^JOjZIOZVHOJZJOJZJOJZJOJZJOJZJOJZJOJZJ
OJZJOJbJOJbJOJbJOJbJOJbJOJbJOJbJOJbJOJfJOjfJOjbIOZ^HOJ^HOJbIOZfJOjfJOj^IO:^IO:^I
O:^IO:^IO:^IO:^IO:^IO:^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^INZ^I
NZ^INZZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJbJNj^INZ^INZZHNJZHNJVGN:VGN:RFMjVFLjZGM:bI
MZjKN:jKN:fJMjbIMZ^HMJ^KMZZJMJRHLjNGLjNFMJRGMZZHNJ^INZZHNJVGN:RFMjVGN:^INZ^INZVG
N:JDMJRHM:RHM:RHM:RHM:RHM:RHM:RHM:RHM:VFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjFFMJNGLjNG
LjVGLZVGLZZGLJZGLJbHKjVGLZVGLZVGLZVGLZVGLZVGLZVGLZVGLZNEL:NEL:NEL:NEL:NEL:NEL:NE
L:NEL:NFKjNFKjNFKjNFKjNFKjNFKjNFKjNFKjJDKjNEL:NEL:NEL:RFLJRFLJRFLJVGLZJDKjJDKjJD
KjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjJCKJJCKJJCKJJCKJJCKJJCKJJC
KJJCKJJEKZJEKZJEKZFDKJFDKJFDKJFDKJFDKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJC
KJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJJDJjJDJjJDJjJDJjJDJjJDJjJD
JjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjJDJjFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFC
JZFCJZFCJZFCJZFCJZFCJZFCJZFCJZJDJjJDJjJDJjFCJZBBJJ>AJ:FCJZFCJZFCJZFCJZFCJZFCJZFC
JZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZ:@Ij>AJ:>AJ:BBJJBBJJFCJZFCJZJDJjFCJZFCJZFC
JZFCJZFCJZFCJZFCJZFCJZ>AJ:>AJ:>AJ:BBJJBBJJFCJZFCJZFCJZRCIZRCIZRCIZRCIZRCIZRCIZRC
IZRCIZRBJJNAJ:J@IjJ@IjJ@IjJ@IjNAJ:RBJJVDIjRCIZRCIZNBIJNBIJJAI:F@HjF@HjJAI:JAI:NB
IJRCIZRCIZNBIJJAI:JAI:JAI:JAI:JAI:NBIJNBIJNBIJRCIZRCIZJBHjJBHjJBHjJBHjJBHjJBHjJB
HjJBHjFAHZFAHZFAHZFAHZB@HJB@HJB@HJB@HJFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZJBHjJBHjJB
HjJBHjJBHjJBHjJBHjJBHj>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?
H:>?H:F?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjB>GZB>GZB>
GZB>GZB>GZB>GZB>GZB>GZF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?Gj:<G:>=GJB>GZF?GjJ@H:J@H:F?
GjF?GjRBHZNAHJF?GjB>GZB>GZB>GZJ@H:NAHJNBGjNBGjNBGjNBGjNBGjNBGjNBGjNBGjN@HZN@HZN@
HZRAHjRAHjRAHjVBI:VBI:VCHjVCHjVCHjRAHjN@HjN@HjJ>I:J>I:F>H:J?HJN@HZN@HZN@HZN@HZJ?
HJF>H:NAHJNAHJNAHJNAHJNAHJNAHJNAHJNAHJF@GJNBGjVDHJRCH:NBGjNBGjRCH:ZEHZJAGJJAGJJA
GZJAGZNAHJN@HZN@HZRAHj>@Hj:BHj:DI9nEIYbDK9bCLIRAMYVANXnBRHnAQHjAPHfBOHjBOi6DQIJD
S9RDThjIRI2JRIBJQiNMQY^NQJ6OQjNQRZ^RSZNWUjFUUJ>STj>STjBTU:RXV:b/W:n_WjZ]WJ^^WZb_
Wjf`XJj`Y:j`Y:j_YJj_YJn`Yjn`Yjn`Yjn`Yjn`Yk2aZ;2aZ;2aZ;>c[KBd[[Bd[[Bd[[Bd[[Bd[[Bd
[[Bd[[Nc[[Jb[KFcZK>aY[:`YK>aY[JdZ[NeZk:hYkFhZKFgZkJd[;Vc[[fd/<6h]<Jl]KRj[[Rj[[Rk
ZkRkZkRk[;Ri/;Nf/[Ne]KZo/;VjZ[jkY[6YS9N=IJ>FH[>UJZBHEZ^CJJ^DIj^DIjZCIJZCIJVCHjVC
HjVDHJRBHZRBHZVCHjZDI:ZDI:VCHjRBHZRBHZVCHjVCHjVCHjVCHjVCHjVCHjVCHjVCHjVDHJZDI:ZD
I:^DIZbEIjbEJ000/J26/J26/J26/J26/J26/J26/J26/J26/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:/Yn:
/9f8/9f8/Ij9/Yn:/Yn:/Ij9/9f8/9f8[ib7[ib7[ib7[ib7[ib7[ib7[ib7[ib7[IZ5[Y^6[Y^6[Y^6
[ib7[ib7[ib7/9f8Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4[9V4[IZ5[IZ5[IZ5[Y^6[Y^6[Y^6[Y^6
ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5ZI^5Z9Z4Z9Z4Z9Z4Z9Z4
Z9Z4Z9Z4Z9Z4Z9Z4[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[Ib2[Ib2[Ib2[Ib2[Ib2[Ib2[Ib2[Ib2
[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9^0[9^0[9^0[9^0[9^0[9^0[9^0[9^0ZiYoZiYoZiYoZiYo
ZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZYUnZYUnZiYoZiYoZiYo[9^0[9^0[9^0
ZYUnZiYo[9^0[9^0[9^0[9^0ZiYoZYUnZYYmZYYmZi]nZi]nZi]n[9ao[9ao[9aoZIQmZYUnZYUnZiYo
ZiYoZYUnZYUnZIQmZYYmZYYmZYYmZYYmZYYmZYYmZYYmZYYm[9Ym[9Ym[9Ym[9Ym[9Ym[9Ym[9Ym[9Ym
[IYo[9Un[9UnZiQmZiQm[9Un[9Un[IYoZiUlZiUlZiUlZiUlZiUlZiUlZiUlZiUlZiUjZiUjZiUjZiUj
ZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZiUjZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQi
ZYQiZYQiZYQiZYQiZYQiZIMhZIMhZIMhZIIcZYMd[9Uf[IYg[Y]h[IYg[9UfZiQeZYYeZIUdZ9QcYiMc
YiIeZ9MfZIMhZYQiZ9IgYiEfYiEfZ9IgZYQiZYQiZ9IgYiEfZ9QdZ9QdZ9QdZ9QdZ9QdZ9QdZ9QdZ9Qd
Z9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbY9EdYYIbYYIbZ9IaZ9IaZII`ZII`ZiM^Z9IaZ9IaZ9IaZ9Ia
Z9IaZ9IaZ9IaZ9IaYiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`YiI_YiI_YiI_YiI_YiI_YiI_YiI_YiI_
YYA_YYA_YiE`YiE`YiE`Z9IaZ9IaZ9IaYYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_
YYA_YYA_YYA_YYA_YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YIA]YIA]YIA]YIA]YIA]YIA]YIA]YIA]
YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]
YY=]YY=]YY=]YY=]YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[YYA[
YI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZY99YYI=ZYYA[YYA[
YYA[YI=ZY99YY99YYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=Z
Xi5XXi5XXi5XY99YY99YY99YY99YY99YYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZXi5XXi5XXi5XY99Y
Y99YY99YYI=ZYI=ZZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ9=VZ99YYi5XYY1WYY1WYY1WYY1WYi5XZ99Y
Z9=VZ9=VYi9UYi9UYY5TYY5TYI1SYI1SYY5TYY5TYi9UZ9=VZ9=VYi9UYY5TYY5TYY5TYY5TYY5TYY5T
Yi9UYi9UZ9=VZ9=VYY9SYY9SYY9SYY9SYY9SYY9SYY9SYY9SYI5RYI5RYI5RY91QY91QY91QY91QY91Q
Y91QY91QY91QY91QY91QY91QY91QY91QYI5RYI5RYI5RYI5RYI5RYI5RYI5RYI5RXhmPXhmPXhmPXhmP
XhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmO
YHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNYHmOYHmOYHmOYHmO
YHmOYHmOYHmOYHmOXheMXheMY8iNYHmOYHmOYHmOY8iNY8iNYY1PYY1PY8iNY8iNY8iNYHmOYY1PYi5Q
Yi9OYi9OYi9OYi9OYY5NYY5NYY5NYY5NYHiPYHiPYXmQYXmQYXmQYi1RYi1RYi1RZ9=PZ99RZ99RZ95S
Yi1SYi1SYhmUYhmUYXmQYi1RYi1RZ95SZ95SYi1RYi1RYXmQYY1PYY1PYY1PYY1PYY1PYY1PYY1PYY1P
Y8mLYY5NYi9OYi9OYI1MYI1MYi9OZ9=PYI1LYY5MYY5NYY5NYi5QYi1RYi1RYi1RYI1SY99SXY9SXY=U
Wi=YW99`W95eW91hTI>0TI>0T961T922TY:6U9B8UYF;V9N=VinDVYb@UYV:UiJ8VIJ7WIN:X9R;XIV<
Win?WYj>WIf=WIf=Win?XJ6AY:BDYZJFYZVIYjZJZ:^LZZfNZjfQZjbRZjbRZjbR/;:V/;:V/;:V/;:V
/;:V/K>W/K>W/K>W/[>Z/[>Z/[>Z/[>Z/[>Z/kB[/kB[/kB[_;Va^[R^^;J[^;J[^KRZ^[R]^kV^^[R]
^[n`^[f^^;Z^^[V_^kV__KR__KJ]^kFZ^K^_^Kb]^;^[]k^X]kZZ]kR^^;Rb^;Je][N]]KFY_KRY_K:N
ZYaoXY5ZY9=RYI=NZi=YZiAWZY=VZY=UZY=UZI=SZI=SZIAQZI=SZI=SZI=SZYATZYATZI=SZI=SZI=S
ZI=SZI=SZI=SZI=SZI=SZI=SZI=SZI=SZIAQZI=SZYATZY=UZY=UZY=V002`WhF`WhF`WhF`WhF`WhF`
WhF`WhF`WhFbWhZbWhZbWhZbWhZbWhZbWhZbWhZbWhZ_W8N`WHRaWXVaWXVaWXVaWXV`WHR_W8N^VhJ^
VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ]VXF]VXF^VhJ^VhJ^VhJ_W8N_W8N_W8NXVXBXVXBXVXBXVXBXVXBX
VXBXVXBXVXB/VHB/VHB/VHB]VXF]VXF^VhJ^VhJ^VhJYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFYVhFY
VhFYVhFYVhFYVhFYVhFYVhFYVhFXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXB]VXF]VXF]VXF]VXF]VXF]
VXF]VXF]VXF[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh2/
Vh2/Vh2/Vh2/Vh2/Vh2/Vh2/Vh2[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWn[
VWn[VWn[VWnZVGjZVGjZVGj[VWn[VWn[VWn/Vh2/Vh2ZVGjZVGj[VWn/Vh2/Vh2[VWnZVGjZVGjZVWfZ
VWfZVWf[Vgj[Vgj[Vgj/W7n/W7nYV7fYV7fZVGj[VWn[VWnZVGjYV7fYV7fZVWfZVWfZVWfZVWfZVWfZ
VWfZVWfZVWf/VWf/VWf/VWf/VWf/VWf/VWf/VWf/VWf]VWn/VGj[V7f[V7f[V7f[V7f/VGj]VWn[VGb[
VGb[VGb[VGb[VGb[VGb[VGb[VGb[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[VGZ[
VGZ[VGZ[VGZYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRZV7VZV7VZV7VZV7VYUW>Z
UgB[V7F/VGJ]VWN/VGJ/VGJ[V7FYVGBYVGBXV7>WUg>WUWFXUgJYUgRYUgRVU7FUTgBTTW>UTgBXUWNY
UgRXUWNWUGJWUg>WUg>WUg>WUg>WUg>WUg>WUg>WUg>XUG:XUG:XUG:XUG:XUG:XUG:XUG:XUG:TUGBV
UW:VUW:XUW6XUW6YUW2YUW2[UfjXUW6XUW6XUW6XUW6XUW6XUW6XUW6XUW6WUG2WUG2WUG2WUG2WUG2W
UG2WUG2WUG2WUVnWUVnWUVnWUVnWUVnWUVnWUVnWUVnVU6nVU6nVU6nWUG2WUG2XUW6XUW6XUW6VU6nV
U6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVTffVTffVTffVTffVTffV
TffVTffVTffUU6fUU6fUU6fUU6fUU6fUU6fUU6fUU6fVTffVTffVTffVTffVTffVTffVTffVTffVTffV
TffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVTffVU6^VU6^VU6^VU6^VU6^V
U6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^VU6^UTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZU
TfZUTfZUTfZUTfZUTfZUTfZUTfZSTFRTTVVUTfZVU6^VU6^UTfZTTVVTTVVUTfZUTfZUTfZUTfZUTfZU
TfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZTTVVTTVVTTVVTTVVSTFRSTFRSTFRSTFRUTfZU
TfZUTfZUTfZUTfZUTfZUTfZUTfZRT6NSTFRSTFRSTFRTTVVTTVVTTVVTTVVWTVFWTVFWTVFWTVFWTVFW
TVFWTVFWTVFWTFNWTFNVT6JUSfFUSfFVT6JWTFNWTFNWTVFWTVFWTVFWTVFVTFBVTFBVTFBUT6>UT6>V
TFBWTVFWTVFWTVFWTVFVTFBUT6>UT6>UT6>VTFBVTFBWTVFWTVFWTVFWTVFUTF:UTF:UTF:UTF:UTF:U
TF:UTF:UTF:TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66TT66UTF:U
TF:UTF:UTF:UTF:UTF:UTF:UTF:SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2S
Sf2SSf2SSf2USenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenUSenTSUjT
SUjTSUjTSUjTSUjTSUjTSUjTSUjUSenUSenUSenUSenUSenUSenUSenUSenSSEfTSUjUSenUSenUSenT
SUjSSEfRS5bTSUjTSUjTSUjTSUjTSUjUSenWTF6XTV:XTf2WTUnWTUnVTEjVTEjUT5fUT5fTSebTSEnT
SEnTSEnTSEnUSV2USV2VSf6VSf6VTEjVTEjVT62WTF6WT6:WT6>WT6>WT6>WT6:WT6:XTF>YTVBYTVBX
TF>WT6:WT6:VT62VT62VT62VT62VT62VT62VT62VT62RSEZTSebVTEjUT5fTSebTSebUT5fWTUnUT5bU
T5bUT5fVTEjVT62WT6:WT6:WT6:XT6:WT6:VTV:UTfBSTVNQTFbPT7>PSgFDUG>DTgVCT86EShRETHbE
Th^GUhVFVXNVXYNPW96JUHbGTXVIThbLUXnLUXnMUHjQX9:QX9:QX9:RXI>SXYBTXiFUY9JVYIN[[Yj/
[j2]/:6_/JF`/ZJa/ZRa/ZVa/ZV^/J:^/J:^/J:_/Z>_/Z>`/jB`/jB`/jBb]:Rb]:Rc]JVc]JVc]JVd
]ZZd]ZZd]ZZe]JNb/ZB`/::a/JFd]:Re]JVc/jF`/::a/ZR`/JN`/ZJe]JNk^Zbk^j^j]jRf/jBk_K6j
_Jji_JZh_:Vh_:Vi_:fj^k:k^kFm_;:o_K?3_;?6^Zjm[Y^VTGJLQV:]UF^ZTVRZTfJZTfJZTfFYTVBY
Tf>YTf>XTf2YTf>ZU6BZU6BZU6BZU6BZU6BZU6BYTf>XTV:XTV:XTV:XTV:XTV:XTV:XTV:XTV:WTUnW
TF6XTV:YTVBZTfF[U6L00;2OQK2OQK2OQK2OQK2OQK2OQK2OQK2OQK6NRK6NRK6NRK6NRK6NRK6NRK6N
RK6NRJnLQk2MR;2MR;6NRK6NRK2MR;2MR:nLQjjKQZjKQZjKQZjKQZjKQZjKQZjKQZjKQZfJQJfJQJfJ
QJjKQZjKQZjKQZnLQjnLQjRJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:bIQ:bIQ:bIQ:bIQ:fJQJfJQJjK
QZjKQZVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJVKQJRJQ:RJQ:RJ
Q:RJQ:RJQ:RJQ:RJQ:RJQ:fJQJfJQJfJQJfJQJfJQJfJQJfJQJfJQJZIOjZIOjZIOjZIOjZIOjZIOjZI
OjZIOjbKPJbKPJbKPJbKPJbKPJbKPJbKPJbKPJbKP:bKP:bKP:bKP:bKP:bKP:bKP:bKP:ZIOZZIOZZI
OZZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZVHOJVHOJZIOZZIOZ^JOj^JOj^J
Oj^JOjVHOJZIOZ^JOj^JOj^JOj^JOjZIOZVHOJVIO:VIO:ZJOJZJOJ^KOZ^KOZ^KOZ^KOZRGO:VHOJZI
OZZIOZZIOZZIOZVHOJRGO:VIO:VIO:VIO:VIO:VIO:VIO:VIO:VIO:^IO:^IO:^IO:^IO:^IO:^IO:^I
O:^IO:bIOZbIOZ^HOJZGO:ZGO:^HOJbIOZbIOZZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNJZHNJZH
NJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJZHNJVGN:VGN:VGN:VGN:VGN:VGN:VG
N:VGN:NEMZRFMjRFMjVGN:VGN:ZHNJZHNJ^INZZGM:ZGM:^HMJ^HMJbIMZbIMZbIMZbIMZRHLjRHLjRH
LjRHM:RGMZRGMZRFMjRFMjFCM:>ALZ:@LJ>ALZJDMJRFMjRFMjNEMZNGLjNGLjNGLjNGLjNGLjNGLjNG
LjNGLjRELZRELZRELZRELZRELZRELZRELZRELZBEM:JFLZJFLZRFLJRFLJVFL:VFL:^GKZRFLJRFLJRF
LJRFLJRFLJRFLJRFLJRFLJNEL:NEL:NEL:NEL:NEL:NEL:NEL:NEL:NFKjNFKjNFKjNFKjNFKjNFKjNF
KjNFKjFCKZJDKjJDKjJDKjNEL:NEL:NEL:RFLJFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFCKZFC
KZFCKZFCKZFCKZFCKZFCKZFBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:BCK:BCK:BCK:BCK:BCK:FDKJFD
KJFDKJFBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:FB
K:FBK:FBK:FBK:FBK:FBK:FCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFC
JZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZFCJZBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJ:@Ij>AJ:BB
JJFCJZFCJZFCJZBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBB
JJBBJJFCJZBBJJBBJJ>AJ:>AJ::@Ij:@Ij6?IZBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJ:@Ij:@Ij:@
Ij>AJ:>AJ:BBJJBBJJBBJJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNBIJNAIjJ@IZF?IJF?IJF?IJF?IJJ@
IZNAIjJAI:JAI:JAI:JAI:JAI:JAI:JAI:JAI:F@HjF@HjJAI:NBIJNBIJJAI:F@HjF@HjF@HjF@HjF@
HjJAI:JAI:JAI:NBIJNBIJFAHZFAHZFAHZFAHZFAHZFAHZFAHZFAHZ>?H:>?H:>?H:>?H:B@HJB@HJB@
HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJB@HJ>?H:>?H:>?
H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:F?GjF?GjF?GjF?GjF?GjF?GjF?
GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?GjF?Gj>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJF?GjF?GjF?
GjF?GjF?GjF?GjF?GjF?GjB>GZB>GZF?GjF?GjB>GZ>=GJ:<G:6;Fj:<G::<G:>=GJB>GZF?GjJ@H:NA
HJRBHZRCH:NBGjNBGjJAGZF@GJF@GJB?G:B?G:B>GZB>GZB>GZF?GjF?GjF?GjJ@H:J@H:B?FjB?G:F@
GJJ@H:J@H:N@HZN@HjN@HjNAHJRBHZRBHZVCHjVCHjRBHZRBHZNAHJJ@H:J@H:J@H:J@H:J@H:J@H:J@
H:J@H::=FZB?G:JAGZJAGZB?G:B?G:F@GJNBGjF@G:F@G:F@GJF@GJJ@H:J?HJN@HZN@HZR@HZRAHJNA
HJRBHZJBHjFAJ:>?K:>>KiRFIYVCL9Z@OYV?R9N?SiNDS9NHR9FKPZJQS::LRI^FQibFRijIT9nMTijL
TI^ISYVHRYZIRibKSIjMSinNT9jMSijMSifLSZ>VUjBWV:JXW:RZWZZ[XJ^/Xjb]Y:b]Y:jaXJnbXZnb
X[2cXk6dY;6dY;:eYK:eYK>eZK>eZK>eZKBfZ[FgZkFgZkJh[;Jh[;^mZ[NhZ;FeYkJeZkZi[kbk/KVi
[KFeYkBd[[Jg[[Rj[[Zm[Kk0[Ko1[/31/L30/[Ri[kNi[KFhZ;BhYKFiY[JiZ[Ri[kZk/[BfXkno/KZh
[KZdZL6dY:jMPj:<JK>KLJZBJ:ZCIZZCIZVBI:VBI:RBHZRBHZRCH:ZDI:ZDI:VCHjVCHjVCHjVCHjZD
I:ZDI:RBHZRBHZRBHZRBHZRBHZRBHZRBHZRBHZF@GJF?GjNAHJVBI:bEIjjGJP00/9n5/9n5/9n5/9n5
/9n5/9n5/9n5/9n5/Ij9/Ij9/Ij9/Ij9/Ij9/Ij9/Ij9/Ij9[ib7[ib7/9f8/9f8/9f8/9f8[ib7[ib7
[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[9V4[9V4[IZ5[IZ5[IZ5[Y^6[Y^6[Y^6Z9Z4Z9Z4Z9Z4Z9Z4
Z9Z4Z9Z4Z9Z4Z9Z4ZiR3ZiR3[9V4[9V4[9V4[IZ5[IZ5[IZ5Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4
Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4[9V4[9V4[9V4[9V4
[9V4[9V4[9V4[9V4ZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0
ZiYoZiYoZiYoZiYoZiYoZiYoZiYoZiYoZYUnZYUnZYUnZYUnZYUnZYUnZYUnZYUnZYUnZYUnZYUnZYUn
ZYUnZYUnZYUnZYUnZIQmZIQmZIQmZYUnZYUnZYUnZiYoZiYoZIQmZIQmZYUnZiYoZiYoZYUnZIQmZIQm
ZIUlZIUlZIUlZYYmZYYmZYYmZi]nZi]nZ9MlZ9MlZIQmZYUnZYUnZIQmZ9MlZ9MlZIUlZIUlZIUlZIUl
ZIUlZIUlZIUlZIUlZiUlZiUlZiUlZiUlZiUlZiUlZiUlZiUl[9UnZiQmZYMlZYMlZYMlZYMlZiQm[9Un
ZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQiZYQi
ZYQiZYQiZYQiZYQiZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhYiEfYiEfZ9IgZ9IgZIMhZIMhZYQiZYQi
ZYMdZYMdZYMdZYMdZYMdZiQe[9Uf[9UfYiMbYiMbZ9QcZ9QdZ9MfZ9MfYiEfYiEfYI=dXi5bXHm`XY1a
YI=dYiEfZ9IgZ9IgYYIbYYIbYYIbYYIbYYIbYYIbYYIbYYIbYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAa
XiAcYIEaYIEaYiE`YiE`Z9E_Z9E_ZYI]YiE`YiE`YiE`YiE`YiE`YiE`YiE`YiE`YYA_YYA_YYA_YYA_
YYA_YYA_YYA_YYA_YYE^YYE^YYE^YYE^YYE^YYE^YYE^YYE^YI=^YI=^YI=^YYA_YYA_YiE`YiE`YiE`
YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI9/YI9/YI9/YI9/
YI9/YI9/YI9/YI9/XY5ZXi9[Xi9[Xi9[Y9=/YIA]YIA]YIA]YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/
YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI=ZYI=ZYI=ZYI=Z
YI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=Z
Y99YY99YY99YY99YY99YY99YY99YY99YXHmVXY1WXi5XY99YYI=ZYI=ZY99YY99YY99YY99YY99YY99Y
Y99YY99YY99YY99YY99YY99YY99YY99YY99YY99YY99YY99YY99YY99YXi5XXi5XXY1WXY1WXHmVXHmV
Y99YY99YY99YY99YY99YY99YY99YY99YXHmVXY1WXY1WXY1WXi5XXi5XXi5XY99YYi9UYi9UYi9UYi9U
Yi9UYi9UYi9UYi9UYY5TYY5TYI1SY8mRY8mRYI1SYY5TYY5TYI1SYI1SYI1SYI1SYI1SYY5TYY5TYY5T
Y8mRYI1SYY5TYY5TYY5TYY5TYI1SY8mRY8mRY8mRYI1SYI1SYY5TYY5TYY5TYY5TY91QY91QY91QY91Q
Y91QY91QY91QY91QXXiOXXiOXXiOXhmPXhmPY91QY91QYI5RXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmP
XhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiO
XXiOXXiOXXiOXXiOY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iN
XheMXheMXheMXheMXheMXheMXheMXheMY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iNXheMY8iNY8iNY8iN
Y8iNXXaLXH]KX8YJXH]KXXaLXheMY8iNYHmOYY1PYY1PYY1PYY5NYY5NYY5NYI1MYI1MY8mLY8mLY8mL
YI1MYI1MYI1MYY5NYY5NYY5NYi9OYi9OXhiJY8mKY8mKYI1MYHmOYY1PYXmQYi1RYi9OYi9OZ9=PZIAQ
ZIAQZ9=PYi9OYi9OYHmOYHmOYHmOYHmOYHmOYHmOYHmOYHmOY8mLYI1MYi9OYi9OYI1MYI1MYY5NZ9=P
Y8mKY8mKYI1MYI1MYHmOYXmQYXmQYXmQYhmQZ95QZ95OYi9OYi5QYY5TYXmYYXe[WY=OWY9XW8meWI22
VY29V9>:UYN7UI^4W9j1VYZ2VYR6ViZ<WYbAWYn?VIj9UYb3ViV>W9Z?WifBXZ2EXj6FXZ2EXInDX9jC
XZBHY:JJYZRLZJZPZjbS[JjU[ZjX[ZjX[[6R[[6R[k:S/;>T/KBU/[FV/[FV/kJW/;:V/;:V/K>W/[BX
/kFY];JZ];JZ]KN[]K^T/[JS[k2V/;2Z/k:^];B^/kBZ/;:V/k6`][J`^;Z^][VY/[JS/KBU/kN/]kVc
^KRd^;V`]kV]]kZZ]kZZ^Kb]^[^a^kbcZK6J_L>`]k^_/K>W`kn]`;FJZiaeZYIWZY9XZI9UZI9UZI9T
Z95SZ99RZ99RYi9OZYATZI=SZ99RYi5QYi5QZ99RZI=SZYATYi5QYi5QYi5QYi5QYi5QYi5QYi5QYi5Q
YY5NYY1PYY1PYi1RZ95SZ95T002_WXB_WXB_WXB_WXB_WXB_WXB_WXB_WXB`WHR`WHR`WHR`WHR`WHR`
WHR`WHR`WHR^VhJ_W8N_W8N`WHR`WHR_W8N_W8N^VhJ]VXF]VXF]VXF]VXF]VXF]VXF]VXF]VXF/VHB/
VHB/VHB]VXF]VXF]VXF^VhJ^VhJXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXB[V8>[V8>[V8>[V8>/VHB/
VHB]VXF]VXFXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXBXVXBX
VXBXVXBXVXBXVXBXVXBXVXBXVXB/VHB/VHB/VHB/VHB/VHB/VHB/VHB/VHBZVGnZVGnZVGnZVGnZVGnZ
VGnZVGnZVGn[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VWn[VWn[VWn[VWn[VWn[VWn[VWn[VWnYV7fY
V7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fXUgbYV7fYV7fYV7fZVGjZ
VGjZVGjZVGjXUgbYV7fZVGjZVGjZVGjZVGjYV7fXUgbXV7^YVGbYVGbYVGbZVWfZVWfZVWfZVWfWUW^X
UgbYV7fYV7fYV7fYV7fXUgbWUW^XV7^XV7^XV7^XV7^XV7^XV7^XV7^XV7^ZV7^ZV7^ZV7^ZV7^ZV7^Z
V7^ZV7^ZV7^[V7f[V7fZUgbYUW^YUW^ZUgb[V7f[V7fYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgRY
UgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRYUgRXUWNXUWNXUWNXUWNXUWNX
UWNXUWNXUWNWUGJXUWNXUWNXUWNXUWNXUWNYUgRYUgRZUgBZUgBYUW>YUW>YUW>ZUgB[V7F/VGJVUW6W
Ug:WUg:XV7BXUgJWUWFWUGJVU7FWUGJTTW>RT76RT76UTgBWUGJXUWNXUWNVUW:VUW:VUW:VUW:VUW:V
UW:VUW:VUW:WU76WU76WU76WU76WU76WU76WU76WU76SU7>UUG6UUG6WUG2WUG2XUFnXUFnZUVfWUG2W
UG2WUG2WUG2WUG2WUG2WUG2WUG2VU6nVU6nVU6nVU6nVU6nVU6nVU6nVU6nVUFjVUFjVUFjVUFjVUFjV
UFjVUFjVUFjUTfjUTfjUTfjUTfjVU6nVU6nVU6nWUG2TTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfTTVfT
TVfTTVfTTVfTTVfTTVfTTVfTTVfTTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^QT6VRTFZRTFZSTV^TTfbT
TfbUU6fUU6fTTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^T
TF^TTF^TTF^TTF^TTF^TTF^TTF^TTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVTTVVT
TVVTTVVTTVVUTfZUTfZUTfZUTfZUTfZUTfZUTfZUTfZSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRPSVFQ
SfJRT6NTTVVUTfZUTfZTTVVTTVVSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRS
TFRSTFRSTFRSTFRSTFRRT6NRT6NRT6NRT6NRT6NQSfJSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRQSfJQ
SfJQSfJRT6NRT6NSTFRSTFRSTFRVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBVTV>UTF:UTF:TT66TT66U
TF:UTF:VTV>TSf:TSf:TSf:UT6>UT6>UT6>VTFBVTFBTSf:UT6>UT6>VTFBVTFBUT6>UT6>TSf:TSf:T
Sf:TSf:UT6>UT6>VTFBVTFBVTFBTT66TT66TT66TT66TT66TT66TT66TT66QSEjQSEjRSUnRSUnSSf2T
T66TT66UTF:SSf2SSf2SSf2SSf2SSf2SSf2SSf2SSf2RSUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnR
SUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnTSUjTSUjTSUjTSUjTSUjT
SUjTSUjTSUjTSUjTSUjTSUjTSUjTSUjTSUjTSUjTSUjRS5bRS5bRS5bRS5bRS5bRS5bRS5bRS5bTSUjT
SUjTSUjTSUjTSUjTSUjTSUjTSUjRS5bSSEfSSEfTSUjSSEfRS5bQRe^QRe^QRe^RS5bSSEfTSUjUSenU
SenUSenTSUjTSebTSebUT5fUT5fUT5fUT5fUT5fUT5fUT5fUT5fUT5fVTEjVTEjWTUnWTUnWTUnSSeRS
SeRTSe^TSe^TSebTSUjUSenUSV2UT5fVTEjWTUnWTUnWTUnWTUnVTEjUT5fUSenUSenUSenUSenUSenU
SenUSenUSenTSebUT5fWTUnWTUnUT5fUT5fWTUnXTf2TSe^TSe^TSebTSebUSenUSV2VSf6VSf6TT66T
T62TTUfTTUfTTUfTT62TSVBTSVFSSf2PSfBOSfZLT7BJTGfFThBFUXZEUXbBV8FCV8VEV8nFUi>FV9:E
VHfFVhJEW86IUhfKVHnMVi6PWYBRX9JRX9JRX9JRX9JPXYJRY9RUYYbXZJ2[[:>][JN^[ZR^[JV[[::/
[J>][ZB^[jF_/:J`/JNa/ZRb/jVc]:^c]:^d]Jbe]Zff]jjh^K2h^K2i^[6f_JRe^Z^d][2b/K>b/KFc
/[Be][:g^[6g/[>k^;>m_k>n`K:l`K:k_kVn`<72`/S8aLO9alO9bL?:bl7;c<;<cL?<c<K<blO9dLK>
f=;6dLo3bl_De]3Fd[ni[hfMSF:YTFNYTVFYTVFXTF>XTF>WTF6WTF6WTUnYTf>XTV:VT62USenUSenV
T62XTV:YTf>WTF6WTF6WTF6WTF6WTF6WTF6WTF6WTF6YU66XTV:VT62TSEnRRefPRE`00:nNQ:nNQ:nN
Q:nNQ:nNQ:nNQ:nNQ:nNQ;2MR;2MR;2MR;2MR;2MR;2MR;2MR;2MR:jKQZjKQZnLQk2MR;2MR:nLQjjK
QZjKQZbIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bIQ:^HPjbIQ:bIQ:bIQ:fJQJfJQJfJQJjKQZRJQ:RJQ:RJ
Q:RJQ:RJQ:RJQ:RJQ:RJQ:ZGPZZGPZ^HPj^HPjbIQ:bIQ:bIQ:bIQ:NIPjNIPjNIPjNIPjNIPjNIPjNI
PjNIPjNIPjNIPjNIPjNIPjNIPjNIPjNIPjNIPjRJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:RJQ:^HPj^HPj^H
Pj^HPj^HPj^HPj^HPj^HPj^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:ZIOjZIOjZIOjZIOjZIOjZIOjZI
OjZIOjZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJVHOJVH
OJVHOJVHOJVHOJVHOJVHOJRGO:RGO:VHOJVHOJVHOJZIOZZIOZZIOZRGO:VHOJVHOJZIOZZIOZVHOJVH
OJRGO:RHNjRHNjVIO:VIO:VIO:ZJOJZJOJZJOJNFNjRGO:RGO:VHOJVHOJRGO:RGO:NFNjRHNjRHNjRH
NjRHNjRHNjRHNjRHNjRHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNj^HOJZGO:ZGO:VFNjVFNjZGO:ZG
O:^HOJVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:VG
N:VGN:VGN:VGN:VGN:VGN:RFMjRFMjRFMjRFMjRFMjRFMjRFMjRFMjRFMjRFMjRFMjRFMjRFMjNEMZNE
MZNEMZZGM:VFLjRELZRELZRELZZGM:^HMJbIMZFEL:JFLJNGLZRHM:RGMZNFMJJDMJFCM:VGN:JDMJ>A
LZ>ALZBBLjNEMZRFMjRFMjFELJFELJFELJFELJFELJFELJFELJFELJJCL:JCL:JCL:JCL:JCL:JCL:JC
L:JCL::CLZBDL:BDL:JDKjJDKjNDKZNDKZVEK:JDKjJDKjJDKjJDKjJDKjJDKjJDKjJDKjFCKZFCKZFC
KZFCKZFCKZFCKZFCKZFCKZFDKJFDKJFDKJFDKJFDKJFDKJFDKJFDKJBBKJBBKJFCKZFCKZFCKZJDKjJD
KjJDKjBBKJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBAJjBAJjBA
JjBAJjBAJjBAJjBAJjBAJj2?J:6@JJ:AJZ:AJZ>BJjBCK:FDKJFDKJBAJjBAJjBAJjBAJjBAJjBAJjBA
JjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJjBBJJBBJJBB
JJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJBBJJFCJZFCJZFCJZFCJZFCJZFCJZFC
JZFCJZ>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ9n=I:2>IJ:@Ij>AJ:BBJJFCJZFCJZBBJJ>AJ:>AJ:>A
J:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:6?IZ6?IZ6?IZ:@Ij:@Ij:@Ij:@
Ij:@Ij>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:6?IZ6?IZ6?IZ:@Ij:@Ij:@Ij>AJ:>AJ:JAI:JAI:JA
I:JAI:JAI:JAI:JAI:JAI:JBHjFAHZB@HJB@HJB@HJB@HJFAHZJBHj>>HJ>>HJB?HZB?HZF@HjF@HjJA
I:JAI:B?HZB?HZF@HjJAI:JAI:F@HjB?HZB?HZB?HZB?HZB?HZB?HZF@HjF@HjF@HjJAI:>?H:>?H:>?
H:>?H:>?H:>?H:>?H:>?H:2<GJ2<GJ6=GZ:>Gj>?H:B@HJB@HJFAHZ:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>
Gj:>Gj6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=GZ6=
GZ6=GZ6=GZ6=GZ6=GZ6=GZ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=
GJ>=GJ:<G::<G::<G::<G::<G::<G::<G::<G:>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ2:FZ6;Fj:<
G:>=GJ>=GJ>=GJ:<G::<G:6;Fj:<G:B>GZF?GjF?GjB>GZ>=GJ:<G::=FZ>>Fj>>FjB?G:F@GJJAGZJA
GZJAGZB?FjB?FjB?FjB?FjF@G:F@G:JAGJJAGJB@FJB@FJB@FJ>>FZ>>Fj>>Fj>=GJ>=GJB?FjF@G:F@
G:JAGJJAGJF@G:F@G:B?FjB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZ:=FZB?G:JAGZF@GJB?G:B?G:F@
GJNBGj>>FZ>>FZB?G:B?G:F?GjF>H:F>H:F>H:2@HJ2BGZ2BGJ:CFj6BFZ6@GJ6?H:6>HjJ9HZB<HYn?
H9bBHiVCKYJCOYFBSIJBUhNBUXbBWI2CXY6AXhn?WI:CUiZMU:2VUIVGSI^ISifKTJ2NU::PUZBRV:FS
VJJTVZ>TVZFVW:RYWjb]Y:n_ZK6aZk>b[[>b[[^k]Kbl][fm]kjn^;no^L71^l;2_<;2_<G3`/G3`/K4
`lO5a<W7a/[8al_9b<c:bMCJamGIcMCDe=3=e/c8e<g9e=?Be][KfMSCe=ODd=OHc]_Odn3Ug=kRhmOG
iLo=hmK@fmSDf]_Hf]gLf=kNf=gLf=cJfM_IfM_Pkl37fk:le;g6hMCHj^3Ng/g3/ZVKOZVAIjVBIJRA
I:RAHjRAHjNAHJNAHJNBGjRBHZJ@H:B>GZ:<G::<G:B>GZJ@H:RBHZNAHJNAHJNAHJNAHJNAHJNAHJNA
HJNAHJVDHJRBHZNAHJB=Gj:;GIn8F`00[ij4[ij4[ij4[ij4[ij4[ij4[ij4[ij4/9f8/9f8/9f8/9f8
/9f8/9f8/9f8/9f8[Y^6[Y^6[ib7/9f8/9f8[ib7[Y^6[Y^6[9V4[9V4[9V4[9V4[9V4[9V4[9V4[9V4
ZiR3ZiR3[9V4[9V4[9V4[IZ5[IZ5[IZ5Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4ZYN2ZYN2ZiR3ZiR3
ZiR3[9V4[9V4[9V4YiV3YiV3YiV3YiV3YiV3YiV3YiV3YiV3YiV3YiV3YiV3YiV3YiV3YiV3YiV3YiV3
Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4Z9Z4ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiZ0ZiZ0ZiZ0ZiZ0
ZiZ0ZiZ0ZiZ0ZiZ0ZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUnZYUnZYUnZYUnZYUnZYUnZYUnZYUn
ZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZ9MlZ9MlZ9MlZIQm
ZIQmZIQmZYUnZYUnZ9MlZIQmZIQmZYUnZYUnZIQmZIQmZ9MlZ9QkZ9QkZ9QkZIUlZIUlZIUlZYYmZYYm
YiIkYiIkZ9MlZIQmZIQmZ9MlYiIkYiIkZ9QkZ9QkZ9QkZ9QkZ9QkZ9QkZ9QkZ9QkZYQkZYQkZYQkZYQk
ZYQkZYQkZYQkZYQkZiQmZYMlZIIkZIIkZIIkZIIkZYMlZiQmZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMj
ZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZIMhZ9IgZ9IgZ9IgZ9Ig
Z9IgZ9IgZ9IgZ9IgZIMhZIMhZ9IgZ9IgYiEfYiEfYYAeYYAeZYMdZIIcZ9EbZ9EbZ9EbZIIcZiQe[9Uf
YIE`YYIaYiMbZ9QdZ9MfYiIeYYAeYI=dZiUjZ9IgY99cXi5bYI=dYiEfZ9IgYiEfYIEaYIEaYIEaYIEa
YIEaYIEaYIEaYIEaYY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`XY=bY9A`Y9A`YYA_YYA_YiA^YiA^ZIE/
YYA_YYA_YYA_YYA_YYA_YYA_YYA_YYA_YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YIA]YIA]YIA]YIA]
YIA]YIA]YIA]YIA]Y99]Y99]Y99]YI=^YI=^YYA_YYA_YYA_Y99]Y99]Y99]Y99]Y99]Y99]Y99]Y99]
Y99]Y99]Y99]Y99]Y99]Y99]Y99]Y99]Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[X8mXX8mXXI1YXY5Z
Xi9[Y9=/YIA]YYE^Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[
Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y99YY99YY99YY99YY99YY99YY99YY99YY99YY99YY99YY99Y
Y99YY99YY99YY99YYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZYI=ZXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5X
WheTX8iUXY1WXi5XY99YYI=ZYI=ZY99YXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5X
Xi5XXi5XXi5XXi5XX8iUX8iUXHmVXHmVXY1WXY1WXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5XXi5X
X8iUXHmVXHmVXHmVXY1WXY1WXY1WXi5XYY5TYY5TYY5TYY5TYY5TYY5TYY5TYY5TYI5RYI5RY91QXhmP
XhmPY91QYI5RYI5RXhiQXhiQXhiQY8mRYI1SYI1SYY5TYY5TXhiQY8mRYI1SYI1SYI1SYI1SY8mRXhiQ
XhiQY8mRY8mRY8mRYI1SYI1SYI1SYI1SXhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPWh]LX8aMXHeNXXiO
XhmPY91QY91QYI5RXXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeN
XHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNXHeNXheMXheMXheMXheM
XheMXheMXheMXheMXheMXheMXheMXheMXheMXheMXheMXheMXXaLXXaLXXaLXXaLXXaLXXaLXXaLXXaL
XheMXheMXheMXheMXheMXheMXheMXheMWhUIX8YJXH]KXheMXheMXheMXheMXheMXXaLXheMY8iNYHmO
YHmOXheMXXaLXH]KXHaIXHaIXXeJY8mLYI1MYY5NYi9OYi9OXXeIXXeIXXeIXhiJXhiJY8mKY8mKY8mK
YI9IY91IY91IXhiJXhiJXXeJXXaLXH]KXhiJY8mKY8mKYI1LYI1LY8mKY8mKXhiJY8iNY8iNY8iNY8iN
Y8iNY8iNY8iNY8iNXHaIXXeJY8mLY8mLXXeJXXeJY8mLYI1MXhiJXhiJY8mLY8mLY8iNYHiPYHiPYHiP
Wi5QWi9NWi=MWY=IWi9JWi5LXI1OXHiQZ8MVYHUPXHmJW9=JUYATUIAhUI6@U8nNP8^VQXj/S8fcRhZa
ShZZUI>WYZBZ];>_`;jd`Kne`l6gaL>ib<JlblVocL_1c/c2cLk4cm36d]?:eMK=fMWCfm[FgMcHg]gI
emGDf=KEfMOFf]SGg=[IgM_Jg]cKgmgLfMOGf]SHfmWIg=[Jg]cLgmgMh=kNhMoOemg<f]gDf]WMe<oN
cLOJc/WHemCMhN3Rj>?Th=gIf=W?fmoDg^;Me=KN_K_AZZG5eLkMf=;Mg=SNgmgMh=kMgmgLgM_KfmSJ
_[oUQXVeN7j]Uio>^kkTemGXf]7>`k>VZI5WZ95TZ95TZ95SYi1RYi5QYi5QYY5NYi5QYHmOXheMXH]K
XH]KXheMYHmOYi5QYY1PYY1PYY1PYY1PYY1PYY1PYY1PYY1PYi9OYi5QYi5QYi1RYXmQYXmR002aWHBa
WHBaWHBaWHBaWHBaWHBaWHBaWHB^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ/Vh6/Vh6/Vh6/Vh6/Vh6/
Vh6/Vh6/Vh6^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ/VHB/VHB/VHB/VHB/VHB/VHB/VHB/VHB/Vh6/
Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6[V8>[V8>[V8>[V8>[V8>[V8>[V8>[V8>/Vh6[VX2ZVGnYV7jZVGn[
VX2]W8:^WH>[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2ZVGnZ
VGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGjZVGjZVGjZVGjZVGjZ
VGjZVGjZVGjYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7f[V7f[V7f[V7f[V7f[V7f[V7f[V7f[V7f/VWf/
VWf/VWf/VWf/VWf/VWf/VWf/VWfZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^Z
V7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^YUgZYUgZYUgZZV7^ZV7^[VGb[VGb[VGbZV7^Z
V7^ZV7^ZV7^ZV7^ZV7^ZV7^ZV7^XUWVYUgZYUgZZV7^ZV7^[VGb[VGb/VWfYUgRYUgRYUgRYUgRYUgRY
UgRYUgRYUgRUUgZUUgZWUgZWUgZYUgZ[UWZ[UWZ[UWZ[UgR[UgR[UgR[UgR[UgR[UgR[UgR[UgRZUgBZ
UgBZUgBZUgBZUgBZUgBZUgBZUgBYUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>ZUgBZUgBZUgBZUgBZUgBZ
UgBZUgBZUgBWU76WU76WU76WU76WU76WU76WU76WU76YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>VTg2W
U76WU76WU76XUG:XUG:XUG:YUW>WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76W
U76WU76WU76RUFnTU6nTU6nVU6nVU6nWU6nWU6nYTfnWU6jWU6jWU6jWU6jWU6jWU6jWU6jWU6jVTffV
TffVTffVTffVTffVTffVTffVTffUTfjUTfjUTfjUTfjUTfjUTfjUTfjUTfjUTVbUTVbUTVbUTVbUTVbU
TVbUTVbUTVbVTffVTffVTffVTffVTffVTffVTffVTffUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbTTF^T
TF^TTF^TTF^TTF^TTF^TTF^TTF^ST6ZST6ZST6ZTTF^TTF^UTVbUTVbUTVbTTF^TTF^TTF^TTF^TTF^T
TF^TTF^TTF^ST6ZST6ZST6ZST6ZST6ZST6ZST6ZST6ZSTFRTTVVTTVVUTfZUTfZTTVVTTVVSTFRUTfZT
TVVRT6NQSfJQSfJRT6NTTVVUTfZRT6NRT6NRT6NSTFRSTFRSTFRTTVVTTVVUTfZRT6NPSVFQSfJTTVVU
TfZSTFRQSfJSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRSTFRS
TFRSTFRSTFRSTFRSTFRSTFRSTFRPT6:PT6:QTF>QTF>RTVBSTfFSTfFSTfFSTfFRTVBPT6:QTF>STfFS
TfFRTVBQTF>WTVFXTfJXTfJXTfJXTfJVTFBUT6>TSf:VTFBVTFBVTFBVTFBVTFBVTFBVTFBVTFBTT66T
T66TT66TT66UTF:UTF:UTF:VTV>UTF:UTF:UTF:UTF:UTF:UTF:UTF:UTF:USV2USV2USV2USV2USV2U
SV2USV2USV2TSEnUSV2VSf6VSf6VSf6VSf6USV2TSEnTSUjUSenUSenUSenVT62VT62VT62WTF6TSEnT
SEnTSEnTSEnTSEnTSEnTSEnTSEnQSEfQSEfQSEfQSEfQSEfQSEfQSEfQSEfRS5bRS5bRS5bRS5bRS5bR
S5bRS5bRS5bSSEfSSEfSSEfSSEfSSEfSSEfSSEfSSEfRS5bRS5bSSEfSSEfSSEfTSUjTSUjTSUjRS5bR
S5bRS5bRS5bRS5bRS5bRS5bRS5bRS5bRS5bQS5VQS5VQS5RRSEVSSeRSSeRTSebSSU^RSEZPReRPReRP
ReRPReRPReRRS5bRS5bQRe^QRe^QRe^RS5bSSEfTSUjRSEZRSEZRSEZRSEZRSEZRSEZRSEZRSEZTSebS
SU^QS5VPReRPReRQS5VSSU^TSebQS5VQS5VRSEZRSEZRSEZSSU^SSU^SSU^USenTSUjSSEfRS5bRS5bS
SEfTSUjUSenRSUNRSUNRSEVRSEVRSEZRSEZRS5bRS5bUSUbUSUbUSUbUSUbUSUbUSUbUSUbUSUbSS5ZS
S5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZWT5jWT5jWT5jWT5jWT5jWT5jWT5jWT5jSS5ZTSE^USUbUSUbUSUbU
SUbTSE^SS5ZVSefVSefVSefVSefUSUbUSUbUSUbUSUbSSeRSSeRTSe^TSe^UT5fUT5fUSenUSenKRefN
ReRSSeJZTUbZU6^LS7^9OhEjLhPRF8lYCjLTA:daF;/O@K8[?;6GWMSPjMCLdKGUg/oJfMg6c=o4bnC;
dnC@fMgHg]WYcnK_g^;ZhmCKg<cGg=g>g>j`an6:Yl;2aNCBdnOLgN7Ng=CRh=KZiNCSgNSDcnBi_mb8
SKYnQ/6W/nW5eoK?g^OJh=oSh]k^f/oPf=ni`NUdQM@oDKIAG;RBVM;5bN;VgN3MeMKLeM[MgN_6coB;
XN96JL<HA:m4I[YhTLne`moJg]oUhn;IfNVh_^VIXn=1K/DhI;l`F;PkGKMUNl:KYlo5aloGe<JQU7jJ
S6nMRF2XSef_Tef]SejYSV:YSVVZTf>YTV:WT62USUjTSEfUSUjVSenWT62XTF6XTF6XTF6XTF6XTF6X
TF6XTF6XTF6WT62WT62XTF6YTV:YTV:XTF400;6MQ;6MQ;6MQ;6MQ;6MQ;6MQ;6MQ;6MQ:jKQZjKQZjK
QZjKQZjKQZjKQZjKQZjKQZbKPJbKPJbKPJbKPJbKPJbKPJbKPJbKPJfJQJfJQJfJQJfJQJfJQJfJQJfJ
QJfJQJbIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bKPJbKPJbKPJbKPJbKPJbKPJbKPJbKPJ^HPj^HPj^H
Pj^HPj^HPj^HPj^HPj^HPjbKPJ^JP:ZIOjVHOZZIOj^JP:fLPZjMPj^JP:^JP:^JP:^JP:^JP:^JP:^J
P:^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:ZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZI
OjZIOjZIOjZIOjZIOjZIOjZIOZZIOZZIOZZIOZZIOZZIOZZIOZZIOZVHOJVHOJVHOJVHOJVHOJVHOJVH
OJVHOJ^HOJ^HOJ^HOJ^HOJ^HOJ^HOJ^HOJ^HOJ^IO:^IO:^IO:^IO:^IO:^IO:^IO:^IO:ZHNjZHNjZH
NjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjZH
NjZHNjVGNZVGNZVGNZZHNjZHNjZHNj^IO:^IO:ZHNjZHNjZHNjZHNjZHNjZHNjZHNjZHNjVGNZVGNZVG
NZZHNjZHNjZHNjZHNjZHNjVGN:VGN:VGN:VGN:VGN:VGN:VGN:VGN:FGNZFGNZNGNZNGNZVGNZ^FNZ^F
NZ^FNZ^GN:^GN:^GN:^GN:^GN:^GN:^GN:^GN:ZGM:ZGM:ZGM:ZGM:ZGM:ZGM:ZGM:ZGM:VFLjVFLjVF
LjVFLjVFLjVFLjVFLjVFLjZGM:ZGM:ZGM:ZGM:ZGM:ZGM:ZGM:ZGM:NDLJNDLJNDLJNDLJNDLJNDLJND
LJNDLJRELZRELZRELZRELZRELZRELZRELZRELZJCL:JCL:NDLJNDLJNDLJRELZRELZRELZNDLJNDLJND
LJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJ:EKjBDKjBDKjJDKjJDKjNDKjND
KjVCKjNDKZNDKZNDKZNDKZNDKZNDKZNDKZNDKZJCKJJCKJJCKJJCKJJCKJJCKJJCKJJCKJFCKZFCKZFC
KZFCKZFCKZFCKZFCKZFCKZFBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:JCKJJCKJJCKJJCKJJCKJJCKJJC
KJJCKJFBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:BAJjBAJjBAJjBAJjBAJjBAJjBAJjBAJj>@JZ>@JZ>@
JZBAJjBAJjBAJjFBK:FBK::?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@
JZ>@JZ>AJ:>AJ:BBJJFCJZFCJZBBJJ>AJ:>AJ:>AJ:>AJ::@Ij6?IZ6?IZ:@IjBBJJFCJZ:@Ij:@Ij:@
Ij:@Ij>AJ:>AJ:BBJJBBJJFCJZ:@Ij2>IJ6?IZBBJJFCJZ>AJ:6?IZ>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>A
J:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:>AJ:6AHj6AHj6A
Hj6AHj:BI::BI::BI::BI::BI:6AHin?HJ2@HZ:BI::BI:6AHj2@HZF@HjF@HjJAI:JAI:JAI:F@HjB?
HZB?HZF@HjF@HjF@HjF@HjF@HjF@HjF@HjF@Hj>?H:B@HJB@HJB@HJFAHZFAHZFAHZFAHZB@HJB@HJB@
HJB@HJB@HJB@HJB@HJB@HJF>H:F>H:F>H:F>H:F>H:F>H:F>H:F>H:B=GjF>H:J?HJJ?HJJ?HJJ?HJF>
H:B=GjB>GZB>GZF?GjF?GjF?GjJ@H:J@H:J@H:B=GjB=GjB=GjB=GjB=GjB=GjB=GjB=Gj6=GJ6=GJ6=
GJ6=GJ6=GJ6=GJ6=GJ6=GJB>GZB>GZB>GZB>GZB>GZB>GZB>GZB>GZ>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=
GJ>=GJ:<G::<G::<G:>=GJ>=GJB>GZB>GZB>GZ:<G::<G::<G::<G::<G::<G::<G::<G:>=GJ:<G::=
FZ6<FJ6<F:6<F::>Ej:>Ej>>Fj:=FZ6<FJ2;F:2;F:2;F:2;F:2;F::<G:6;Fj6;Fj6;Fj6;Fj:<G:>=
GJB>GZ:=FZ:=FZ:=FZ:=FZ:=FZ:=FZ:=FZ:=FZ>>Fj>>Fj6<FJ2;F:2;F:6<FJ>>Fj>>Fj6<FJ6<FJ6<
FJ:=FZ:=FZ:=FZ>>Fj>>FjB>GZB>GZ:<G:6;Fj6;Fj:<G:B>GZB>GZ:>Ej:>Ej:=FJ:=FJ:=FZ:=FZ:<
G::<G:F>G:F>G:F>G:F>G:F>G:F>G:F>G:F>G:><FZ><FZ><FZ><FZ><FZ><FZ><FZ><FZF>G:F>G:F>
G:F>G:F>G:F>G:F>G:F>G:><FZB=FjB=FjF>G:F>G:B=FjB=Fj><FZF>G:F>G:F>G:F>G:F>G:F>G:F>
G:F>G:>?F:>?F:B?FjB?FjB?G:F@GJF?GjF?Gj2@HZ6>Fj:>EJN?FJRAI:6=M9:3P8IkQDMSX3A5YQ@W
VQ<eYPX^ZQle/hN@dloJb^k[kMGIk:nlj6j4aCiGWF5f/jNgh/K?l>GKimOCd];HcM?OhKW7i7fAbdUS
[c9CXfQk^9>Rd<;=hmgQi^;Ti=WKiKo6gjRaeTAS[S9>YBe6Y45GZG66^KW4f^?Qin7Ff>?Rk;FnfF1h
/RM9YbI7_2i9]dIJZ6n0/K:`_=KDh=kNk:jdbfemYdMRYCIL^RaJaSE<^DaN/GEm[:VY]mGBe=GFh:6W
a6IaWCEE[SaK^41M_d=J]U5PZGEkZ:ZY^MC=b[2UTJFGNj6@JJRBHZbDGZN?FjJ?Gj^CJJbEIJZCHjN@
H:F>GZF>GZJ?GjRAHJVBHZN@H:N@H:N@H:N@H:N@H:N@H:N@H:N@H:F>GZJ?GjJ?GjN@H:N@H:J?G`00
/9b3/9b3/9b3/9b3/9b3/9b3/9b3/9b3[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[9^1[9^1[9^1[9^1
[9^1[9^1[9^1[9^1[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[IZ5[9V4[9V4[9V4[9V4[9V4[9V4[9V4[9V4
[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9^1ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiZ0ZYUoZYUoZYUo
ZYUoZiZ0[9^1[Ib2ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0
ZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUnZYUnZYUnZYUn
ZYUnZYUnZYUnZYUnZIQmZIQmZIQmZIQmZIQmZIQmZIQmZIQmZiQmZiQmZiQmZiQmZiQmZiQmZiQmZiQm
ZYQkZYQkZYQkZYQkZYQkZYQkZYQkZYQkZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMj
ZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZ9IiZIMjZIMjZIMjZYQkZYQkZYQkZYQk
ZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjZYQkZYQkZYQkZYQkZIMjZIMjZIMjZIMjZ9IgZ9IgZ9IgZ9Ig
Z9IgZ9IgZ9IgZ9IgY9IiY9IiYYIiYYIiZ9IiZYEiZYEiZYEiZYMfZYMfZYMfZYMfZYMfZYMfZYMfZYMf
ZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIc
ZIIcZIIcZIIcZIIcYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9Eb
YY=`YY=`YY=`YiAaYiAaZ9EbZ9EbZ9EbYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAa
YiAaYiAaYiAaYiAaXYE_Y9A_Y9A_YYA_YYA_YiA_YiA_ZI=_YiA^YiA^YiA^YiA^YiA^YiA^YiA^YiA^
YY=]YY=]YY=]YY=]YY=]YY=]YY=]YY=]YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI=^YI9/YI9/YI9/YI9/
YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/
Xi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXXmYXi1ZXi1ZXi1ZY95[Y95[Y95[Y95[XHiXXHiXXHiXXHiX
XHiXXHiXXHiXXHiXXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXY1WXi5XY99YY99YY99YY99YXi5XXY1W
XY1WXHmVXHmVXHmVXY1WXi5XY99YYI=ZXHmVXHmVXY1WXY1WXi5XXi5XXi5XXi5XY99YXY1WXHmVXHmV
Xi5XY99YXi5XXHmVXY1WXY1WXY1WXY1WXY1WXY1WXY1WXY1WXY5VXY5VXY5VXY5VXY5VXY5VXY5VXY5V
XY1WXY1WXY1WXY1WXY1WXY1WXY1WXY1WXY9TXY9TXY9TXI5SXI5SXI5SXI5SXI5SXI5SWhmQWXiPWhmQ
X91RXI5SX91RWXiPXXePXhiQY8mRYI1SYI1SYI1SY8mRXhiQYI1SYI1SYI1SYI1SYI1SYI1SYI1SYI1S
XhmPXhmPXhmPY91QY91QYI5RYI5RYI5RY91QY91QY91QY91QY91QY91QY91QY91QYHiPYHiPYHiPYHiP
YHiPYHiPYHiPYHiPY8eOYHiPYHiPYXmQYXmQYHiPYHiPY8eOY8iNY8iNY8iNYHmOYHmOYY1PYY1PYY1P
Y8eOY8eOY8eOY8eOY8eOY8eOY8eOY8eOXHeMXHeMXHeMXHeMXHeMXHeMXHeMXHeMY8iNY8iNY8iNY8iN
Y8iNY8iNY8iNY8iNXheMXheMXheMXheMXheMXheMXheMXheMXXaLXXaLXXaLXXaLXheMXheMY8iNY8iN
XXaLXXaLXXaLXXaLXXaLXXaLXXaLXXaLXheMXheMXhiKXXeJXHaHXHaHX8aEX8aEXXeJXXeJXHaIX8]H
WhYGWhYGX8]HX8]HXXeJXHaIXHaIX8]HXHaIXXeJXhiKY8mLXXeJXXeJXXeJXXeJXXeJXXeJXXeJXXeJ
XhiKXXeJXHaIXHaIXHaIXHaIXXeJXhiKXHaIXHaIXHaIXHaIXXeJXXeJXXeJXhiKXhiKXhiKXXeJXHaI
XHaIXXeJXhiKXhiKXXiGXXiGXXeIXXeIXXeJXXeJXXaLXXaLY8eKY8eKY8eKY8eKY8eKY8eKY8eKY8eK
XhaJXhaJXhaJXhaJXhaJXhaJXhaJXhaJXheIXheIXheIXheIXheIXheIXheIXheIXhaJXhaJY8eKYHiL
YHiLY8eKXhaJXhaJY8eKY8eKY8eKY8eKY8eKY8eKY8eKY8eKXhmHXhmHXhiJY8mKY8mLY8mLYHmOYHmO
XiAVXI1MXXeFYXeEZ8iOYXe[WhYeV8IkOGRUGEBZ:2bL3RbM026U42NbM87@b=GC/kSGTZ;G?E^b0BZN
23:]5c^W>4nULgo5^;bmd=[De>;PY[W>HgRf;dR^5SJe33:h43JD?U^UP9:k^/7BeM_R`L_LPIFhAV6C
03NZ54C19Dg;9TJ_?EBHRI:ce<gJkmgT[K_GGGNO<eRL:5Bi5Cjl8DBl?Ebi?5VNYj^nbLgPd]S[Y:o;
JWZX@enP;E6Y7dV^:SR^C5JdOh6k/k36fMKHgmkP`<C?W:>gEF>e@U6W>dVQCe^]LGVlUYO3^KG8d/_>
`[RV[J:7W8iZVHUJUXA?SWY3SgY6UH5A[IIVZiATYi1PYHiNY8eMYXmOZI9RZiATYi1PYi1PYi1PYi1P
Yi1PYi1PYi1PYi1PY8eMYHiNYHiNYXmOYXmOYHiN002`W8>`W8>`W8>`W8>`W8>`W8>`W8>`W8>^VhJ^
VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6]VXF]VXF]VXF]VXF]VXF]
VXF]VXF]VXF/VHB/VHB/VHB/VHB/VHB/VHB/VHB/VHB/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6ZUh:Z
Uh:ZUh:ZUh:ZUh:ZUh:ZUh:ZUh:ZVGnZVGnZVGnZVGnZVGn[VX2[VX2/Vh6ZVGnZVGnZVGnZVGnZVGnZ
VGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jY
V7jYV7jYV7jYV7jYV7jYV7jYV7jYV7fYV7fYV7fYV7fYV7fYV7fYV7fYV7fXUgbXUgbXUgbXUgbXUgbX
UgbXUgbXUgbZUgbZUgbZUgbZUgbZUgbZUgbZUgbZUgbYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZY
UgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZY
UgZYUgZYUgZXUWVXUWVXUWVYUgZYUgZZV7^ZV7^ZV7^YUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZ[VGbZ
V7^ZV7^YUgZYUgZXUWVXUWVWUGRXUWNXUWNXUWNXUWNXUWNXUWNXUWNXUWNTUWVTUWVVUWVVUWVXUWVZ
UGVZUGVZUGVZUgJZUgJZUgJZUgJZUgJZUgJZUgJZUgJYUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>Y
UW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>WU76WU76WU76WU76WU76W
U76WU76WU76XUG:XUG:XUG:XUG:XUG:XUG:XUG:XUG:UTVnVTg2VTg2VTg2WU76WU76WU76XUG:WU76W
U76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76QU6jSTfjSTfjUTfjUTfjV
TfjVTfjXTVjVTffVTffVTffVTffVTffVTffVTffVTffUTVbUTVbUTVbUTVbUTVbUTVbUTVbUTVbTTVfT
TVfTTVfTTVfTTVfTTVfTTVfTTVfTTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^T
TF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^ST6ZST6ZST6ZST6ZST6ZST6ZST6ZST6ZRSfVR
SfVRSfVST6ZST6ZTTF^TTF^TTF^QSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRRSfVRSfVRSfVRSfVRSfVR
SfVRSfVRSfVRT6NSTFRSTFRTTVVTTVVSTFRSTFRRT6NPSVFPSVFQSfJQSfJRT6NSTFRTTVVTTVVQSfJQ
SfJQSfJRT6NRT6NRT6NSTFRSTFRRT6NRT6NQSfJRT6NRT6NRT6NRT6NQSfJRT6NRT6NRT6NRT6NRT6NR
T6NRT6NRT6NRTFJRTFJRTFJRTFJRTFJRTFJRTFJRTFJRT6NRT6NRT6NRT6NRT6NRT6NRT6NRT6NRTVBR
TVBRTVBQTF>PT6:PT6:OSf6OSf6PT6:NSV2MSEnMSEnOSf6PT6:OSf6MSEnQS5nRSF2SSV6UT6>UT6>U
T6>UT6>UT6>TSf:TSf:TSf:TSf:TSf:TSf:TSf:TSf:SSf2SSf2SSf2SSf2TT66TT66UTF:UTF:TT66T
T66TT66TT66TT66TT66TT66TT66USV2USV2USV2USV2USV2USV2USV2USV2TSEnTSEnUSV2USV2USV2U
SV2TSEnTSEnSSEfTSUjTSUjTSUjUSenUSenUSenVT62SS5jSS5jSS5jSS5jSS5jSS5jSS5jSS5jPS5bP
S5bPS5bPS5bPS5bPS5bPS5bPS5bQRe^QRe^QRe^QRe^QRe^QRe^QRe^QRe^RS5bRS5bRS5bRS5bRS5bR
S5bRS5bRS5bQRe^QRe^RS5bRS5bRS5bSSEfSSEfSSEfQRe^QRe^QRe^QRe^QRe^QRe^QRe^QRe^SSEfS
SEfSSU^RSEZQS5RPReNOReBNRU>QS5VQS5VPReRORUNORUNORUNPReRQS5VQS5VQS5VPReRPReRPReRQ
S5VRSEZSSU^QS5VQS5VQS5VQS5VQS5VQS5VQS5VQS5VQS5VQS5VQS5VQS5VQS5VQS5VQS5VQS5VPReRP
ReRQS5VQS5VQS5VRSEZRSEZRSEZRSEZQS5VQS5VQS5VQS5VQS5VQS5VRSEZQSEJQSEJQS5RQS5RQS5VQ
S5VQRe^QRe^SS5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZRReVRReVRReVRReVRReVRReVRReVRReVSSEVS
SEVSSEVSSEVSSEVSSEVSSEVSSEVRReVSS5ZTSE^TSE^TSE^TSE^SS5ZRReVSS5ZSS5ZSS5ZSS5ZTSE^T
SE^TSE^TSE^RSUNRSUNSSUZSSUZTSebTSebTSUjTSUjRU6BRTF2SSEVWSEN/SebZT6:XSVVVSFfNR8:=
MYaQGJ@aBZ06:Z098:]XLL_?enRa^MM8G9DA=iL:?;X0:[89<JPgCJa6DI^WYjg;dM3:e]Z:V[M2E9/M
=:4A<K<9;[PA?J8oGZf2T[g2aMCQh^K;e>6:XL5?L9hNE;T2<Id7;Y/kF;=hS/Rc_]WIf>;Uf>2ncN2b
b>A^Sl0gFjT`D;@]AZa?IK>M/N_=cM_:b]K<cmg=dnJd`N65VLUFL;8lFjIQLLB>V][2b>gNgnWTi=kS
h=_Mgn3Hf^B]/^V1QKmXKZV7S<>k_^[Gf?;LfN;Ie];CbkZh/9VPUgJHSfBHSE^IReJPT5^ZVFJ/UFFY
TV:VSenSS5bSS5bUSUjYTV:[U6BWT62WT62WT62WT62WT62WT62WT62WT62USUjUSUjVSenWT62WT62V
Sel00:nKPZnKPZnKPZnKPZnKPZnKPZnKPZnKPZjKQZjKQZjKQZjKQZjKQZjKQZjKQZjKQZbKPJbKPJbK
PJbKPJbKPJbKPJbKPJbKPJbIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bIQ:bIQ:^HPj^HPj^HPj^HPj^HPj^HPj^H
Pj^HPj^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:ZGPZZGPZZGPZZGPZZGPZZGPZZGPZZGPZRGOJVHOZVH
OZZIOjZIOj^JP:^JP:^JP:ZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZIOjZI
OjZIOjVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOJVHOJVH
OJVHOJVHOJVHOJVHOJVHOJRGO:RGO:RGO:RGO:RGO:RGO:RGO:RGO:ZGO:ZGO:ZGO:ZGO:ZGO:ZGO:ZG
O:ZGO:RFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVG
NZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZNEN:RFNJRFNJRFNJVGNZVGNZVG
NZZHNjVGNZVGNZVGNZVGNZVGNZVGNZVGNZVGNZZHNjZHNjVGNZVGNZRFNJRFNJNEN:NEN:NEMZNEMZNE
MZNEMZNEMZNEMZNEMZNEMZ>EN:>EN:FEN:FEN:NEN:VDN:VDN:VDN:VFLjVFLjVFLjVFLjVFLjVFLjVF
LjVFLjRELZRELZRELZRELZRELZRELZRELZRELZVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjRELZRELZRE
LZRELZRELZRELZRELZRELZNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJND
LJNDLJFBKjFBKjFBKjJCL:JCL:NDLJNDLJNDLJJCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JC
L:JCL:JCL:JCL:JCL:JCL:6DKZ>CKZ>CKZFCKZFCKZJCKZJCKZRBKZJCKJJCKJJCKJJCKJJCKJJCKJJC
KJJCKJFBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:BBKJBBKJBBKJBBKJBBKJBBKJBBKJBBKJBAJjBAJjBA
JjBAJjBAJjBAJjBAJjBAJj>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZBAJjBAJjBAJjBAJjBAJjBAJjBA
JjBAJj>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ6>J::?JJ:?JJ:?JJ>@JZ>@JZ>@JZBAJj:?JJ:?JJ:?
JJ:?JJ:?JJ:?JJ:?JJ:?JJ6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J::@Ij:@Ij>AJ:>AJ:>AJ:>AJ::@
Ij:@Ij2>IJ2>IJ6?IZ6?IZ:@Ij:@Ij:@Ij:@Ij2>IJ2>IJ6?IZ6?IZ:@Ij:@Ij:@Ij:@Ij6?IZ6?IZ:@
Ij:@Ij6?IZ6?IZ6?IZ:@Ij6?IZ6?IZ6?IZ6?IZ6?IZ6?IZ6?IZ6?IZ6AHj6AHj6AHj6AHj6AHj6AHj6A
Hj6AHj6?IZ6?IZ6?IZ6?IZ6?IZ6?IZ6?IZ6?IZ:BI::BI:6AHj6AHj2@HYn?HIn?HIn?HIn?HIj>H9b<
GYf=Gin?HIn?HIj>H9b<GZ:=H:>>HJF@HjJAI:JAI:JAI:JAI:JAI:>>HJ>>HJ>>HJ>>HJ>>HJ>>HJ>>
HJ>>HJ:>Gj:>Gj>?H:>?H:>?H:B@HJB@HJB@HJ>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:B=GjB=GjB=
GjB=GjB=GjB=GjB=GjB=Gj><GZB=GjB=GjF>H:F>H:B=GjB=Gj><GZ>=GJ>=GJ>=GJB>GZB>GZF?GjF?
GjF?Gj><GZ><GZ><GZ><GZ><GZ><GZ><GZ><GZ2<G:2<G:2<G:2<G:2<G:2<G:2<G:2<G:6;Fj6;Fj6;
Fj6;Fj6;Fj6;Fj6;Fj6;Fj:<G::<G::<G::<G::<G::<G::<G::<G:6;Fj6;Fj6;Fj:<G::<G::<G:>=
GJ>=GJ6;Fj6;Fj6;Fj6;Fj6;Fj6;Fj6;Fj6;Fj:<G::<G:>>Fj:=FZ6<F:2;Eij:Dif9DZ2;F:2;F9n:
Eij9EYn:Ein:Ej2;F:6<FJ6<F:2;Ej2;Ein:EZ2;Ej6<F::=FJ>>FZ6<FJ6<FJ6<FJ6<FJ6<FJ6<FJ6<
FJ6<FJ2;F:2;F:6<FJ6<FJ6<FJ6<FJ2;F:2;F:2;F:2;F:2;F:2;F:6<FJ6<FJ:=FZ:=FZ2;Ej2;Ej6<
F:6<F:6<F:6<F:2;Ej2;Ej6=EZ6=EZ6<F:6<F:6<FJ6<FJ6;Fj6;Fj><FZ><FZ><FZ><FZ><FZ><FZ><
FZ><FZ:;FJ:;FJ:;FJ:;FJ:;FJ:;FJ:;FJ:;FJ>>Ej>>Ej>>Ej>>Ej>>Ej>>Ej>>Ej>>Ej:;FJ:;FJ><
FZB=FjB=Fj><FZ:;FJ:;FJ6:F:6:F::;FJ:;FJ><FZ><FZB=FjB=Fj:>Ej:>Ej:=FJ>>FZ>>Fj>>FjB>
GZB>GYj?GZ:?G:F?FjR@G:bAGZbAGjV@GZR>Gj>@C::<Lhb4SUaaT2i<VB<dZFMX`/k?jL;8cJ>cd4e]
[a<mWAU2ZBE3W5ETXjb_g>[Nl=gEgmCDf/_?ijVaiVmobd5J/2e>Y55a_HJJe<O;j>_TincTgM[Jf/CA
gkO>j7nLb51ZX59UXXbMc[o@jmKVkMoVjMcOhn[[jM?KflkKjJFcef=/YG9f/;Jhh<oBinORhN;Mf^CQ
gN[Zj^;UkLG<h:NbdYNSbjo4fKg?f/WGeLcEb<W<_<?3]kRf]K:^/jjbaI:FZH>7VY6EYj6V[j:TY9jP
U9nQS/G1[jbWTXj:KH9nFhR2EiB:Fi^=GIb<GJVBHZN@H:B=GJ:;Fj:;FjB=GJN@H:VBHZJ?GjJ?GjJ?
GjJ?GjJ?GjJ?GjJ?GjJ?GjJ?GjN@H:RAHJRAHJRAHJRAH@00[i^2[i^2[i^2[i^2[i^2[i^2[i^2[i^2
[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[Y^6[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9V4[9V4[9V4[9V4
[9V4[9V4[9V4[9V4ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiR3ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0
ZIJ1ZIJ1ZIJ1ZIJ1ZIJ1ZIJ1ZIJ1ZIJ1YiIlZ9MmZIQnZYUoZiZ0ZYUoZYUoZIQnZIQnZIQnZIQnZIQn
ZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9Mm
Z9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MlZ9MlZ9MlZ9MlZ9MlZ9MlZ9MlZ9MlYiIkYiIkYiIkYiIk
YiIkYiIkYiIkYiIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMj
Z9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9Ii
Z9IiZ9IiZ9IiZ9IiYiEhYiEhYiEhZ9IiZ9IiZIMjZIMjZIMjZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9Ii
ZIMjZIMjZ9IiZ9IiZ9IiZ9IiZ9IiYiEhYiEfYiEfYiEfYiEfYiEfYiEfYiEfYiEfXiEhXiEhYIEhYIEh
YiEhZIAhZIAhZIAhZIMbZIMbZIMbZIMbZIMbZIMbZIMbZIMbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9Eb
ZIIcZIIcZIIcZIIcZIIcZIIcZIIcZIIcZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbYiAaYiAaYiAaYiAa
YiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYI9_YI9_YI9_YI9_YY=`YY=`YY=`YiAa
YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`X9=]XY9]XY9]Y99]
Y99]YI9]YI9]Yi5]YI9/YI9/YI9/YI9/YI9/YI9/YI9/YI9/Y95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[
Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/Xi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1Z
Xi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXi1ZXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmY
XHiXXHiXXHiXXXmYXXmYXi1ZXi1ZXi1ZXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXHiXXHiXXHiXXHiX
XHiXXHiXXHiXXHiXXHmVXY1WXY1WXi5XXi5XXY1WXY1WXHmVX8iUXHmVXY1WXY1WXY1WXHmVX8iUX8iU
X8iUX8iUX8iUXHmVXHmVXY1WXY1WXY1WX8iUXHmVXY1WXY1WX8iUWheTXHmVXY1WXHmVXHmVXHmVXHmV
XHmVXHmVXHmVXHmVXI5RXI5RXI5RXI5RXI5RXI5RXI5RXI5RXHmVXHmVXHmVXHmVXHmVXHmVXHmVXHmV
X91RX91RX91RX91RX91RWhmQWhmQWhmQWhmQWXiPWHeOWHeOWhmQX91RWXiPWHeOY8mRY8mRYI1SYY5T
YY5TYY5TYI1SYI1SXXePXXePXXePXXePXXePXXePXXePXXePXXiOXXiOXXiOXXiOXhmPXhmPY91QY91Q
XhmPXhmPXhmPXhmPXhmPXhmPXhmPXhmPY8eOY8eOY8eOY8eOY8eOY8eOY8eOY8eOXhaNXhaNY8eOYHiP
YHiPY8eOXhaNXhaNXheMXheMXheMXheMY8iNY8iNY8iNYHmOXX]MXX]MXX]MXX]MXX]MXX]MXX]MXX]M
Wh]KWh]KWh]KWh]KWh]KWh]KWh]KWh]KXheMXheMXheMXheMXheMXheMXheMXheMXH]KXH]KXH]KXH]K
XH]KXH]KXH]KXH]KX8YJX8YJXH]KXH]KXXaLXXaLXXaLXXaLX8YJX8YJX8YJX8YJX8YJX8YJX8YJX8YJ
X8YJXH]KXXeJXhiKXXeIX8]GWXYCW8QAWhYGWhYGWXUFWXUFWXUFWhYGX8]HXHaIX8]GX8]GWhYFWhYF
WhYFX8]GXHaHXXeIX8]HX8]HX8]HX8]HX8]HX8]HX8]HX8]HWhYGX8]HXHaIXHaIXHaIXHaIX8]HWhYG
WhYGWhYGX8]HX8]HX8]HXHaIXHaIXHaIWXUEWhYFX8]GXHaHXHaHX8]GWhYFWXUEX8aEX8aEX8]GX8]G
X8]HX8]HX8YJX8YJXX]IXX]IXX]IXX]IXX]IXX]IXX]IXX]IXHYHXHYHXHYHXHYHXHYHXHYHXHYHXHYH
XhmFXhmFXhmFXhmFXhmFXhmFXhmFXhmFXHYHXX]IXhaJXhaJXhaJXhaJXX]IXHYHX8UGX8UGX8UGXHYH
XX]IXhaJXhaJY8eKXHeFXXiGXXeIXXeIXhiKXhiKXheMXheMWXaGX8eJYHmOZ95QZ95QYi5MYI1IXhmF
XILiXY1EVi1ZOXQaK7^EH66aNW>fcl_GiNGCdMWI^L[UOiG5D6FLOHfhb/oXf]WSgm3Ug]?MgMOHgm_Q
emG[^/7RUJC5MhjX/KgQb/oXi>7Zk^CMi]g@gMS?f]oMg^W]e]kGcM7Fd]CVem[Xc=KFbMO<cM[Bc=OE
d/ZilnoLinSHd];BfmKUe<[Kb;g0f=33_KFXa/2cal:c^[ZZ_;^a^kbhY:FYPX>=O8ehNh]cMXEZLWiR
KWIOJfiOIfMQIV9QEUiDC5A:C597E5]>F5e>E5Q5E5M1FEa3>cTW=C@P;RhF>C/NI693TheZYYQdWHeY
YHiNY8eMXhaLXX]KXhaLY8eMYXmOYi1PYXmOYXmOYXmOYXmOYXmOYXmOYXmOYXmOYi1PYi1PZ95QZI9R
ZI9RZ95Q002^VX6^VX6^VX6^VX6^VX6^VX6^VX6^VX6^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ^VhJ/Vh6/
Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6[V8>[V8>[V8>[V8>[V8>[V8>[V8>[V8>ZUh:ZUh:ZUh:ZUh:ZUh:Z
Uh:ZUh:ZUh:ZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnYUX6YUX6YUX6YUX6YUX6YUX6YUX6YUX6WUWbX
UgfYV7jZVGn[VX2ZVGnYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jY
V7jYV7jYV7jXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgbX
UgbXUgbXUgbXUgbXUgbXUgbXUgbWUW^WUW^WUW^WUW^WUW^WUW^WUW^WUW^YUW^YUW^YUW^YUW^YUW^Y
UW^YUW^YUW^YUgZYUgZYUgZYUgZYUgZYUgZYUgZYUgZXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVX
UWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVWUGRWUGRWUGRXUWVXUWVX
UWVYUgZYUgZXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVWUGRWUGRWUGRXUWVXUWVXUWVXUWVXUWVWUGJW
UGJWUGJWUGJWUGJWUGJWUGJWUGJSUGRSUGRUUGRUUGRWUGRYU7RYU7RYU7RYUg:YUg:YUg:YUg:YUg:Y
Ug:YUg:YUg:WU76WU76WU76WU76WU76WU76WU76WU76YUW>YUW>YUW>YUW>YUW>YUW>YUW>YUW>WU76W
U76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76VTg2VTg2VTg2VTg2VTg2V
Tg2VTg2VTg2TTFjTTFjUTVnUTVnUTVnVTg2VTg2VTg2UTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnU
TVnUTVnUTVnUTVnUTVnUTVnUTVnPTffRTVfRTVfTTVfTTVfUTVfUTVfWTFfUTVbUTVbUTVbUTVbUTVbU
TVbUTVbUTVbTTF^TTF^TTF^TTF^TTF^TTF^TTF^TTF^STFbSTFbSTFbSTFbSTFbSTFbSTFbSTFbST6ZS
T6ZST6ZST6ZST6ZST6ZST6ZST6ZRSfVRSfVRSfVRSfVRSfVRSfVRSfVRSfVST6ZST6ZST6ZST6ZST6ZS
T6ZST6ZST6ZRSfVRSfVRSfVRSfVRSfVRSfVRSfVRSfVQSVRQSVRQSVRRSfVRSfVRSfVST6ZST6ZQSVRQ
SVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSVRQSfJQSfJRT6NSTFRSTFRR
T6NQSfJQSfJQSfJRT6NRT6NSTFRRT6NPSVFNS6>MRf:PSVFPSVFPSVFPSVFQSfJQSfJQSfJRT6NOSFBQ
SfJSTFRRT6NOSFBNS6>PSVFSTFRQSfJQSfJQSfJQSfJQSfJQSfJQSfJQSfJQTF:QTF:QTF:QTF:QTF:Q
TF:QTF:QTF:QSfJQSfJQSfJQSfJQSfJQSfJQSfJQSfJOSf6OSf6OSf6OSf6PT6:PT6:PT6:PT6:PT6:O
Sf6MSEnNSV2PT6:PT6:OSf6NSV2SSV6TSf:UT6>UT6>UT6>TSf:SSV6RSF2QS5nQS5nQS5nQS5nQS5nQ
S5nQS5nQS5nQSEjQSEjRSUnRSUnSSf2SSf2SSf2SSf2RSUnRSUnRSUnRSUnRSUnRSUnRSUnRSUnSS5jS
S5jSS5jSS5jSS5jSS5jSS5jSS5jRRefSS5jTSEnTSEnTSEnTSEnSS5jRRefRS5bRS5bSSEfSSEfSSEfT
SUjTSUjTSUjRRefRRefRRefRRefRRefRRefRRefRRefORe^ORe^ORe^ORe^ORe^ORe^ORe^ORe^RS5bR
S5bRS5bRS5bRS5bRS5bRS5bRS5bQRe^QRe^QRe^QRe^QRe^QRe^QRe^QRe^PRUZPRUZPRUZQRe^QRe^R
S5bRS5bRS5bPRUZPRUZPRUZPRUZPRUZPRUZPRUZPRUZNR5ROREVQS5VRSEZRSEVQS5RNRU>MRE:NREJN
REJNREJMR5FNREJORUNPReRQS5VPS5FOReBOReBOReBOReBPS5FQSEJRSUNPReRPReRPReRPReRPReRP
ReRPReRPReRNREJORUNPReRQS5VQS5VPReRORUNNREJORUNORUNORUNPReRPReRPReRQS5VQS5VMRE:N
RU>OReBPS5FPS5FOReBNRU>MRE:PS5FPS5FPReNPReNPReRPReRPRUZPRUZQRURQRURQRURQRURQRURQ
RURQRURQRURQRURQRURQRURQRURQRURQRURQRURQRURQSEBQSEBQSEBQSEBQSEBQSEBQSEBQSEBQRURR
ReVRReVSS5ZSS5ZRReVRReVQRURNQeFOR5JPRENPRENQRURRReVSS5ZSS5ZQSEJQSEJRSEVRSEVRSEZS
SU^SSEfSSEfOS5>QS5RRSUnSSV6QSV6PSejPSeNPT5FJUE2NRUZUT5fIT5NIUH><P:B?P9oHdL3Ddko_
k^COh>C3`m?:c=kHf>CKfMWQgmO;b]CUi^C^k^;If<kDdM?ThncUj^_Ag]KOgMcHeM7AcLS@c<OCd<SB
d<S<cL?8bKoBeLK2`;nl^;jl^;fm`;O5c;fmaKZUZZRg]J^KW8bGVHFDUXZ7Ph::Q8FARgioOVB6QWR>
SX2;SWj3RGJ9Sgj=THEfMfeBDTa9BcE>DC]BF45@Ed9:Dci<DSmDFTUOHU=GH4aCG4MFG4EQI4i_LE]j
NFAjNFEhMVBCU82EUh>:SgZ7S7NZZIG@bKG6^::PSWNSS5bTSEfTSEfUSUjVSenVSenVSenVSenUSUjU
SUjUSUjUSUjUSUjUSUjUSUjUSUjVSenVSenWT62XTF6XTF6WT6000:jJPJjJPJjJPJjJPJjJPJjJPJjJ
PJjJPJjKQZjKQZjKQZjKQZjKQZjKQZjKQZjKQZbKPJbKPJbKPJbKPJbKPJbKPJbKPJbKPJ^HPj^HPj^H
Pj^HPj^HPj^HPj^HPj^HPjZGPZZGPZZGPZZGPZZGPZZGPZZGPZZGPZZIOjZIOjZIOjZIOjZIOjZIOjZI
OjZIOjVFPJVFPJVFPJVFPJVFPJVFPJVFPJVFPJJENjNFO:VHOZZIOj^JP:ZIOjVHOZRGOJVHOZVHOZVH
OZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZRGOJRGOJRGOJRGOJRGOJRGOJRG
OJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGO:RGO:RGO:RGO:RGO:RGO:RGO:RGO:NFNjNFNjNF
NjNFNjNFNjNFNjNFNjNFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjZHNjZHNjZHNjZHNjZHNjZHNjZH
NjZHNjRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJRF
NJRFNJRFNJRFNJRFNJRFNJJDMjNEN:NEN:NEN:RFNJRFNJRFNJVGNZRFNJRFNJRFNJRFNJRFNJRFNJRF
NJRFNJJDMjJDMjNEN:NEN:RFNJRFNJVGNZVGNZJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJ:DMj:DMjBD
MjBDMjJDMjRCMjRCMjRCMjRFLJRFLJRFLJRFLJRFLJRFLJRFLJRFLJNDLJNDLJNDLJNDLJNDLJNDLJND
LJNDLJVFLjVFLjVFLjVFLjVFLjVFLjVFLjVFLjNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJND
LJNDLJNDLJNDLJNDLJNDLJJCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:BAKZBAKZBAKZFBKjFBKjJCL:JC
L:JCL:FBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKj2CKJ:BKJ:B
KJBBKJBBKJFBKJFBKJNAKJFBK:FBK:FBK:FBK:FBK:FBK:FBK:FBK:BAJjBAJjBAJjBAJjBAJjBAJjBA
JjBAJj>AK:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ6>J:6>J:6>
J:6>J:6>J:6>J:6>J:6>J:>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ:?JJ:?JJ:?JJ:?JJ:?JJ:?JJ:?
JJ:?JJ2=Ij6>J:6>J:6>J::?JJ:?JJ:?JJ>@JYn<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IZ2=Ij2=Ij2=
Ij2=Ij2=Ij2=Ij2=Ij2=Ij6?IZ6?IZ:@Ij>AJ:>AJ::@Ij6?IZ6?IZ:@Ij:@Ij>AJ:>AJ::@Iin=I9f;
HY^9H9n=I:2>IJ2>IJ2>IJ6?IZ6?IZ6?IZ6?IYj<Hj6?IZ>AJ::@Iin=I9j<Hj2>IJ>AJ:2>IJ2>IJ2>
IJ2>IJ2>IJ2>IJ2>IJ2>IJ2@HJ2@HJ2@HJ2@HJ2@HJ2@HJ2@HJ2@HJ2>IJ2>IJ2>IJ2>IJ2>IJ2>IJ2>
IJ2>IIj>H9j>H9j>H9n?HJ2@HZ2@HZ6AHj6AHj6AHin?HIj>H9n?HJ2@HZ6AHj2@HYj>H:>>HJ>>HJ>>
HJ>>HJ>>HJ:=H:2;GZ2;GZ6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj6=GZ6=GZ:>Gj:>Gj:>Gj>?H:>?
H:>?H::>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj:>Gj><GZ><GZ><GZ><GZ><GZ><GZ><GZ><GZ:;GJ><GZ><
GZB=GjB=Gj><GZ><GZ:;GJ:<G::<G::<G:>=GJ>=GJB>GZB>GZB>GZ:;GJ:;GJ:;GJ:;GJ:;GJ:;GJ:;
GJ:;GIn;Fin;Fin;Fin;Fin;Fin;Fin;Fin;Fj2:FZ2:FZ2:FZ2:FZ2:FZ2:FZ2:FZ2:FZ6;Fj6;Fj6;
Fj6;Fj6;Fj6;Fj6;Fj6;Fj2:FZ2:FZ2:FZ6;Fj6;Fj6;Fj:<G::<G:2:FZ2:FZ2:FZ2:FZ2:FZ2:FZ2:
FZ2:FYb6EYj8F:2;F::=FZ>>FZ6<F9n;E9f9DYj9EYj9EYf8EIf8EIj9EYn:Ej2;F:6<FJ2<EIn;E9n;
E9j:Din;E:2<EJ6=EZ:>Ej2;F:2;F:2;F:2;F:2;F:2;F:2;F:2;F9j9EYn:Ej2;F:6<FJ6<FJ2;F9n:
Eij9EYn:Ein:Ein:Ein:Ej2;F:2;F:6<FJ6<FIf9DYj:Din;E:2<EJ2<EIn;E9j:Dif9DZ2<EJ2<EJ2;
Ej2;Ej2;F:2;F:2:FZ2:FZ6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:
F:6:F9n;DYn;DYn;DYn;DYn;DYn;DYn;DYn;DZ6:F:6:F::;FJ><FZ><FZ:;FJ6:F:6:F9j7EIj7EIn8
EZ29Ej6:F::;FJ><FZ><FZ6=EZ6=EZ6<F::=FJ:=FZ:=FZ>=GJ>=GJ2<DZ6<F:2<GIf;HY^;HIZ<G9^@
EifBEY2:IiZ3JJf>HJB=BJBBJIF0R920PMoI[/W8^[bg[/6h]Lc1`lFj_KR`/;Re[Kfl/Znk^jBbYZ2/
UZV/W:bYY:VTYJJVX:N/WK:ZTk2YV:^ZX:V/ZZJ[ZZFXYZVZX:f]Wj:ZZIjPZZVV][6[]ZBQW9fNSZBT
V:JSWYRQYI6MUhnLSYZTV9nTXi6FUI:IS:RaUiVRV9NQUIVVV9j[ViVVUY6KSY>KT9jTVJ>DTIjDSIZG
SijOUInVUijWTibVSibURYZUTJ:[UZN]UZFXSjJUT:n[VKJ`YKN_Z:2RSZZ_VZBZVJ2UU/?3]NWQe=71
]9V3Mj><G:B=GJJ?GjRAHJRAHJRAHJN@H:J?GjF>GZF>GZF>GZF>GZF>GZF>GZF>GZF>GZB=GJF>GZJ?
GjJ?GjJ?GjJ?G`00[Y^0[Y^0[IYo[9Qo[9N1[IR2[YV4[YV4[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9^1
ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0ZiZ0[9^1[9^1[9^1[9^1ZiZ0ZiZ0ZYUoZYUoZYUoZYUoZYUoZYUo
ZYUoZYUoZYUoZYUoZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQn
YiIlZ9MmZ9MmZIQnZIQnZYUoZiZ0ZiZ0ZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQn
ZIQnZIQnZIQnZIQnYYEjYiIkYiIkZ9MlZ9MlZIQmZIQmZYUnYiIkYiIkYiIkYiIkYiIkYiIkYiIkYiIk
ZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIMjZIMjZIMjZIMjZIMjZIMjZIMjZIMjYiEhYiEhYiEhZ9Ii
Z9IiZ9IiZIMjZIMjZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9Ii
YYAgYYAgYiEhYiEhYiEhYiEhYYAgYYAgZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiYiEfYiEfYiEfYiEf
YiEfYiEfYiEfYiEfYiEfYiEfYiEfYiEfYiEfYiEfYiEfYiEfZ9IgYiEfYYAeYYAeYYAeYYAeYiEfZ9Ig
YYAeYYAeYYAeYYAeYiEfYiEfYiEfZ9IgYiEfYiEfYiEfYiEfYiEfYiEfYiEfYiEfZIIcZIIcZIIcZIIc
ZIIcZIIcZIIcZIIcYY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAa
YiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`
YY=`YY=`YY=`YY=`YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_
Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95/Y95/Y95/Y95/Y95/Y95/Y95/Y95/XY5VXY5VXHmVX8iU
X8eWXHiYXXmZXXmZY95[Y95[Y95[Y95[Y95[Y95[Y95[Y95[XY5ZXY5ZXY5ZXi1ZYI1ZYI1ZYi1ZYi1Z
XXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYXi1ZXi1ZXi1ZXXmY
XHiXXHiXX8eWX8eWXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXXmYXXmYXXmYXHiXX8eWX8eWWhaVWhaV
XXmYXHiXX8eWWhaVWhaVX8eWXHiXXXmYWheTWheTWheTWheTWheTWheTWheTWheTXHmVXHmVXHmVXHmV
XHmVXHmVXHmVXHmVY8iUY8iUYHmVYY1WYY1WYHmVY8iUY8iUXXePXhiQXhiQXhiQY8mRY8mRY8mRYI1S
XHmVXHmVXHmVXHmVXHmVXHmVXHmVXHmVYI1SYI1SYI1SYI1SYI1SYI1SYI1SYI1SXXiOXhmPY91QY8mR
Y8iTY8iTXheTXXaSXXaRXXaRXXaRXXaRXXaRXXaRXXaRXXaRYI1SY8mRXhiQXXePXXePXhiQY8mRYI1S
XhiQXhiQXhiQXhiQXXePXXePXHaOXHaOY91QY91QY91QY91QY91QY91QY91QY91QXHeNXHeNXHeNXHeN
XHeNXHeNXHeNXHeNXX]MY8eOYHiPY8eOXX]MXX]MXhaNYHiPY8iNY8iNY8iNY8iNY8iNY8iNY8iNY8iN
XX]MXX]MXX]MXX]MXX]MXX]MXX]MXX]MXhaNXhaNXhaNXhaNXhaNXhaNXhaNXhaNXXeJXhiKXhiKXhiK
Y8mLY8mLY8mLY8mLXheMXXaLXXaLXH]KXH]KXXaLXXaLXheMWhYGWhYGX8]HXHaIXHaIX8]HWhYGWhYG
WXQHWhUIXH]KXXaLXXaLXH]KWhUIWXQHX8]HX8]HX8]HX8]HX8]HX8]HX8]HX8]HWXUFWhYGX8]HWhYG
WXUFWhYGXHaIY8mLWhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaE
WhYCWhYCWhYCWhYCWhYCWhYCWhYCWhYCX8]DX8]DWhYCWXUBWHQAWXUBWXUBWhYCWhYCWhYCWhYCWhYC
WhYCWhYCWhYCWhYCXHaEX8]DX8]DX8]DX8]DXHaEXXeFXhiGWhYCWhYCWhYCX8]DX8]DX8]DXHaEXHaE
WhYCX8]DXXeFXXeFX8]DX8]DXXeFXhiGXXeFXHaEX8]DX8]DX8]DX8]DXHaEXXeFX8]DX8]DX8]DX8]D
X8]DX8]DX8]DX8]DX8]DX8]DX8]DX8]DWhYCWhYCWhYCWhYCX8aCX8aCX8aCXHeDXHeDXHeDXXiEXXiE
XXeFXXeFXXeFXXeFXXeFXXeFXXeFXXeFX8]DX8]DX8]DX8]DX8]DX8]DX8]DX8]DXhiGXXeFXXeFXHaE
XHaEX8]DWhYCWhYCXHeDXHeDXHeDXXeFXXaHXheIXhaJXhaJZ95CYY1FXhiGXH]KX8YPX8YVWhYZXHa]
XiUgXI]nWYf8VinCV:2FVYjHVYfDVY^AXijEY9nFYZ6HYJ2GY9nFXijEYJ2GYZ6HZjRJZJJHYjBFYjBF
Z:FGZJJHZ:FGYjBFZJFJZZJKZZJKZJJHYjBFY:6BXj2AXYn@VibBWifCZ9nE[:2DZ9b@XIR>VYR>VY^A
WIn<X::?XjFBY:JCXZBAX::?Wj6>Wj6>Yj:CYZ6BYZ6BZ:>DZjJG[:NHZZFFZJBE[:NH[JRI[jZK/JbM
/jjO]K2Q]k:S^;>T]JZV/k>SZ;2IXjbH_[jbflo5ck^R[9E_XHiKXhiKXhiKY8eKY8eKYXeKYXeKZ8eK
YHiLYHiLYHiLYHiLYHiLYHiLYHiLYHiLY8eKY8eKYHiLYHiLYXmMYXmM002^Vh2^Vh2]VWn/V7n/Uh6]
V8:^VHB^VHB/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6/Vh6[VX2[VX2[VX2[VX2[VX2[VX2[VX2[VX2/Vh6/
Vh6/Vh6[VX2[VX2[VX2ZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnYV7jYV7jYV7jYV7jYV7jY
V7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jWUWbXUgfXUgfYV7jYV7jZVGnZVGnZVGnYV7jY
V7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jWUW^WUW^WUW^XUgbXUgbX
UgbXUgbXUgbWUW^WUW^WUW^WUW^WUW^WUW^WUW^WUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^YUgZY
UgZYUgZYUgZYUgZYUgZYUgZYUgZVU7NWUGRWUGRWUGRXUWVXUWVXUWVYUgZXUWVXUWVXUWVXUWVXUWVX
UWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVXUWVVU7NVU7NWUGRWUGRWUGRWUGRVU7NVU7NXUWVX
UWVXUWVXUWVXUWVXUWVXUWVXUWVVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FVU7FV
U7FVU7FVU7FWUGJWUGJVU7FUTgBUTgBVU7FWUGJWUGJUTgBVU7FVU7FVU7FWUGJWUGJWUGJWUGJVU7FV
U7FVU7FVU7FVU7FVU7FVU7FVU7FXUG:XUG:XUG:XUG:XUG:XUG:XUG:XUG:VTg2VTg2VTg2VTg2VTg2V
Tg2VTg2VTg2WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76WU76VTg2V
Tg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2UTVnUTVnUTVnUTVnUTVnU
TVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFbT
TFbTTFbTTFbTTFbTTFbTTFbTTFbSTVNSTVNRT6NQSfJQSVRRSfZST6^ST6^TTF^TTF^TTF^TTF^TTF^T
TF^TTF^TTF^RTFZRTFZRTFZST6ZUT6ZUT6ZWT6ZWT6ZRSfVRSfVRSfVRSfVRSfVRSfVRSfVRSfVRSfVR
SfVRSfVRSfVRSfVRSfVRSfVRSfVST6ZST6ZRSfVRSfVQSVRQSVRPSFNPSFNPSFNPSFNPSFNPSFNPSFNP
SFNPSFNPSFNRSfVRSfVQSVRQSVRPSFNPSFNOS6JOS6JRSfVQSVRPSFNOS6JOS6JPSFNQSVRRSfVOSFBO
SFBOSFBOSFBOSFBOSFBOSFBOSFBPSVFPSVFPSVFPSVFPSVFPSVFPSVFPSVFSSFBTSVFUSfJUSfJUSfJU
SfJTSVFSSFBRSF2RSF2SSV6SSV6SSV6TSf:TSf:TSf:PSVFPSVFPSVFPSVFPSVFPSVFPSVFPSVFTSf:T
Sf:TSf:TSf:TSf:TSf:TSf:TSf:RSUnSSf2TT66TSf:TSVBTSVBSSFBRS6>RSF2RSF2RSF2RSF2RSF2R
SF2RSF2RSF2UT6>TSf:SSV6RSF2RSF2SSV6TSf:UT6>SSV6SSV6SSV6RSF2RSF2RSF2QS5nQS5nSSf2S
Sf2SSf2SSf2SSf2SSf2SSf2SSf2QSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjRRefSS5jUSV2TSEnRRefQ
RUbSS5jTSEnTSUjTSUjTSUjTSUjTSUjTSUjTSUjTSUjRRefRRefRRefRRefRRefRRefRRefRRefSS5jS
S5jSS5jSS5jSS5jSS5jSS5jSS5jQS5VRSEZRSEZRSEZSSU^SSU^SSU^SSU^SSEfRS5bRS5bQRe^QRe^R
S5bRS5bSSEfORUNORUNPReRQS5VQS5VPReRORUNORUNOREVOREVPRUZPRUZPRUZPRUZOREVOREVPReRP
ReRPReRPReRPReRPReRPReRPReRORUNPReRPReRORUNNREJNREJPReRSSU^ORUNORUNORUNORUNORUNO
RUNORUNORUNQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FNRE:NRE:NRE:NRE:NRE:NRE:NRE:NRE:PReBO
RU>NRE:NRE:MR56NRE:NRE:ORU>NRE:NRE:NRE:NRE:NRE:NRE:NRE:NRE:QS5FPReBPReBORU>PReBQ
S5FRSEJSSUNNRE:ORU>ORU>ORU>PReBPReBPReBQS5FNRE:PReBRSEJQS5FPReBPReBQS5FSSUNRSEJQ
S5FPReBPReBPReBPReBQS5FRSEJPReBPReBPReBPReBPReBPReBPReBPReBQS5FPReBPReBPReBPReBP
ReBPReBPReBPS5>PS5>PS5>PS5>QSEBQSEBRSUFRSUFORU>ORU>ORU>ORU>ORU>ORU>ORU>ORU>PReBP
ReBPReBPReBPReBPReBPReBPReBRSEJRSEJQS5FQS5FPReBPReBORU>ORU>QSEBQSEBQSEBRSEJRS5RR
S5RSS5ZSS5ZVSeNUSUJRS5RQRe^PRejORf:QRfNPS6VRUVjOUWBLV7nIVhRGVi2FVi:HVi:JVi6NWhnP
XI6RXi>QXY:PXI6PXI6RXi>TYIFTY9RTY9RTY9RUYIVVYYZWYi^VYYZUYIVVYI^WYYbXYifZZYjZZYjX
Z9bTY9RQXIFPY9VRXYJTX9FYXIBYXIBTX9FPX9BLX9FJWHjLWi2MX96MX96KWXnJWHjLWi2MX96RWi6R
Wi6RWi6TXI>VXiFWY9JVXiFTXI>WY9JWY9JYYYR[Z9Z]ZYb_[9ja[Z2b[j6f[jbh^:ZZ/ijT[Yg1`[WP
elkA`:^YUG:QSU^SSU^SSU^TSE^TSE^VSE^VSE^XSE^USUbUSUbUSUbUSUbUSUbUSUbUSUbUSUbTSE^T
SE^USUbUSUbUSUbVSed00:jKP:fJOjbIOZbHOjbGPJbGPJfHPjjIQ:bKPJbKPJbKPJbKPJbKPJbKPJbK
PJbKPJ^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:bKPJbKPJ^JP:^JP:^JP:ZIOjZIOjZIOjZIOjZIOjZI
OjZIOjZIOjZIOjZIOjZIOjVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVH
OZVHOZRGOJRGOJRGOJRGOJVHOZVHOZVHOZZIOjVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZVH
OZVHOZVHOZVHOZVHOZVHOZRGO:RGO:RGO:RGO:NFNjNFNjNFNjNFNjNFNjNFNjNFNjNFNjNFNjNFNjNF
NjNFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjRFNJRFNJRFNJRFNJRFNJRFNJRFNJRFNJJDMjJDMjNE
N:NEN:NEN:RFNJRFNJRFNJNEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NE
N:NEN:JDMjJDMjNEN:NEN:NEN:NEN:JDMjJDMjNEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:JDMJJDMJJD
MJJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJNEMZJDMJJDMJFCM:FCM:JDMJJD
MJNEMZFCM:FCM:FCM:JDMJJDMJNEMZNEMZNEMZJDMJJDMJJDMJJDMJJDMJJDMJJDMJJDMJRELZRELZRE
LZRELZRELZRELZRELZRELZJCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:NDLJNDLJNDLJNDLJNDLJNDLJND
LJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJJCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JC
L:JCL:JCL:JCL:JCL:JCL:FBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFBKjFB
KjFBKjBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZ>@Jj>@Jj>@Jj>@Jj>@Jj>@Jj>@Jj>@JjBCJ:BCJ:>A
J::@Ij:?JJ>@JjBAK:BAK:>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ>@JZ6@JJ6@JJ6@JJ:?JJB?JJB?JJJ?
JJJ?JJ6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J::?JJ:?JJ:?
JJ6>J:6>J:6>J:2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij6>J:6>J:6>J:2=Ij2=Ij2=Iin<
IYn<IZ6>J:2=Ij2=Iin<IYn<IZ2=Ij2=Ij6>J9n=I9n=I9n=I9n=I9n=I9n=I9n=I9n=I:2>IJ2>IJ2>
IJ2>IJ2>IJ2>IJ2>IJ2>IJ>=I:B>IJB>IJF?IZF?IZB>IJB>IJ>=I::=H::=H::=H:>>HJ>>HJB?HZB?
HZB?HZ2>IJ2>IJ2>IJ2>IJ2>IJ2>IJ2>IJ2>IJB?HZB?HZB?HZB?HZB?HZB?HZB?HZB?HZ:>Gj>?H:>?
H:B?HZB>I:>=Hj>=I::<Hj:=H::=H::=H::=H::=H::=H::=H::=H:B?HZ>>HJ>>HJ:=H::=H:>>HJ>>
HJB?HZ>>HJ>>HJ:=H::=H::=H:6<Gj6<Gj6<Gj>?H:>?H:>?H:>?H:>?H:>?H:>?H:>?H:6=GZ6=GZ6=
GZ6=GZ6=GZ6=GZ6=GZ6=GZ6:G:><GZB=GjB=Gj:;GJ6:G::;GJB=Gj>=GJ>=GJ>=GJ>=GJ>=GJ>=GJ>=
GJ>=GJ:;GJ:;GJ:;GJ:;GJ:;GJ:;GJ:;GJ:;GJ><GZ><GZ><GZ><GZ><GZ><GZ><GZ><GZ2;F:2;F:2;
F:6<FJ6<FJ:=FZ:=FZ:=FZ>=GJ:<G:6;Fj6;Fj6;Fj6;Fj:<G:>=GIj9EYn:Ej2;F:2;F:2;F:2;F9n:
Eij9EZ2:FZ2:FYn9FIn9FIn9FIn9FJ2:FZ2:FYn:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ej2;F:6<FJ6<
FIn:Eif8EIf8EIn:Ej6<FIj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EZ2;E:2;E:2;E:2;E:2;E:2;E:2;
E:2;E9j9DYj9DYj9DYj9DYj9DYj9DYj9DYj9DYn:Dij9DYj9DYf8DIf8DIj9DYn:Din:Dij9DYj9DYj9
DYj9DYj9DYj9DYj9DYj9DZ2;E9n:Din:Din:Din:Dj2;E:6<EJ:=EYj9DYj9DYn:Din:Din:Dj2;E:2;
E:2;E9j9DYn:Dj6<EJ6<EIn:Din:Dj2;E::=EZ6<EJ6<EJ2;E9n:Din:Dj2;E:6<EJ6<EJ2;E:2;E:2;
E:2;E:2;E:2;E:2;E:2;E:6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EIn;DYn;DZ2<Dj2<Dj6=E:6=E:6=
E:6=E9n:Din:Din:Din:Din:Din:Din:Din:Dj6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<EJ6<
EJ6<EJ2;E:2;E:2;E9n:Dj2<Dj6=E:6=E:6<EJ:<F::<F::;FJ:;FJ><FZ><FZ:;Fj6;Fin;G:2;GYn<
Gj2=HZ2@HIj@IYZAKiNCNYFEPiJHS9JJSiRLTIJMR9RORYZQS9^RSIZQS9ZQS9bSSYjUT9fPUijQV9nR
VJ2SVYnRVIfPUibOUYZMU9ZNTiVMTYZMU9jQV:2SVYnRVIVLTi>FSIjSU9bOT9ZHSI^GS9fISYfKT9RK
S9>HRJ2QUj6RV::SVJ6RV:2QUj6RV:BUVjJWWJJVVZFUVJFUVJNWVjZZWZ^[WjVYWJNWVj^[Wjb/X:f]
XJn_Xk6aYK>cYkBdZ;FeZJn/Z;6eZJ>^VYbVU[Zl]]_Ed<VmZiV<K:6>Fj>>Fj>>FjB=FjB=FjJ=FjJ=
FjR=FjB=FjB=FjB=FjB=FjB=FjB=FjB=FjB=FjB=FjB=FjB=FjF>G:F>G:F>G000[IYo[IYo[9UnZiMn
ZiJ0[9N1[IR3[IR3[9^1[9^1[9^1[9^1[9^1[9^1[9^1[9^1ZYUoZYUoZYUoZYUoZYUoZYUoZYUoZYUo
ZiZ0ZiZ0ZiZ0ZiZ0ZYUoZYUoZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZ9MmZ9MmZ9MmZ9Mm
Z9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9Mm
Z9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZIQmZ9MlZ9MlYiIk
YiIkYYEjYYEjYIAiYiIkYiIkYiIkYiIkYiIkYiIkYiIkYiIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIIk
Z9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiZ9IiYYAgYYAgYYAgYiEhYiEhYiEhZ9IiZ9IiYiEhYiEhYiEhYiEh
YiEhYiEhYiEhYiEhYiEhYiEhYiEhYiEhYiEhYiEhYiEhYiEhYYAgYYAgYiEhYiEhYiEhYiEhYYAgYYAg
YiEhYiEhYiEhYiEhYiEhYiEhYiEhYiEhYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAe
YYAeYYAeYYAeYYAeYiEfYYAeYI=dYI=dYI=dYI=dYYAeYiEfYI=dYI=dYI=dYI=dYYAeYYAeYiEfYiEf
YYAeYYAeYYAeYYAeYYAeYYAeYYAeYYAeZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbZ9EbYY=`YY=`YY=`YY=`
YY=`YY=`YY=`YY=`YiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAaYiAa
YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_Y95^Y95^Y95^Y95^
Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]
Xi1[Xi1[Xi1[Xi1[Xi1[Xi1[Xi1[Xi1[YIAYY9=XY99YXi5XXi1ZY95/Y95/YI9]Xi1ZXi1ZXi1ZXi1Z
Xi1ZXi1ZXi1ZXi1ZXI1YXI1YXI1YXXmYY8mYY8mYYXmYYXmYXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiX
XHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXXHiXX8eWX8eWX8eWX8eWX8eWX8eW
X8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eWWhaVWhaVWhaVX8eWX8eWWhaVWhaVWhaVWhaVX8eWX8eW
WheTWheTWheTWheTWheTWheTWheTWheTX8iUX8iUX8iUX8iUX8iUX8iUX8iUX8iUXheTXheTY8iUYHmV
YHmVY8iUXheTXheTXHaOXXePXXePXXePXhiQXhiQXhiQY8mRX8iUX8iUX8iUX8iUX8iUX8iUX8iUX8iU
Y8mRY8mRY8mRY8mRY8mRY8mRY8mRY8mRXXiOXXiOXhmPXhiQXheSXheSXXaSXXaSXHeNXHeNXHeNXHeN
XHeNXHeNXHeNXHeNXhiQXhiQXXePXXePXXePXXePXhiQXhiQXXePXXePXXePXXePXHaOXHaOX8]NX8]N
XXiOXXiOXXiOXXiOXXiOXXiOXXiOXXiOX8aMX8aMX8aMX8aMX8aMX8aMX8aMX8aMXH]KXheMY8iNXheM
XH]KXH]KXXaLY8iNXXaLXXaLXXaLXXaLXXaLXXaLXXaLXXaLXH]KXH]KXH]KXH]KXH]KXH]KXH]KXH]K
XXaLXXaLXXaLXXaLXXaLXXaLXXaLXXaLWhYGWhYGWhYGX8]HX8]HX8]HXHaIXHaIXXaLXXaLXH]KX8YJ
X8YJXH]KXXaLXXaLWXUFWXUFWhYGX8]HX8]HWhYGWXUFWXUFXH]KX8YJWXQHWHMGWHMGWXQHX8YJXH]K
WhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGX8]HXHaIXHaIWhYGWHQEW8MDWXUFX8]HWXUFWXUFWXUFWXUF
WXUFWXUFWXUFWXUFWhYCWhYCWhYCWhYCWhYCWhYCWhYCWhYCWXUBWXUBWXUBWXUBWXUBWXUBWXUBWXUB
WXUBWHQAWHQAWHQAWHQAWXUBWhYCWhYCWXUBWXUBWXUBWXUBWXUBWXUBWXUBWXUBWhYCWXUBWXUBWXUB
WXUBWhYCX8]DXHaEWXUBWXUBWXUBWhYCWhYCWhYCX8]DX8]DWHQAWXUBX8]DX8]DWXUBWXUBX8]DXHaE
XHaEX8]DWhYCWhYCWhYCWhYCX8]DXHaEX8]DX8]DX8]DX8]DX8]DX8]DX8]DX8]DX8]DXHaEXHaEXHaE
XHaEXXeFXXeFXXeFWh]BWh]BWh]BX8aCX8aCX8aCXHeDXHeDXHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaE
XHaEXHaEXHaEXHaEXHaEXHaEXHaEXHaEX8]DX8]DX8]DX8]DX8]DX8]DX8]DX8]DX8aCX8aCX8aCXHaE
XH]GXXaHXX]IXX]IXHYLXHYLXHYLXH]KXH]KWhaIX8eJX8eJXHaHWh]KVhiRV8i/UY9fUiJ2V9V9VI^?
TiV8UI^:V9j=V9j=V9j=VIn>Vj6@WJ>BWJ6FWj>HXjNLY:RMXjNLXJFJWj>HWj>HWZFHVZ6DV9nBVj6F
WjFJXJJMWZ>JVIjEX:JCXjJFX::FWinCWinCX::FWj:BVIn<VIN=ViV?WYbBWifCWYbBWYbBWifCXInE
WYjBWIfAWYjBX:2DXZ:FXj>GXZ:FX:2DY:BHYJFIYZJJZ:RLZZZNZj^O[JfQ[JfQ/:fX];NXYZnJWJBE
^k^efmG@a[j]Uhe_X8eJXXeJXXeJXhaJXhaJYHaJYHaJYhaJXhaJXhaJXhaJXhaJXhaJXhaJXhaJXhaJ
XhaJXhaJY8eKY8eKYHiLYHiL002]VWn/VGj[V7f[Ugj[UX2[UX2/Uh:]V8>[VX2[VX2[VX2[VX2[VX2[
VX2[VX2[VX2ZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGn[VX2[VX2ZVGnZVGnZVGnYV7jYV7jYV7jYV7jY
V7jYV7jYV7jYV7jYV7jYV7jYV7jXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfX
UgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfWUWbWUWbWUWbXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfX
UgfXUgfXUgfXUgfXUgfXUgfXUgfXUgbXUgbWUW^WUW^VUGZVUGZUU7VUU7VWUW^WUW^WUW^WUW^WUW^W
UW^WUW^WUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^WUGRWUGRWUGRWUGRWUGRWUGRWUGRWUGRUTgJU
TgJVU7NVU7NVU7NWUGRWUGRWUGRVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NV
U7NVU7NVU7NVU7NVU7NWUGRWUGRWUGRWUGRVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NUTgBU
TgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBVU7FVU7FUTgBTTW>TTW>U
TgBVU7FVU7FTTW>TTW>UTgBUTgBUTgBVU7FVU7FVU7FUTgBUTgBUTgBUTgBUTgBUTgBUTgBUTgBWU76W
U76WU76WU76WU76WU76WU76WU76VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2V
Tg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2UTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnU
TVnUTVnUTVnUTVnUTVnUTVnUTVnTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjT
TFjTTFjTTFjST6fST6fST6fST6fST6fST6fST6fST6fST6^ST6^ST6^ST6^ST6^ST6^ST6^ST6^UU6VT
TfRTTVVSTFRST6ZTTFbTTFbUTVfST6ZST6ZST6ZST6ZST6ZST6ZST6ZST6ZPSfRPSfRPSfRQSVRSSVRS
SVRUSVRUSVRPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNP
SFNPSFNPSFNPSFNPSFNQSVRQSVROS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JO
S6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JNS6>NS6>NS6>NS6>NS6>NS6>NS6>NS6>OSFBO
SFBOSFBOSFBOSFBOSFBOSFBOSFBRS6>SSFBTSVFTSVFTSVFTSVFSSFBRS6>QS5nQS5nQS5nRSF2RSF2S
SV6SSV6SSV6OSFBOSFBOSFBOSFBOSFBOSFBOSFBOSFBSSV6SSV6SSV6SSV6SSV6SSV6SSV6SSV6QSEjR
SUnRSUnSSV6SSF>RS6:RS6>QRf:QSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjRSF2RSF2RSF2RSF2RSF2R
SF2RSF2RSF2RSF2RSF2QS5nQS5nQS5nPRejPRejPRejQSEjQSEjQSEjQSEjQSEjQSEjQSEjQSEjPS5fP
S5fPS5fPS5fPS5fPS5fPS5fPS5fPReRRSEZSSU^SSU^QS5VPReRQS5VSSU^RS5bRS5bRS5bRS5bRS5bR
S5bRS5bRS5bQS5VQS5VQS5VQS5VQS5VQS5VQS5VQS5VRSEZRSEZRSEZRSEZRSEZRSEZRSEZRSEZNREJN
REJORUNORUNPReRPReRPReRPReRRS5bQRe^PRUZPRUZPRUZPRUZQRe^RS5bMR5FNREJORUNORUNORUNO
RUNNREJMR5FPRUZOREVNR5RLQUJLQUJNR5ROREVPRUZNREJNREJNREJNREJNREJNREJNREJNREJPReRP
ReRPReRORUNLQeBLQeBMR5FORUNMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FNRE:NRE:NRE:NRE:NRE:N
RE:NRE:NRE:MR56MR56MR56MR56MR56MR56MR56MR56MR56LQe2LQe2LQe2LQe2NRE:ORU>ORU>MR56M
R56MR56MR56MR56MR56MR56MR56NRE:NRE:MR56MR56MR56NRE:ORU>PReBMR56MR56NRE:NRE:NRE:O
RU>ORU>ORU>LQe2MR56ORU>ORU>MR56MR56ORU>PReBPReBPReBORU>NRE:NRE:ORU>PReBPReBPReBP
ReBPReBPReBPReBPReBPReBPReBORU>PReBPReBPReBQS5FQS5FRSEJRSEJNRU6NRU6ORe:ORe:PS5>P
S5>PS5>PS5>QS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FQS5FORU>O
RU>ORU>ORU>ORU>PReBPReBPReBORe:PS5>PS5>PReBQReNQReNQRURRReVNREbORebORebQRe^QS5VP
ReNPS5FPS5FPS5>OReBNReRLS66KT6ZLU7JLV82KVXJHUXbJV8jMVi6MVi6MVi6NW9:PWYBRX9JRXY:T
Y9BWYiNUYIFPX92KVh^IVHVHV8RBV86>Tgj;T7^<T7fCUXJJWHjOXIFPXYJ?TG^GVHJMWHnJVi6KW9:Q
XI>QXi2NX8ZPVhbTWi2XXiB[YYNZYIJXXiBXXiBXXiBWYY:VYI6VYI6XYi>[ZYJ/ZiNZZIFXYi>ZZIFZ
ZIF[ZYJ][9R^[IV`[i^a/9ba/9bh]JJm_JFc]iZ[[IO3_K;MdlW;`:ZQV7JPSEZRSEZRSEZSS5ZSS5ZU
S5ZUS5ZWS5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZSS5ZTSE^TSE^TSE/00:bIOZbIOZ^H
OJZFOJZEOj^FP:bGPZbGPZ^JP:^JP:^JP:^JP:^JP:^JP:^JP:^JP:VHOZVHOZVHOZVHOZVHOZVHOZVH
OZVHOZZIOjZIOjZIOjZIOjVHOZVHOZVHOZRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJRGOJNFO:NFO:NF
O:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:RGOJRGOJRGOJNFO:NFO:NFO:JE
NjJENjNFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFNjNFNjJE
NZJENZJENZJENZJENZFDNJNFNjNFNjNFNjNFNjNFNjNFNjNFNjNFNjVFNjVFNjVFNjVFNjVFNjVFNjVF
NjVFNjNEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:FCMZFCMZFCMZJDMjJDMjJDMjNEN:NEN:JDMjJDMjJD
MjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjNEN:NEN:NEN:NEN:JD
MjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjFCM:FCM:FCM:FCM:FCM:FCM:FCM:FCM:FCM:FCM:FC
M:FCM:FCM:FCM:FCM:FCM:JDMJFCM:BBLjBBLjBBLjBBLjFCM:JDMJBBLjBBLjBBLjBBLjFCM:FCM:JD
MJJDMJFCM:FCM:FCM:FCM:FCM:FCM:FCM:FCM:NDLJNDLJNDLJNDLJNDLJNDLJNDLJNDLJJCL:JCL:JC
L:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JC
L:JCL:BAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZ>@KJ>@KJ>@
KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ:?K::?K::?K::?K::?K::?K::?
K::?K::?JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZBCJ:BCJ:>AJ::@Ij:?JJ>@JjBAK:BAK::?JJ:?JJ:?
JJ:?JJ:?JJ:?JJ:?JJ:?JJ2?J:2?J:2?J:6>J:>>J:>>J:F>J:F>J:2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=
Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=Iin<IYn<IYn<IZ2=Ij2=Ij2=Ij6>J:6>J9n<IYn<IYn<
IYn<IYn<IYn<IYn<IYn<IYj;IIj;IIj;IIj;IIn<IYn<IYn<IZ2=Iij;IIj;IIn<IZ2=Ij2=Iin<IYj;
IIj;IIj<Hij<Hij<Hij<Hij<Hij<Hij<Hij<Hin=I9n=I9n=I9n=I9n=I9n=I9n=I9n=I::<Hj:<Hj>=
I:B>IJB>IJ>=I::<Hj:<Hj6<Gj6<Gj6<Gj6<Gj:=H::=H::=H:>>HIn=I9n=I9n=I9n=I9n=I9n=I9n=
I9n=I:>>HJ>>HJ>>HJ>>HJ>>HJ>>HJ>>HJ>>HJ6=GZ6=GZ:>Gj>>HJ>=Hj:<HZ6;HZ6;HZ2<G:2<G:2<
G:2<G:2<G:2<G:2<G:2<G:6<Gj6<Gj:=H:>>HJ>>HJ:=H:6<Gj6<Gj6<Gj6<Gj6<Gj6<Gj2;GZ2;GZ2;
GYn:GJ2<GJ2<GJ2<GJ2<GJ2<GJ2<GJ2<GJ2<GIn;G9n;G9n;G9n;G9n;G9n;G9n;G9n;G:2;F::=FZ>>
Fj:=FZ2;F:2;F:6<FJ>>Fj6;Fj6;Fj6;Fj6;Fj6;Fj6;Fj6;Fj6;Fj2;F:2;F:2;F:2;F:2;F:2;F:2;
F:2;F:6<FJ6<FJ6<FJ6<FJ6<FJ6<FJ6<FJ6<FIn:Ein:Ein:Ein:Ej2;F:2;F:6<FJ6<FJ6;Fj6;Fj2:
FYn9FIn9FJ2:FZ6;Fj6;Fif8EIj9EYj9EYn:Ein:Eij9EYj9EYf8EIn9FIj8F9j8F9f7Eif7Eij8F9j8
F9n9FIj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYn:Ein:Eij9EYb7E9b7E9f8EJ2;F9f8EIf8EIf8
EIf8EIf8EIf8EIf8EIf8EIf8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIf8
DIf8DIb7D9^6Ci^6Ci^6Cib7D9f8DIn:Dj2;E9f8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIb7
D9b7D9b7D9f8DIj9DYn:Dif8DIf8DIf8DIj9DYj9DYj9DYn:Din:Di^6Cif8DIj9DYj9DYb7D9b7D9j9
DYn:Dj2;E9n:Din:Dij9DYj9DYn:Din:Dj2;E:2;E:2;E:2;E:2;E:2;E:2;E:2;E:2;E9f8DIj9DYj9
DYn:Dj2;E:6<EJ6<EJ6<EIj:DIj:DIj:DIn;DYn;DZ2<Dj2<Dj2<Dij9DYj9DYj9DYj9DYj9DYj9DYj9
DYj9DYn:Din:Din:Din:Din:Din:Din:Din:Dij9DYj9DYj9DYn:Din:Din:Dj2;E:2;E9n;DYn;DYn;
DZ2;E:2:EZ6;Ej6:F:6:F9^:FIb;FYj:FYn<FJ2;F:2:EYn9EIn:Din;E:2<Dj6<EJ6<F:6?H:2BJ9jD
LYfEMinDQZ6FR:>HRZ>HRZ>HRZ>HRZFJS:NLSZFNPjBMPZ2IOYF>LhEnHgQaEW1YCViWC4M78dE48T=1
8TA294Y7:eEA>F1KAVQSCX9nIHn;N9NFR9bJTZBRVZ^ZW:ZVTj6MQ:VOQjbRR[2VS[:XT;2VSZnUSJjT
S:nUSK:XR[6WRK6WRK>YRkJ/S[N]SkF[SK>YRjnUQk2VR;6WRK:XR[>YRkBZS;F[SKJ/SZnWR[6[QZjX
OjVPOkFWTLBcX;NZRZ2EJIn<FJ6<FJ6<FJ:;FJ:;FJB;FJB;FJJ;FJ:;FJ:;FJ:;FJ:;FJ:;FJ:;FJ:;
FJ:;FJ:;FJ><FZ><FZ><FZB=FjB=F`00[9UnZiQmZiQmZYImZYEoZiJ0ZiJ1[9N2ZYUoZYUoZYUoZYUo
ZYUoZYUoZYUoZYUoZIQnZIQnZIQnZIQnZIQnZIQnZIQnZIQnZYUoZYUoZYUoZIQnZIQnZIQnZ9MmZ9Mm
Z9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIl
YiIlYiIlYiIlYiIlZ9MmZ9MmZ9MmYiIlYiIlYYEkYYEkYIAjYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIl
YiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYIAiYIAiYIAiYYEjYYEjYYEjYYEjYYEjYiIkYiIkYiIkYiIk
YiIkYiIkYiIkYiIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkZIIkYiEhYiEhYiEhYiEhYiEhYiEhYiEhYiEh
Y99eYI=fYI=fYI=fYYAgYYAgYYAgYiEhYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=f
YI=fYI=fYI=fYI=fYYAgYYAgYiEhYiEhYiEhYiEhYYAgYYAgYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=f
Y99cY99cY99cY99cY99cY99cY99cY99cY99cY99cY99cY99cY99cY99cY99cY99cYI=dYI=dY99cXi5b
Xi5bY99cYI=dYI=dXi5bXi5bY99cY99cYI=dYI=dYI=dYI=dY99cY99cY99cY99cY99cY99cY99cY99c
YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YI9_YI9_YI9_YI9_
YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^
Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]
Xi1]Xi1]Xi1]Xi1]XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXmZXXmZXXmZXXmZXXmZXXmZXXmZXXmZ
Xi9WXi9WXY1WXHmVXHiXXXmZXi1[Xi1[XXmYXXmYXXmYXXmYXXmYXXmYXXmYXXmYX8mXX8mXX8mXXHiX
XhiXXhiXYHiXYHiXWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaV
WX]UWX]UWhaVWhaVX8eWX8eWXHiXXHiXWX]UWX]UWX]UWX]UWX]UWX]UWX]UWX]UWHYTWHYTWX]UWX]U
WhaVWhaVX8eWX8eWWHYTWX]UWhaVX8eWX8eWWhaVWX]UWHYTWH]RWH]RWH]RWH]RWH]RWH]RWH]RWH]R
WXaSWXaSWXaSWXaSWXaSWXaSWXaSWXaSXH]RXXaSXheTXheTXheTXheTXXaSXH]RX8]NX8]NXHaOXHaO
XHaOXXePXXePXXePWXaSWXaSWXaSWXaSWXaSWXaSWXaSWXaSXXePXXePXXePXXePXXePXXePXXePXXeP
X8aMXHeNXXiOXXePXXaRXXaRXH]RX8YQX8aLX8aLX8aLX8aLX8aLX8aLX8aLX8aLX8]NXHaOXXePXhiQ
XhiQXXePXHaOX8]NXHaOXHaOXHaOX8]NX8]NX8]NWhYMWhYMWh]LWh]LWh]LWh]LWh]LWh]LWh]LWh]L
Wh]LWh]LWh]LWh]LWh]LWh]LWh]LWh]LX8]GXHaHXhiJXXeIX8]GWhYFXHaHXXeIX8YJX8YJX8YJX8YJ
X8YJX8YJX8YJX8YJX8]GX8]GX8]GX8]GX8]GX8]GX8]GX8]GXHaHXHaHXHaHXHaHXHaHXHaHXHaHXHaH
WhYGWhYGX8]HX8]HXHaIXHaIXHaIXHaIXH]KX8YJWhUIWhUIWhUIWhUIX8YJXH]KWHQEWHQEWXUFWhYG
WhYGWXUFWHQEWHQEWHMGWHMGWXQHWXQHWXQHWXQHWHMGWHMGWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUF
WHQEWXUFWXUFWHQEW8MDW8MDWXUFXHaIW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8M@W8M@W8M@W8M@
W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@VhI?VhI?VhI?VhI?W8M@WHQAWhYCX8]D
W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@VhI?VhI?W8M@WHQAWXUBWXUBW8M@WHQAWHQAWHQA
WXUBWXUBWXUBWhYCVXE>W8M@WHQAWHQAW8M@VhI?WHQAWhYCX8]DWhYCWXUBWXUBWXUBWXUBWhYCX8]D
X8]DX8]DX8]DX8]DX8]DX8]DX8]DX8]DW8M@W8M@WHQAWXUBWhYCWhYCX8]DXHaEWXYAWXYAWXYAWXYA
Wh]BWh]BWh]BX8aCWHQAWHQAWHQAWHQAWHQAWHQAWHQAWHQAWXUBWXUBWXUBWXUBWXUBWXUBWXUBWXUB
WHQAWHQAWXUBWXUBWhYCWhYCX8]DX8]DWh]BWh]BWh]BX8]DX8YFX8YFXHYHXHYHVH]FVh]FW8aGWheH
X8]GX8UGX8MEWhIDVXYEWh]DXXaBYHeCYHiFXhiKWhmQWHmUX8m^XY5`Y9=bXi9aXY5`XY5`Y9=bYYEd
XY9]XY9]WHeXT81KP71;Lf<nKEdhKEdhKVThKfTjKfTlKVHnKVDoMF]9PGIFRh1RVI1eXY^7[:JI/k2X
`[ngc<Ji_[NSZJ25VXaXVXaXVXaXVH]WUhUUUhUUVXaXWHm[WhmUWXiTWhmUXI5WXi=YY9AZXi=YXI5W
Vh]QW8aRWHeSWXiTWhmUX91VX91VXI5WXI5WX99QX99NXHiQXha/Y8a^X8aSVhaDWhaIXHaIXHaIXX]I
XX]IY8]IY8]IYX]IXHYHXHYHXHYHXHYHXHYHXHYHXHYHXHYHXX]IXX]IXhaJXhaJXhaJY8eK002/VGj[
V7f[V7fZUWfZUGn[UX2[UX6/Uh:ZVGnZVGnZVGnZVGnZVGnZVGnZVGnZVGnYV7jYV7jYV7jYV7jYV7jY
V7jYV7jYV7jZVGnZVGnYV7jYV7jYV7jXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfXUgfWUWbW
UWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbXUgfXUgfXUgfWUWbVUG^V
UG^UU7ZUU7ZWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbWUWbTTgRT
TgRUU7VUU7VVUGZVUGZWUW^WUW^WUW^WUW^WUW^WUW^WUW^WUW^WUW^WUW^YUW^YUW^YUW^YUW^YUW^Y
UW^YUW^YUW^VU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NTTWFTTWFUTgJUTgJUTgJVU7NVU7NVU7NUTgJU
TgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJVU7NVU7NWUGRWUGRWUGRW
UGRVU7NVU7NUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJTTW>TTW>TTW>TTW>TTW>TTW>TTW>TTW>TTW>T
TW>TTW>TTW>TTW>TTW>TTW>TTW>UTgBUTgBTTW>STG:STG:TTW>UTgBUTgBSTG:STG:TTW>TTW>TTW>U
TgBUTgBUTgBTTW>TTW>TTW>TTW>TTW>TTW>TTW>TTW>VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2V
Tg2VTg2VTg2VTg2VTg2VTg2VTg2UTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnU
TVnUTVnUTVnTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjST6fS
T6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fRSfbRSfbRSfbRSfbRSfbR
SfbRSfbRSfbRSfZRSfZRSfZRSfZRSfZRSfZRSfZRSfZRTFJRTFJQSfJPSVFPSFNQSVVRSfZRSfZRSfVR
SfVRSfVRSfVRSfVRSfVRSfVRSfVOSVNOSVNOSVNPSFNRSFNRSFNTSFNTSFNOS6JOS6JOS6JOS6JOS6JO
S6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JNRfFNRfFNRfFOS6JPSFNPSFNQSVRQSVRNRfFN
RfFNRfFNRfFNRfFNRfFNRfFNRfFLRF>MRVBMRVBNRfFNRfFOS6JPSFNPSFNLRF>MRVBOS6JPSFNPSFNO
S6JMRVBLRF>MRf:MRf:MRf:MRf:MRf:MRf:MRf:MRf:NS6>NS6>NS6>NS6>NS6>NS6>NS6>NS6>QRf:R
S6>SSFBSSFBSSFBSSFBRS6>QRf:PRejPRejPRejQS5nQS5nRSF2RSF2RSF2NS6>NS6>NS6>NS6>NS6>N
S6>NS6>NS6>RSF2RSF2RSF2RSF2RSF2RSF2RSF2RSF2PS5fQSEjQSEjRSF2RS6:QRf6QRf:PRV6PSEZP
SEZPSEZPSEZPSEZPSEZPSEZPSEZORUfPRejRSF2SSV6SSV6RSF2PRejORUfQS5nQS5nPRejPRejPRejO
RUfORUfORUfORebORebORebORebORebORebORebORebORebORebORebORebORebORebORebORebORUJQ
S5RRSEVRSEVPReNORUJPReNRSEVPRUZPRUZPRUZPRUZPRUZPRUZPRUZPRUZPReNPReNPReNPReNPReNP
ReNPReNPReNQS5RQS5RQS5RQS5RQS5RQS5RQS5RQS5RPReRPReRPReRQS5VQS5VRSEZRSEZRSEZQRe^P
RUZOREVOREVOREVOREVPRUZQRe^LQeBMR5FNREJNREJNREJNREJMR5FLQeBKQEFMQeNNR5ROREVOREVN
R5RMQeNKQEFMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FKQU>MR5FNREJMR5FLQeBLQeBORUNQS5VLQeBL
QeBLQeBLQeBLQeBLQeBLQeBLQeBLQe2LQe2LQe2LQe2LQe2LQe2LQe2LQe2LQe2LQe2LQe2LQe2LQe2L
Qe2LQe2LQe2JQDjJQDjJQDjKQTnLQe2MR56ORU>PReBLQe2LQe2LQe2LQe2LQe2LQe2LQe2LQe2LQe2L
Qe2KQTnKQTnKQTnLQe2MR56NRE:LQe2LQe2MR56MR56MR56NRE:NRE:NRE:JQDjKQTnMR56MR56KQTnK
QTnMR56NRE:ORU>ORU>NRE:MR56MR56NRE:ORU>ORU>PReBPReBPReBPReBPReBPReBPReBPReBJQDjK
QTnLQe2MR56NRE:ORU>ORU>PReBMRE2NRU6NRU6NRU6ORe:ORe:ORe:ORe:PReBPReBPReBPReBPReBP
ReBPReBPReBMR56MR56MR56MR56MR56MR56MR56MR56MR56MR56MR56NRE:ORU>ORU>PReBPReBNRU6O
Re:ORe:ORU>PRUJPRUJPRENQRURHS5:ISE>LSEFOSERPReNOR5JOQEJPQ5FGRERLRUFRS5:VSDnXS52U
S5BPReRNRU^LREJNReROS5VOS5VMRUNMRUNNReRPSEZLQeZPRejSSV6QS5nMR5^LQeZPRejUT6>KT5NO
TefPTenKSEfEQUREQE^OSVNXUW6PU7RUVXBYXIBc[JK7`K[>a[VfZiFCQf^NSV>LS66HR5fCPeRAPEJD
Q5VJRUnOSfBQRe^PRUZQRe^SSEfUSenVT62USenSSEfPRUZPRUZQRe^RS5bSSEfTSUjUSenUSenSSEfQ
SUFST5>WSe^SQUnLOeZLQEFST5>OS5VQS5VQS5VRReVRReVTReVTReVVReVQRURQRURQRURQRURQRURQ
RURQRURQRURRReVRReVRReVSS5ZSS5ZSS5X00:^GOZ^GOZ^GOZ^GOZ^GOZ^GOZ^GOZ^GOZVHOZVHOZZI
OjZIOjZIOj^JP:^JP:^JP:VHOZVHOZVHOZVHOZVHOZVHOZVHOZVHOZRGOJRGOJRGOJRGOJRGOJRGOJRG
OJRGOJZIOjVHOZVHOZRGOJRGOJNFO:NFO:JENjNFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFNjNFNjNF
NjNFNjNFNjNFNjNFNjNFNjNFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NF
O:NFO:JENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJENZJE
NZJENZJENZJENZJENZJENZNEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NEN:NE
N:NEN:FCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZBBMJFCMZFC
MZFCMZJDMjJDMjJDMjNEN:>AM:BBMJFCMZFCMZFCMZFCMZBBMJ>AM:JDMJJDMJFCM:BBLjBBLjFCM:JD
MJJDMJ>ALZ>ALZBBLjBBLjFCM:FCM:FCM:FCM:BBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBLjBBLjBB
LjBBLjBBLjBBLjBBLjBBLj>ALZ>ALZBBLjBBLjFCM:FCM:FCM:FCM:BBLjBBLjBBLjBBLjBBLjBBLjBB
LjBBLjJCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:JCL:FBKjFBKjFB
KjFBKjFBKjFBKjFBKjFBKjBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBA
KZBAKZ>AK:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>AK:>AK:BAKZ>@KJ>@
KJ:?K::?K:6>Jj2=JZ2=JZ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?
JZ:?JZ6>J:6>J:6>J:6>J:6>J:6>J:6>J:6>J9n<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYj;IIn<IYn<
IYn<IZ2=Ij2=Ij2=Ij6>J:2?J:2?J9n>Ij2=Ij6<IZ6<IZ:;IJ:;IIj;IIj;IIj;IIj;IIj;IIj;IIj;
IIj;IIf:I9f:I9f:I9f:I9f:I9f:I9f:I9f:I9j;IIj;IIj;IIj;IIj;IIj;IIj;IIj;IJ>=I:>=I:>=
I:>=I:>=I:>=I:>=I:>=I:2>IJ2>IIn=I9n=I9j<Hif;HYf;HYf;HZ6;HZ6;HZ6;HZ6;HZ6;HZ6;HZ6;
HZ6;HZ2:HJ2:HJ2:HJ6;HZ:<Hj:<Hj>=I:>=I::>Gj:>Gj:>Gj6<Gj6;HJ6;HJ6;HZ6;HYj:Fin;G9n;
G:2<GJ2<GJ6=GZ6=GZ:>Gj6<Gj6<Gj2;GZ2;GZ2;GZ2;GYn:GIn:GJ6;HJ6;HJ6;HJ6;HJ6;HJ6;HJ6;
HJ6;HJ:=H::=H:6<Gj2;GZ2;GYn:GIn:GIj9G9j:Fij:Fij:Fin;G9n;G:2<GJ2<GJ2<GJ2<GIn;G9n;
G9j:Fij:Fin;G9n;G:2<GIn;G9n;G9n;G9n;G9n;G9n;G9n;G9n;G9b8FIb8FIf9FYj:Fij:Fin;G9n;
G9n;G:6;Fj2:FYj8F9n9FJ6;Fj6;Fj2:FYn9FJ6:F:6:F:6:F:6:F:6:F:6:F:6:F:6:F9n:Ein:Ein:
Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:Ein:
Ein:Ej2;F:2;F:2;F:2;F:2;F:2;F:2;F:2;F9j9EYn:Ein:Ej2;F:2;F:6<FJ6<FJ:=FYn:Ein:Ein:
Eij9EYf8EIf8EIb7E9b7E9j9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYb7E9b7E9b7E9b7E9b7E9b7E9b7
E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b5Dib5Dib5Dib5Dib5Dib5Dib5Dib5DiZ9DIb8DIf9
DYj9DYf8DIj6D9f5Cij4CYj9DYj9DYf8DIf8DIb7D9^6Ci^6Ci^6Cin:Dib7D9Z5CY^6Cij9DYn:Dif8
DIZ5CY^6Ci^6Cib7D9b7D9f8DIf8DIf8DIf8DJ2<Din;DYf9D9^7CYZ6CI^7CYb8Cib8Cib7D9b7D9b7
D9b7D9b7D9b7D9b7D9b7D9f8DIf8DIf8DIf8DIf8DIf8DIf8DIf8DIb5Dib5Dib5Dib5Dib5Dib5Dib5
Dib5Di^6Ci^6Ci^6Cib7D9f8DIf8DIj9DYj9DYn;DYn;DYj:DIj:DIf9D9f9D9b8Cib8Cif9D9f9D9f9
D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9b8Cif9D9f9D9f9D9j:DIj:DIj:
DIn;DYj9DYf8DIb7D9^6Cib7D9f8DIn:Dj2;E9b7D9b7D9f8DIf8DIj9DYj9DYn:Din:Dif9D9f9D9f9
D9f9D9f9D9f9D9f9D9f9D:2;E9n:Dij9DYj9DYj9DYj9DYn:Dj2;E:6:F:6:F:6:F:6:F:6:F:6:F:6:
F:6:F:>>Ej:=EZ:=EZ6<EJ6<EJ2;E:2;E9n:Dj><FZ6:F9n8EYj7EIj7EJ29Ej><FZF>G9nAKJ:DL:bN
N[Z/R<>eTKb^RZNIMIF7Hi^9E:6>Fin<FIR4E9n;G:fIJ[2KKZNBIJ6:F:6:F:6:F::;FJ:;FJ><FZ><
FZ><FZ:;FJ:;FJ><FZ><FZ><FZB=FjB=FjB=Fj6:F:29Ej29Ej29Ej29Ej6:F::;FJ><FYn:Din:Dj2;
E:6<EJ6<EJ:=EZ:=EZ:=EZ>>Ej:=EZ:=EZ6<EJ6<EJ2;E9n:Din:Dj>;EJ>;EJ>;EJ>;EJ>;EJ>;E@00
ZiMnZiMnZiMnZiMnZiMnZiMnZiMnZiMnZIQnZIQnZIQnZYUoZYUoZiZ0ZiZ0ZiZ0ZIQnZIQnZIQnZIQn
ZIQnZIQnZIQnZIQnZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZIQnZIQnZIQnZ9MmYiIlYiIlYiIlYYEk
YiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIkYiIkYiIkYiIkYiIkYiIkYiIkYiIkYiIlYiIlYiIlYiIl
YiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYYEjYYEjYYEjYYEjYYEjYYEjYYEjYYEj
YYEjYYEjYYEjYYEjYYEjYYEjYYEjYYEjYYEjYYEjYYEjYYEjYYEjYYEjYYEjYYEjYYAgYYAgYYAgYYAg
YYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAgYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=f
YI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fY99eY99eYI=fYI=fYI=fYYAgYYAgYYAgXi5dY99eYI=fYI=f
YI=fYI=fY99eXi5dYYAeYYAeYI=dY99cY99cYI=dYYAeYYAeXi5bXi5bY99cY99cY99cYI=dYI=dYI=d
Y99eY99eY99eY99eY99eY99eY99eY99eY99cY99cY99cY99cY99cY99cY99cY99cXi5bXi5bY99cY99c
Y99cYI=dYI=dYI=dY99cY99cY99cY99cY99cY99cY99cY99cYY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`
YY=`YY=`YY=`YY=`YY=`YY=`YY=`YY=`YI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_Y95^Y95^Y95^Y95^
Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/
Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/Xi5/Xi1]Xi1]XXm/XXm/XHi[XHi[X8eZX8eZXXm/XXm/XXm/XXm/
XXm/XXm/XXm/XXm/XXmZXXmZXXmZXXmZXXmZXXmZXXmZXXmZX8eWX8eWX8eWX8eWX8eWX8eWX8eWX8eW
WhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWX]UWX]UWhaVWhaVWhaVX8eWX8eWX8eWX8mXWhiWWhiWX8eW
XHaVX8]UXX]UXX]UWX]UWX]UWX]UWX]UWX]UWX]UWX]UWX]UWHYTWHYTWHYTWHYTWHYTWHYTWHYTWHYT
WX]UWX]UWX]UWX]UWX]UWX]UWX]UWX]UXXaSXXaSXXaSXXaSXXaSXXaSXXaSXXaSWheTWheTWheTWXaS
WXaSWH]RWH]RWH]RXH]RXH]RXH]RXH]RXH]RXH]RXH]RXH]RX8YQX8YQX8YQXH]RXH]RXXaSXXaSXXaS
XHeNXHeNXHeNXHaOXH]QXH]QXH]RXH]RWh]LWh]LX8aMX8aMX8aMX8aMX8aMXHeNXXePXXePXXePXHaO
XHaOXHaOXHaOXHaOXHaOXHaOXHaOXHaOXHaOXHaOXHaOXHaOXHaOXHaOXHaOX8]NX8]NWhYMWhYMWXUL
WXYKWXYKWXYKWh]LWh]LWh]LX8aMX8aMX8aMWh]LWXYKWXYKWXYKWXYKWh]LX8aMWh]LWh]LWh]LWh]L
Wh]LWh]LWh]LWh]LWHUJWHUJWHUJWXYKWXYKWXYKWXYKWXYKXH]KWhUIWXQHWhUIXH]KXH]KX8YJWXQH
XHYHXHYHXHYHXHYHXHYHXHYHXHYHXHYHWhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYG
WhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGWhYGX8]HX8]HX8]HX8]HX8]HX8]HX8]HX8]H
WXUFWXUFWhYGWhYGX8]HX8]HXHaIXHaIWhYGWhYGWXUFWXUFWHQEWHQEW8MDW8MDWHQEWHQEWHQEWHQE
WHQEWHQEWHQEWHQEW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MD
W8ECW8ECW8ECW8ECW8ECW8ECW8ECW8ECVXUAW8QAW8QAWHQAWHQAWXI@WHE?WXA>WHQAWHQAWHQAW8M@
W8M@W8M@W8M@W8M@WXUBW8M@VXE>VhI?WHQAWXUBWHQAVXE>VhI?VhI?W8M@W8M@W8M@WHQAWHQAWHQA
Wh]BWXYAW8Q?VhM>VXI=VhM>W8Q?W8Q?W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@WHQAWHQAWHQAWHQA
WHQAWHQAWHQAWHQAW8ECW8ECW8ECW8ECW8ECW8ECW8ECW8ECW8M@W8M@W8M@W8M@W8M@WHQAWHQAWHQA
Wh]BWXYAWXYAWXYAWHU@W8Q?W8Q?W8Q?WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@
WHU@WHU@WHU@WHU@W8Q?W8Q?WHU@WHU@WHU@WXYAWXYAWXYAWXUBWHQAW8M@W8M@W8M@WHQAWhYCX8]D
W8M@W8M@W8M@WHQAWXUBWXUBWXUBWhYCWHU@WHU@WHU@WHU@WHU@WHU@WHU@WHU@WhYCWhYCWXUBWHQA
WHQAWXUBWhYCWhYCXHYHXHYHXHYHXHYHXHYHXHYHXHYHXHYHXXeFXXeFXHaEXHaEX8]DX8]DWhYCWhYC
XX]IXHYHWhQFWXMEWXMEX8UGXX]IY8eKWHaUVhYSVhYSXI1YYiI_YYE^WXeVUXENX8]GY8mKXXeJVhEE
WhUIZiAV[9EWY8ePXHYHXHYHXHYHXHYHXX]IXX]IXhaJXhaJXX]IXX]IXX]IXhaJXhaJXhaJY8eKY8eK
XHYHX8UGX8UGWhQFX8UGXHYHXX]IXhaJX8]DX8]DX8]DXHaEXHaEXHaEXHaEXHaEXXeFXXeFXHaEXHaE
X8]DX8]DWhYCWhYCXh]EXh]EXh]EXh]EXh]EXh]E002[Ugj[Ugj[Ugj[Ugj[Ugj[Ugj[Ugj[UgjYV7jY
V7jYV7jYV7jZVGnZVGn[VX2[VX2YV7jYV7jYV7jYV7jYV7jYV7jYV7jYV7jWUWbWUWbWUWbWUWbWUWbW
UWbWUWbWUWbXUgfXUgfXUgfXUgfWUWbWUWbWUWbVUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUGZV
UGZVUGZVUGZVUGZVUGZVUGZVUGZVUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^V
UG^VUG^VUG^UU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VU
U7VUU7VUU7VUU7VUU7VUU7VUU7VVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NV
U7NVU7NVU7NUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJTTWFT
TWFTTWFUTgJUTgJVU7NVU7NVU7NSTGBSTGBTTWFUTgJUTgJTTWFSTGBSTGBVU7FUTgBUTgBTTW>TTW>U
TgBUTgBVU7FSTG:STG:STG:TTW>TTW>TTW>UTgBUTgBTTWFTTWFTTWFTTWFTTWFTTWFTTWFTTWFTTW>T
TW>TTW>TTW>TTW>TTW>TTW>TTW>STG:STG:STG:TTW>TTW>TTW>UTgBUTgBTTW>TTW>TTW>TTW>TTW>T
TW>TTW>TTW>VTg2VTg2VTg2VTg2VTg2VTg2VTg2VTg2UTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnUTVnU
TVnUTVnUTVnUTVnUTVnUTVnUTVnTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjTTFjT
TFjTTFjTTFjRT6^RT6^RT6^RT6^RT6^RT6^RT6^RT6^RT6^RT6^RT6^RT6^RT6^RT6^RT6^RT6^RSfbR
SfbRSfbRSfbQSV^QSV^QSV^PSFZQSV^QSV^QSV^QSV^QSV^QSV^QSV^QSV^QSVVQSVVQSVVQSVVQSVVQ
SVVQSVVQSVVPSFNPSFNPSFNPSFNPSFNPSFNPSFNPSFNOS6JOS6JOS6JOS6JOS6JOS6JOS6JOS6JNRfFN
RfFNRfFOS6JOS6JPSFNPSFNPSFNOSVNOSVNNSFJOS6JQS6JPRfFRRfFRRfFNRfFNRfFNRfFNRfFNRfFN
RfFNRfFNRfFMRVBMRVBMRVBMRVBMRVBMRVBMRVBMRVBNRfFNRfFNRfFNRfFNRfFNRfFNRfFNRfFPRV6P
RV6PRV6PRV6PRV6PRV6PRV6PRV6NS6>NS6>NS6>NS6>MRf:MRf:MRf:LRV6QRf:QRf:QRf:QRf:QRf:Q
Rf:QRf:QRf:PRV2PRV2PRV2PRV2QRf6QRf6QRf6RS6:PS5fPS5fPS5fPRejPRV2PRV2PRV6PRV6PS5fP
S5fPS5fPS5fORebORebORebORebRSF2RSF2RSF2RSF2RSF2RSF2RSF2RSF2PRejPRejPRejPRejPRejP
RejPRejPRejQS5nPRejPRejPRejORUfORUfORUfORUfMREZNRU^NRU^NRU^ORebORebORebORebORebO
RebNRU^MREZMREZNRU^ORebORebNRU^NRU^NRU^NRU^NRU^NRU^NRU^NRU^NRU^NRU^NRU^MREZMREZM
REZMREZMREZQRe^OREVNR5RNR5RPRUZQRe^PRUZNR5RPRENPRENPRENPRENPRENPRENPRENPRENNREJN
REJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJNREJN
REJNREJNREJORUNORUNORUNORUNORUNORUNORUNORUNNREJNREJNREJORUNORUNORUNPReRPReRNREJN
REJNREJMR5FMR5FMR5FLQeBLQeBMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FLQeBLQeBLQeBLQeBLQeBL
QeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQeBLQE>LQE>LQE>LQE>LQE>LQE>LQE>LQE>IR52K
Qe2LR56MR56MR56NQU2MQDnNQ4jKQTnKQTnKQTnLQe2LQe2LQe2LQe2LQe2MR56LQe2JQDjKQTnMR56M
R56LQe2KQTnKQTnKQTnKQTnLQe2LQe2LQe2MR56MR56NRU6MRE2LR4nKQdjKQdjKQdjKQdjLR4nLQe2L
Qe2LQe2LQe2LQe2LQe2LQe2LQe2MR56MR56MR56MR56MR56MR56MR56MR56LQU:LQU:LQU:LQU:LQU:L
QU:LQU:LQU:LQe2LQe2LQe2LQe2LQe2KQTnKQTnKQTnNRU6NRU6MRE2MRE2MRE2LR4nLR4nLR4nMRE2M
RE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2LR4nLR4nLR4nMRE2MRE2N
RU6NRU6NRU6MR56LQe2LQe2LQe2LQe2MR56NRE:ORU>LQe2LQe2LQe2MR56MR56MR56NRE:NRE:MRE2M
RE2MRE2MRE2MRE2MRE2MRE2MRE2ORU>NRE:NRE:MR56MR56NRE:NRE:ORU>PRUJPRUJPRUJPRUJPRUJP
RUJPRUJPRUJQS5FQS5FPReBPReBPReBORU>ORU>ORU>QRURPRENNQeFNQeFNQeFPRENRReVSS5ZORUfL
QeZIQ5NIQ5NLQeZNREbORUfNREbQS5RUT5bRSEVKQU>MQeNUSenVSf6OR5ZPRENPRENPRENQRURQRURR
ReVRReVRReVQRURQRURRReVRReVRReVSS5ZSS5ZSS5ZPRENPRENOR5JOR5JPRENPRENRReVRReVQS5FQ
S5FQS5FPReBPReBPReBPReBPReBQS5FQS5FQS5FQS5FPReBPReBPReBORU>RRUBRRUBRRUBRRUBRRUBR
RU@00:ZFOJZFOJZFOJZFOJZFOJZFOJZFOJZFOJRGOJRGOJVHOZVHOZVHOZZIOjZIOjZIOjRGOJRGOJRG
OJRGOJRGOJRGOJRGOJRGOJNFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:NF
O:NFO:JENjJENjJENjJENjJENjJENjJENjJENjJENZJENZJENZJENZJENZJENZJENZJENZJENjJENjJE
NjJENjJENjJENjJENjJENjJENjJENjJENjJENjJENjJENjJENjJENjFDNJFDNJFDNJFDNJFDNJFDNJFD
NJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNJJDMjJDMjJD
MjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjFCMZFCMZFCMZFCMZFCMZFCMZFC
MZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZFCMZ>AM:BBMJBBMJBBMJFCMZFCMZFCMZJDMj:@Lj>AM:BB
MJBBMJBBMJBBMJ>AM::@LjFCM:FCM:BBLjBBLjBBLjBBLjFCM:FCM::@LJ:@LJ>ALZ>ALZBBLjBBLjBB
LjBBLj>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>ALZ>ALZ>ALZ>ALZ>ALZ>ALZ>ALZ>ALZ:@LJ:@LJ>A
LZ>ALZBBLjBBLjBBLjBBLj>ALZ>ALZ>ALZ>ALZ>ALZ>ALZ>ALZ>ALZFBKjFBKjFBKjFBKjFBKjFBKjFB
KjFBKjBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZ>@KJ>@KJ>@
KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@
Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj:@Jj6>Jj6>Jj6>Jj6>Jj6>Jj6>Jj6>Jj6>Jj2=JZ2=JZ2=
JZ2=JZ2=JZ2=JZ2=JZ2=JZ6>JJ6>JJ6>JJ6>JJ6>JJ6>JJ6>JJ6>JJ2=Ij2=Ij2=Ij2=Ij2=Ij2=Ij2=
Ij2=Iin<IYn<IYn<IYn<IYn<IYn<IYn<IYn<IYf:I9j;IIj;IIj;IIn<IYn<IYn<IZ2=Iij=IYj=IYj=
IYn<IZ2;IJ2;IJ:;IJ:;IIf:I9f:I9f:I9f:I9f:I9f:I9f:I9f:I9b9Hib9Hib9Hib9Hib9Hib9Hib9
Hib9Hif:I9f:I9f:I9f:I9f:I9f:I9f:I9f:I9n9H9n9H9n9H9n9H9n9H9n9H9n9H9n9H9f;HYf;HYf;
HYf;HYb:HIb:HIb:HIb:HJ2:HJ2:HJ2:HJ2:HJ2:HJ2:HJ2:HJ2:HJ2:H:2:H:2:H:2:H:2:H:2:H:6;
HJ6;HIn;G9n;G9n;G9n:GIn9Gj2:H:2:HJ2:HJ6=GZ2<GJ2<GIn;G9n;G9j:Fij:Fij:Fj2;GZ2;GZ6<
Gj6<Gj6<Gj6<Gj:=H::=H9n;G9n;G9n;G9n;G9n;G9n;G9n;G9n;G9n:GIn:GIn:GIn:GIn:GIn:GIn:
GIn:GIf9FYf9FYf9FYj:Fij:Fin;G9n;G9n;G9n;G9j:Fij:Fif9FYf9FYj:Fij:Fin;G9j:Fij:Fij:
Fij:Fij:Fij:Fij:Fij:Fij:Fij:Fij:Fif9FYf9FYb8FIb8FI^7F:2:FYn9FIf7Eij8F:2:FZ2:FYn9
FIj8F:29Ej29Ej29Ej29Ej29Ej29Ej29Ej29Eij9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9
EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYn:Ein:Ein:Ein:Ein:Ein:Ein:
Ein:Eij9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYf8EIf8EIf8EIf8EIf8EIb7E9b7E9b7E9f8EIf8EIf8
EIf8EIf8EIf8EIf8EIf8EIb7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7
E9b7E9^4DY^4DY^4DY^4DY^4DY^4DY^4DY^4DYR7CiZ6Ci^7D9b7D9b7D9j6D9f5Cij4CYZ5CYZ5CYZ5
CY^6Cib7D9b7D9f8DIf8DIb7D9^6Ci^6Ci^6Cib7D9b7D9^6Ci^6CiZ5CYZ5CY^6Ci^6Cib7D9b7D9b7
D9b7D9b8Cib8Ci^7CY^7CY^7CY^7CY^7CY^7CY^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6Cif8DIf8DIf8
DIf8DIf8DIf8DIf8DIf8DI^5DI^5DI^5DI^5DI^5DI^5DI^5DI^5DIf8DIf8DIb7D9b7D9^6CiZ5CYZ5
CYZ5CYf9D9f9D9f9D9f9D9b8Cib8Cib8Cib8Cif9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9f9
D9f9D9f9D9f9D9f9D9f9D9^7CYb8Cib8Cib8Cif9D9f9D9f9D9j:DIb7D9b7D9b7D9b7D9b7D9f8DIj9
DYj9DYb7D9b7D9b7D9b7D9f8DIf8DIf8DIf8DIf9D9f9D9f9D9f9D9f9D9f9D9f9D9f9D9n:Dij9DYf8
DIf8DIf8DIf8DIj9DYn:Din9EIn9EIn9EIn9EIn9EIn9EIn9EIn9EIn:Din:Din:Din:Din:Din:Din:
Din:Din8EYn8EYj7EIf6E9j7EIn8EZ29Ej6:F9j7EJ29Ej><FZB=Fj><FZ:;FJ6:F:6:F:6<EJB?F::<
F9b6DYf6E::;Fj:;Fij6F9n8EYn8EZ29Ej29Ej29Ej6:F:6:F:6:F:29Ej29Ej6:F:6:F:6:F::;FJ:;
FJ:;FJ29Ein8EYn8EYn8EYn8EZ29Ej6:F::;FJ6<EJ6<EJ6<EJ2;E:2;E9n:Din:Dij9DZ2;E:2;E:2;
E:2;E:2;E:2;E:2;E:2;E:::E:::E:::E:::E:::E:::E000ZYImZYImZYImZYImZYImZYImZYImZYIm
Z9MmZ9MmZ9MmZIQnZIQnZIQnZYUoZYUoZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmZ9MmYiIlYiIlYiIlYiIl
YiIlYiIlYiIlYiIlYYEkYYEkYYEkYYEkYiIlYiIlYiIlYiIlYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAj
YIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAiYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAjYIAj
YIAjYIAjYIAjYIAjY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=h
Y9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=hYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=fYI=f
YI=fYI=fYI=fYI=fY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99e
Xi5dXi5dXi5dY99eY99eYI=fYI=fYI=fXY1cXY1cXi5dY99eY99eXi5dXY1cXY1cYI=dY99cY99cXi5b
Xi5bY99cY99cYI=dXY1aXY1aXY1aXi5bXi5bXi5bY99cY99cXi5dXi5dXi5dXi5dXi5dXi5dXi5dXi5d
Xi5bXi5bXi5bXi5bXi5bXi5bXi5bXi5bXY1aXY1aXY1aXi5bXi5bXi5bY99cY99cXi5bXi5bXi5bXi5b
Xi5bXi5bXi5bXi5bYI9_YI9_YI9_YI9_YI9_YI9_YI9_YI9_Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^
Y95^Y95^Y95^Y95^Y95^Y95^Y95^Y95^Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]
Xi1]Xi1]Xi1]Xi1]XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[XY1[
X8eZX8eZX8eZX8eZX8eZXHi[XHi[XHi[WhaYWhaYWhaYWhaYWhaYWhaYWhaYWhaYX8eXX8eXX8eXX8eX
X8eXX8eXX8eXX8eXWhaVWhaVWhaVWhaVWhaVWhaVWhaVWhaVWX]UWX]UWX]UWX]UWX]UWX]UWX]UWX]U
WHYTWHYTWHYTWX]UWX]UWhaVWhaVWhaVWHaUWHaUWHaUWX]UX8]UX8]UXX]UXX]UWHYTWHYTWHYTWHYT
WHYTWHYTWHYTWHYTW8USW8USW8USW8USW8USW8USW8USW8USWHYTWHYTWHYTWHYTWHYTWHYTWHYTWHYT
WXQOWXQOWXQOWXQOWXQOWXQOWXQOWXQOVhUPVhUPVhUPVhUPW8YQW8YQW8YQW8YQX8YQX8YQX8YQX8YQ
X8YQX8YQX8YQX8YQX8]NX8]NX8]NX8]NX8]NX8]NWhYMWhYMWHUJWHUJWXYKWXULWhUOWhUOX8YQX8YQ
X8aMX8aMX8aMWh]LWXYKWXYKWHUJWHUJWXULWXULWXULWhYMWhYMX8]NX8]NX8]NWXYKWXYKWXYKWXYK
WXYKWXYKWXYKWXYKWXULWXULWXULWhYMWhYMWhYMWhYMWhYMW8QIWHUJWHUJWHUJWXYKWXYKWXYKWh]L
WXYKWXYKWHUJWHUJWHUJWHUJWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXYKWHUJWHUJ
W8QIVhMHVhMHVhMHX8YJWXQHWHMGWHMGWhUIX8YJWhUIWHMGWhQFWhQFWhQFWhQFWhQFWhQFWhQFWhQF
WHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQE
WHQEWHQEWHQEWHQEWXUFWXUFWXUFWXUFWXUFWXUFWXUFWXUFWHQEWHQEWHQEWHQEWHQEWHQEWHQEWHQE
W8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDVhICVhICVhICVhIC
VhICVhICVhICVhICVhICVhICVhICVhICVhICVhICVhICVhICVhABVhABVhABVhABVhABVhABVhABVhAB
UhI>VHE>VXI?W8M@W8M@WHE?WHE?WXA>VHA=VXE>VXE>VhI?VhI?W8M@W8M@W8M@VXE>VhI?VhI?VhI?
VhI?VXE>VhI?VhI?VXE>VXE>VXE>VhI?VhI?VhI?W8M@W8M@VXI=VXI=VhM>VhM>VhM>VhM>VhM>VhM>
VhI?VhI?VhI?VhI?VhI?VhI?VhI?VhI?W8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@VhI?VhI?VhI?VhI?
VhI?VhI?VhI?VhI?W8M@W8M@W8M@VhI?VhI?VXE>VXE>VHA=W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?
W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?VhM>VhM>VhM>W8Q?
W8Q?WHU@WHU@WHU@VhI?VhI?W8M@W8M@WHQAWHQAWHQAWHQAW8M@W8M@W8M@W8M@W8M@W8M@W8M@W8M@
W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?WXUBWXUBWHQAW8M@W8M@WHQAWXUBWXUBWXUBWXUBWXUBWXUB
WXUBWXUBWXUBWXUBWXUBWXUBWXUBWXUBWXUBWXUBWXUBWXUBWXMEWHIDWHIDWHIDWXMEWXMEWhQFX8UG
WH9?XHICYX]HYhaIYHYGXhQEXXMDXXMDWXYAX8]DX8]DWHMCWHIDWhQFX8UIWhQHWXMEWXMEWhQFWhQF
WhQFX8UGX8UGX8UGWhQFWhQFX8UGX8UGX8UGXHYHXHYHXHYHWhQFWhQFWXMEWXMEWhQFX8UGXHYHXHYH
XHaEXHaEX8]DX8]DWhYCWXUBWXUBWXUBWhYCWhYCWhYCWhYCWhYCX8]DX8]DX8]DXHUCXHUCXHUCXHUC
XHUCXHUC002YUGbYUGbYUGbYUGbYUGbYUGbYUGbYUGbWUWbWUWbXUgfXUgfYV7jYV7jYV7jYV7jWUWbW
UWbWUWbWUWbWUWbWUWbWUWbWUWbVUG^VUG^VUG^VUG^VUG^VUG^VUG^VUG^UU7ZUU7ZVUG^VUG^VUG^W
UWbWUWbWUWbUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7VUU7ZU
U7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZUU7ZTTgRTTgRTTgRTTgRTTgRT
TgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRTTgRUTgJU
TgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJTTWFTTWFTTWFTTWFTTWFT
TWFTTWFTTWFTTWFTTWFTTWFTTWFTTWFTTWFTTWFTTWFSTGBSTGBSTGBSTGBTTWFTTWFTTWFUTgJQSg:R
T7>STGBSTGBSTGBSTGBRT7>QSg:UTgBTTW>STG:STG:STG:STG:TTW>UTgBQSg2RT76RT76RT76STG:S
TG:STG:STG:RT7>RT7>RT7>RT7>RT7>RT7>RT7>RT7>RT76RT76RT76RT76RT76RT76RT76RT76QSg2R
T76RT76RT76STG:STG:STG:STG:RT76RT76RT76RT76RT76RT76RT76RT76TTFjTTFjTTFjTTFjTTFjT
TFjTTFjTTFjST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fST6fRSfbR
SfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbQSfZQSfZQSfZQSfZQSfZQ
SfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZQSfZOS6VOS6VOS6VPSFZPSFZPSFZQSV^QSV^OS6VO
S6VOS6VOS6VOS6VOS6VOS6VOS6VPSFRPSFRPSFRPSFRPSFRPSFRPSFRPSFROS6JOS6JOS6JOS6JOS6JO
S6JOS6JOS6JNRfFNRfFNRfFNRfFNRfFNRfFNRfFNRfFMRVBMRVBMRVBMRVBNRfFNRfFNRfFOS6JLRfBL
RfBLRfBMRVBPRfFPRfFRRfFSS6JLRF>LRF>LRF>LRF>LRF>LRF>LRF>LRF>KR6:KR6:KR6:KR6:KR6:K
R6:KR6:KR6:LRF>LRF>LRF>LRF>LRF>LRF>LRF>LRF>ORF2ORF2ORF2ORF2ORF2ORF2ORF2ORF2JR5nJ
R5nJR5nJR5nKRF2KRF2KRF2LRV6ORF2ORF2ORF2ORF2ORF2ORF2ORF2ORF2PS5fPS5fPS5fPS5fORebO
RebORebNRU^LR5VLR5VLR5VMR5^NR5jOREnORF2ORF2ORebORebORebNRU^NRU^NRU^NRU^NRU^LQeZL
QeZMR5^NREbNREbORUfPRejPRejNRUZNRUZNRUZNRUZNRUZNRUZNRUZNRUZMR5^MR5^NREbNREbNREbO
RUfORUfORUfLR5VLR5VLR5VMREZMREZNRU^NRU^NRU^NRU^MREZMREZLR5VLR5VMREZMREZNRU^MREZM
REZMREZMREZMREZMREZMREZMREZMREZLR5VLR5VLR5VLR5VLR5VKQeRKQeROREVNR5RLQUJMQeNOREVO
REVNR5RMQeNOR5JOR5JOR5JOR5JOR5JOR5JOR5JOR5JMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FM
R5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FMR5FNREJNREJNREJNREJNREJN
REJNREJNREJMR5FMR5FMR5FLQeBLQeBLQeBKQU>KQU>KQU>KQU>KQU>KQU>LQeBLQeBLQeBMR5FLQeBL
QeBLQeBLQeBLQeBLQeBLQeBLQeBKQU>KQU>KQU>KQU>KQU>KQU>KQU>KQU>KQU>KQU>KQU>KQU>KQU>K
QU>KQU>KQU>JPe6JPe6JPe6JPe6JPe6JPe6JPe6JPe6FQDfHQ4fIQDjKQTnLQe2MQDnMQDnNQ4jJQDjJ
QDjJQDjJQDjKQTnKQTnKQTnKQTnIQ4fKQTnLQe2KQTnJQDjIQ4fJQDjLQe2IQ4fJQDjJQDjJQDjKQTnK
QTnKQTnKQTnHQ4^IQDbJQTfKQdjLR4nKQdjKQdjJQTfJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjLQe2L
Qe2LQe2LQe2LQe2LQe2LQe2LQe2JQTfJQTfJQTfJQTfJQTfJQTfJQTfJQTfKQTnKQTnKQTnKQTnJQDjJ
QDjJQDjJQDjKQdjKQdjKQdjKQdjLR4nLR4nLR4nMRE2LR4nLR4nLR4nLR4nLR4nLR4nLR4nLR4nLR4nL
R4nLR4nLR4nLR4nLR4nLR4nLR4nKQdjKQdjKQdjKQdjLR4nLR4nLR4nMRE2JQDjJQDjKQTnLQe2MR56M
R56LQe2LQe2MR56LQe2LQe2LQe2KQTnKQTnKQTnKQTnLR4nLR4nLR4nLR4nLR4nLR4nLR4nLR4nNRE:M
R56LQe2LQe2LQe2LQe2MR56NRE:MRE2MRE2MRE2MRE2MRE2MRE2MRE2MRE2LQe2LQe2MR56MR56MR56N
RE:NRE:NRE:LQE>LQE>MQUBMQUBMQUBNQeFNQeFNQeFQQU>RQeBQQU>OQ56NPe2PQE:SR5FVReRNQdnP
RE6QRE>QRE>OQe>OQUBQR5JRRENMQUBMQUBNQeFNQeFNQeFOR5JOR5JOR5JNQeFNQeFOR5JOR5JPRENP
RENPRENPRENOR5JNQeFNQeFNQeFNQeFOR5JPRENQRURPReBORU>ORU>ORU>ORU>ORU>NRE:NRE:NRE:N
RE:NRE:ORU>ORU>ORU>PReBPReBQRE>QRE>QRE>QRE>QRE>QRE<00:VEO:VEO:VEO:VEO:VEO:VEO:VE
O:VEO:NFO:NFO:NFO:RGOJRGOJVHOZVHOZVHOZNFO:NFO:NFO:NFO:NFO:NFO:NFO:NFO:JENjJENjJE
NjJENjJENjJENjJENjJENjBCNJFDNZFDNZFDNZJENjNFO:NFO:NFO:FDNZFDNZFDNZFDNZFDNZFDNZFD
NZFDNZFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNJFDNZFDNZFDNZFDNZFDNZFDNZFDNZFDNZFDNZFDNZFD
NZFDNZFDNZFDNZFDNZFDNZ>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>B
Mj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMj>BMjBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBBMJBB
MJBBMJBBMJBBMJBBMJBBMJ>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>AM:>A
M:>AM::@Lj:@Lj>AM:>AM:>AM:BBMJBBMJBBMJ6?LZ:@Lj:@Lj>AM:>AM::@Lj:@Lj6?LZBBLjBBLj>A
LZ:@LJ:@LJ>ALZBBLjBBLj6?L:6?L::@LJ:@LJ:@LJ>ALZ>ALZ>ALZ:@Lj:@Lj:@Lj:@Lj:@Lj:@Lj:@
Lj:@Lj:@LJ:@LJ:@LJ:@LJ:@LJ:@LJ:@LJ:@LJ6?L:6?L::@LJ:@LJ:@LJ>ALZ>ALZ>ALZ:@LJ:@LJ:@
LJ:@LJ:@LJ:@LJ:@LJ:@LJBAKZBAKZBAKZBAKZBAKZBAKZBAKZBAKZ:?K::?K::?K::?K::?K::?K::?
K::?K:>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ:?K::?K::?K::?K::?K::?K::?K::?K::?K::?K::?
K::?K::?K::?K::?K::?K:6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?JZ6?
JZ6?JYj;J9j;J9n<JIn<JJ2=JZ2=JZ6>Jj6>Jj2=JZ2=JZ2=JZ2=JZ2=JZ2=JZ2=JZ2=JYn<Iin<Iin<
Iin<Iin<Iin<Iin<Iin<Iij;IIj;IIj;IIj;IIj;IIj;IIj;IIj;IIf:I9f:I9f:I9f:I9f:I9f:I9f:
I9f:I9b9Hib9Hif:I9f:I9f:I9j;IIj;IIj;II^:Hi^:Hi^:Hif:I:2;IJ2;IJ:;IJ><IYb9Hib9Hib9
Hib9Hib9Hib9Hib9Hib9Hi^8HY^8HY^8HY^8HY^8HY^8HY^8HY^8HYb9Hib9Hib9Hib9Hib9Hib9Hib9
Hib9Hj2:HJ2:HJ2:HJ2:HJ2:HJ2:HJ2:HJ2:HIV7GYV7GYV7GYZ8GiZ8Gi^9H9^9H9^9H9n9H9n9H9n9
H9n9H9n9H9n9H9n9H9n9H:2<GJ2<GJ2<GIn;G9n;G9j:Fij:Fij:FiZ6Ei^7F9^7F9b7FYf7GIj8GYn9
H9n9H9f9FYf9FYf9FYj:Fij:Fij:Fij:Fij:Fib7FYf8Fif8Fij9G9n:GJ2;GZ6<Gj6<Gif9FIf9FIf9
FIf9FIf9FIf9FIf9FIf9FIb7FYf8Fif8Fij9G9j9G9n:GIn:GIn:GIb8FIb8FIb8FIf9FYf9FYf9FYj:
Fij:Fij:Fif9FYb8FIb8FIb8FIb8FIf9FYj:Fif9FYf9FYf9FYf9FYf9FYf9FYf9FYf9FY^7F9^7F9^7
F9^7F9b8FIb8FIb8FIb8FIn9FIf7Eib6EYf7Eij8F9n9FIj8F9b6EYn8EYn8EYn8EYn8EYn8EYn8EYn8
EYn8EYb7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7E9b7
E9b7E9b7E9b7E9b7E9b7E9j9EYj9EYj9EYj9EYj9EYj9EYj9EYj9EYf8EIf8EIb7E9b7E9^6Di^6DiZ5
DYZ5DYZ5DYZ5DY^6Di^6Dib7E9b7E9f8EIf8EI^6Di^6Di^6Di^6Di^6Di^6Di^6Di^6DiZ5DYZ5DYZ5
DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ5DYZ3DIZ3DIZ3DIZ3DIZ3DIZ3DIZ3
DIZ3DIF4C9N3C9V5CY^6Ci^6Cif5Cif5Cin5Ci^6Ci^6CiZ5CYZ5CYZ5CYZ5CYZ5CYV4CIR3C9^6Cib7
D9^6CiV4CIR3C9Z5CYb7D9V4CIV4CIZ5CYZ5CYZ5CY^6Ci^6Ci^6CiN3BYR4BiZ6CI^7CYb8Cib8Ci^7
CYZ6CIZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CY^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6CiZ6CIZ6CIZ6
CIZ6CIZ6CIZ6CIZ6CIZ6CIV4CIZ5CYZ5CYZ5CYZ5CYZ5CY^6Ci^6CiZ6CIZ6CIZ6CI^7CYb8Cib8Cib8
Cif9D9^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CYZ6CIZ6CI^7
CY^7CY^7CYb8Cib8Cib8CiV4CIZ5CY^6Cif8DIf8DIb7D9^6Ci^6Cif8DIb7D9b7D9b7D9^6CiZ5CYZ5
CYZ5CY^7CY^7CY^7CY^7CY^7CY^7CY^7CY^7CYf8DIf8DIb7D9^6Ci^6Cib7D9f8DIf8DIb8Cib8Cib8
Cib8Cib8Cib8Cib8Cib8Ci^6Ci^6Cib7D9b7D9f8DIf8DIj9DYj9DY^4DY^4DYb5Dif6E9f6E9f6E9f6
E9f6E:>:F:68EYj5Dif4DYj5Dj68EZ>:F:B;FIn9Cj6:DZ><E:>;EJ28DYf5DIj5Dj68EYf6E9f6E9f6
E9f6E9j7EIj7EIj7EIn8EYj7EIj7EIj7EIj7EIn8EYn8EZ29Ej29Ein8EYj7EIj7EIf6E9j7EIn8EZ29
Ej6:F9j9DYj9DYj9DYj9DYn:Din:Din:Din:Dif8DIf8DIj9DYj9DYn:Din:Dj2;E:2;E:69Dj69Dj69
Dj69Dj69Dj69D`00ZIElZIElZIElZIElZIElZIElZIElZIElYiIlYiIlYiIlZ9MmZ9MmZ9MmZIQnZIQn
YiIlYiIlYiIlYiIlYiIlYiIlYiIlYiIlYYEkYYEkYYEkYYEkYYEkYYEkYYEkYYEkY9=iY9=iYIAjYIAj
YYEkYYEkYiIlYiIlY9=iY9=iY9=iY9=iY9=iY9=iY9=iY9=iY9=hY9=hY9=hY9=hY9=hY9=hY9=hY9=h
Y9=iY9=iY9=iY9=iY9=iY9=iY9=iY9=iY9=iY9=iY9=iY9=iY9=iY9=iY9=iY9=iXi9gXi9gXi9gXi9g
Xi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9gXi9g
Y99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eY99eXi5dXi5dXi5dXi5d
Xi5dXi5dXi5dXi5dXi5dXi5dXi5dXi5dXi5dXi5dXi5dXi5dXY1cXY1cXY1cXi5dXi5dY99eY99eY99e
XHmbXY1cXY1cXi5dXi5dXY1cXY1cXHmbY99cXi5bXi5bXY1aXY1aXi5bXi5bY99cXHm`XHm`XHm`XY1a
XY1aXY1aXi5bXi5bXY1cXY1cXY1cXY1cXY1cXY1cXY1cXY1cXY1aXY1aXY1aXY1aXY1aXY1aXY1aXY1a
XHm`XHm`XHm`XY1aXY1aXY1aXi5bXi5bXY1aXY1aXY1aXY1aXY1aXY1aXY1aXY1aY95^Y95^Y95^Y95^
Y95^Y95^Y95^Y95^XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]Xi1]
XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XXm/XHmZXHmZXHmZXHmZ
XHmZXHmZXHmZXHmZXHmZXHmZXHmZXHmZXHmZXHmZXHmZXHmZWX]XWX]XWX]XWhaYX8eZX8eZXHi[XHi[
XHi[XHi[XHi[XHi[XHi[XHi[XHi[XHi[WhaWWhaWWhaWWhaWWhaWWhaWWhaWWhaWWX]UWX]UWX]UWX]U
WX]UWX]UWX]UWX]UWHYTWHYTWHYTWHYTWHYTWHYTWHYTWHYTW8USW8USW8USWHYTWHYTWX]UWX]UWX]U
VXURVhYSVhYSWHYTWhYTX8]UXX]UXhaVW8USW8USW8USW8USW8USW8USW8USW8USVhQRVhQRVhQRVhQR
VhQRVhQRVhQRVhQRW8USW8USW8USW8USW8USW8USW8USW8USX8YQX8YQX8YQX8YQX8YQX8YQX8YQX8YQ
V8IMV8IMVHMNVHMNVXQOVhUPVhUPVhUPWhUPWhUPWhUPWhUPWhUPWhUPWhUPWhUPX8aMX8aMX8aMWh]L
WXYKWXYKWHUJWHUJVXIGVXIGVhMHW8MJWHMMWXQNWhUPWhUPW8QIW8QIWHUJWHUJWXYKWh]LWh]LWh]L
WHQKWXULWXULWhYMXHaOXXePXXePXhiQW8UFW8UFW8UFW8UFW8UFW8UFW8UFW8UFW8MJW8MJWHQKWHQK
WXULWhYMWhYMWhYMVhMHW8QIW8QIW8QIWHUJWHUJWHUJWXYKWXYKWHUJW8QIW8QIW8QIW8QIWHUJWXYK
WHUJWHUJWHUJWHUJWHUJWHUJWHUJWHUJVXIGVXIGVXIGVhMHW8QIW8QIWHUJWHUJWhUIWHMGW8IFWHMG
WXQHWhUIWXQHW8IFWXMEWXMEWXMEWXMEWXMEWXMEWXMEWXMEW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MD
W8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDW8MDWHQEWHQEWHQEWHQE
WHQEWHQEWHQEWHQEWHQEW8MDW8MDVhICVhICVXEBVXEBVHAAVHAAVXEBVXEBVhICVhICW8MDWHQEWHQE
VhICVhICVhICVhICVhICVhICVhICVhICVXEBVXEBVXEBVXEBVXEBVXEBVXEBVXEBVXEBVXEBVXEBVXEB
VXEBVXEBVXEBVXEBVX=AVX=AVX=AVX=AVX=AVX=AVX=AVX=AU8=;Uh=<V8A=VhI?VhI?WHE?WHE?WhE?
W8M@VhI?VhI?VXE>VXE>VHA=VHA=V8=<V8=<VXE>WHQAVhI?V8=<Uh9;VHA=W8M@VHA=VHA=VHA=VXE>
VXE>VXE>VhI?VhI?UX99V8A;VXI=VhM>W8Q?W8Q?VhM>VXI=VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>
VhI?VhI?VhI?VhI?VhI?VhI?VhI?VhI?VXI=VXI=VXI=VXI=VXI=VXI=VXI=VXI=V8=<VHA=VHA=VXE>
VXE>VhI?VhI?W8M@VHE<VXI=VXI=VhM>VhM>W8Q?W8Q?WHU@VhM>VhM>VhM>VhM>VhM>VhM>VhM>VhM>
VhM>VhM>VhM>VhM>VhM>VhM>VhM>VhM>VXI=VXI=VXI=VhM>VhM>W8Q?W8Q?W8Q?V8=<VHA=VhI?WHQA
WHQAW8M@VhI?VXE>WHQAW8M@W8M@VhI?VhI?VXE>VXE>VHA=VhM>VhM>VhM>VhM>VhM>VhM>VhM>VhM>
WHQAWHQAW8M@VhI?VhI?W8M@WHQAWHQAW8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?W8Q?VXE>VhI?VhI?W8M@
W8M@WHQAWHQAWXUBVX=AVhABW8ECWHIDWHIDWHIDWHIDW8ECW8EEVhADW8EEWXMGXHYJXHYJWXMGVX=C
Xh]AY8aBYXeEYXeEXXQBWX=@WX=@XXMEW8ECW8ECWHIDWHIDWHIDWXMEWXMEWXMEWHIDWHIDWXMEWXME
WhQFWhQFWhQFWhQFWXMEWXMEWHIDWHIDWXMEWhQFX8UGX8UGWHQAWHQAWHQAWXUBWhYCWhYCX8]DX8]D
WHQAWHQAWHQAWXUBWhYCWhYCX8]DX8]DX8QBX8QBX8QBX8QBX8QBX8QB002YUW^YUW^YUW^YUW^YUW^Y
UW^YUW^YUW^WU7VWU7VWU7VWU7VXUGZXUGZYUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^YUW^XUGZX
UGZXUGZXUGZXUGZXUGZXUGZXUGZZUWfXU7^WTgZVTWVVTWVWTgZXU7^ZUWfWU7VWU7VWU7VWU7VWU7VW
U7VWU7VWU7VWU7VWU7VWU7VWU7VWU7VWU7VWU7VWU7VUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNVTgRV
TgRUTWNTTGJTTGJUTWNVTgRVTgRUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNTTGJTTGJTTGJTTGJTTGJT
TGJTTGJTTGJVTgRUTWNTTGJST7FST7FTTGJUTWNVTgRUTgJUTgJTTWFTTWFSTGBRT7>RT7>RT7>VTW>V
TW>VTW>VTW>VTW>VTW>VTW>VTW>UT7BUT7BUT7BUT7BUT7BUT7BUT7BUT7BUTG:UTG:UTG:UTG:UTG:U
TG:UTG:UTG:VTW>VTW>UTG:TT76TT76SSg2SSg2RSVnRT7>RT7>RT7>RT7>RT7>RT7>RT7>RT7>UTG:T
T76TT76SSg2SSg2TT76TT76UTG:UTG:UTG:UTG:TT76TT76TT76SSg2SSg2PTG6PTG6PTG6PTG6PTG6P
TG6PTG6PTG6TT76TT76SSg2SSg2SSg2SSg2RSVnRSVnTT76SSg2SSg2RSVnRSVnSSg2SSg2TT76VTW>U
TG:TT76RSVnRSVnRSVnRSVnRSVnTTFbTTFbTTFbTTFbTTFbTTFbTTFbTTFbST6fST6fST6fST6fST6fS
T6fST6fST6fSSfbSSfbSSfbSSfbSSfbSSfbSSfbSSfbUTVfTTFbTTFbST6^ST6^RSfZQSVVQSVVRSV^R
SV^RSV^RSV^RSV^RSV^RSV^RSV^RSfZRSfZRSfZRSfZRSfZRSfZRSfZRSfZQSFZQSFZQSFZQSFZQSFZQ
SFZQSFZQSFZQSVVQSVVQSVVQSVVQSVVQSVVQSVVQSVVNS6>OS6JPSFNPSFRPSFRPS6VORfRNRFVNRfJO
S6NOS6NPSFNOSFBNS6>MS66LRf2QRVBQRVBQRVBQRVBQRVBQRVBQRVBQRVBNRfJNRfJNRfJNRfJNRfJN
RfJNRfJNRfJPRV6PRV6QRf:QRf:RS6>RS6>RS6>RS6>NR5nORF2ORF2PRV6PRV6ORF2ORF2NR5nPRV6O
RF2ORF2NR5nNR5nORF2ORF2PRV6NQf6NQf6NQf6NQf6NQf6NQf6NQf6NQf6NR5nNR5nNR5nNR5nNR5nN
R5nNR5nNR5nNREbNREbNREbNREbNREbNREbNREbNREbPRejORUfORUfNREbNREbMR5^LQeZLQeZORF2N
R5nMQejLQUfLQUfNR5nORF2QRf:QREnQREnQREnPR5jPR5jOQefNQUbNQUbPRE^PRE^PRE^PRE^PRE^P
RE^PRE^PRE^MREZMREZMREZMREZMREZMREZMREZMREZMREZMREZMREZMREZMREZMREZMREZMREZOR5ZO
R5ZOR5ZOR5ZOR5ZOR5ZOR5ZOR5ZMQURMQURNQeVNQeVOR5ZPRE^PRE^PRE^KREZKREZKREZLRU^LRU^L
RU^MRebMRebNQeVNQeVNQeVNQeVNQeVNQeVNQeVNQeVOR5ZOR5ZOR5ZOR5ZOR5ZOR5ZOR5ZOR5ZNR5RN
R5RNR5RNR5RNR5RNR5RNR5RNR5RMQeNMQeNMQeNMQeNNR5RNR5RNR5ROREVOR5JOR5JOR5JOR5JOR5JO
R5JOR5JOR5JMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBOR5JO
R5JOR5JPRENPRENPRENQRURQRURLQE>MQUBMQUBMQUBNQeFNQeFNQeFOR5JORU>ORU>OREFNR5BMQUBM
QUBLQEFLQEFKQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:JQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjKQTnK
QTnKQTnKQTnKQTnKQTnKQTnKQTnLQe2KQTnKQTnJQDjJQDjIQ4fIQ4fHPdbLQe2LQe2KQTnJQDjJQDjI
Q4fIQ4fHPdbLQe2LQe2KQTnJQDjJQDjIQ4fIQ4fHPdbLQDfLQDfLQDfKQ4bKQ4bJPd^JPd^JPd^HQ4^I
QDbIQDbJQTfJQTfIQDbIQDbHQ4^LQdZLQTbKQD^KQ4bKQ4bKPdfJPTbJPTjIQDbIQDbIQDbIQDbIQDbI
QDbIQDbIQDbJQTfJQTfJQTfJQTfJQTfJQTfJQTfJQTfKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bK
Q4bLQDfLQDfLQDfMQTjMQTjMQTjJPd^JPd^JPd^KQ4bKQ4bLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfL
QDfLQDfLQDfMQTjNQdnOR52OR52OR52OR52NQdnMQTjLQDfLQDfMQTjMQTjMQTjNQdnNQdnNQdnNQdnN
QdnMQTjLQDfLQDfMQTjNQdnNQdnLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfL
QDfLQDfLQDfMQE6MQE6MQE6MQE6MQE6MQE6MQE6MQE6LQDfLQDfMQTjMQTjMQTjNQdnNQdnNQdnLPe6L
Pe6MQ5:MQ5:MQ5:NQE>NQE>NQE>NRE:NRE:NRE:NRE:MR56MR56MR56MR56MQTjMQTjMQTjMQTjMQTjM
QTjMQTjMQTjMQDnMQDnNQU2NQU2OQe6OQe6OQe6OQe6NQU2NQU2NQU2NQU2NQU2NQU2NQU2NQU2LQDfL
QDfLQDfMQTjMQTjNQdnNQdnNQdnQR5JQR5JRRENSRURSRURRRENQR5JQR5JOQe6OQe6OQe6OQe6OQe6O
Qe6OQe6OQe6PR5:PR5:OQe6NQU2NQU2OQe6PR5:PR5:QRE>QRE>QRE>QRE>QRE>QRE>QRE>QRE>QRE>Q
RE>QRE>QRE>QRE>QRE<00:VFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjNDNJNDNJNDNJNDNJRENZRENZVF
NjVFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjVFNjRENZRENZRENZRENZRENZRENZRENZRENZVEO:RDNjNC
NZJBNJJBNJNCNZRDNjVEO:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JC
N:JCN:FBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjJCN:JCN:FBMjBAMZBAMZFBMjJCN:JCN:FBMjFBMjFB
MjFBMjFBMjFBMjFBMjFBMjBAMZBAMZBAMZBAMZBAMZBAMZBAMZBAMZJCN:FBMjBAMZ>@MJ>@MJBAMZFB
MjJCN:BBMJBBMJBBMJ>AM:>AM::@Lj:@Lj:@LjJBLjJBLjJBLjJBLjJBLjJBLjJBLjJBLjF@M:F@M:F@
M:F@M:F@M:F@M:F@M:F@M:FALZFALZFALZFALZFALZFALZFALZFALZFALZFALZFALZB@LJB@LJ>?L:>?
L::>Kj:@Lj:@Lj:@Lj:@Lj:@Lj:@Lj:@Lj:@LjFALZB@LJB@LJ>?L:>?L:B@LJB@LJFALZFALZFALZB@
LJB@LJB@LJ>?L:>?L:>?L::@LJ:@LJ:@LJ:@LJ:@LJ:@LJ:@LJ:@LJ>?L:>?L:>?L:>?L:>?L:>?L::>
Kj:>KjB@LJ>?L::>Kj:>Kj:>Kj:>Kj>?L:B@LJFALZB@LJ>?L::>Kj:>Kj:>Kj:>Kj:>KjBAK:BAK:BA
K:BAK:BAK:BAK:BAK:BAK:>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>@KJ>?K:>?K:>?K:>?K:>?K:>?K:>?
K:>?K:BAK:BAK:>@Jj>@Jj:?JZ:?JZ6>JJ6>JJ:>Jj:>Jj:>Jj:>Jj:>Jj:>Jj:>Jj:>Jj2=J:2=J:2=
J:2=J:2=J:2=J:2=J:2=J:2<JJ2<JJ2<JJ2<JJ2<JJ2<JJ2<JJ2<JJ2=J:2=J:2=J:2=J:2=J:2=J:2=
J:2=J9j<Hin<IZ2=Ij2=J:2=J:2<JIn;J9j9JIj;IYn<Iin<Iin<IYn=I9j<Hif<HIb;H:6:I:6:I:6:
I:6:I:6:I:6:I:6:I:6:I9j;IYj;IYj;IYj;IYj;IYj;IYj;IYj;IZ2:HJ2:HJ2:HJ6;HZ6;HZ:<Hj:<
Hj:<Hij8Gij8Gin9H:2:HJ2:HIn9H9j8Gij8Gj2:HIn9H9j8Gij8Gij8Gij8Gin9H:2:HIj7HIj7HIj7
HIj7HIj7HIj7HIj7HIj7HIj8Gij8Gij8Gij8Gij8Gij8Gij8Gij8Gij9G9j9G9j9G9j9G9j9G9j9G9j9
G9j9G9n:GIn:GIj9G9j9G9f8Fif8Fib7FYb7FYn9H9j8Gif7GYb6GIb6GIf7GYn9H9n9H:29G:29G:29
G:29G:29G9n8Fin8Fin8Fj29Fj29Fj29Fj29Fj29Fj29Fj29Fj29Fif9FYf9FYf9FYf9FYf9FYf9FYf9
FYf9FYf9FYf9FYf9FYf9FYf9FYf9FYf9FYf9FYn8FYn8FYn8FYn8FYn8FYn8FYn8FYn8FYj7FIj7FIj7
FIj7FIn8FYn8FYn8FYn8FYV7F9V7F9Z8FIZ8FIZ8FI^9FY^9FY^9FYf6F9f6F9f6F9f6F9f6F9f6F9f6
F9f6F9n8FYn8FYn8FYn8FYn8FYn8FYn8FYn8FYf7Eif7Eif7Eif7Eif7Eif7Eif7Eif7Eib6EYf7Eif7
Eif7Eij8F9j8F9j8F9j8F9j7EIj7EIj7EIj7EIj7EIj7EIj7EIj7EIf6E9f6E9f6E9f6E9f6E9f6E9f6
E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9f6E9j7EIj7EIn8EYn8EYn8EYb5Dib5Dif6
E9f6E9f6E9j7EIj7EIj7EIf8DIf8DIf7Dif7Dif6E9b5Dib5EIb5EI^4DY^4DY^4DY^4DY^4DY^4DY^4
DY^4DYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CY^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6CiZ5CYZ5
CYZ5CYZ5CYZ5CYV4CIV4CI^6Ci^6Ci^6CiZ5CYZ5CYV4CIV4CIR3C9^6Ci^6Ci^6CiZ5CYZ5CYV4CIV4
CIR3C9b5CIb5CI^4C9^4C9^4C9Z3BiZ3BiZ3BiR4BiR4BiV5C9Z6CIZ6CIV5C9R4BiR4Bi^6BI^5Bi^5
Bi^4C9^4C9^3CIZ2C9Z2CYV5C9V5C9V5C9V5C9V5C9V5C9V5C9V5C9Z6CIZ6CIZ6CIZ6CIZ6CIZ6CIZ6
CIZ6CI^4C9^4C9^4C9^4C9^4C9^4C9^4C9^4C9^4C9^4C9^4C9b5CIb5CIb5CIf6CYf6CYZ3BiZ3BiZ3
Bi^4C9^4C9^4C9b5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIf6CYj7Cij7Cin8D9n8D9j7Cij7
Cif6CY^4C9^4C9^4C9^4C9b5CIb5CIf6CYf6CYj7Cif6CYf6CYb5CIb5CIf6CYf6CYj7Cib5CIb5CIb5
CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CIf5Cif5Cif5Cif5Cif5Cif5Cif5
Cif5Cib5CIb5CIb5CIf6CYf6CYj7Cij7Cij7Cib3DIb3DIb3DIf4DYf4DYj5Dij5Dij5Dib7D9b7D9b7
D9b7D9b7D9b7D9b7D9^6Cif6CYf6CYf6CYf6CYf6CYf6CYf6CYf6CYf5Cif5Cij6D9j6D9j6D9n7DIn7
DIn7DIj6D9j6D9j6D9j6D9j6D9j6D9j6D9j6D9f6CYf6CYf6CYf6CYj7Cij7Cin8D9n8D:27EJ68EZ:9
Ej:9Ej:9Ej:9Ej68EZ27EIn7DIn7DIn7DIn7DIn7DIn7DIn7DIn7DJ28DZ28DYn7DIj6D9j6D9n7DJ28
DZ28DZ28DZ28DZ28DZ28DZ28DZ28DZ28DZ28DZ28DZ28DZ28DZ28DZ28DZ28DP00Z9EjZ9EjZ9EjZ9Ej
Z9EjZ9EjZ9EjZ9EjYiAiYiAiYiAiYiAiZ9EjZ9EjZIIkZIIkZ9EjZ9EjZ9EjZ9EjZ9EjZ9EjZ9EjZ9Ej
YiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiZ9AkZ9AkYi=jYY9iYY9iYi=jZ9AkZ9AkYY=hYY=hYY=hYY=h
YY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9g
YY=hYI9gYI9gY95fY95fYI9gYI9gYY=hYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gY95fY95fY95fY95f
Y95fY95fY95fY95fYI9gY95fXi1eXi1eXi1eXi1eY95fYI9gY99eXi5dXi5dXi5dXY1cXY1cXY1cXY1c
YY9cYY9cYY9cYY9cYY9cYY9cYY9cYY9cYI1dYI1dYI1dYI1dYI1dYI1dYI1dYI1dYI5bYI5bYI5bYI5b
YI5bYI5bYI5bYI5bYI5bY91aY91aY91aXhm`Xhm`Xhm`Xhm`XY1cXY1cXY1cXY1cXY1cXY1cXY1cXY1c
YI5bY91aXhm`Xhm`Xhm`Xhm`Y91aYI5bYI5bY91aY91aY91aXhm`Xhm`Xhm`Xhm`XY1aXY1aXY1aXY1a
XY1aXY1aXY1aXY1aXXi_XXi_XXi_XXi_XXi_XXi_Xhm`Xhm`Xhm`Xhm`XXi_XHe^XHe^XXi_Xhm`Xhm`
Y91aY91aXhm`XXi_XHe^XHe^XXi_XXi_Xi1[Xi1[Xi1[Xi1[Xi1[Xi1[Xi1[Xi1[XXm/XXm/XXm/XXm/
XXm/XXm/XXm/XXm/XXi[XXi[XXi[XXi[XXi[XXi[XXi[XXi[Xi1[Xi1[Xi1[Xi1[XXmZXXmZXXmZXHiY
XHeZXHeZXHeZXHeZXHeZXHeZXHeZXHeZWhaWWhaWWhaWWhaWWhaWWhaWWhaWWhaWX8aYX8aYX8aYX8aY
X8aYX8aYX8aYX8aYX8eXX8eXX8eXX8eXX8eXX8eXX8eXX8eXWXaSWhaVWhaVX8eXX8eXWh]XWh]XWXUY
WX]VWX]VWhaWWhaVWheTWXaSWHaQW8]PXHYTXHYTXHYTXHYTXHYTXHYTXHYTXHYTWHYUWHYUWHYUWHYU
WHYUWHYUWHYUWHYUWhUPWhUPX8YQX8YQX8YQXH]RXH]RXH]RWHMNWXQOWhUPWhUPWhUPWhUPWXQOWHMN
WhUPWhUPWXQOWHMNWHMNWXQOWhUPWhUPWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMNWHMN
WHMNWHMNWHMNWHMNWHQKWHQKWHQKWHQKWHQKWHQKWHQKWHQKWXULWXULWXULWXULWHQKWHQKWHQKW8MJ
WhUOWXQNWHMMW8ILW8ILWHMMWHMMWXQNWhQKWhQKWhQKWhQKWhQKX8ULX8ULX8ULWhQJWhQJWhQJWhQJ
WhQJWhQJWhQJWhQJW8QIW8QIW8QIW8QIW8QIW8QIW8QIW8QIWXYKWXYKWXYKWXYKWXYKWXYKWXYKWXYK
WXMIWXMIWXMIWXMIWXMIWXMIWXMIWXMIWhQJWhQJWhQJWXMIWXMIWXMIWXMIWXMIVXIGVXIGVXIGVhMH
VhMHVhMHW8QIW8QIWHIHWHIHWHIHWHIHWHIHWHIHWHIHWHIHWXMIWXMIWXMIWXMIWXMIWXMIWXMIWXMI
WHMGWHMGWHMGWHMGWHMGWHMGWHMGWHMGW8IFW8IFW8IFWHMGWHMGWXQHWXQHWXQHWXMEWXMEWXMEWXME
WXMEWXMEWXMEWXMEWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHID
VhABVhABW8ECW8ECW8ECWHIDWHIDWHIDW8ECW8ECW8ECWHIDWHIDWXMEWXMEWXMEVhI?VhI?VhEAVhEA
VhABW8ECW8EEW8EEVhABVhABVhABVhABVhABVhABVhABVhABVXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>
VhI?VhI?VhI?VhI?VhI?VhI?VhI?VhI?VHA=VHA=VHA=VHA=VXE>VXE>VXE>VXE>VhI?VXE>VXE>VXE>
VHA=VHA=VHA=VHA=VhI?VXE>VXE>VXE>VHA=VHA=VHA=VHA=VhA<VhA<VhA<VhA<VX=;VX=;VX=;VH9:
Uh=:V8A;VHE<VHE<VHE<VHE<V8A;Uh=:VXE8VXA:VXA:VX=;VX=;VX9<Vh==Vh=?V8A;V8A;V8A;V8A;
V8A;V8A;V8A;V8A;VXI=VXI=VXI=VXI=VXI=VXI=VXI=VXI=VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;
VhA<VhA<VhA<VhA<W8E=W8E=W8E=WHI>VH9:VX=;VX=;VX=;VhA<VhA<VhA<VhA<W8E=W8E=W8E=W8E=
W8E=W8E=W8E=W8E=W8E=WHI>WXM?WXM?WXM?WXM?WHI>W8E=VH9:VH9:VX=;VX=;VX=;VhA<VhA<VhA<
WXM?WHI>W8E=W8E=W8E=W8E=WHI>WXM?W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=W8E=
W8E=W8E=W8E=W8E=WHE?WHE?WHE?WHE?WHE?WHE?WHE?WHE?W8E=W8E=W8E=W8E=WHI>WHI>WXM?WXM?
W8A@W8A@W8A@W8A@WHEAWHEAWXIBWXIBVXE>VXE>VXE>VXE>VXE>VXE>VhI?VhI?WHI>WHI>WHI>WHI>
WHI>WHI>WHI>WHI>WHE?WHE?WHE?WXI@WXI@WXI@WhMAWhMAWXI@WXI@WXI@WXI@WXI@WXI@WXI@WXI@
WHI>WHI>WXM?WXM?WhQ@WhQ@WhQ@WhQ@X8QDX8QDXHUEXXYFXXYFXHUEX8QDX8QDWhMAWhMAWhMAWhMA
WhMAWhMAWhMAWhMAX8QBWhMAWhMAWXI@WXI@WhMAWhMAX8QBX8QBX8QBX8QBX8QBX8QBX8QBX8QBX8QB
X8QBX8QBX8QBX8QBX8QBX8QB002XUGZXUGZXUGZXUGZXUGZXUGZXUGZXUGZWU7VWU7VWU7VWU7VXUGZX
UGZYUW^YUW^XUGZXUGZXUGZXUGZXUGZXUGZXUGZXUGZWU7VWU7VWU7VWU7VWU7VWU7VWU7VWU7VWTgZW
TgZWTgZVTWVVTWVWTgZWTgZWTgZVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRV
TgRVTgRVTgRUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNTTGJTTGJTTGJTTGJUTWNUTWNUTWNU
TWNUTWNUTWNUTWNUTWNUTWNUTWNST7FST7FST7FST7FST7FST7FST7FST7FTTGJTTGJST7FST7FST7FS
T7FTTGJTTGJSTGBSTGBRT7>RT7>RT7>RT7>RT7>RT7>UTG:UTG:UTG:UTG:UTG:UTG:UTG:UTG:TSg>T
Sg>TSg>TSg>TSg>TSg>TSg>TSg>TT76TT76TT76TT76TT76TT76TT76TT76SSg2SSg2SSg2SSg2SSg2S
Sg2SSg2SSg2QSg:QSg:QSg:QSg:QSg:QSg:QSg:QSg:TT76TT76SSg2RSVnRSVnSSg2TT76TT76TT76T
T76TT76SSg2SSg2SSg2RSVnRSVnSSg2SSg2SSg2SSg2SSg2SSg2SSg2SSg2QSFjQSFjRSVnRSVnRSVnR
SVnSSg2SSg2SSg2RSVnRSVnQSFjQSFjRSVnRSVnSSg2SSg2SSg2RSVnQSFjQSFjQSFjRSVnSSg2ST6^S
T6^ST6^ST6^ST6^ST6^ST6^ST6^RSfbRSfbRSfbRSfbRSfbRSfbRSfbRSfbRSV^RSV^RSV^RSV^RSV^R
SV^RSV^RSV^RSfZRSfZRSfZRSfZRSfZRSfZRSfZRSfZQSFZQSFZQSFZQSFZQSFZQSFZQSFZQSFZPSFRP
SFRPSFRPSFRPSFRPSFRPSFRPSFRPS6VPS6VPS6VPS6VPS6VPS6VPS6VPS6VPSFRPSFRPSFRPSFRPSFRP
SFRPSFRPSFRNS6>NRfFOS6JOS6NOS6NORfRNRVNNRFVMRVFNRfJNRfJOS6JNS6>MRf:LRf2KRUnPRF>P
RF>PRF>PRF>PRF>PRF>PRF>PRF>LRF>LRF>LRF>LRF>LRF>LRF>LRF>LRF>NR5nNR5nORF2ORF2PRV6P
RV6PRV6PRV6MQejNR5nNR5nORF2ORF2NR5nNR5nMQejORF2NR5nNR5nMQejMQejNR5nNR5nORF2MQejM
QejMQejMQejMQejMQejMQejMQejMQejMQejMQejMQejMQejMQejMQejMQejMR5^MR5^MR5^MR5^MR5^M
R5^MR5^MR5^MR5^MR5^MR5^MR5^MR5^MR5^MR5^MR5^NR5jNR5jMQefMQefLQUbLQUbLQUbLQUbMQURN
QeVNQeVOR5ZOR5ZPRE^PRE^PRE^OR5ZOR5ZOR5ZOR5ZOR5ZOR5ZOR5ZOR5ZLR5VLR5VLR5VLR5VLR5VL
R5VLR5VLR5VNRU^NRU^NRU^NRU^NRU^NRU^NRU^NRU^NQeVNQeVNQeVNQeVNQeVNQeVNQeVNQeVOR5ZO
R5ZOR5ZNQeVMQURMQURLQENLQENJQUNJQUNJQUNKQeRKQeRLR5VLR5VLR5VMQURMQURMQURMQURMQURM
QURMQURMQURNQeVNQeVNQeVNQeVNQeVNQeVNQeVNQeVMQeNMQeNMQeNMQeNMQeNMQeNMQeNMQeNLQUJL
QUJLQUJLQUJMQeNMQeNNR5RNR5RNQeFNQeFNQeFNQeFNQeFNQeFNQeFNQeFMQUBMQUBMQUBMQUBMQUBM
QUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBMQUBKQ5:KQ5:KQ5:LQE>LQE>MQUBMQUBMQUBKQ5:L
QE>LQE>LQE>MQUBMQUBMQUBNQeFHPdbIQ4fIPdnJQ52JPe6KQ5:KQ5BLQEFJPe6JPe6JPe6JPe6JPe6J
Pe6JPe6JPe6IQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjHPdbH
PdbHPdbIQ4fIQ4fJQDjJQDjKQTnIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fI
Q4fIQ4fIQ4fKQ4bKQ4bKQ4bJPd^JPd^IPTZIPTZIPTZGPdZHQ4^HQ4^IQDbIQDbHQ4^HQ4^GPdZIQ4NI
PdVJQ4ZJPd^JPd^JPTbKPdfKPdnHQ4^HQ4^HQ4^HQ4^HQ4^HQ4^HQ4^HQ4^IQDbIQDbIQDbIQDbIQDbI
QDbIQDbIQDbJPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^KQ4bKQ4bKQ4bLQDfLQDfLQDfIPTZI
PTZIPTZJPd^JPd^KQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bLQDfMQTjMQTjMQTjM
QTjLQDfKQ4bIPTZIPTZJPd^JPd^KQ4bKQ4bKQ4bKQ4bMQTjMQTjLQDfKQ4bKQ4bLQDfMQTjMQTjKQ4bK
Q4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bLQDfLQDfLQDfLQDfLQDfL
QDfLQDfLQDfKQ4bKQ4bLQDfLQDfLQDfMQTjMQTjMQTjKPdnKPdnLQ52LQ52LQ52MQE6MQE6MQE6JQDjJ
QDjJQDjJQDjKQTnKQTnKQTnKQTnLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQDfLQ4jLQ4jMQDnMQDnNQU2N
QU2NQU2NQU2MQDnMQDnMQDnMQDnMQDnMQDnMQDnMQDnNQdnNQdnNQdnNQdnOR52OR52PRE6PRE6OQe>O
Qe>PR5BQREFQREFPR5BOQe>OQe>OQe6OQe6OQe6OQe6OQe6OQe6OQe6OQe6OQe6OQe6NQU2NQU2NQU2N
QU2OQe6OQe6PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5:PR5800:NDNJNDNJND
NJNDNJNDNJNDNJNDNJNDNJNDNJNDNJNDNJNDNJRENZRENZVFNjVFNjNDNJNDNJNDNJNDNJNDNJNDNJND
NJNDNJJCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JBNJJBNJJBNJNCNZNCNZJBNJJBNJJBNJFBMjFBMjFB
MjFBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjBAMZBAMZBAMZBAMZBAMZBAMZBA
MZBAMZFBMjBAMZBAMZ>@MJ>@MJBAMZBAMZFBMjBAMZBAMZBAMZBAMZBAMZBAMZBAMZBAMZ>@MJ>@MJ>@
MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ6?LZ6?LZ:@Lj:@Lj:@Lj:@Lj:@
Lj:@LjFALZFALZFALZFALZFALZFALZFALZFALZB?LjB?LjB?LjB?LjB?LjB?LjB?LjB?LjB@LJB@LJB@
LJB@LJB@LJB@LJB@LJB@LJ:>Kj:>Kj:>Kj>?L:>?L:>?L:>?L:>?L:6?LZ6?LZ6?LZ6?LZ6?LZ6?LZ6?
LZ6?LZB@LJ>?L::>Kj:>Kj:>Kj:>Kj>?L:B@LJB@LJB@LJ>?L:>?L::>Kj:>Kj:>Kj:>Kj>?L:>?L:>?
L:>?L:>?L:>?L:>?L:>?L:2<KJ2<KJ6=KZ6=KZ:>Kj:>Kj>?L:>?L::>Kj:>Kj6=KZ6=KZ6=KZ6=KZ:>
Kj:>Kj:>Kj:>Kj6=KZ2<KJ6=KZ6=KZ:>Kj>?L:>@Jj>@Jj>@Jj>@Jj>@Jj>@Jj>@Jj>@Jj:?K::?K::?
K::?K::?K::?K::?K::?K:6=JZ6=JZ6=JZ6=JZ6=JZ6=JZ6=JZ6=JZ6>JJ6>JJ6>JJ6>JJ6>JJ:?JZ:?
JZ:?JZ2<JJ2<JJ2<JJ2<JJ2<JJ2<JJ2<JJ2<JJ6>JJ6>JJ6>JJ6>JJ6>JJ6>JJ6>JJ6>JIn;J9n;J9n;
J9n;J9n;J9n;J9n;J9n;J9n<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Iif;HYj;IIj;IIn<Iin<Iij:Iij:
Iif8J9f:IIf:IIj;IYj;IIj<Hif;HYb;H9^:Gj29Hj29Hj29Hj29Hj29Hj29Hj29Hj29Hib:HIb:HIb:
HIb:HIb:HIb:HIb:HIb:HIf7GYj8Gij8Gij8Gin9H9n9H9n9H9n9H9f7GYf7GYj8Gij8Gij8Gij8Gif7
GYf7GYj8Gij8Gif7GYf7GYf7GYf7GYj8Gij8Gib6G9b6G9b6G9b6G9b6G9b6G9b6G9b6G9b6GIb6GIb6
GIb6GIb6GIb6GIb6GIb6GIb7FYb7FYb7FYb7FYb7FYb7FYb7FYb7FYb7FYb7FYb7FYb7FYb7FYf8Fif8
Fif8Fib7FYb7FYf8Fif8Fif8Fib7FYb7FYb7FYf6F9f6F9f6F9j7FIn8FYn8FZ29Fj29Fij7FIj7FIj7
FIj7FIj7FIj7FIj7FIj7FI^7F9^7F9^7F9^7F9^7F9^7F9^7F9^7F9j:Fij:Fij:Fij:Fij:Fij:Fij:
Fij:Fif6F9f6F9f6F9f6F9f6F9f6F9f6F9f6F9n8FYn8FYj7FIj7FIf6F9b5Eib5Eib5Eif6F9f6F9f6
F9j7FIj7FIn8FYn8FYn8FYb5Eib5Eib5Eib5Eib5Eib5Eib5Eib5Eif6F9f6F9f6F9f6F9f6F9f6F9f6
F9f6F9b6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EY^5EI^5EIb6EYb6EYb6EYf7Eif7Eif7Eif6E9f6E9f6
E9f6E9f6E9f6E9f6E9f6E9b5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Dib5
Dib5Dib5Dib5Dib5Dib5Dif6E9f6E9f6E9j7EI^4DY^4DY^4DYb5Dib5Dif6E9f6E9f6E9R3C9R3C9V3
CiV3CiZ3DIZ3DI^4E9^4E9Z3DIZ3DIZ3DIZ3DIZ3DIZ3DIZ3DIZ3DIV4CIV4CIV4CIV4CIV4CIV4CIV4
CIV4CIZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYN2BiN2BiR3C9R3C9V4CIZ5CYZ5CYZ5CYR3C9R3C9R3
C9V4CIV4CIV4CIV4CIV4CIR3C9R3C9R3C9V4CIV4CIV4CIV4CIV4CI^4C9Z3BiZ3BiZ3BiV2BYV2BYV2
BYR1BIN3BYN3BYR4BiR4BiR4BiR4BiN3BYN3BYR3AYR2B9V3BIV2BYZ3BiZ2C9^3CI^3CiR4BiR4BiR4
BiR4BiR4BiR4BiR4BiR4BiV5C9V5C9V5C9V5C9V5C9V5C9V5C9V5C9Z3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3
BiZ3BiZ3BiZ3BiZ3BiZ3Bi^4C9^4C9b5CIb5CIR1BIV2BYV2BYV2BYZ3BiZ3BiZ3Bi^4C9^4C9^4C9^4
C9^4C9^4C9^4C9^4C9^4C9^4C9^4C9b5CIf6CYf6CYb5CI^4C9^4C9Z3Bi^4C9^4C9^4C9b5CIb5CIb5
CIb5CIf6CYb5CI^4C9^4C9^4C9^4C9b5CIf6CY^4C9^4C9^4C9^4C9^4C9^4C9^4C9^4C9^4C9^4C9^4
C9^4C9^4C9^4C9^4C9^4C9b5CIb5CIb5CIb5CIb5CIb5CIb5CIb5CI^4C9^4C9^4C9b5CIb5CIb5CIf6
CYf6CY^3CI^3CI^3CIb4CYb4CYb4CYf5Cif5CiZ5CYZ5CY^6Ci^6Cib7D9b7D9f8DIf8DIb5CIb5CIb5
CIb5CIb5CIb5CIb5CIb5CIb4CYb4CYb4CYf5Cif5Cif5Cij6D9j6D9f5Cif5Cif5Cif5Cif5Cif5Cif5
Cif5Cif6CYf6CYj7Cij7Cij7Cin8D9n8D9n8D9j6D9n7DIn7DJ28DZ28DYn7DIn7DIj6D9j6D9j6D9j6
D9j6D9j6D9j6D9j6D9j6D9n7DIj6D9j6D9f5Cif5Cij6D9j6D9n7DIn7DIn7DIn7DIn7DIn7DIn7DIn7
DIn7DIn7DIn7DIn7DIn7DIn7DIn7D@00YiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAi
Z9EjZ9EjZIIkZIIkYiAiYiAiYiAiYiAiYiAiYiAiYiAiYiAiYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=h
YI5hYI5hYY9iYi=jYi=jYY9iYI5hYI5hYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9g
YI9gYI9gYI9gYI9gY95fY95fY95fY95fY95fY95fY95fY95fYI9gY95fXi1eXi1eXi1eXi1eY95fYI9g
Y95fY95fY95fY95fY95fY95fY95fY95fXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXHicXXmdXi1eXi1e
Xi1eXi1eXXmdXHicX8iaXHmbXHmbXHmbXY1cXY1cXY1cXY1cY91aY91aY91aY91aY91aY91aY91aY91a
XhibXhibXhibXhibXhibXhibXhibXhibXhm`Xhm`Xhm`Xhm`Xhm`Xhm`Xhm`Xhm`XHe^XHe^XXi_XXi_
XXi_Xhm`Xhm`Xhm`X8iaX8iaX8iaX8iaX8iaX8iaX8iaX8iaXhm`Xhm`XXi_XHe^XHe^XXi_Xhm`Xhm`
Xhm`Xhm`Xhm`XXi_XXi_XXi_XHe^XHe^Xhi_Xhi_Xhi_Xhi_Xhi_Xhi_Xhi_Xhi_Wh]/Wh]/X8a]XHe^
XHe^XXi_Xhm`Xhm`XXi_XHe^XHe^X8a]X8a]XHe^XHe^XXi_XHe^XHe^X8a]X8a]X8a]XHe^XXi_Xhm`
XXmZXXmZXXmZXXmZXXmZXXmZXXmZXXmZXHi[XHi[XHi[XHi[XHi[XHi[XHi[XHi[XHeZXHeZXHeZXHeZ
XHeZXHeZXHeZXHeZX8eXX8eXX8eXXHiYXHiYXHiYXXmZXXmZX8aYX8aYX8aYX8aYX8aYX8aYX8aYX8aY
XXmZXXmZXXmZXXmZXXmZXXmZXXmZXXmZWh]XWh]XWh]XWh]XWh]XWh]XWh]XWh]XWhaWWhaWWhaWWhaW
WhaWWhaWWhaWWhaWWH]RWHYTWX]UWhaWWhaWWXYWWHUVWHQXW8UTWHYUWHYUWX]UWH]RW8YQVhYOVXUN
WhQRWhQRWhQRWhQRWhQRWhQRWhQRWhQRVhUPVhUPVhUPVhUPVhUPVhUPVhUPVhUPW8IMWHMNWHMNWHMN
WXQOWXQOWXQOWhUPW8IMWHMNWHMNWXQOWXQOWHMNWHMNW8IMWXQOWHMNWHMNW8IMW8IMWHMNWHMNWXQO
W8ILW8ILW8ILW8ILW8ILW8ILW8ILW8ILW8IMW8IMW8IMW8IMW8IMW8IMW8IMW8IMW8MJW8MJW8MJW8MJ
W8MJW8MJW8MJW8MJVhIIVhIIVhIIW8MJW8MJW8MJWHQKWHQKVXIGVXIGW8QIWHUJWHUJWHUJWHUJW8QI
WHMGWHMGWXQHWXQHWXQHWXQHWXQHWhUIWXMIWXMIWXMIWXMIWXMIWXMIWXMIWXMIVhMHVhMHVhMHVhMH
VhMHVhMHVhMHVhMHW8QIW8QIW8QIW8QIW8QIW8QIW8QIW8QIWHIHWHIHWHIHWHIHWHIHWHIHWHIHWHIH
WHIHWHIHWHIHWHIHWHIHW8EGW8EGW8EGWXIHWXIHWhMIWhMIWhMIX8QJX8QJX8QJW8EGW8EGW8EGW8EG
W8EGW8EGW8EGW8EGWHIHWHIHWHIHWHIHWHIHWHIHWHIHWHIHW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IF
VhEEVhEEVhEEVhEEW8IFW8IFWHMGWHMGWHIDWHIDWHIDWHIDWHIDWHIDWHIDWHIDW8ECW8ECW8ECW8EC
W8ECW8ECW8ECW8ECW8ECW8ECW8ECW8ECW8ECW8ECW8ECW8ECVhABVhABW8ECW8ECW8ECWHIDWHIDWHID
VhABVhABVhABVhABW8ECW8ECW8ECWHIDVHA=VHA=VXA@VXA@VX=AVX=AVX=CVhADVH9@VH9@VH9@VH9@
VH9@VH9@VH9@VH9@V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=
V8=<V8=<V8=<V8=<V8=<VHA=VHA=VHA=Uh9;Uh9;V8=<V8=<V8=<VHA=VHA=VHA=Uh9;Uh9;V8=<V8=<
V8=<VHA=VHA=VHA=VX=;VX=;VX=;VH9:VH9:V859V859V859UX99Uh=:Uh=:V8A;V8A;Uh=:Uh=:UX99
Uh95Uh57V898VH9:VH9:VX9<Vh==Vh=?Uh=:Uh=:Uh=:Uh=:Uh=:Uh=:Uh=:Uh=:V8A;V8A;V8A;V8A;
V8A;V8A;V8A;V8A;VH9:VH9:VH9:VH9:VH9:VH9:VH9:VH9:VH9:VH9:VX=;VX=;VX=;VhA<VhA<VhA<
V859V859V859VH9:VH9:VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VhA<W8E=
W8E=VhA<VX=;VX=;VhA<VhA<VhA<VhA<W8E=W8E=W8E=WHI>W8E=W8E=VhA<VX=;VX=;VhA<W8E=W8E=
VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VhE;VhE;VhE;VhE;
VhE;VhE;VhE;VhE;VX=;VX=;VhA<VhA<W8E=W8E=W8E=W8E=VX=;VX=;VhA<VhA<W8E=W8E=W8E=W8E=
VXE>VXE>VhI?VhI?W8M@WHQAWXUBWXUBVhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<Vh==W8A>W8A>W8A>
WHE?WHE?WHE?WHE?W8A>W8A>W8A>W8A>W8A>W8A>W8A>W8A>W8E=W8E=W8E=WHI>WHI>WXM?WXM?WXM?
WHI>WXM?WXM?WhQ@WhQ@WXM?WXM?WHI>WXI@WXI@WXI@WXI@WXI@WXI@WXI@WXI@WhMAWXI@WHE?WHE?
WHE?WHE?WXI@WhMAWhMAWhMAWhMAWhMAWhMAWhMAWhMAWhMAWhMAWhMAWhMAWhMAWhMAWhMA002WU7VW
U7VWU7VWU7VWU7VWU7VWU7VWU7VWU7VWU7VWU7VWU7VXUGZXUGZYUW^YUW^WU7VWU7VWU7VWU7VWU7VW
U7VWU7VWU7VUTWNUTWNUTWNUTWNUTWNUTWNUTWNUTWNTT7NUTGRVTWVWTgZWTgZVTWVUTGRTT7NTTGJT
TGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJST7FST7FST7FST7FST7FS
T7FST7FST7FTTGJTTGJST7FRSgBRSgBST7FTTGJTTGJST7FST7FST7FST7FST7FST7FST7FST7FRSgBR
SgBRSgBRSgBRSgBRSgBRSgBRSgBQSW>QSW>ST7FTTGJTTGJST7FQSW>QSW>PSW6PSW6PSW6QSg:QSg:R
T7>RT7>RT7>TT76TT76TT76TT76TT76TT76TT76TT76SSW:SSW:SSW:SSW:SSW:SSW:SSW:SSW:SSg2S
Sg2SSg2SSg2SSg2SSg2SSg2SSg2PS6fQSFjQSFjRSVnRSVnSSg2SSg2SSg2PSW6PSW6PSW6PSW6PSW6P
SW6PSW6PSW6SSg2RSVnQSFjQSFjQSFjQSFjRSVnSSg2SSg2SSg2RSVnRSVnRSVnQSFjQSFjQSFjSSVnS
SVnSSVnSSVnSSVnSSVnSSVnSSVnNRV^ORfbORfbPS6fQSFjRSVnSSg2SSg2RSVnQSFjPS6fPS6fPS6fP
S6fQSFjRSVnPS6fPS6fPS6fORfbPS6fQSFjRSVnSSg2RSfZRSfZRSfZRSfZRSfZRSfZRSfZRSfZQSV^Q
SV^QSV^QSV^QSV^QSV^QSV^QSV^QSFZQSFZQSFZQSFZQSFZQSFZQSFZQSFZOS6NOS6NPSFRPSFRQSVVQ
SVVRSfZRSfZORfRORfRORfRORfRORfRORfRORfRORfRQSVVQSVVQSVVQSVVQSVVQSVVQSVVQSVVNRVNN
RVNNRVNNRVNNRVNNRVNNRVNNRVNNRfJNRfJNRfJNRfJNRfJNRfJNRfJNRfJLRV6MRVBNRfFNRfJNRfJN
RVNMRFJLQfNLRFBMRVFMRVFMRVBMRf:LRV6KRUnJREjOR6:OR6:OR6:OR6:OR6:OR6:OR6:OR6:JREjJ
REjJREjJREjJREjJREjJREjJREjLQUfLQUfLQUfMQejMQejMQejNR5nNR5nLQUfLQUfMQejNR5nNR5nM
QejLQUfLQUfNR5nMQejLQUfLQUfLQUfLQUfMQejNR5nLQeZLQeZLQeZLQeZLQeZLQeZLQeZLQeZLQUfL
QUfLQUfLQUfLQUfLQUfLQUfLQUfLQeZLQeZLQeZLQeZLQeZLQeZLQeZLQeZJQERJQERKQUVKQUVLQeZL
QeZMR5^MR5^GPeBHQ5FJQUNMREZNRU^NRU^NRU^MREZNR5RNR5RNR5RNR5RMQeNMQeNMQeNMQeNNQeVN
QeVNQeVNQeVNQeVNQeVNQeVNQeVJQUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNKQeRKQeRKQeRKQeRKQeRK
QeRKQeRKQeRLQENLQENLQENLQENLQENLQENLQENLQENLQENLQENLQENLQENMQURMQURMQURMQURMQENM
QENMQENNQURNQURNQUROQeVOQeVKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JLQENLQENLQENLQENLQENL
QENLQENLQENKQEFKQEFKQEFKQEFKQEFKQEFKQEFKQEFJQ5BJQ5BKQEFKQEFLQUJLQUJLQUJLQUJLQE>L
QE>LQE>LQE>LQE>LQE>LQE>LQE>KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:KQ5:K
Q5:KQ5:KQ5:IPU2JPe6JPe6JPe6KQ5:KQ5:KQ5:LQE>JPe6JPe6KQ5:KQ5:KQ5:LQE>LQE>LQE>KQTnK
QTnKQE6KQE6JPe6JPe6JPe>JPe>IPU2IPU2IPU2IPU2IPU2IPU2IPU2IPU2HPdbHPdbHPdbHPdbHPdbH
PdbHPdbHPdbIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fHPdbHPdbHPdbHPdbHPdbGPT^GPT^GPT^FPDZG
PT^GPT^HPdbHPdbIQ4fIQ4fIQ4fFPDZGPT^GPT^HPdbHPdbIQ4fIQ4fIQ4fJPd^JPd^IPTZIPTZIPTZH
PDVHPDVHPDVFPTVFPTVGPdZHQ4^HQ4^GPdZFPTVFPTVFPDBGPDNGPDNHPDVIPTZJPTbKPdfKPdnGPdZG
PdZGPdZGPdZGPdZGPdZGPdZGPdZHQ4^HQ4^HQ4^HQ4^HQ4^HQ4^HQ4^HQ4^IPTZIPTZIPTZIPTZIPTZI
PTZIPTZIPTZIPTZIPTZIPTZJPd^JPd^JPd^KQ4bKQ4bHPDVHPDVHPDVIPTZIPTZIPTZJPd^JPd^JPd^J
Pd^JPd^JPd^JPd^JPd^JPd^JPd^IPTZJPd^JPd^KQ4bKQ4bJPd^JPd^IPTZIPTZIPTZJPd^JPd^JPd^K
Q4bKQ4bKQ4bLQDfKQ4bKQ4bJPd^JPd^KQ4bKQ4bLQDfJPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^JPd^J
Pd^JPd^JPd^JPd^JPd^JPd^JPd^KQD^KQD^KQD^KQD^KQD^KQD^KQD^KQD^JPd^JPd^JPd^KQ4bKQ4bL
QDfLQDfLQDfJPd^JPd^JPd^KQ4bKQ4bLQDfLQDfLQDfHPdbHPdbIQ4fJQDjKQTnLQe2LQe2MR56KQ4bK
Q4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bKPdfKPdfLQ4jLQ4jLQ4jMQDnMQDnMQDnLQ4jLQ4jLQ4jLQ4jLQ4jL
Q4jLQ4jLQ4jKQ4bKQ4bKQ4bKQ4bLQDfLQDfLQDfMQTjLQDfMQTjNQdnNQdnNQdnNQdnMQTjLQDfMQDnM
QDnMQDnMQDnMQDnMQDnMQDnMQDnNQU2NQU2MQDnLQ4jLQ4jMQDnNQU2NQU2NQU2NQU2NQU2NQU2NQU2N
QU2NQU2NQU2NQU2NQU2NQU2NQU2NQU2NQU000:JCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:NDNJNDNJND
NJNDNJRENZRENZVFNjVFNjJCN:JCN:JCN:JCN:JCN:JCN:JCN:JCN:FBMjFBMjFBMjFBMjFBMjFBMjFB
MjFBMj>?MZFAN:JBNJNCNZNCNZJBNJFAN:>?MZBAMZBAMZBAMZBAMZBAMZBAMZBAMZBAMZBAMZBAMZBA
MZBAMZBAMZBAMZBAMZBAMZ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJBAMZ>@MJ>@MJ:?M::?M:>@MJ>@
MJBAMZ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ:?M::?M::?M::?M::?M::?M::?M::?M:2=LZ6>Lj>@
MJBAMZBAMZ>@MJ6>Lj2=LYn=L9n=L:2>LJ2>LJ6?LZ:@Lj:@Lj:@LjB@LJB@LJB@LJB@LJB@LJB@LJB@
LJB@LJ>>LZ>>LZ>>LZ>>LZ>>LZ>>LZ>>LZ>>LZ>?L:>?L:>?L:>?L:>?L:>?L:>?L:>?L:2<KJ2<KJ6=
KZ6=KZ:>Kj>?L:>?L:>?L:2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ>?L::>Kj6=KZ6=KZ6=KZ6=KZ:>
Kj>?L:>?L:>?L::>Kj:>Kj6=KZ6=KZ6=KZ6=KZF=KjF=KjF=KjF=KjF=KjF=KjF=KjF=Kij:Jij:Jin;
K:2<KJ6=KZ:>Kj>?L:>?L::>Kj6=KZ2<KJ2<KJ2<KJ2<KJ6=KZ:>Kj2<KJ2<KIn;K9n;K:2<KJ6=KZ:>
Kj>?L::?JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZ:?JZ6>Jj6>Jj6>Jj6>Jj6>Jj6>Jj6>Jj6>Jj2<JJ2<JJ2<
JJ2<JJ2<JJ2<JJ2<JJ2<JIn<Iin<Iin<Ij2=J:6>JJ6>JJ:?JZ:?JYn;J9n;J9n;J9n;J9n;J9n;J9n;
J9n;J9n<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Iij:Iij:Iij:Iij:Iij:Iij:Iij:Iij:Iij;IYj;IYj;
IYj;IYj;IYj;IYj;IYj;IYb:HIf:I9f:I9j;IYj;IYf9IYf9IYb7Iib9I9b9I9f:IIf:I9f;HYb:HI^:
GiZ9GYn8HYn8HYn8HYn8HYn8HYn8HYn8HYn8HYZ9GYZ9GYZ9GYZ9GYZ9GYZ9GYZ9GYZ9GY^5G9b6GIb6
GIb6GIf7GYf7GYf7GYf7GYb6GIb6GIf7GYj8Gij8Gif7GYb6GIb6GIj8Gif7GYb6GIb6GIb6GIb6GIf7
GYj8Gi^6FI^6FI^6FI^6FI^6FI^6FI^6FI^6FI^5G9^5G9^5G9^5G9^5G9^5G9^5G9^5G9^6FI^6FI^6
FI^6FI^6FI^6FI^6FI^6FIZ5F9Z5F9Z5F9^6FIb7FYb7FYf8Fif8FiF1DYN3E9Z6Eib8FIj:Fin;G9j:
Fij:Fin:Ein:Eij9EYj9EYf8EIb7E9b7E9b7E9f6F9f6F9f6F9f6F9f6F9f6F9f6F9f6F9Z6EiZ6EiZ6
EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6Eib5Eib5Eib5Eib5Eib5Eib5Eib5
Eib5Ei^4EY^4EY^4EYb5Eif6F9f6F9j7FIj7FI^3EI^3EIb4EYb4EYb4EYf5Eif5Eif5Ei^4EY^4EY^4
EY^4EY^4EY^4EY^4EY^4EYb5Eib5Eib5Eib5Eib5Eib5Eib5Eib5Ei^5EI^5EI^5EI^5EI^5EI^5EI^5
EI^5EIZ4E9Z4E9^5EI^5EI^5EIb6EYb6EYb6EYb5Dib5Dib5Dib5Dib5Dib5Dib5Dib5Di^4DY^4DY^4
DY^4DY^4DY^4DY^4DY^4DY^4DY^4DY^4DY^4DY^4DY^4DY^4DY^4DYR1CiR1CiR1CiR1CiV2D9V2D9Z3
DIZ3DIZ3DIZ3DIZ3DI^4DY^4DYb5Dib5Dib5Dif8DIf8DIb6DYb6DY^4DYZ3DIZ3DiZ3DiV2D9V2D9V2
D9V2D9V2D9V2D9V2D9V2D9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9V4CIV4CIV4CIV4CIV4CIV4CIV4
CIV4CIV4CIV4CIV4CIR3C9N2BiN2BiJ1BYJ1BYJ1BYJ1BYN2BiN2BiR3C9V4CIV4CIV4CIJ1BYJ1BYN2
BiN2BiR3C9V4CIV4CIV4CIZ3BiV2BYV2BYV2BYR1BIR1BIR1BIN0B9J2BIJ2BIN3BYR4BiR4BiN3BYJ2
BIJ2BIJ1A9J0AYN1AiR1BIV2BYZ2C9^3CI^3CiN3BYN3BYN3BYN3BYN3BYN3BYN3BYN3BYR4BiR4BiR4
BiR4BiR4BiR4BiR4BiR4BiV2BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYZ3BiZ3Bi^4
C9^4C9N0B9R1BIR1BIR1BIV2BYV2BYV2BYZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiV2BYV2BYZ3
Bi^4C9^4C9Z3BiV2BYV2BYN0B9R1BIR1BIR1BIV2BYV2BYV2BYZ3Bib5CI^4C9Z3BiZ3BiZ3BiZ3Bi^4
C9b5CIZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3BiZ3Bi^6BI^6BI^6
BI^6BI^6BI^6BI^6BI^6BIZ3BiZ3BiZ3Bi^4C9^4C9^4C9b5CIb5CIZ3BiZ3BiZ3Bi^4C9^4C9^4C9b5
CIb5CIJ1BYJ1BYN2BiR3C9V4CIZ5CY^6Ci^6Ci^4C9^4C9^4C9^4C9^4C9^4C9^4C9^4C9^3CI^3CI^3
CIb4CYb4CYb4CYf5Cif5Cib4CYb4CYb4CYb4CYb4CYb4CYb4CYb4CYZ3BiZ3BiZ3BiZ3Bi^4C9^4C9^4
C9b5CIb5CIf6CYf6CYj7Cij7Cif6CYf6CYb5CIf5Cif5Cif5Cif5Cif5Cif5Cif5Cif5Cij6D9f5Cif5
Cib4CYb4CYf5Cif5Cij6D9j6D9j6D9j6D9j6D9j6D9j6D9j6D9j6D9j6D9j6D9j6D9j6D9j6D9j6D000
YiEhYiEhYiEhYiEhYiEhYiEhYiEhYiEhYY=hYY=hYY=hYY=hYiAiYiAiYiAiZ9EjYiAiYiAiYiAiYiAi
YiAiYiAiYiAiYiAiYI9gYI9gYI9gYI9gYI9gYI9gYI9gYI9gY95fY95fY95fY95fY95fY95fY95fY95f
Y95fY95fY95fY95fY95fY95fY95fY95fXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eY95fY95fY95f
YI9gYI9gYI9gYI9gXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1e
XHicXHicXHicXHicXHicXHicXHicXHicXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXHm`XHm`XHm`XHm`
XHm`XHm`XHm`XHm`Xi5dXY1cXY1cXHmbXHmbX8iaX8iaWhe`XXeaXXeaXXeaXXeaXXeaXXeaXXeaXXea
XXi_XXi_XXi_XXi_XXi_XXi_XXi_XXi_XHe^XHe^XHe^XXi_XXi_XXi_Xhm`Xhm`XXi_XXi_XXi_XXi_
XXi_XXi_XXi_XXi_XHe^XHe^XHe^XXi_XXi_XXi_Xhm`Xhm`XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^
XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^X8a]X8a]X8a]XHe^XHe^XHe^XXi_XXi_XHe^XHe^XHe^XHe^
XHe^XHe^XHe^XHe^X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]XHiYXHiYXHiYXHiYXHiYXHiYXHiYXHiY
XXmZXHiYX8eXX8eXX8eXX8eXXHiYXXmZXHiYXHiYXHiYXHiYXHiYXHiYXHiYXHiYXXmZXHiYXHiYXHiY
X8eXX8eXX8eXX8eXWhaWWhaWWhaWWhaWWhaWWhaWWhaWWhaWWX]VWX]VWX]VWX]VWX]VWX]VWX]VWX]V
WHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUVXQOVXMQVXMQVhQS
VhQSVhMTW8QUW8MWW8QUW8QUWXQTWHMSWhQRWXQOX8MOX8QNWXQOWXQOWXQOWhUPWhUPX8YQX8YQX8YQ
X8YQWXQOWHMMVhEKVhIIVhMHWHUJWHUJW8MJW8MJWHQKWXULWXULWHQKW8MJW8MJW8MJW8MJW8MJW8MJ
W8MJW8MJW8MJW8MJWHQKW8MJVhIIVXEHVXEHVhIIW8MJWHQKWHQKWHQKWHQKW8MJVhIIVhIIVXEHVXEH
W8MJW8MJW8MJW8MJW8MJW8MJW8MJW8MJW8QIW8QIW8QIW8QIW8QIW8QIW8QIW8QIVhAFVhAFVhAFVhAF
VhAFVhAFVhAFVhAFVhAFW8EGW8EGW8EGWHIHWHIHWHIHWXMIW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IF
WXQHWXQHWXQHWXQHWXQHWXQHWXQHWXQHW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8EGW8EGW8EGW8EG
W8EGW8EGW8EGW8EGW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFVXADVhEEW8IFW8IFW8IFW8IFVhEEVXAD
VhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVXADVXADVhEEVhEE
W8IFW8IFW8IFW8IFVH=CVhEEWHMGWHMGVhEEVXADVhEEW8IFVX=AVX=AVhABVhABVhABW8ECW8ECW8EC
VhI?VhI?VhI?VhI?VhI?VhI?VhI?VhI?VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VhI?VhI?VhI?VhI?
VhI?VhI?VhI?VhI?W8M@W8M@VhI?VXE>VXE>VHA=VHA=V8=<V8=<VHA=VHA=VXE>VXE>VhI?VhI?W8M@
VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=
VHA=VHA=VHA=VHA=VXI=VHE<VHE<V8A;V8A;Uh=:UX99UX99Uh=:Uh=:Uh=:Uh=:Uh=:Uh=:Uh=:Uh=:
Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Th5<UH1<UX5=V89>V89>Vh=?Vh=?WH9?V859VH9:VhA<W8E=
W8E=VhA<VH9:V859UGm5UX16V898VH=9VXA:VH=9V898Uh57VH=9VH=9VH=9VH=9VH=9VH=9VH=9VH=9
UX16Uh57VH=9VXA:VhE;VXA:VH=9V898V898V898V898V898V898V898V898V898VH9:VH9:VH9:VH9:
VH9:VH9:VH9:VH9:VH9:VH9:VH9:VH9:VH9:V859V859V859UX16UX16Uh57V898VH=9VXA:VhE;VhE;
VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:VH=9VH=9VH=9VH=9VH=9VH=9VH=9VH=9VHA6VHA6VHA7VXE8
VXA:VX=;VhA<VhA<VhE;VhE;W8I<W8I<W8I<WHM=WHM=WHM=VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:
VXA:VXA:VXA:VXA:VXA:VH=9VH=9VH=9V898V898V898VH=9VH=9VH=9VXA:VXA:V859V859VH9:VX=;
VX=;VhA<VhA<VhA<VH9:VH9:VX=;VhA<VhA<VX=;VH9:VH9:WHI>W8E=W8E=VhA<VhA<VX=;VX=;VH9:
VX=;VX=;VX=;VhA<VhA<W8E=W8E=W8E=VX=;VhA<VhA<W8E=W8E=VhA<VhA<VX=;Vh=?Vh=?Vh=?Vh=?
Vh=?Vh=?Vh=?Vh=?VX=;VX=;VX=;VhA<VhA<W8E=W8E=W8E=VhA<VhA<W8E=WHI>WXM?WhQ@X8UAX8UA
VXI=VXI=VHE<VhA<WHA<WXE=XHI>XXM?WXIBWXIBWXIBWHEAWHEAWHEAWHEAWHEAW8A@W8A@W8A@W8A@
W8A@W8A@W8A@W8A@WXM?WXM?WXM?WHI>WHI>WHI>002VU7NVU7NVU7NVU7NVU7NVU7NVU7NVU7NUTWNV
TgRVTgRVTgRWU7VWU7VWU7VWU7VVTgRVTgRVTgRVTgRVTgRVTgRVTgRVTgRUTWNUTWNUTWNUTWNUTWNU
TWNUTWNUTWNTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJST7FS
T7FST7FST7FST7FST7FST7FST7FST7FST7FST7FTTGJTTGJUTWNUTWNUTWNST7FST7FST7FST7FST7FS
T7FST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FQSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>RSgBR
SgBRSgBRSgBRSgBRSgBRSgBRSgBQSg2QSg2QSg2QSg2QSg2QSg2QSg2QSg2QSg:QSg:QSg:QSg:QSg:P
SW6PSW6PSW6RSG6RSG6RSG6RSG6RSG6RSG6RSG6RSG6RSVnRSVnRSVnRSVnRSVnRSVnRSVnRSVnQSFjQ
SFjQSFjQSFjRSVnRSVnSSg2SSg2RSVnRSVnRSVnRSVnRSVnRSVnRSVnRSVnQSFjQSFjQSFjQSFjRSVnR
SVnSSg2SSg2QSFjQSFjQSFjQSFjQSFjQSFjQSFjQSFjQSFjQSFjQSFjQSFjQSFjQSFjQSFjQSFjORfbP
S6fPS6fPS6fQSFjQSFjQSFjRSVnQSFjQSFjQSFjQSFjQSFjQSFjQSFjQSFjORfbORfbORfbORfbORfbO
RfbORfbORfbPSFRPSFRPSFRPSFRPSFRPSFRPSFRPSFRQSVVQSVVPSFROS6NOS6NPSFRQSVVQSVVPSFRP
SFRPSFRPSFRPSFRPSFRPSFRPSFRQSVVQSVVQSVVQSVVPSFRPSFRPSFROS6NOS6NOS6NOS6NOS6NOS6NO
S6NOS6NOS6NNRfJNRfJNRfJNRfJNRfJNRfJNRfJNRfJMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFM
RVFMRVFMRVFMRVFMRVFMRVFMRVFJR5nJQf6KR6:KR6>LRFBLR6FLR6FLQfNLR6FLRFBMQf>MR6:OR6:N
R5nPR5jPR5jNR5nNR5nNR5nNR5nORF2ORF2PRV6PRV6ORF2NR5nLQUbKQE^KQUVKQeRLR5VMREZLQeZL
QeZMR5^NREbNREbMR5^LQeZLQeZKQUVKQUVKQUVKQUVKQUVKQUVKQUVKQUVMR5^LQeZKQUVJQERJQERK
QUVLQeZMR5^MR5^MR5^LQeZLQeZKQUVKQUVJQERJQERKQUVKQUVKQUVKQUVKQUVKQUVKQUVKQUVJQUNJ
QUNJQUNJQUNJQUNJQUNJQUNJQUNKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JLQENLQENLQENM
QURMQURMQURLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJL
QUJLQUJLQUJLQUJLQUJLQUJLQUJLQENLQENLQENLQENLQENLQENLQENLQENLQUJLQUJLQUJLQUJLQUJL
QUJLQUJLQUJJQ5BKQEFLQUJLQUJLQUJLQUJKQEFJQ5BKQEFKQEFKQEFKQEFKQEFKQEFKQEFKQEFKQEFK
QEFKQEFKQEFKQEFKQEFKQEFKQEFJQ5BJQ5BKQEFKQEFKQEFLQUJLQUJLQUJIPe>KQEFMQeNMQeNKQEFJ
Q5BJQ5BKQEFJPe6JPe6JPe6KQ5:KQ5:LQE>LQE>LQE>KQTnKQTnKQTnKQTnKQTnKQTnKQTnKQTnIQ4fI
Q4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fKQTnKQTnKQTnKQTnKQTnKQTnKQTnKQTnKQTnKQTnKQTnJQDjJQDjI
Q4fIQ4fHPdbIQ4fIQ4fJQDjJQDjJQDjJQDjJQDjKQTnIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fI
Q4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQDbIQDbHQ4^HQ4^GPdZG
PdZFPTVFPTVGPdZGPdZGPdZGPdZGPdZGPdZGPdZGPdZGPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^DPd^F
PT^FPT^HPdbHPdbJPTbJPTbLPTbHPDVIPTZJPd^KQ4bKQ4bJPd^IPTZHPDVEOdFFP4JGPDNIPdVIPdVI
PdVHPTRGPDNIPdVIPdVIPdVIPdVIPdVIPdVIPdVIPdVFP4JGPDNHPTRJQ4ZJQ4ZJQ4ZIPdVHPTRGPDNG
PDNGPDNGPDNGPDNGPDNGPDNGPDNIPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZIPTZHPDVH
PDVHPDVHPDVGPDNGPDNHPTRHPTRIPdVIPdVJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZIPdVI
PdVIPdVIPdVIPdVIPdVIPdVIPdVIQ4JIQ4JIQ4NIQ4NJQ4ZJPd^KQ4bKQ4bIPdVJQ4ZJQ4ZJQ4ZKQD^K
QD^KQD^KQD^JQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZJQ4ZIPdVIPdVIPdVGPDNH
PTRHPTRHPTRIPdVIPdVIPdVJQ4ZIPTZIPTZIPTZJPd^JPd^JPd^JPd^JPd^IPTZIPTZJPd^KQ4bKQ4bJ
Pd^IPTZIPTZKQ4bKQ4bKQ4bKQ4bKQ4bJPd^JPd^JPd^JPd^JPd^JPd^KQ4bKQ4bKQ4bLQDfLQDfJPd^J
Pd^KQ4bLQDfLQDfKQ4bJPd^JPd^KPdfKPdfKPdfKPdfKPdfKPdfKPdfKPdfJPd^JPd^JPd^KQ4bKQ4bK
Q4bLQDfLQDfIPTZJPd^JPd^KQ4bLQDfMQTjNQdnNQdnJQTfIQDbIQDbKQ4bMQ4bNQDfQQTjRQdnMQDnM
QDnMQDnMQDnMQDnMQDnMQDnMQDnLQ4jLQ4jLQ4jLQ4jLQ4jLQ4jLQ4jLQ4jMQTjMQTjMQTjMQTjMQTjM
QTh00:JDMjJDMjJDMjJDMjJDMjJDMjJDMjJDMjFBMjFBMjFBMjJCN:JCN:NDNJNDNJNDNJJCN:JCN:JC
N:JCN:JCN:JCN:JCN:JCN:FBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjBAMZBAMZBAMZBAMZBAMZBAMZBA
MZBAMZBAMZBAMZBAMZBAMZBAMZBAMZBAMZBAMZ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ:?M::?M:>@
MJ>@MJBAMZBAMZBAMZBAMZ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@
MJ>@MJ:?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M:2>Kj2>Kj2>
Kj2>Kj2>Kj2>Kj2>Kj2>Kj2>LJ2>LJ2>LJ2>LJ6?LZ6?LZ6?LZ6?LZ6<L:6<L:6<L:6<L:6<L:6<L:6<
L:6<L:6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ6=KZ2<KJ2<KJ6=KZ6=KZ:>Kj:>Kj:>Kj:>Kj6=KZ6=KZ6=
KZ6=KZ6=KZ6=KZ6=KZ6=KZ2<KJ2<KJ6=KZ6=KZ:>Kj:>Kj:>Kj:>Kj2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<
KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KIn;K9n;K:2<KJ2<KJ2<KJ6=KZ6=KZ6=KZ2<KJ2<KJ2<
KJ2<KJ2<KJ2<KJ2<KJ2<KIn;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K:2=J:2=J:2=J:2=J:2=J:2=J:2=
J:2=J:6>JJ2=J:2=J9n<Iin<Ij2=J:2=J:6>JJ2=J:2=J:2=J:2=J:2=J:2=J:2=J:2=J:6>JJ6>JJ6>
JJ2=J:2=J9n<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Iij;IYj;IYj;IYj;IYj;IYj;IYj;
IYj;IYf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:II^9H9^8HYb9
Hib9I9b9I9f9IYf9IYf8J9^8Hi^8Hif8HYf8HYj8Gij8GZ28GYn7GIf7GIf7GIf7GIj8GYj8GYn9Gin9
Gin9Gij8Gif7GYb6G9^5Fi^6FI^7F9b8FIb8FI^6FIb7FYf8Fif8Fif8Fif8Fib7FY^6FI^6FI^6FI^6
FI^6FI^6FI^6FI^6FI^6FIb7FY^6FI^6FIZ5F9Z5F9^6FI^6FIb7FYb7FYb7FYb7FY^6FI^6FI^6FIZ5
F9Z5F9^6FI^6FI^6FI^6FI^6FI^6FI^6FI^6FIV5EYV5EYV5EYV5EYV5EYV5EYV5EYV5EY^4EY^4EY^4
EY^4EY^4EY^4EY^4EY^4EY^4EY^4EY^4EYb5Eib5Eif6F9f6F9f6F9b6EYb6EYb6EYb6EYb6EYb6EYb6
EYb6EY^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EIb6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYb5Eib5Eib5
Eib5Eib5Eib5Eib5Eib5Eib6EYb6EYb6EYb6EYb6EYb6EYb6EYb6EYZ4E9Z4E9^5EIb6EYb6EY^5EIZ4
E9Z4E9^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EI^6Di^6Di^6Di^6Di^6Di^6Di^6Di^6DiZ4E9Z4E9Z4
E9^5EI^5EI^5EIb6EYb6EYV3Di^5EIf7Eif7Ei^5EIZ4E9Z4E9^5EIZ3DIZ3DIZ3DIZ3DI^4DY^4DYb5
Dib5Di^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6CiZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CYZ5CY^6Ci^6Ci^6
Ci^6Ci^6Ci^6Ci^6Ci^6Ci^6CiZ5CYZ5CYZ5CYV4CIV4CIV4CIV4CIZ5CYZ5CYZ5CYZ5CYV4CIV4CIV4
CIV4CIN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiR3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3
C9R3C9R3C9R3C9R3C9R3C9R4BiR4BiR4BiR4BiN3BYN3BYN3BYJ2BIJ2BIJ2BIJ2BIJ2BIJ2BIJ2BIJ2
BIJ2BIJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYJ1BYF4C9N3C9N3C9N2BiN2BiV1BiV1Bi^1BiR1BIR1BIV2
BYZ3BiZ3BiV2BYR1BIR1BIEoAIJ0AYN1AiR2B9R2B9R2B9R2B9N1AiR2B9R2B9R2B9R2B9R2B9R2B9R2
B9R2B9J0AYJ0AYR2B9V3BIV3BIV3BIR2B9R2B9N1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiR1BIR1BIR1
BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIR2B9R2B9R2B9R2B9R2B9R2B9V3
BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIR2B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9R3AIR3AIV4
AiV4AiZ4BYZ3BiZ3BiZ3BiR2B9R2B9R2B9R2B9V3BIV3BIZ4BYZ4BYV3BIV3BIV3BIV3BIV3BIV3BIV3
BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIN1AiN1AiR2B9R2B9R2B9V3BIV3BIV3BIZ3BiZ3BiZ3
BiV2BYV2BYV2BYV2BYV2BYR1BIV2BYZ3BiZ3BiZ3BiZ3BiV2BYR1BIZ3BiZ3BiZ3BiZ3Bi^4C9^4C9^4
C9^4C9V2BYZ3BiZ3BiZ3Bi^4C9^4C9^4C9^4C9V2BYZ3Bi^4C9^4C9^4C9^4C9Z3BiV2BYZ2C9Z2C9Z2
C9Z2C9Z2C9Z2C9Z2C9Z2C9V2BYZ3BiZ3BiZ3Bi^4C9^4C9^4C9^4C9R1BIR1BIV2BYZ3Bi^4C9^4C9b5
CIb5CIZ6CIV5C9V5C9Z3Bif4C9j5CJ66CZ:7Cif5Cif5Cif5Cif5Cif5Cif5Cif5Cif5Cib4CYb4CYb4
CYb4CYb4CYb4CYb4CYb4CYf6CYf6CYf6CYf6CYf6CYf6CP00YYAgYYAgYYAgYYAgYYAgYYAgYYAgYYAg
YI9gYI9gYI9gYI9gYY=hYY=hYiAiYiAiYY=hYY=hYY=hYY=hYY=hYY=hYY=hYY=hYI9gYI9gYI9gYI9g
YI9gYI9gYI9gYI9gXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1e
XXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXHicXXmdXXmdXXmdXi1eXi1eXi1eY95fXXmdXXmdXXmdXXmd
XXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmd
XHicXHicXHicXHicXHicXHicXHicXHicX8i_X8i_X8i_X8i_X8i_X8i_X8i_X8i_WXa_Whe`Whe`X8ia
X8iaXHmbXHmbXY1cXHa`XHa`XHa`XHa`XHa`XHa`XHa`XHa`XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^
X8a]X8a]X8a]XHe^XHe^XHe^XXi_XXi_XHe^XHe^XHe^XHe^XHe^XHe^XHe^XHe^X8a]X8a]X8a]XHe^
XHe^XHe^XXi_XXi_X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]
Wh]/Wh]/Wh]/X8a]X8a]X8a]XHe^XHe^X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]Wh]/Wh]/Wh]/Wh]/
Wh]/Wh]/Wh]/Wh]/X8eXX8eXX8eXX8eXX8eXX8eXX8eXX8eXXHiYX8eXWhaWWhaWWhaWWhaWX8eXXHiY
X8eXX8eXX8eXX8eXX8eXX8eXX8eXX8eXXHiYXHiYX8eXX8eXWhaWWhaWWhaWWhaWWhaWWhaWWhaWWhaW
WhaWWhaWWhaWWhaWWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UT
W8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTVhUPW8USW8USW8UTWHYUWHUVWHUVWHQXVhQSVhQRWHQRW8QO
WXQNWHMMWhQKWhQKW8ILW8ILWHMMWHMMWHMMWXQNWXQNWXQNWHMNWHMNW8ILW8ILVhIIVhMHVhMHVhMH
VhIIVhIIW8MJWHQKWHQKW8MJVhIIVhIIVhIIVhIIVhIIVhIIVhIIVhIIVhIIVhIIVhIIVhIIVXEHVXEH
VXEHVXEHVhIIVhIIVhIIVhIIVhIIVhIIVhIIVXEHVXEHVXEHVhIIVhIIVhIIVhIIVhIIVhIIVhIIVhII
VHEFVHEFVHEFVHEFVHEFVHEFVHEFVHEFVhAFVhAFVhAFVhAFVhAFVhAFVhAFVhAFVX=EVhAFVhAFVhAF
W8EGW8EGW8EGWHIHW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEE
W8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IFW8IF
W8IFW8IFW8IFW8IFVH=CVXADVhEEVhEEVhEEVhEEVXADVH=CVXADVXADVXADVXADVXADVXADVXADVXAD
VXEBVXEBVXEBVXEBVXEBVXEBVXEBVXEBVH=CVH=CVXADVXADVhEEVhEEVhEEVhEEV89BVXADW8IFW8IF
VXADVH=CVXADVhEEVH9@VH9@VX=AVX=AVX=AVhABVhABVhABVXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>
VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VXE>VHA=VHA=VHA=VHA=
VHA=VHA=VHA=VHA=VhI?VXE>VXE>VHA=VHA=V8=<V8=<V8=<Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;
V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<Uh=:Uh=:Uh=:Uh=:
Uh=:Uh=:Uh=:Uh=:UX99UX99UX99UX99UX99UX99UX99UX99UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:
UHA;UhA;UhA;Uh=:Uh=:V859V859VH18V859V859V859V859V859V859V859V859UGm5UX16UX16Uh57
Uh57Uh57Uh57Uh57V898V898V898V898V898V898V898V898UGm5UX16UX16Uh57Uh57V898V898V898
Uh57Uh57Uh57Uh57Uh57Uh57Uh57Uh57V859V859V859V859V859V859V859V859Uh18Uh18Uh18V859
V859V859V859V859V898V898V898V898V898Uh57Uh57Uh57VH=9VH=9VH=9VH=9VH=9VH=9VH=9VH=9
V898V898V898V898V898V898V898V898V8=5V8=5V8=6VHA7VH=9VH9:VX=;VX=;Uh57Uh57V898V898
VH=9VH=9VH=9VH=9VH=9VH=9VH=9VH=9VH=9VH=9VH=9VH=9V898V898V898VH=9VH=9VH=9VH=9VXA:
Uh57Uh57Uh57V898V898V898VH=9VH=9VX=;VX=;VX=;VH9:VH9:V859V859Uh18V859V859VH9:VX=;
VX=;VH9:V859V859V859VH9:VH9:VX=;VX=;VhA<VhA<W8E=VH9:VH9:VH9:VX=;VX=;VhA<VhA<VhA<
VH9:VX=;VX=;VhA<VhA<VX=;VX=;VH9:VX=;VX=;VX=;VX=;VX=;VX=;VX=;VX=;VH9:VH9:VH9:VX=;
VX=;VhA<VhA<VhA<VH9:VH9:VX=;VX=;VhA<VhA<W8E=W8E=VHE<VHE<V8A;VX=;W8=;WHA<X8E=XHI>
W8E=W8E=W8E=W8E=W8E=WHI>WHI>WHI>VhA<VhA<VhA<VhA<VhA<VhA<VhA<VhA<W8E=W8E=W8E=W8E=
W8E=WHI>002UTgJUTgJUTgJUTgJUTgJUTgJUTgJUTgJTTGJTTGJUTWNUTWNUTWNVTgRVTgRVTgRUTWNU
TWNUTWNUTWNUTWNUTWNUTWNUTWNTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJST7FST7FST7FST7FST7FS
T7FST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBPSG:Q
SW>QSW>QSW>RSgBRSgBRSgBST7FRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBR
SgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBQSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>PSVnP
SVnPSVnPSVnPSVnPSVnPSVnPSVnNS6nNS6nOSG2OSG2PSW6PSW6QSg:QSg:PRfnPRfnPRfnPRfnPRfnP
RfnPRfnPRfnPS6fPS6fPS6fPS6fPS6fPS6fPS6fPS6fORfbORfbPS6fPS6fQSFjQSFjQSFjQSFjPS6fP
S6fPS6fPS6fPS6fPS6fPS6fPS6fORfbORfbPS6fPS6fQSFjQSFjQSFjQSFjORfbORfbORfbORfbORfbO
RfbORfbORfbORfbORfbORfbORfbORfbORfbORfbORfbNRV^NRV^ORfbORfbORfbPS6fPS6fPS6fORfbO
RfbORfbORfbORfbORfbORfbORfbNRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^OS6NOS6NOS6NOS6NOS6NO
S6NOS6NOS6NPSFRPSFROS6NNRfJNRfJOS6NPSFRPSFROS6NOS6NOS6NOS6NOS6NOS6NOS6NOS6NPSFRP
SFRPSFROS6NOS6NOS6NNRfJNRfJNRfJNRfJNRfJNRfJNRfJNRfJNRfJNRfJMRVFMRVFMRVFMRVFMRVFM
RVFMRVFMRVFLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBKRF2K
R6:KR6:LRFBLRFBMRFJMRFJMR6RKR6:JQf6LR5nLR5nMQefMR5^OR5^NQeVKQUVKQUVLQeZLQeZLQeZM
R5^MR5^MR5^LQUfLQUfLQUbLQUbKQUVKQeRJQUNJQUNJQERKQUVLQeZLQeZLQeZLQeZKQUVJQERJQERJ
QERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERJ
QERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQERJQUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNKQ5JK
Q5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JJPeFJPeFJPeFKQ5JKQ5JLQENLQENLQENKQEFKQEFKQEFKQEFKQEFK
QEFKQEFKQEFLQUJLQUJLQUJLQUJLQUJLQUJLQUJLQUJKQEFKQEFKQEFKQEFKQEFKQEFKQEFKQEFKQU>K
QU>KQU>KQU>KQU>KQU>KQU>KQU>KQEFKQEFKQEFKQEFKQEFKQEFKQEFKQEFIPe>IPe>JQ5BKQEFKQEFJ
Q5BIPe>IPe>JQ5BJQ5BJQ5BJQ5BJQ5BJQ5BJQ5BJQ5BJQE6JQE6JQE6JQE6JQE6JQE6JQE6JQE6IPe>I
Pe>IPe>JQ5BJQ5BJQ5BKQEFKQEFHPU:JQ5BLQUJLQUJJQ5BIPe>IPe>JQ5BIPU2IPU2IPU2JPe6JPe6J
Pe6KQ5:KQ5:JQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjJQDjJ
QDjJQDjJQDjJQDjJQDjJQDjJQDjHPdbHPdbHPdbIQ4fIQ4fIQ4fIQ4fIQ4fJQDjJQDjJQDjIQ4fHPdbH
PdbGPT^GPT^HPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbH
PdbHPdbHPdbHPdbHPdbHPdbHPdbFPTVFPTVFPTVFPTVFPTVGPdZGPdZGPdZEPDREPDREPDREPDREPDRE
PDREPDREPDREP4VEP4VEP4VEP4VEP4VEP4VEP4VEP4VEQ4^GQ4^FPdZGPdZFPTVGP4RGP4RIP4RGP4RG
P4RGP4RGP4RGP4RGP4RGP4RGP4REOdFEOdFEOdFFP4JFP4JGPDNGPDNHPTRGPDNGPDNGPDNGPDNGPDNG
PDNGPDNGPDNEOdFEOdFEOdFEOdFFP4JFP4JGPDNGPDNFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JGP4RG
P4RGP4RGP4RGP4RGP4RGP4RGP4RFOdNFOdNFOdNGP4RHPDVHPDVHPDVIPTZHPTRHPTRHPTRGPDNGPDNG
PDNGPDNGPDNHPTRHPTRHPTRHPTRHPTRHPTRHPTRHPTRGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPTBG
PTBHPdJHPdJIPdVIPTZIPTZIPTZHPTRHPTRHPTRIPdVIPdVJQ4ZJQ4ZJQ4ZHPTRHPTRHPTRHPTRHPTRH
PTRHPTRHPTRGPDNGPDNHPTRHPTRIPdVIPdVJQ4ZJQ4ZFP4JFP4JGPDNGPDNGPDNHPTRHPTRHPTRJPd^J
Pd^IPTZIPTZHPDVGP4RGP4RGP4RGP4RHPDVIPTZIPTZIPTZIPTZHPDVGP4RHPDVHPDVIPTZIPTZJPd^J
Pd^KQ4bKQ4bHPDVIPTZIPTZIPTZJPd^JPd^JPd^KQ4bIPTZIPTZJPd^JPd^JPd^JPd^IPTZIPTZJPd^J
Pd^JPd^JPd^JPd^JPd^JPd^JPd^HPDVIPTZIPTZIPTZJPd^JPd^JPd^KQ4bKQ4bKQ4bKQ4bKQ4bLQDfL
QDfLQDfLQDfIQDbHQ4^HQ4^IPTZLPd^MQ4bPQDfQQTjJPd^KQ4bKQ4bKQ4bLQDfMQTjMQTjMQTjKQ4bK
Q4bKQ4bKQ4bKQ4bKQ4bKQ4bKQ4bJPd^KQ4bKQ4bKQ4bLQDfMQTh00:FCMZFCMZFCMZFCMZFCMZFCMZFC
MZFCMZBAMZBAMZBAMZBAMZFBMjFBMjJCN:JCN:FBMjFBMjFBMjFBMjFBMjFBMjFBMjFBMjBAMZBAMZBA
MZBAMZBAMZBAMZBAMZBAMZ:?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?
M::?M:6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj2=LZ2=LZ2=LZ2=LZ6>Lj6>Lj:?M::?M:6>Lj6>Lj6>
Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>
Lj6>Lj2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LYn=KYn=KYn=KYn=KYn=KYn=KYn=KYn=KYj<Kin=L9n=
L9n=L9n=L9n=L:2>LJ2>LJ2;Kj2;Kj2;Kj2;Kj2;Kj2;Kj2;Kj2;Kj2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<
KJ2<KIn;K9n;K9n;K:2<KJ2<KJ6=KZ6=KZ6=KZ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KIn;K9n;K9n;
K:2<KJ2<KJ6=KZ6=KZ6=KYn;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9n;
K9n;K9j:Jij:Jij:Jin;K9n;K9n;K:2<KJ2<KIn;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9j:Jij:Jij:
Jij:Jij:Jij:Jij:Jij:Jin<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Ij2=J9n<Iij;IYj;IYj;IYj;IYn<
Ij2=J9n<Iin<Iin<Iin<Iin<Iin<Iin<Iin<Ij2=J:2=J9n<Iin<Iij;IYj;IYj;IYj;IYj;IYj;IYj;
IYj;IYj;IYj;IYj;IYj;IYb9I9b9I9b9I9b9I9b9I9b9I9b9I9b9I9^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8
Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8HiZ8GiZ7HIZ7HI^8Hi^8Hi^7I9b8IIb7IiZ8GiZ8Gib8
Gi^8GIf8Fib7FYj7FIj7FIZ6EiZ6Ei^7F9^7F9^7F9b8FIb8FIb8FI^5G9^5G9b6G9b6G9b7FY^7F9Z6
EiV5EYZ5F9Z5F9^6FIb7FYb7FY^6FIZ5F9Z5F9Z5F9Z5F9Z5F9Z5F9Z5F9Z5F9Z5F9Z5F9V4EiV4EiZ5
F9^6FI^6FIZ5F9V4EiV4EiV4EiV4EiV4EiV4EiZ5F9Z5F9Z5F9^6FIZ5F9Z5F9Z5F9Z5F9Z5F9Z5F9Z5
F9Z5F9Z6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6Ei^4EY^4EY^4EY^4EY^4EY^4EY^4EY^4EYZ3EIZ3EIZ3
EIZ3EI^4EY^4EY^4EYb5Ei^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EIb6EYb6EYb6EYb6EYb6EYb6EYb6
EYb6EY^5EI^5EI^5EI^5EI^5EI^5EI^5EI^5EI^6Di^6Di^6Di^6Di^6Di^6Di^6Di^6Di^5EI^5EI^5
EI^5EI^5EI^5EI^5EI^5EIR2DYV3DiZ4E9Z4E9Z4E9Z4E9V3DiR2DYV3DiV3DiV3DiV3DiV3DiV3DiV3
DiV3DiV4D9V4D9V4D9V4D9V4D9V4D9V4D9V4D9R2DYV3DiV3DiV3DiZ4E9Z4E9Z4E9Z4E9N1DIV3Di^5
EI^5EIZ4E9R2DYV3DiZ4E9R1CiR1CiV2D9V2D9Z3DIZ3DIZ3DIZ3DIV4CIV4CIV4CIV4CIV4CIV4CIV4
CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIN2BiN2BiR3
C9R3C9R3C9V4CIV4CIV4CIV4CIV4CIV4CIR3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3C9R3
C9R3C9N2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiF1B9F1B9F1
B9J2BIJ2BIJ2BIN3BYN3BYF1B9F1B9F1B9F1B9F1B9F1B9F1B9F1B9F0BIF0BIF0BIF0BIF0BIF0BIF0
BIF0BIB4BIF3B9F3B9J2B9J2B9R2B9N1AiV1AiN0B9N0B9IoAiEnAYEnAYIoAiN0B9N0B9J0AYEoAIEo
AIAnA9EoAIJ0AYN1AiR2B9N1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiEoAIEoAIAnA9AnA9AnA9EoAIJ0
AYN1AiJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYN0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9EnAYEnAYIo
AiIoAiN0B9R1BIV2BYV2BYJ0AYJ0AYN1AiN1AiN1AiN1AiN1AiN1AiR2B9R2B9R2B9R2B9R2B9R2B9R2
B9R2B9N1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiN2A9N2A9N2AIR3AYR2B9V2BYV2BYV2BYR2B9R2B9R2
B9R2B9V3BIV3BIZ4BYZ4BYR2B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9J0AYJ0AYN1AiR2B9R2B9V3BIZ4
BYZ4BYJ0AYJ0AYJ0AYN1AiN1AiN1AiR2B9R2B9V2BYR1BIR1BIR1BIR1BIR1BIN0B9N0B9N0B9R1BIR1
BIV2BYV2BYR1BIR1BIN0B9R1BIV2BYV2BYV2BYV2BYV2BYZ3BiZ3BiR1BIR1BIR1BIV2BYV2BYZ3BiZ3
BiZ3BiR1BIV2BYV2BYZ3BiZ3BiV2BYV2BYR1BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIV3BIR1BIR1BIR1
BIV2BYV2BYZ3BiZ3BiZ3Bi^4C9^4C9b5CIb5CIb5CIb5CIb5CIb5CIR4BiR4BiN3BYV2BY^2BYb3Bin4
C:25CIV3BIZ4BYZ4BY^5Bib6C9b6C9f7CIf7CIZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYV2BYZ3BiZ3
Bi^4C9b5CIb5C@00Y99eY99eY99eY99eY99eY99eY99eY99eXi1eXi1eY95fY95fYI9gYI9gYI9gYI9g
Y95fY95fY95fY95fY95fY95fY95fY95fXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXXmdXXmdXXmdXXmd
XXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXHicXHicXHicXHicXHicXHicXHicXHic
WhaaWhaaWhaaX8ebX8ebXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHic
XHicXHicXHicXHicWhaaWhaaWhaaWhaaWhaaWhaaWhaaWhaaX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8eb
Whe^Whe^Whe^Whe^Whe^Whe^Whe^Whe^Whe`Whe`Whe`Whe`Whe`WXa_WXa_WXa_X8]_X8]_X8]_X8]_
X8]_X8]_X8]_X8]_X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]Wh]/Wh]/Wh]/Wh]/X8a]X8a]X8a]XHe^
X8a]X8a]X8a]X8a]X8a]X8a]X8a]X8a]Wh]/Wh]/Wh]/Wh]/X8a]X8a]X8a]XHe^WXY[WXY[WXY[WXY[
WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WHUZWXY[WXY[WXY[Wh]/Wh]/Wh]/X8a]
WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWX]VWX]VWX]VWX]V
WX]VWX]VWX]VWX]VWhaWWhaWWX]VWHYUWHYUWX]VWhaWWhaWWX]VWX]VWX]VWX]VWX]VWX]VWX]VWX]V
WhaWWhaWWhaWWhaWWX]VWX]VWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUW8UTW8UTW8UTW8UT
W8UTW8UTW8UTW8UTVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQS
V8IMV8EOVHIPVHIQVXMRVXISVXISVXEUVXQOVXQOVhQMVhQKWHQKW8QIWXMIWXQHVXIGVXIGVXIGVXIG
VhMHVhMHVhMHW8QIVXAKVhELW8ILW8ILW8MJVhMHVHEFV8AEVHAGVXEHVhIIVhIIVhIIVhIIVXEHVHAG
VHAGVHAGVHAGVHAGVHAGVHAGVHAGVHAGV8=FVHAGVXEHVhIIVhIIVXEHVHAGV8=FV8=FV8=FVHAGVHAG
VXEHVXEHVhIIVhIIVHAGVHAGVHAGVHAGVHAGVHAGVHAGVHAGVHEFVHEFVHEFVHEFVHEFVHEFVHEFVHEF
VhAFVhAFVhAFVhAFVhAFVhAFVhAFVhAFVH9DVH9DVX=EVX=EVX=EVhAFVhAFVhAFVXADVXADVXADVXAD
VXADVXADVXADVXADVhEEVhEEVhEEVhEEVhEEVhEEVhEEVhEEVXADVXADVXADVXADVXADVXADVXADVXAD
VXEAVXEAVXEAVXEAVXEAVXEAVXEAVXEAVXADVXADVXADVXADVXADVXADVXADVXADV89BVH=CVH=CVXAD
VXADVH=CVH=CV89BVH=CVH=CVH=CVH=CVH=CVH=CVH=CVH=CVHE>VHE>VHE>VHE>VHE>VHE>VHE>VHE>
V89BV89BVH=CVH=CVH=CVXADVXADVXADUh5AVH=CVhEEVhEEVH=CV89BV89BVH=CV85?V85?V85?VH9@
VH9@VX=AVX=AVX=AVHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;
VHA=VHA=VHA=VHA=VHA=VHA=VHA=VHA=UX5:Uh9;Uh9;V8=<V8=<VHA=VHA=VHA=Uh9;Uh9;Uh9;V8=<
V8=<V8=<V8=<V8=<Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;
Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;U817U817UH58UH58UX99UX99Uh=:Uh=:U817U817U817U817
U817U817U817U817U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8TX97U897U897UH57UX98V898V898VX98
Uh18UWm7UGi6U7e5U7e5UGi6UWm7Uh18UX16UGm5U7i4U7i4U7i4UGm5Uh57V898UX16UX16UX16UX16
UX16UX16UX16UX16UGm5U7i4Tge3Tge3Tge3U7i4UX16Uh57UGm5UGm5UGm5UGm5UGm5UGm5UGm5UGm5
UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7U7e5U7e5UGi6UWm7Uh18V859VH9:VH9:UGm5UGm5UX16UX16
Uh57Uh57V898V898V898V898V898V898V898V898V898V898UX16UX16UX16UX16UX16UX16UX16UX16
Uh94Uh94Uh95Uh95V898V859V859VH9:UX16UX16UX16Uh57Uh57Uh57V898V898V898V898V898V898
V898V898V898V898UGm5UGm5UX16Uh57V898VH=9VXA:VXA:UGm5UX16UX16UX16Uh57Uh57Uh57V898
Uh18Uh18Uh18Uh18V859V859V859V859Uh18Uh18V859VH9:VH9:V859Uh18Uh18VH9:VH9:VH9:VH9:
VH9:V859V859V859V859V859V859VH9:VH9:VH9:VX=;VX=;V859V859VH9:VX=;VX=;VH9:V859V859
VH=9VH=9VH=9VH=9VH=9VH=9VH=9VH=9V859V859V859VH9:VH9:VH9:VX=;VX=;VhA<VX=;VX=;VX=;
VX=;VX=;VX=;VX=;V8A;Uh=:Uh=:VH9:Vh9:W8=;WhA<X8E=V898VH=9VXA:VXA:VhE;W8I<WHM=WHM=
VXA:VXA:VXA:VXA:VXA:VXA:VXA:VXA:V859VH9:VX=;VX=;VhA<W8E=002TTWFTTWFTTWFTTWFTTWFT
TWFTTWFTTWFST7FST7FTTGJTTGJTTGJUTWNUTWNUTWNTTGJTTGJTTGJTTGJTTGJTTGJTTGJTTGJST7FS
T7FST7FST7FST7FST7FST7FST7FRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBR
SgBRSgBRSgBQSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>OS76OS76OS76OS76PSG:PSG:PSG:QSW>QSW>Q
SW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>NRg2NRg2NRg2NRg2NRg2N
Rg2NRg2NRg2PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:OSFjOSFjOSFjOSFjOSFjOSFjOSFjOSFjPSW6P
SW6OSG2OSG2NS6nNS6nMRfjMRfjORVjORVjORVjORVjORVjORVjORVjORVjORfbORfbORfbORfbORfbO
RfbORfbORfbNRV^ORfbORfbORfbPS6fPS6fPS6fPS6fORfbORfbORfbORfbORfbORfbORfbORfbNRV^O
RfbORfbORfbPS6fPS6fPS6fPS6fNRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^N
RV^NRV^NRV^MRFZMRFZNRV^NRV^NRV^ORfbORfbORfbNRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^MRFZM
RFZMRFZMRFZMRFZMRFZMRFZMRFZNRfJNRfJNRfJNRfJNRfJNRfJNRfJNRfJOS6NOS6NNRfJMRVFMRVFN
RfJOS6NOS6NNRfJNRfJNRfJNRfJNRfJNRfJNRfJNRfJOS6NOS6NOS6NNRfJNRfJNRfJMRVFMRVFMRVFM
RVFMRVFMRVFMRVFMRVFMRVFMRVFLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBKR6>KR6>KR6>KR6>KR6>K
R6>KR6>KR6>KR6>KR6>KR6>KR6>KR6>KR6>KR6>KR6>GQEbGQ5jHQEnHQF2IQV6IQF:IQF:IQ6BJR5nI
R5fKR5fKR5^LR5VLR5VNR5RMQeNIQEJIQEJJQUNJQUNJQUNKQeRKQeRKQeRJQ5^JQ5^LQUbLQUbLQeZJ
QUNIQEJGPeBIQ5NJQERKQUVKQUVKQUVKQUVJQERIQ5NIQ5NIQ5NIQ5NIQ5NIQ5NIQ5NIQ5NIQ5NGPUFH
PeJJQERKQUVKQUVJQERHPeJGPUFGPUFHPeJHPeJIQ5NIQ5NJQERKQUVKQUVIQ5NIQ5NIQ5NIQ5NIQ5NI
Q5NIQ5NIQ5NGPeBGPeBGPeBGPeBGPeBGPeBGPeBGPeBKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JKQ5JIPUBI
PUBIPUBJPeFJPeFKQ5JKQ5JKQ5JJQ5BJQ5BJQ5BJQ5BJQ5BJQ5BJQ5BJQ5BIPe>IPe>IPe>IPe>IPe>I
Pe>IPe>IPe>JQ5BJQ5BJQ5BJQ5BJQ5BJQ5BJQ5BJQ5BJQE6JQE6JQE6JQE6JQE6JQE6JQE6JQE6JQ5BJ
Q5BJQ5BJQ5BJQ5BJQ5BJQ5BJQ5BHPU:IPe>IPe>JQ5BJQ5BIPe>IPe>HPU:IPe>IPe>IPe>IPe>IPe>I
Pe>IPe>IPe>IQDjIQDjIQDjIQDjIQDjIQDjIQDjIQDjHPU:HPU:HPU:IPe>IPe>IPe>JQ5BJQ5BGPE6I
Pe>KQEFKQEFIPe>HPU:HPU:IPe>HPDnHPDnHPDnIPU2IPU2IPU2JPe6JPe6IQ4fIQ4fIQ4fIQ4fIQ4fI
Q4fIQ4fIQ4fFPDZFPDZFPDZFPDZFPDZFPDZFPDZFPDZIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fIQ4fFPDZF
PDZGPT^GPT^HPdbIQ4fIQ4fIQ4fFPDZFPDZGPT^GPT^HPdbIQ4fIQ4fIQ4fEP4VEP4VEP4VEP4VEP4VE
P4VEP4VEP4VGPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^DP4ND
P4NDP4NEPDRFPTVFPTVGPdZGPdZDP4NDP4NDP4NDP4NDP4NDP4NDP4NDP4NDOdRDOdRDOdRDOdRDOdRD
OdRDOdRDOdRAPTBCPDBCPDBEPTFFPdJHPdJIQ4NKPdNGP4RFOdNDODFCO4BCO4BDODFFOdNGP4RFP4JE
OdFDOTBCOD>DOTBEOdFGPDNHPTRFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JEOdFDOTBCOD>BO4:BO4:D
OTBFP4JGPDNEOdFEOdFEOdFEOdFEOdFEOdFEOdFEOdFFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNDODFD
ODFEOTJFOdNGP4RHPDVIPTZIPTZDOTBDOTBEOdFFP4JGPDNHPTRIPdVIPdVGPDNGPDNGPDNGPDNGPDNG
PDNGPDNGPDNFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JFPD>GPTBGPTFGPTFHPTRHPDVHPDVHPDVDOTBD
OTBDOTBEOdFEOdFFP4JFP4JFP4JGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNEOdFEOdFFP4JGPDNHPTRI
PdVJQ4ZJQ4ZEOdFEOdFFP4JFP4JFP4JGPDNGPDNGPDNFOdNFOdNFOdNGP4RHPDVHPDVIPTZIPTZFOdNG
P4RHPDVHPDVHPDVHPDVGP4RFOdNJPd^JPd^IPTZIPTZHPDVHPDVGP4RGP4RGP4RHPDVHPDVHPDVIPTZI
PTZIPTZJPd^HPDVHPDVIPTZJPd^JPd^IPTZHPDVHPDVIQ4NIQ4NIQ4NIQ4NIQ4NIQ4NIQ4NIQ4NGP4RH
PDVHPDVHPDVIPTZIPTZIPTZJPd^IPTZIPTZIPTZIPTZHPDVHPDVHPDVHPDVHQ4^GPdZGPdZHPDVKPTZL
Pd^OQ4bPQDfHPdJHPdJIQ4NJQDRKQTVLQdZMR4^NRDbJQDRJQDRJQDRJQDRJQDRJQDRJQDRJQDRHPDVH
PDVIPTZJPd^KQ4bLQDd00:JAMJJAMJF@M:F@M:JAMJNBMZRCMjRCMj>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@
MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ:?M::?M::?M::?M::?M::?M::?M::?M::?M::?M::?
M::?M::?M::?M::?M::?M:6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=
LZ2=LZ2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ2>LJ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ6>Lj6>Lj6>
Lj6>Lj6>Lj6>Lj6>Lj6>Lin<LIn<LIn<LJ2=LZ2=LZ2=LZ6>Lj6>Lif;KYf;KYj<Kij<Kin=L:2>LJ2>
LJ2>LJ6=KZ6=KZ2<KJ2<KIn;K9n;K9j:Jij:Jj:>Kj:>Kj:>Kj6=KZ2<KJ2<KIn;K9n;K:2<KJ2<KJ2<
KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<KIn;K9n;K9j:Jij:Jif9JYf9JZ2<KJ2<KJ2<KJ2<KJ2<KJ2<KJ2<
KJ2<KIn;K9n;K9n;K9n;K:2<KJ2<KJ2<KJ6=KYj:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:
Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:
Jij:Jif9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYj:Jij:Jif9JYb8JIb8JIf9JYj:Jij:Jif:IIf:IIf:
IIf:IIf:IIf:IIf:IIf:IIj;IYj;IYj;IYj;IYj;IYj;IYj;IYj;IYn<Iin<Iij;IYj;IYf:IIb9I9b9
I9b9I9j;IYf:IIf:IIb9I9b9I9^8Hi^8HiZ7HYb9I9b9I9b9I9b9I9b9I9b9I9b9I9b9I9Z7HY^8Hi^8
Hib9I9b9I9^8Hi^8HiZ7HY^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8HY^8HYZ7HIZ7HIZ7HIV6H9V6
H9V6H9b9Hib9Hi^8HY^8HY^8HY^8HY^8HYZ7HIV6H9R5GiZ6GIZ6GI^5Fi^5Fif6FIf6FIZ6EiZ6EiZ6
EiZ6EiZ6EiZ6EiZ6EiZ6EiR4EIR4EIR4EIV5EYZ6EiZ6Ei^7F9^7F9j7FIf6F9b5Ei^4EYZ3EIZ3EIZ3
EI^4EYR4EIR4EIR4EIV5EYZ6EiZ6Ei^7F9^7F9B0DIF1DYJ2DiR4EIR4EIR4EIR4EIR4EIZ6EiR4EIN3
E9N3E9V5EYZ6EiV5EYN3E9Z3EIZ3EIZ3EIZ3EIZ3EIZ3EIZ3EIZ3EIZ4E9Z4E9Z4E9Z4E9Z4E9Z4E9Z4
E9Z4E9^4EY^4EYZ3EIV2E9V2E9Z3EI^4EY^4EYb6EYb6EY^5EI^5EIZ4E9V3DiV3DiV3Di^5EI^5EI^5
EIZ4E9Z4E9Z4E9Z4E9Z4E9V4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4
DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4
DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4
DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIV4DIR1CiR1CiR1CiV2D9V2D9Z3DIZ3DIZ3DIZ5CYZ5CYZ5
CYV4CIV4CIR3C9R3C9R3C9V4CIV4CIV4CIV4CIV4CIV4CIV4CIV4CIR4BiR4BiR4BiR4BiR4BiR4BiR4
BiR4Bib5CIV2BYN0B9R1BI^4C9b5CIZ3BiR1BIZ6CIV5C9V5C9R4BiR4BiN3BYJ2BIJ2BIN3BYN3BYR4
BiV5C9V5C9R4BiN3BYN3BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYR1BIR1BIR1BIR1BIR1BIR1BIR1
BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIV2BYIoAiAmAIEnAYR1BIV2BYN0B9AmAIIoAiIoAiIo
AiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiEoAIEoAIEoAIEoAIEoAIEoAIEo
AIEoAIN1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiN1AiAo@IAo@IF0
@iF0@iJ0AYIoAiIoAiIoAi=m@i=m@i=m@i=m@i=m@i=m@i=m@i=m@iAnA9AnA9EoAIEoAIJ0AYJ0AYJ0
AYJ0AY9nA9B0AYJ2B9R2B9V1AiMoAIYoAY^0AiInBYInB9IoAiJ0AYJ1A9J1@iJ2@IJ2@IEoAIEoAIEo
AIEoAIEoAIEoAIEoAIEoAIJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYMl@iQmA9YoAY^0Ai^0AiYoAYQm
A9Ml@iEoAIJ0AYJ0AYJ0AYN1AiN1AiN1AiR2B9J0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYN1
AiN1AiR2B9V3BIV3BIV3BI^0Ai^0AiYoAYUnAIUnAIYoAY^0Ai^0AiJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0
AYJ0AYR2B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9EoAIJ0AYJ0AYJ0AYN1AiN1AiN1AiR2B9V2BYR1BIN0
B9N0B9N0B9N0B9R1BIV2BYR1BIR1BIR1BIR1BIR1BIR1BIR1BIR1BIZ4BYV3BIN1AiN1AiN1AiV3BIZ4
BYb6C9V3BIZ4BYZ4BYZ4BYV3BIR2B9N1AiJ0AYJ1@iR3AIZ5B9V4AiR2B9R1BIV2BY^4C9V2BYV2BYR1
BIR1BIN0B9IoAiIoAiIoAiZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYZ4BYf8Bib6C9^5BiZ3Bi^4C9b4CYj6
D9n7Dij3Bij3Bij3Bij3Bij3Bij3Bij3Bij3Bij3Bij3Bij3Bij3Bij3Bij3B`00YY5eYY5eYI1dYI1d
YI1dYY5eYi9fZ9=gXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1e
XXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXHicXHicXHicXHic
XHicXHicXHicXHicX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8iaX8iaX8iaX8iaX8iaX8iaX8iaX8ia
X8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebXHicXHicXHicXHicXHicXHicXHicXHicWhaaWhaaWhaaWhaa
X8ebX8ebXHicXHicWXa_WXa_WXa_WXa_Whe`Whe`Whe`Whe`XHe^XHe^X8a]X8a]Wh]/Wh]/WXY[WXY[
XXi_XXi_XHe^XHe^X8a]X8a]Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/X8a]Wh]/Wh]/Wh]/
WXY[WHUZWHUZWHUZWh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/WXY[Wh]/Wh]/Wh]/X8a]X8a]X8a]X8a]
WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[
WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZ
WXY[WXY[WHUZW8QYW8QYWHUZWXY[WXY[WHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWX]VWX]VWX]VWX]V
WX]VWX]VWX]VWX]VWX]VWX]VWX]VWHYUWHYUW8UTW8UTW8UTX8eXWhaWWhaWWhaWWX]VWHYUWHYUWHYU
W8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTVXMRVXMRVhQSW8UTW8UTVhQSVXMRVXMRVhQSVhQSVhQSVhQS
VhQSVhQSVhQSVhQSVhQRVhQRVXMQVXMQVHIPVHIPVHIPVHIPVhQRVhQRVhQRVhQRVhQRVXMQVXMQVXMQ
V8EOV8EOVXIMVXIMVhEKVhEKWHIIW8EHVXIGVXIGVXIGVXIGVXIGVXIGVXIGVXIGVHEFVHEFVHEFVHEF
VHEFVXIGVXIGVXIGWHIHW8EGVhAFVX=EVX=EVX=EVhAFVhAFVHEFVHEFVHEFVHEFVHEFVXIGVXIGVXIG
UH5BUX9CUh=DV8AEVHEFVHEFV8AEV8AEVHEFV8AEUX9CUh=DVHEFVXIGV8AEUh=DVX=EVX=EVX=EVX=E
VX=EVX=EVX=EVX=EV89BV89BV89BV89BV89BV89BV89BV89BVhAFVX=EVX=EVH9DVH9DVX=EVX=EVhAF
VhEEVhEEVhEEVXADVXADVH=CVH=CVH=CVXADVXADVXADVXADVXADVXADVXADVXADVHAAVHAAVHAAVHAA
VHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAA
VHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAA
VHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVHAAVXEBVXEBVHAAVHAAVHAAV8=@V8=@V8=@
V85?V85?V85?VH9@VH9@VH9@VX=AVX=AVXE>VXE>VHA=VHA=VHA=V8=<V8=<V8=<VHA=VHA=VHA=VHA=
VHA=VHA=VHA=VHA=V8A;V8A;V8A;V8A;V8A;V8A;V8A;V8A;W8E=VH9:Uh18V859VhA<W8E=VX=;V859
VHE<VHE<V8A;V8A;Uh=:Uh=:UX99UX99Uh=:Uh=:V8A;VHE<VHE<V8A;Uh=:Uh=:VH9:VH9:VH9:VH9:
VH9:VH9:VH9:VH9:Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18
V859UWm7U7e5UGi6V859VH9:Uh18U7e5UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7
UWm7UWm7UWm7UWm7UGm5UGm5UGm5UGm5UGm5UGm5UGm5UGm5UX16UX16UX16UX16UX16UX16UX16UX16
UGm5UGm5UGm5UGm5UGm5UGm5UGm5UGm5U7m1U7m1UH13UH13UGm5UWm7UWm7UWm7U7i4U7i4U7i4U7i4
U7i4U7i4U7i4U7i4U7i4U7i4UGm5UGm5UGm5UX16UX16UX16TWi4U816UX98V898V816Ugm5VWm6Vh17
UWi8UWi8UWm7UX16UX54UX53UX53UX91UGm5UGm5UGm5UGm5UGm5UGm5UGm5UGm5UX16UX16UX16UX16
UX16UX16UX16UX16V7e4VGi5VWm6Vh17Vh17VWm6VGi5V7e4UGm5UGm5UX16UX16UX16Uh57Uh57Uh57
UX16UX16UX16UX16UX16UX16UX16UX16Uh57Uh57Uh57Uh57V898V898V898V898Vh17Vh17VWm6VGi5
VGi5VWm6Vh17Vh17UX16UX16UX16UX16UX16UX16UX16UX16Uh57Uh57Uh57Uh57Uh57Uh57Uh57Uh57
UGm5UGm5UX16UX16UX16Uh57Uh57Uh57V859V859Uh18UWm7UWm7Uh18V859V859Uh18Uh18Uh18Uh18
Uh18Uh18Uh18Uh18V898V898V898V898V898VH=9VXA:VXA:VH=9VH=9VXA:VXA:VH=9V898Uh57UX16
UX53V8=5VXE8VHA7V898V859VH9:VhA<VH9:VH9:VH9:V859V859Uh18Uh18Uh18VXA:VXA:VXA:VXA:
VXA:VXA:VXA:VXA:VhI9VXA:VH=9VH9:VH9:VX9<W8A>WHEAWX=;WX=;WX=;WX=;WX=;WX=;WX=;WX=;
WX=;WX=;WX=;WX=;WX=;WX=;002VTGFUT7BUT7BUT7BUT7BVTGFWTWJXTgNST7FST7FST7FST7FST7FS
T7FST7FST7FST7FST7FST7FST7FST7FST7FST7FST7FRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBRSgBR
SgBRSgBRSgBRSgBRSgBRSgBRSgBQSW>QSW>QSW>QSW>QSW>QSW>QSW>QSW>PSG:PSG:PSG:PSG:PSG:P
SG:PSG:PSG:OSG2OSG2OSG2OSG2OSG2OSG2OSG2OSG2OS76OS76OS76OS76OS76OS76OS76OS76PSG:P
SG:PSG:PSG:PSG:PSG:PSG:PSG:NRg2NRg2OS76OS76PSG:PSG:PSG:PSG:OSG2OSG2OSG2NS6nNS6nN
S6nNS6nNS6nPS6fPS6fPS6fPS6fORfbORfbORfbORfbQSFjQSFjQSFjPS6fPS6fPS6fORfbORfbORfbO
RfbORfbORfbORfbORfbORfbORfbORfbORfbNRV^NRV^NRV^MRFZMRFZMRFZORfbORfbORfbORfbORfbO
RfbORfbORfbNRV^NRV^NRV^ORfbORfbPS6fPS6fPS6fNRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^N
RV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^N
RV^NRV^NRV^MRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZNRV^MRFZLR6VLR6VLR6VLR6VMRFZNRV^MRVFM
RVFMRVFMRVFMRVFMRVFMRVFMRVFNRfJNRfJNRfJNRfJNRfJNRfJNRfJNRfJNRfJMRVFMRVFMRVFLRFBL
RFBLRFBLRFBOS6NOS6NNRfJNRfJNRfJMRVFMRVFMRVFLRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBIQV6J
Qf:KR6>KR6>KR6>KR6>JQf:IQV6JQf:JQf:JQf:JQf:JQf:JQf:JQf:JQf:JQf6JQf6JQf6JQf6IQV2I
QV2HQEnHQEnJQf6JQf6JQf6JQf6JQf6JQf6JQf6JQf6HQEnHQEnJQUfIQEbKQE^JQ5ZLQERLQERJQUNJ
QUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNJQUNIQEJIQEJIQEJIQEJIQEJKQ5JKQ5JJPeFJPeFJPeFK
Q5JLQENLQENIQEJIQEJIQEJIQEJIQEJHQ5FHQ5FHQ5FFPU>GPeBHQ5FIQEJIQEJIQEJIQEJHQ5FIQEJG
PeBFPU>GPeBIQEJIQEJHQ5FFPU>JPeFJPeFJPeFJPeFJPeFJPeFJPeFJPeFGPE6GPE6GPE6GPE6GPE6G
PE6GPE6GPE6KQ5JJPeFIPUBIPUBIPUBIPUBJPeFKQ5JKQEFJQ5BJQ5BJQ5BIPe>IPe>IPe>IPe>JQ5BJ
Q5BJQ5BJQ5BJQ5BJQ5BJQ5BJQ5BIQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56I
Q56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56I
Q56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56IQ56I
Q56IQ56IQ56JQE:JQE:IQ56IQ56HPe2HPe2GPTnGPTnGP4jHPDnHPDnHPDnIPU2IPU2IPU2IPU2IQ4fI
Q4fIQ4fIQ4fHPdbHPdbHPdbGPT^HPdbHPdbHPdbHPdbHPdbHPdbHPdbHPdbGPdZGPdZGPdZGPdZGPdZG
PdZGPdZGPdZKQ4bIPTZHPDVHPDVJPd^KQ4bJPd^HPDVHQ4^HQ4^HQ4^HQ4^GPdZGPdZGPdZFPTVFPTVG
PdZHQ4^HQ4^HQ4^HQ4^GPdZFPTVHPDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVGP4RGP4RGP4RGP4RGP4RG
P4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RFOdNDODFEOTJGP4RGP4RFOdNEOTJFOdNF
OdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNEOdFEOdFEOdFEOdFEOdFE
OdFEOdFEOdFFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JCOD>COD>COD>COD>COD>COD>COD>COD>DOd6D
Od6DOd:EP4>EOdFEOTJFOdNFOdNDOTBDOTBDOTBDOTBDOTBDOTBDOTBDOTBDOTBDOTBDOTBEOdFEOdFE
OdFFP4JFP4JBOTBDP4JFPTRHPTRHP4JGOdFIOTFJOdJFOdNFOdNFOdNFP4JFPDBFPDBFPD>FPD>EOdFE
OdFEOdFEOdFEOdFEOdFEOdFEOdFFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JIOTFJOdJKP4NKP4NKP4NK
P4NJOdJIOTFEP4>EP4>EP4>FPDBFPDBGPTFGPTFGPTFFP4JFP4JFP4JFP4JFP4JFP4JFP4JFP4JHPTRH
PTRGPDNGPDNGPDNGPDNGPDNFP4JKP4NJOdJJOdJIOTFIOTFJOdJJOdJKP4NFP4JFP4JFP4JFP4JFP4JF
P4JFP4JFP4JGPDNGPDNGPDNGPDNGPDNGPDNGPDNGPDNEOdFEOdFEOdFFP4JFP4JGPDNGPDNGPDNHPDVG
P4RGP4RFOdNFOdNGP4RGP4RHPDVGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RFP4JGPDNHPTRIPdVIPdVI
PdVIPdVHPTRHPTRIPdVIPdVIPdVIPdVHPTRGPDNFP4JFPD>HPdFIQ4NIQ4NHPTRGP4RIPTZKQ4bJPd^J
Pd^IPTZIPTZIPTZHPDVHPDVHPDVIPdVIPdVIPdVIPdVIPdVIPdVIPdVIPdVIQ4NIPdVHPTRHPDVHPDVI
PD^JPTbKPdnMPTZMPTZMPTZMPTZMPTZMPTZMPTZMPTZMPTZMPTZMPTZMPTZMPTZMPTX00:F@M:F@M:B?
LjB?LjF@M:JAMJNBMZNBMZ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ>@MJ:?M::?M::?M::?M::?M::?M::?
M::?M:6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>
Lj6>Lj6>Lj6>Lj6>Lj6>Lj2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LYn=L9n=L9n=L9n=L9n=L9n=L9n=
L9n=L9n<LIn<LIn<LIn<LIn<LIn<LIn<LIn<LJ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LYj;L9j;L9j;
L9n<LIn<LIn<LJ2=LZ2=LYn=L9n=L9n=L9j<Kif;KYf;KYb:KIb:KJ2<KJ2<KJ2<KJ2<KIn;K9n;K9n;
K9n;K:2<KJ2<KJ2<KJ2<KJ2<KJ2<KIn;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9j:Jij:Jij:
Jij:Jif9JYf9JYf9JYf9JYn;K9n;K9n;K9n;K9n;K9n;K9n;K9n;K9j:Jij:Jij:Jij:Jin;K9n;K:2<
KJ2<KIj:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:
Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jij:Jib8JIb8JIb8JIb8JIb8JIb8JIb8
JIb8JIf9JYf9JYb8JI^7J9^7J9b8JIf9JYf9JYf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:
IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIb9I9b9I9b9I9b9I9b9I9b9I9^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8
Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8HiV6HIZ7HYZ7HY^8Hi^8HiZ7HYZ7HYV6HIZ7HYZ7HYZ7
HYZ7HYZ7HYZ7HYZ7HYZ7HYZ7HIZ7HIV6H9V6H9V6H9R5GiR5GiR5GiR5GiV6H9V6H9V6H9V6H9V6H9Z7
HIZ7HIR5GiR5GiV5G9V5G9Z4FYZ4FYb5F9b5F9Z6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6EiZ6Ei^7F9^7F9Z6
EiZ6EiV5EYR4EIR4EIR4EIZ3EIV2E9V2E9V2E9Z3EI^4EYb5Eif6F9Z6EiZ6EiV5EYV5EYR4EIN3E9N3
E9N3E9N3E9R4EIV5EYV5EYZ6EiV5EYR4EIR4EIV5EYN3E9J2DiJ2DiR4EIV5EYR4EIJ2DiV2E9V2E9V2
E9V2E9V2E9V2E9V2E9V2E9V3DiV3DiV3DiV3DiV3DiV3DiV3DiV3DiZ3EIZ3EIV2E9R1DiR1DiV2E9Z3
EIZ3EIZ4E9Z4E9V3DiV3DiV3DiV3DiV3DiV3DiV3DiV3DiV3DiV3DiV3DiZ4E9Z4E9Z4E9R3D9R3D9R3
D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3
D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3
D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9R3D9Z5DYZ5DYV4DIV4DIR3D9N2CiN2
CiJ1CYN0CYN0CYN0CYR1CiR1CiV2D9V2D9V2D9V4CIV4CIV4CIR3C9R3C9N2BiN2BiN2BiR3C9R3C9R3
C9R3C9R3C9R3C9R3C9R3C9N3BYN3BYN3BYN3BYN3BYN3BYN3BYN3BYV2BYV2BYR1BIV2BYV2BYV2BYV2
BYR1BIN3BYN3BYN3BYN3BYN3BYN3BYN3BYN3BYJ2BIJ2BIN3BYR4BiR4BiN3BYJ2BIJ2BIR1BIR1BIR1
BIR1BIR1BIR1BIR1BIR1BIN0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0
B9N0B9IoAiEnAYEnAYEnAYIoAiIoAiIoAiEnAYIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIo
AiIoAiIoAiIoAiIoAiIoAiAnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9EoAIEoAIEoAIEoAIEoAIEoAIEo
AIEoAIAnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9=n@9=n@9Ao@YAo@YEoAIEnAYEnAYEnAYEoAIEoAIEo
AIEoAIEoAIEoAIEoAIEoAI=m@i=m@iAnA9AnA9EoAIEoAIEoAIEoAI5m@i=oAIF1AiN1AiR0AYInA9Un
AIYoAYJ0AYJ0AYJ0AYJ0AYJ0AYJ1A9J1A9J1A9AnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9J0AYJ0AYJ0
AYJ0AYJ0AYJ0AYJ0AYJ0AYYoAY^0Ai^0Ai^0Ai^0Ai^0Ai^0AiYoAYAo@YF0@iF0@iF0@iJ1A9J1A9J1
A9N2AIJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYR2B9R2B9R2B9N1AiJ0AYJ0AYEoAIEoAIYoAYYoAYUn
AIUnAIUnAIUnAIYoAYYoAYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYJ0AYN1AiN1AiN1AiN1AiN1AiN1AiN1
AiN1AiAnA9EoAIEoAIEoAIJ0AYJ0AYJ0AYN1AiR1BIN0B9IoAiIoAiIoAiIoAiN0B9R1BIN0B9N0B9N0
B9N0B9N0B9N0B9N0B9N0B9EoAIJ0AYR2B9V3BIZ4BYV3BIR2B9N1AiN1AiR2B9R2B9V3BIV3BIR2B9N1
AiJ0AYF0@YN2A9V4AiR3AYN1AiN0B9R1BIZ3BiV2BYV2BYV2BYV2BYV2BYV2BYV2BYV2BYV3BIV3BIV3
BIV3BIV3BIV3BIV3BIV3BIV4AiR2B9R2B9V2BYV2BYZ2C9Z2C9^3Cif2BYf2BYf2BYf2BYf2BYf2BYf2
BYf2BYf2BYf2BYf2BYf2BYf2BYf2BP00YI1dY8mcY8mcY8mcY8mcYI1dYY5eYi9fXi1eXi1eXi1eXi1e
Xi1eXi1eXi1eXi1eXXmdXXmdXXmdXXmdXXmdXXmdXXmdXXmdXHicXHicXHicXHicXHicXHicXHicXHic
XHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicXHicX8ebX8ebX8ebX8eb
X8ebX8ebX8ebX8ebWXa_WXa_WXa_WXa_WXa_WXa_WXa_WXa_WX]`WX]`WX]`WX]`WX]`WX]`WX]`WX]`
X8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebWHY_WHY_WX]`WX]`WhaaWhaaWhaaWhaaWhe`Whe`WXa_WXa_
WH]^W8Y]W8Y]W8Y]Wh]/Wh]/Wh]/Wh]/X8a]X8a]X8a]X8a]Wh]/Wh]/Wh]/Wh]/Wh]/Wh]/X8a]X8a]
WXY[WXY[WXY[WXY[WXY[WXY[WXY[WXY[WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWXY[WXY[WXY[WXY[
WXY[WXY[WXY[WXY[WHUZWHUZWXY[WXY[WXY[Wh]/Wh]/Wh]/WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZ
WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZ
WHUZWHUZWHUZWHUZW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYWHUZW8QYVhMXVhMXVhMXVhMXW8QYWHUZ
WHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYUVhQSVhQSW8UTW8UT
W8UTW8UTW8UTW8UTVXMRVXMRVXMRVXMRVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQSVhQS
VHIQVHIQVXMRVXMRVXMRVXMRVHIQVHIQVXMRVXMRVXMRVXMRVXMRVXMRVXMRVXMRVHIPVHIPVHIPVHIP
V8EOV8EOUhANUhANUhANUhANUhANV8EOV8EOVHIPVHIPVXMQUhANUhANVHELV8AKVXAJVXAJVhAGVhAG
VHEFVHEFVHEFVHEFVHEFVHEFVHEFVHEFVhMHVhMHVXIGVXIGVHEFV8AEV8AEV8AEVH9DVH9DVH9DVH9D
VH9DVX=EW8EGW8EGVHEFVHEFVHEFV8AEV8AEUh=DUh=DUX9CUh=DV8AEVHEFVHEFVHEFV8AEUh=DUh=D
V8AEUX9CUH5BUX9CV8AEV8AEUh=DUH5BVH9DVH9DVH9DVH9DVH9DVH9DVH9DVH9DVH=CVH=CVH=CVH=C
VH=CVH=CVH=CVH=CVX=EVH9DV85CV85CV85CV85CVH9DVX=EV89BV89BVH=CVH=CVH=CVH=CVH=CVH=C
Uh5AV89BV89BV89BVH=CVXADVXADVXADV8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@
V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@
V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@V8=@
V8=@V8=@V8=@V8=@VHAAVHAAV8=@V8=@Uh9?Uh9?Uh9?UX5>UWm=Uh1>Uh1>Uh1>V85?V85?V85?VH9@
VHA=V8=<V8=<V8=<Uh9;Uh9;Uh9;UX5:V8=<V8=<V8=<V8=<V8=<V8=<V8=<V8=<UX99UX99UX99UX99
UX99UX99UX99UX99V859V859VH9:VH9:V859V859V859VH9:UX99UX99UX99UX99UX99Uh=:Uh=:Uh=:
UH58UX99Uh=:Uh=:Uh=:Uh=:UX99UH58Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18UWm7UWm7UWm7UWm7
UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UGi6UGi6UWm7UGi6UGi6U7e5UGi6UGi6
UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6U7i4U7i4U7i4U7i4
U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4UGm5UGm5UGm5UGm5UGm5UGm5UGm5UGm5
Tgi0Tgi0Tgi1U7m2U7i4U7e5UGi6UGi6U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4Tge3Tge3Tge3U7i4
U7i4U7i4UGm5UGm5TGe3Tgm5UH57Uh57Ugm5UWi4V7e4VGi5UH13UH13UH13UGm5UGm5UGm5UGm5UGm5
U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4UGm5UGm5UGm5UGm5UGm5UGm5UGm5UGm5Vh17VWm6VWm6VWm6
VWm6VWm6VWm6Vh17U7m1U7m1U7m1UH12UH12UX53UX53UX53UGm5UGm5UGm5UGm5UGm5UGm5UGm5UGm5
V898Uh57Uh57UX16UX16UGm5UGm5UGm5VWm6VGi5VGi5V7e4V7e4VGi5VGi5VWm6UGm5UGm5UGm5UGm5
UGm5UGm5UGm5UGm5UX16UX16UX16UX16UX16UX16UX16UX16U7i4U7i4U7i4UGm5UGm5UX16UX16UX16
Uh18Uh18UWm7UGi6UGi6UWm7Uh18Uh18UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7U7i4UX16Uh57VH=9
VH=9VH=9Uh57UX16UX16Uh57Uh57V898V898V898Uh57Uh57UH12Uh94V8=6V8=6Uh57UWm7V859VX=;
V859V859V859V859VH9:VH9:VH9:VH9:V898V898V898V898V898V898V898V898VHA7VH=9VXA:VX=;
VhA<Vh==Vh==Vh=?W859W859W859W859W859W859W859W859W859W859W859W859W859W859002TSg>T
Sg>SSW:SSW:TSg>UT7BVTGFVTGFST7FST7FST7FST7FST7FST7FST7FST7FQSW>QSW>QSW>QSW>QSW>Q
SW>QSW>QSW>PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:QSW>Q
SW>QSW>QSW>QSW>QSW>QSW>QSW>PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:NS6nNS6nNS6nNS6nNS6nN
S6nNS6nNS6nNRg2NRg2NRg2NRg2NRg2NRg2NRg2NRg2OS76OS76OS76OS76OS76OS76OS76OS76MRVnM
RVnMRVnNRg2NRg2OS76OS76OS76MRfjMRfjMRfjMRfjMRfjLRVfLRVfLRVfORfbORfbORfbORfbPS6fP
S6fPS6fPS6fNRV^NRV^NRV^ORfbORfbORfbPS6fPS6fNRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^LR6VL
R6VLR6VLR6VMRFZMRFZMRFZNRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^NRV^MRFZMRFZMRFZMRFZNRV^N
RV^ORfbORfbMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZM
RFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZKQfRKQfRKQfRKQfRKQfRK
QfRKQfRKQfRLR6VLR6VKQfRJQVNJQVNKQfRLR6VLR6VMRVFMRVFMRVFMRVFMRVFMRVFMRVFMRVFLRFBL
RFBLRFBLRFBLRFBLRFBLRFBLRFBJQf:KR6>KR6>KR6>LRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBMRVFM
RVFMRVFNRfJJQf:JQf:JQf:JQf:JQf:JQf:JQf:JQf:HQF2IQV6IQV6JQf:JQf:IQV6IQV6HQF2IQV6I
QV6IQV6IQV6IQV6IQV6IQV6IQV6IQV2IQV2IQV2HQEnHQEnGQ5jGQ5jGQ5jEPUbFPefFPefGQ5jHQEnH
QEnIQV2IQV2GQ5jGQ5jHQ5^HQ5^IPeVIPeVKQ5NKQ5NIQEJIQEJIQEJIQEJIQEJIQEJIQEJIQEJJQUNJ
QUNJQUNIQEJIQEJIQEJIQEJIQEJJPeFIPUBIPUBHPE>IPUBIPUBJPeFKQ5JHQ5FHQ5FHQ5FHQ5FGPeBG
PeBGPeBGPeBGPeBGPeBHQ5FHQ5FHQ5FGPeBFPU>EPE:HQ5FFPU>EPE:EPE:GPeBHQ5FGPeBEPE:HPE>H
PE>HPE>HPE>HPE>HPE>HPE>HPE>FP52FP52FP52FP52FP52FP52FP52FP52IPUBIPUBHPE>GP5:GP5:H
PE>IPUBIPUBGPE6HPU:HPU:HPU:IPe>IPe>IPe>IPe>FP52GPE6GPE6HPU:IPe>IPe>JQ5BJQ5BGPTnG
PTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnG
PTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnG
PTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnGPTnG
PTnGPTnGPTnFOdfFOdfFOdfGP4jGP4jHPDnHPDnHPDnHPdbHPdbHPdbGPT^GPT^FPDZFPDZFPDZGPT^G
PT^GPT^GPT^GPT^GPT^GPT^GPT^FPTVFPTVFPTVFPTVFPTVFPTVFPTVFPTVGP4RHPDVIPTZIPTZGP4RF
OdNHPDVIPTZEPDREPDREPDRFPTVFPTVFPTVGPdZGPdZEPDRFPTVFPTVGPdZGPdZFPTVFPTVEPDRGP4RG
P4RGP4RGP4RGP4RGP4RGP4RGP4RFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNFOdNF
OdNFOdNFOdNCO4BEOTJFOdNEOTJDODFCO4BDODFFOdNEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJE
OTJEOTJEOTJEOTJEOTJEOTJEOTJCOD>COD>COD>COD>COD>COD>COD>COD>COD>COD>COD>COD>COD>C
OD>COD>COD>EOdFEOdFEOdFEOdFEOdFEOdFEOdFEOdFBOCnCOT2COT6COT6DOTBDODFDODFDODFCOD>C
OD>COD>COD>COD>COD>COD>COD>BO4:COD>COD>COD>DOTBDOTBDOTBDOTB@O4:BOTBEPDNFP4JGOdFE
OD>HODBIOTFEP4:EP4:EP4>EP4>EOdFEOTJEOTJEOTJCOD>COD>COD>COD>COD>COD>COD>COD>EOdFE
OdFEOdFEOdFEOdFEOdFEOdFEOdFJOdJJOdJIOTFHODBHODBIOTFJOdJJOdJDOd6DOd6DOd6DOd6EP4:E
P4:EP4:FPD>EOdFEOdFEOdFEOdFEOdFEOdFEOdFEOdFFP4JFP4JFP4JFP4JFP4JEOdFEOdFEOdFJOdJI
OTFHODBHODBHODBHODBIOTFJOdJEOdFEOdFEOdFEOdFEOdFEOdFEOdFEOdFFP4JFP4JFP4JFP4JFP4JF
P4JFP4JFP4JDOTBDOTBDOTBDOTBEOdFEOdFEOdFFP4JGP4RFOdNEOTJEOTJEOTJEOTJFOdNGP4RFOdNF
OdNFOdNFOdNFOdNFOdNFOdNFOdNEOdFFP4JGPDNGPDNHPTRHPTRGPDNGPDNEOdFFP4JGPDNHPTRHPTRH
PTRGPDNGPDNDOd6FPD>HPdJGPTFFP4JFOdNGP4RIPTZFOdNGP4RGP4RGP4RHPDVHPDVHPDVHPDVHPTRH
PTRHPTRHPTRHPTRHPTRHPTRHPTRHPdJIPdVJQ4ZKQ4bLQDfKPdfKPdfJPTjLPDVLPDVLPDVLPDVLPDVL
PDVLPDVLPDVLPDVLPDVLPDVLPDVLPDVLPDT00:B?LjB?Lj>>LZ>>LZ>>LZB?LjF@M:JAMJ>@MJ>@MJ>@
MJ>@MJ>@MJ>@MJ>@MJ>@MJ6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=
LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj2=LZ2=LZ2=
LZ2=LZ2=LZ2=LZ2=LZ2=LYj<Kij<Kij<Kij<Kij<Kij<Kij<Kij<Kij;L9j;L9j;L9j;L9j;L9j;L9j;
L9j;L9n<LIn<LIn<LIn<LIn<LIn<LIn<LIn<LIf:Kif:Kif:Kif:Kij;L9j;L9j;L9n<LIb:KIb:KIb:
KIb:KIf;KYf;KYf;KYf;KYj:Jij:Jin;K9n;K:2<KJ2<KJ6=KZ6=KYf9JYf9JYj:Jij:Jin;K9n;K:2<
KJ2<KIf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JY^7J9^7J9^7J9b8JIf9JYf9JYf9JYj:Jif9JYf9JYf9
JYf9JYf9JYf9JYf9JYf9JYb8JIb8JIf9JYf9JYj:Jij:Jij:Jij:Jib8JIb8JIb8JIb8JIb8JIb8JIb8
JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8
JIb8JIb8JIb8JIb8JIb8JI^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9b8JI^7J9^7J9Z6IiZ6Ii^7J9^7
J9b8JIf:IIf:IIf:IIf:IIf:IIf:IIf:IIf:IIb9I9b9I9b9I9b9I9b9I9b9I9b9I9b9I9Z7HYZ7HYZ7
HY^8Hi^8Hib9I9b9I9b9I9^8Hi^8Hi^8Hib9I9f:IIf:IIf:IIj;IYZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYZ7
HYZ7HYR5H9R5H9V6HIZ7HYZ7HYV6HIR5H9R5H9V6HIV6HIV6HIV6HIV6HIV6HIV6HIV6HIV6H9R5GiR5
GiR5GiN4GYN4GYN4GYN4GYB1FiB1FiF2G9J3GIN4GYR5GiV6H9V6H9J3GIJ3GIR4FiR4FiV3FIV3FIZ3
EYZ3EYR4EIR4EIR4EIR4EIR4EIR4EIR4EIR4EIV5EYV5EYV5EYV5EYV5EYZ6EiZ6EiZ6Ei^4EYZ3EIV2
E9R1DiR1DiR1DiV2E9V2E9J2DiN3E9N3E9N3E9N3E9N3E9R4EIR4EIJ2DiJ2DiN3E9N3E9J2DiF1DYB0
DI=oD9N3E9J2DiB0DIF1DYN3E9R4EIJ2DiF1DYR1DiR1DiR1DiR1DiR1DiR1DiR1DiR1DiJ0D9J0D9J0
D9J0D9J0D9J0D9J0D9J0D9V2E9R1DiR1DiN0DYN0DYR1DiR1DiV2E9N1DIN1DIN1DIR2DYR2DYV3DiV3
DiV3DiEoCiJ0D9N1DIN1DIR2DYV3DiZ4E9Z4E9N2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2
CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2
CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2CiN2
CiN2CiN2CiN2CiN2CiN2CiF0CIF0CIJ1CYJ1CYN2CiR3D9V4DIV4DIIoCIIoCIIoCIN0CYN0CYN0CYR1
CiR1CiR3C9R3C9N2BiN2BiN2BiJ1BYJ1BYJ1BYN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiJ2BIJ2BIJ2
BIJ2BIJ2BIJ2BIJ2BIJ2BIIoAiR1BIZ3BiV2BYIoAiEnAYN0B9Z3BiB0AiB0AiF1B9F1B9J2BIJ2BIN3
BYN3BYF1B9F1B9J2BIN3BYN3BYJ2BIF1B9F1B9IoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiEnAYEnAYEn
AYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAY9k@iEnAYIoAiEnAY=lA99k@iAm
AIIoAiAmAIAmAIAmAIAmAIAmAIAmAIAmAIAmAIAmAIAmAIAmAIAmAIAmAIAmAIAmAIAmAI=m@i=m@i=m
@i=m@i=m@i=m@i=m@i=m@i9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y=m@i=m@i=m@i=m@i=m@i=m@i=m
@i=m@i9m?i9m?i=n@I=n@I=m@iAmAIAmAIAmAI5k@I5k@I5k@I5k@I5k@I5k@I5k@I5k@I9l@Y9l@Y=m
@i=m@i=m@iAnA9AnA9AnA91l@Y9nA9B0AYJ0AYInA9Em@iQmA9UnAIB0?iAo@IAo@IAo@YAnA9AmAIAl
AYAlAY=m@i=m@i=m@i=m@i=m@i=m@i=m@i=m@iAnA9AnA9AnA9AnA9AnA9AnA9AnA9AnA9UnAIQmA9Ml
@iIk@YIk@YMl@iQmA9UnAI=o?Y=o?YB0?iB0?iB0?iF1@9F1@9F1@9AnA9AnA9AnA9AnA9AnA9AnA9An
A9AnA9EoAIEoAIEoAIEoAIEoAIJ0AYJ0AYJ0AYUnAIUnAIQmA9Ml@iMl@iQmA9UnAIUnAIAnA9AnA9An
A9AnA9AnA9AnA9AnA9AnA9EoAIEoAIEoAIEoAIEoAIEoAIEoAIEoAI=m@i=m@iAnA9AnA9AnA9EoAIEo
AIEoAIIoAiIoAiEnAYAmAIAmAIEnAYIoAiIoAiEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYJ0AYJ0AYJ0
AYEoAIJ0AYN1AiR2B9R2B9AnA9EoAIJ0AYN1AiR2B9R2B9N1AiN1AiAo@IJ1@iN2AIN2AIJ0AYEnAYN0
B9V2BYEnAYEnAYEnAYIoAiIoAiN0B9N0B9N0B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9R2B9J1A9N1AiV3
BIZ3Bi^4C9Z2C9V1BiR0C9b1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1BIb1B@00
Y8mcXhibXhibXhibXhibY8mcYI1dYY5eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXi1eXHicXHicXHicXHic
XHicXHicXHicXHicX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8eb
XHicXHicXHicXHicXHicXHicXHicXHicX8ebX8ebX8ebX8ebX8ebX8ebX8ebX8ebWH]^WH]^WH]^WH]^
WH]^WH]^WH]^WH]^WHY_WHY_WHY_WHY_WHY_WHY_WHY_WHY_WhaaWhaaWhaaWhaaWhaaWhaaWhaaWhaa
W8U^WHY_WHY_WHY_WX]`WX]`WX]`WX]`VhU/VhU/VhU/W8Y]WH]^WH]^WXa_WXa_WXY[WXY[Wh]/Wh]/
X8a]X8a]XHe^XHe^WHUZWHUZWHUZWXY[Wh]/Wh]/X8a]X8a]WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZ
VXIWVhMXVhMXW8QYW8QYWHUZWHUZWXY[WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZW8QYW8QYWHUZWHUZ
WHUZWXY[WXY[WXY[W8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QY
W8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYVhMXVhMXVhMXVhMX
VhMXVhMXVhMXVhMXW8QYVhMXVhMXVXIWVXIWVhMXVhMXW8QYWHYUWHYUWHYUWHYUWHYUWHYUWHYUWHYU
W8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UTVHIQVHIQVXMRVXMRVhQSW8UTW8UTW8UTV8EPV8EPVHIQVHIQ
VXMRVXMRVhQSVhQSVXMRVXMRVXMRVXMRVXMRVXMRVXMRVXMRV8EPV8EPVHIQVXMRVXMRVHIQV8EPV8EP
VHIQVHIQVHIQVHIQVHIQVHIQVHIQVHIQV8EOV8EOV8EOV8EOUhANUhANUhANUX=MTh1JU85KUH9LUX=M
UhANV8EOVHIPVHIPUX=MUX=MV8AKUh=JVH=IVH=IVX=FVX=FV8AEV8AEV8AEV8AEV8AEV8AEV8AEV8AE
V8AEV8AEV8AEVHEFVXIGVXIGVhMHVhMHVhAFVhAFVH9DV85CV85CV85CV85CV85CUH5BUX9CUX9CUh=D
Uh=DV8AEV8AEVHEFUH5BUH5BUX9CUX9CUH5BU81ATgm@TWi?Uh=DUH5BU81AUH5BUh=DUh=DUX9CU81A
V85CV85CV85CV85CV85CV85CV85CV85CV89BV89BV89BV89BV89BV89BV89BV89BVH9DV85CUh1BUh1B
Uh1BUh1BV85CVH9DUX1@UX1@Uh5AUh5AV89BVH=CVH=CVH=CUGm?UGm?UX1@Uh5AV89BVH=CVXADVhEE
Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?
Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?
Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Uh9?Tgi;U7m<UH1=UX5>
Uh9?V8=@VHAAVXEBUGi<UWm=UWm=UWm=Uh1>Uh1>Uh1>V85?V8=<Uh9;Uh9;Uh9;UX5:UX5:UX5:UH19
Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;UH58UH58UH58UH58UH58UH58UH58UH58UGi6V859VX=;VH9:
UWm7UGi6Uh18VX=;U817U817U817UH58UX99UX99Uh=:Uh=:U817UH58UX99UX99UX99UX99UH58U817
UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6
UGi6UGi6UGi6UGi6TW]3UGi6Uh18UWm7Tga4TGY2U7e5UWm7U7e5U7e5U7e5U7e5U7e5U7e5U7e5U7e5
U7e5U7e5U7e5U7e5U7e5U7e5U7e5U7e5Tge3Tge3Tge3Tge3Tge3Tge3Tge3Tge3TWa2TWa2TWa2TWa2
TWa2TWa2TWa2TWa2TWa2TWa2TWa2TWa2TWa2TWa2TWa2TWa2TWdoTWdoTWe0Tgi1Tge3Tga4U7e5U7e5
T7Y0T7Y0T7Y0T7Y0T7Y0T7Y0T7Y0T7Y0TWa2TWa2TWa2Tge3Tge3Tge3U7i4U7i4T7a2TWi4U816UX16
UWi4UGe3Uga3V7e4U80oU80oU7m1U7m2U7i4U7e5U7a6U7a8Tge3Tge3Tge3Tge3Tge3Tge3Tge3Tge3
U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4VGi5Uga3UW]2UGY1UGY1UW]2Uga3VGi5TglnTglnTglnU80o
U80oUH50UH50UH50U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4UGm5UGm5UX16Uh57Uh57
VGi5V7e4V7e4Uga3Uga3V7e4V7e4VGi5U7i4U7i4U7i4U7i4U7i4U7i4U7i4U7i4UGm5UGm5UGm5UGm5
UGm5UGm5UGm5UGm5Tge3Tge3Tge3U7i4U7i4UGm5UGm5UGm5UWm7UWm7UGi6U7e5U7e5UGi6UWm7UWm7
UGi6UGi6UGi6UGi6UGi6UGi6UGi6UGi6Uh57UX16UGm5U7i4UGm5UX16V898VH=9U7i4U7i4UX16Uh57
V898V898Uh57Uh57U7m1UX53Uh95Uh95UX16UGi6Uh18VH9:Tga4U7e5U7e5UGi6UGi6UWm7UWm7Uh18
Uh57Uh57Uh57Uh57Uh57Uh57Uh57Uh57UH13UX16V898VH9:VH9:VH5;V81:Ugm;Vh18Vh18Vh18Vh18
Vh18Vh18Vh18Vh18Vh18Vh18Vh18Vh18Vh18Vh18002SSW:SSW:TSg>TSg>TSg>UT7BUT7BUT7BTSgBT
SgBTSgBTSgBTSgBTSgBTSgBTSgBST7FRSgBRSgBQSW>QSW>PSG:PSG:OS76QSW>QSW>QSW>QSW>QSW>Q
SW>QSW>QSW>PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:OSG2OSG2OSG2PSW6PSW6PSW6QSg:QSg:PSW6P
SW6PSW6OSG2NS6nNS6nMRfjMRfjOSG2OSG2OSG2OSG2OSG2OSG2OSG2OSG2MRVnMRVnNRg2OS76OS76N
Rg2MRVnMRVnPRfnPRfnPRfnPRfnPRfnPRfnPRfnPRfnRSG:ORVnMR6fNRFjQS76RSG:PRg2MR6fLRVfL
RVfLRVfLRVfLRVfLRVfLRVfLRVfPRfnPRfnORVjORVjNRFfNRFfMR6bMR6bMRFZMRFZMRFZMRFZMRFZM
RFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VL
R6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VL
R6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VKQfRLR6VMRFZMRFZMRFZMRFZLR6VKQfRMR6VM
R6VMR6VMR6VMR6VMR6VMR6VMR6VLQfRLQfRLQfRLQfRLQfRLQfRLQfRLQfRKQfBKQfBKQfBKQfBKQfBK
QfBKQfBKQfBLRF>LRF>LRF>LRF>LRF>LRF>LRF>LRF>LRFBLRFBLRFBLRFBLRFBLRFBLRFBLRFBQRFFP
R6BPR6BOQf>OQf>NQV:NQV:MQF6NQV:NQV:NQV:NQV:NQV:NQV:NQV:NQV:IQV6IQV6IQV6IQV6IQV6I
QV6IQV6IQV6MQV2MQV2MQV2MQV2MQV2MQV2MQV2MQV2LQUfLQUfLQUfLQUfLQUfLQUfLQUfLQUfLQUfL
QUfKQEbKQEbJQ5^JQ5^IPeZIPeZIPUbIPUbIPUbIPUbIPUbIPUbIPUbIPUbMQ5bLPe^KPeVJPURIPUFI
PUBIPUBJPeFJPeFJPeFJPeFJPeFJPeFJPeFJPeFJPeFIPUBIPUBIPUBIPUBIPUBIPUBIPUBIPUBIPe>I
Pe>IPe>IPe>IPe>IPe>IPe>IPe>GPTjGPTjGPTnHPe2HPU:IPUBIPUBIPUBHPU:HPU:HPU:HPU:HPU:H
PU:HPU:HPU:GPE6GPE6GPE6GPE6GPE6GPE6GPE6GPE6FP52FP52FP52GPE6GPE6GPE6HPU:HPU:FP52F
P52FP52GPE6GPE6GPE6HPU:HPU:FP52FP52FP52GPE6GPE6GPE6HPU:HPU:EOU2EOU2EOU2EOU2FOe6H
PE>IPUBJPeFHPDnHPDnHPDnHPDnHPDnHPDnHPDnHPDnHPDnHPDnHPDnHPDnHPDnHPDnHPDnHPDnGPT^G
PT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^FP52FP52FP52FP52FP52F
P52FP52FP52FPT^FPT^FPDfFPDjFPDjFP52FP52FOe6GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^G
PT^GPT^GPT^GPT^GPT^GPT^GPT^JQDjIQ4fIQ4fHPdbHPdbGPT^GPT^FPDZFPDZFPDZFPDZFPDZFPDZF
PDZFPDZFPDZCP4fEP4fEP4fFOdfFOdfHOdfHOdfJOdfHPDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVHPDVH
PDVHPDVHPDVHPDVHPDVHPDVHPDVEOTJFOdNFOdNFOdNGP4RGP4RGP4RHPDVEOTJFOdNFOdNFOdNGP4RG
P4RGP4RHPDVIPTZHPDVFOdNEOTJDODFEOTJFOdNGP4RGP4RGP4RFOdNFOdNEOTJDODFDODFDODFEODVE
ODVDO4RCNdNCNdNDO4REODVEODVGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RBNd>CO4BCO4BDODFDODFC
O4BCO4BBNd>CO4BCO4BCO4BCO4BCO4BCO4BCO4BCO4BANT:BNd>BNd>CO4BCO4BDODFDODFEOTJFNd:F
Nd:FNd:FNd:FNd:FNd:FNd:FNd:ENT6ENT6ENT6FNd:FNd:GO4>GO4>GO4>COD>COD>COD>COD>COD>C
OD>COD>COD>ENT6ENT6ENT6FNd:FNd:GO4>GO4>GO4>ANd6ANd6ANd6BO4:BO4:COD>COD>COD>FNd:F
Nd:FNd:FNd:FNd:FNd:FNd:FNd:BO4:BO4:COD>COD>COD>DOTBDOTBDOTBCOD>COD>COD>COD>COD>C
OD>COD>COD>DOTBDOTBDOTBCOD>COD>COD>BO4:BO4:BO4:BO4:COD>COD>COD>DOTBDOTBDOTBGOD6G
OD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6HOT:HOT:HOT:IOd>IOd>IOd>HOT:HOT:HOT:HOT:HOT:H
OT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:HOT:FNd:FNd:GO4>GO4>GO4>HODBHODBHODBHOT:H
OT:HOT:HOT:HOT:HOT:HOT:HOT:IP42IP42HOcnGOSjGOSjFOCfFOCfEO3bFO42FO42GOD6GOD6GOD6H
OT:HOT:HOT:FOdNFOdNEOTJDODFDODFEOTJFOdNFOdNFNd:GO4>HODBIOTFIOTFIOTFIOTFHODBCOT2C
OT2COT6DOd:DOTBEOTJEOTJEOTJKP4NJOdJIOTFHODBHODBIOTFJOdJKP4NGO4>GO4>HODBHODBHODBI
OTFIOTFIOTFHODBHODBIOTFIOTFIOTFJOdJJOdJJOdJJOdJJOdJJOdJJOdJJOdJJOdJJOdJJOdJIOTFJ
OdJKP4NKP4NKP4NKP4NJOdJIOTFJOdJJOdJIOTFIOTFJOdJKP4NLPDRLPDRNQDNNQDNNQ4RNQ4RNPdZN
Pd/00:>>LZ>>LZ>>LZB?LjB?LjB?LjF@M:F@M:B?M:B?M:B?M:B?M:B?M:B?M:B?M:B?M::?M::?M::?
M:6>Lj2=LZ2=LZ2=LYn<LJ6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj6>Lj2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=
LZ2=LYn=L9n=L9n=L9n=L:2>LJ2>LJ6?LZ6?LZ2>LJ2>LIn=L9n=L9j<Kij<Kif;KYf;KYn=L9n=L9n=
L9n=L9n=L9n=L9n=L9n=L9b9KYf:Kij;L9j;L9j;L9j;L9f:Kib9KYn:KYn:KYn:KYn:KYn:KYn:KYn:
KYn:KZ6<LIn:Kif8KIj9KZ6<LJ:=LZ2;L9f8KIb:KIb:KIb:KIb:KIb:KIb:KIb:KIb:KJ2;Kin:KYn:
KYn:KYj9KIf8K9f8K9f8K9f9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9
JYf9JYb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8
JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8
JIb8JI^7J9b8JIb8JIf9JYf9JYb8JIb8JI^7J9f8JIf8JIf8JIf8JIf8JIf8JIf8JIf8JIb7J9b7J9b7
J9b7J9b7J9b7J9b7J9b7J9^7I9^7I9^7I9^7I9^7I9^7I9^7I9^7I9b9Hib9Hib9Hib9Hib9Hib9Hib9
Hib9Hib9I9b9I9b9I9b9I9b9I9b9I9b9I9b9I:28I:28I:28I9n7Hij6HYj6HYj6HYf5HIj6HYj6HYj6
HYj6HYj6HYj6HYj6HYj6HYV6HIV6HIV6HIV6HIV6HIV6HIV6HIV6HIf6H9f6H9f6H9f6H9f6H9f6H9f6
H9f6H9^5G9^5G9^5G9^5G9^5G9^5G9^5G9^5G9b6GI^5G9^5G9^5G9Z4FiV3FYV3FYV3FYV2G9V2G9V2
G9V2G9V2G9V2G9V2G9V2G9b3Fib3FiZ2F9V1EiV2EIV2E9V2E9Z3EIZ3EIZ3EIZ3EIZ3EIZ3EIZ3EIZ3
EIZ3EIV2E9V2E9V2E9V2E9V2E9V2E9V2E9V2E9V3DiV3DiV3DiV3DiV3DiV3DiV3DiV3DiN2CYN2CYN2
CiR3D9R2DYR1DiV2E9V2E9R2DYR2DYR2DYR2DYR2DYR2DYR2DYR2DYJ0D9J0D9J0D9J0D9J0D9J0D9J0
D9J0D9J0D9J0D9J0D9J0D9N1DIN1DIR2DYR2DYJ0D9J0D9J0D9J0D9N1DIN1DIR2DYR2DYAnCYAnCYEo
CiEoCiEoCiJ0D9J0D9J0D9IoDIIoDIEnD9EnD9IoDIN0DYR1DiV2E9R1CiR1CiR1CiR1CiR1CiR1CiR1
CiR1CiR1CiR1CiR1CiR1CiR1CiR1CiR1CiR1CiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2
BiN2BiN2BiN2BiN2BiN2BiJ0D9J0D9J0D9J0D9J0D9J0D9J0D9J0D9J2BiJ2BiJ1CIJ1CIJ1CYJ0D9J0
D9J0D9N2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiR3C9R3C9R3
C9R3C9N2BiN2BiN2BiN2BiF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BI9oC9AoC9AoC9EnC9EnC9MnC9Mn
C9UnC9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9N0B9EnAYEnAYIo
AiIoAiIoAiN0B9N0B9N0B9EnAYEnAYIoAiIoAiIoAiN0B9N0B9N0B9V2BYR1BIIoAiEnAYEnAYEnAYIo
AiN0B9N0B9IoAiIoAiEnAYEnAYAmAIAmAIAmAIEmAiAlAYAlAY=kAI=kAIAlAYAlAYEmAiEnAYEnAYEn
AYEnAYEnAYEnAYEnAYEnAY9k@i=lA9=lA9AmAIAmAI=lA9=lA99k@i=lA9=lA9=lA9=lA9=lA9=lA9=l
A9=lA99k@i9k@i=lA9=lA9=lA9=lA9=lA9AmAIIk@YIk@YIk@YIk@YIk@YIk@YIk@YIk@YEj@IEj@IEj
@IIk@YIk@YIk@YMl@iMl@i9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@Y9l@YEj@IEj@IEj@IIk@YIk@YIk@YMl
@iMl@i5k@I5k@I5k@I9l@Y9l@Y9l@Y=m@i=m@iIk@YIk@YIk@YIk@YIk@YIk@YIk@YIk@Y9l@Y9l@Y9l
@Y=m@i=m@i=m@iAnA9AnA9=m@i=m@i=m@i=m@i=m@i=m@i=m@i=m@iAnA9AnA9=m@i=m@i=m@i9l@Y9l
@Y9l@Y9l@Y9l@Y9l@Y=m@i=m@i=m@iAnA9AnA9Mm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm
@IQn@YQn@YUo@iUo@iUo@iQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn@YQn
@YQn@YIk@YIk@YIk@YMl@iMl@iMl@iQmA9QmA9Mm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IQo?iQo?iQo
?iMn?YMn?YIm?IIm?IEl?9Il@9Il@9Il@9Mm@IMm@IMm@IQn@YQn@YIoAiEnAYEnAYAmAIAmAIEnAYEn
AYIoAiIk@YMl@iQmA9UnAIUnAIUnAIUnAIQmA9Ao@IAo@IAo@YAo@YEoAIEnAYIoAiIoAi^0AiYoAYUn
AIQmA9QmA9UnAIYoAY^0AiMl@iMl@iQmA9QmA9QmA9UnAIUnAIUnAIUnAIUnAIUnAIYoAYYoAYYoAY^0
Ai^0Ai^0Ai^0Ai^0Ai^0Ai^0Ai^0Ai^0Ai^0AiUnAIYoAY^0Ai^0Ai^0Ai^0AiYoAYUnAIYoAYYoAYUn
AIUnAIYoAYYoAYb1B9b1B9b3AIb3AIb2AYb2AYb1B9b1B@00XhibXhibXhibXhibY8mcY8mcY8mcYI1d
Y8mdY8mdY8mdY8mdY8mdY8mdY8mdY8mdXHicXHicXHicXHicX8ebX8ebX8ebWhaaX8ebX8ebX8ebX8eb
X8ebX8ebX8ebX8ebWhaaWhaaWhaaWhaaWhaaWhaaWhaaWhaaWXa_WXa_Whe`Whe`X8iaX8iaX8iaX8ia
Whe`Whe`Whe`WXa_WXa_WXa_WH]^WH]^WXa_WXa_WXa_WXa_WXa_WXa_WXa_WXa_W8U^WHY_WHY_WX]`
WX]`WHY_WHY_W8U^WhY^WhY^WhY^WhY^WhY^WhY^WhY^WhY^X8]`WhY_WXU^WXU^X8]`XHaaWhY_WXU^
W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]WhY^WhY^WXU]WXU]WXU]WHQ/WHQ/WHQ/WHUZWHUZWHUZWHUZ
WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QY
W8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QY
W8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYVhMXVhMXW8QYWHUZWHUZW8QYVhMXVhMX
WHQYWHQYWHQYWHQYWHQYWHQYWHQYWHQYW8MXW8MXW8MXW8MXW8MXW8MXW8MXW8MXVhMTVhMTVhMTVhMT
VhMTVhMTVhMTVhMTW8USW8USW8USW8USW8USW8USW8USW8USW8UTW8UTW8UTW8UTW8UTW8UTW8UTW8UT
WhMSWhMSWhMSWhMSWXIRWXIRWXIRWHEQWHEQWHEQWHEQWHEQWHEQWHEQWHEQWHEQV8EPV8EPV8EPV8EP
V8EPV8EPV8EPV8EPW8EOW8EOW8EOW8EOW8EOW8EOW8EOW8EOVhELVhELVhELVhELVhELVhELVhELVhEL
VhELVhELVXAKVXAKVXAKVH=JVH=JVH=JVH=JVH=JVH=JVH=JVH=JVH=JVH=JVH=JW8=KVh9JVX9HVH5G
VH9EVH9DVH9DVX=EVX=EVX=EVX=EVX=EVX=EVX=EVX=EVX=EVH9DVH9DVH9DVH9DVH9DVH9DVH9DVH9D
VH=CVH=CVH=CVH=CVH=CVH=CVH=CVH=CUX5=Uh9>Uh9?Uh9?V89BV85CV85CV85CUh5AUh5AUh5AUh5A
Uh5AUh5AUh5AUh5AUGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?UX1@UX1@Uh5AUh5AUh5AUh5A
UGm?UGm?UX1@UX1@Uh5AUh5AUh5AUh5ATge=Tge=Tge=U7i>U7i>U7i>UGm?UGm?Uh1BUWmAUWmAUGi@
UGi@UWmAUh1BV85CUh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>Uh1>
Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;UH1=UH1=UH1=UH1=
UH1=UH1=UH1=UH1=UH99UH5:UH5:UH1<UH1=UH1=UGm?UGm?UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:
UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:Uh9;Uh9;Uh9;Uh9;Uh9;V8=<UH19UH19UH19UH19
UH19UH19UH19UH19TX1;U7m;U7m;UGm;UGm;Ugm;Ugm;VGi;Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18
Uh18Uh18Uh18Uh18Uh18Uh18Uh18Uh18UGi6UGi6UGi6UWm7UWm7Uh18Uh18Uh18UGi6UGi6UGi6UWm7
UWm7Uh18Uh18Uh18V859Uh18UWm7UGi6UGi6UGi6UGi6UWm7UWm7UWm7UGi6UGi6UGi6U7e5U7e5U7e5
UGe7U7a6Tg]5Tg]5Tg]5Tg]5U7a6UGe7Tga4Tga4Tga4Tga4Tga4Tga4Tga4Tga4TW]3TW]3Tga4U7e5
U7e5Tga4TW]3TW]3Tga4Tga4Tga4Tga4Tga4Tga4Tga4Tga4Tga4Tga4Tga4Tga4TW]3TW]3TW]3TW]3
UGY1UGY1UGY1UGY1UGY1UGY1UGY1UGY1U7U0UGY1UGY1UGY1UW]2UW]2UW]2UW]2T7Y0T7Y0T7Y0T7Y0
T7Y0T7Y0T7Y0T7Y0U7U0UGY1UGY1UGY1UW]2UW]2UW]2UW]2T7Y0TG]1TG]1TG]1TWa2TWa2TWa2TWa2
UGY1UGY1UGY1UGY1UGY1UGY1UGY1UGY1TWa2TWa2TWa2TWa2Tge3Tge3Tge3U7i4Tge3Tge3Tge3Tge3
Tge3Tge3Tge3Tge3U7i4Tge3Tge3Tge3TWa2TWa2TWa2TWa2TWa2TWa2TWa2TWa2Tge3Tge3Tge3U7i4
Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1V7i2V7i2VGm3VGm3V7i2V7i2V7i2V7i2
V7i2V7i2V7i2V7i2V7i2V7i2V7i2V7i2V7i2V7i2V7i2V7i2UW]2UW]2UW]2UW]2Uga3Uga3Uga3V7e4
UG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oV7m1Ugi0Ugi0Ugi0UWdoUWdoUWdoUWdoUWa0UWa0UWa0UWa0
Uge1Uge1Uge1V7i2UGi6UGi6U7e5Tga4Tga4U7e5UGi6UGi6UW]2UW]2V7e4V7e4VGi5VGi5V7e4V7e4
U7m1U7m1UH13UH13UX16UWm7UWm7UWm7VWm6VGi5V7e4V7e4V7e4V7e4VGi5VWm6Uga3Uga3V7e4V7e4
V7e4VGi5VGi5VGi5VGi5VWm6VWm6VWm6Vh17Vh17Vh17W858Vh17Vh17Vh17Vh17Vh17Vh17Vh17Vh17
VGi5VWm6VWm6Vh17Vh17VWm6VWm6VGi5VWm6VGi5VGi5VGi5VGi5VWm6Vh17W858VX53VX53VX14VX14
VWm6VWm7002RSG6RSG6SSW:SSW:SSW:TSg>TSg>TSg>SSW>SSW>SSW>SSW>SSW>SSW>SSW>SSW>PSG:P
SG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:PSG:OS76OS76OS76OS76OS76O
S76OS76OS76NS6nNS6nNS6nOSG2OSG2OSG2PSW6PSW6NS6nNS6nNS6nNS6nNS6nNS6nMRfjMRfjNS6nN
S6nNS6nNS6nNS6nNS6nNS6nNS6nLRFjLRFjMRVnNRg2NRg2MRVnLRFjLRFjORVjORVjORVjORVjORVjO
RVjORVjORVjORVnORVnNRFjNRFjORVnORVnORVnNRFjLRVfLRVfLRVfLRVfLRVfLRVfLRVfLRVfNRFfN
RFfNRFfNRFfMR6bMR6bMR6bMR6bMRFZMRFZMRFZMRFZMRFZMRFZMRFZMRFZLR6VLR6VLR6VLR6VLR6VL
R6VLR6VLR6VKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRK
QfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRK
QfRKQfRKQfRJQVNKQfRLR6VLR6VLR6VLR6VKQfRJQVNLQfRLQfRLQfRLQfRLQfRLQfRLQfRLQfRKQVNK
QVNKQVNKQVNKQVNKQVNKQVNKQVNKQfBKQfBKQfBKQfBKQfBKQfBKQfBKQfBKR6:KR6:KR6:KR6:KR6:K
R6:KR6:KR6:KR6>KR6>KR6>KR6>KR6>KR6>KR6>KR6>NQV:NQV:NQV:NQV:NQV:NQV:NQV:NQV:MQV2M
QV2MQV2MQV2MQV2MQV2MQV2MQV2HQEnHQEnHQEnHQEnHQEnHQEnHQEnHQEnLQEnLQEnLQEnLQEnLQEnL
QEnLQEnLQEnKQEbKQEbKQEbKQEbKQEbKQEbKQEbKQEbJQ5^JQ5^JQ5^JQ5^IPeZIPeZIPeZIPeZHPUVH
PUVHPUVHPUVHPUVHPUVHPUVHPUVKPUZJPEVIPENHP5JHPEBIPUBIPUBJPeFIPUBIPUBIPUBIPUBIPUBI
PUBIPUBIPUBHPE>HPE>HPE>HPE>HPE>HPE>HPE>HPE>HPU:HPU:HPU:HPU:HPU:HPU:HPU:HPU:FPDfF
PDfFPDjGPTnGPE6HPE>HPE>HPE>GPE6GPE6GPE6GPE6GPE6GPE6GPE6GPE6CODfCODfCODfCODfCODfC
ODfCODfCODfEOdnEOdnEOdnFP52FP52FP52GPE6GPE6EOdnEOdnEOdnFP52FP52FP52GPE6GPE6CODfC
ODfCODfDOTjDOTjEOdnEOdnEOdnGPE6GPE6FP52EOdnEOdnEOdnFP52FP52GP4jGP4jGP4jGP4jGP4jG
P4jGP4jGP4jGP4jGP4jGP4jGP4jGP4jGP4jGP4jGP4jGPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^G
PT^GPT^GPT^GPT^GPT^GPT^GPT^EP4fEP4fEP4fEP4fEP4fEP4fEP4fEP4fEPTVEPTVEPDZEPDZEP4bE
P4fEP4fEP4fFPDZFPDZFPDZFPDZFPDZFPDZFPDZFPDZFPDZFPDZFPDZFPDZFPDZFPDZFPDZFPDZDOdRE
P4VEP4VFPDZFPDZGPT^GPT^HPdbEP4VEP4VEP4VEP4VEP4VEP4VEP4VEP4VBP4^DOd^DOd^EOd^EOd^G
Od^GOd^IOT^GP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RGP4RDODFE
OTJEOTJEOTJFOdNFOdNFOdNGP4RDODFEOTJEOTJEOTJFOdNFOdNFOdNGP4RGP4RGP4RFOdNEOTJEOTJE
OTJEOTJEOTJEOTJEOTJEOTJDODFDODFDODFDODFDODFDODFDODFCO4BBNd>BNd>CO4BDODFDODFCO4BC
O4BCO4BCO4BCO4BCO4BCO4BCO4BANT:BNd>CO4BCO4BCO4BCO4BBNd>ANT:BNd>BNd>BNd>BNd>BNd>B
Nd>BNd>BNd>DODFCO4BCO4BBNd>BNd>ANT:ANT:ANT:ENT6ENT6ENT6ENT6ENT6ENT6ENT6ENT6DND2D
ND2DND2ENT6ENT6FNd:FNd:FNd:@NT2@NT2@NT2@NT2@NT2@NT2@NT2@NT2DND2DND2DND2ENT6ENT6F
Nd:FNd:FNd:@NT2@NT2@NT2ANd6ANd6BO4:BO4:BO4:ENT6ENT6ENT6ENT6ENT6ENT6ENT6ENT6ANd6A
Nd6BO4:BO4:BO4:COD>COD>COD>BO4:BO4:BO4:BO4:BO4:BO4:BO4:BO4:COD>COD>COD>BO4:BO4:B
O4:ANd6ANd6ANd6ANd6BO4:BO4:BO4:COD>COD>COD>FO42FO42FO42FO42FO42FO42FO42FO42FO42F
O42GOD6GOD6GOD6HOT:HOT:HOT:GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6GOD6G
OD6GOD6GOD6ENT6ENT6FNd:FNd:FNd:GO4>GO4>GO4>ENcnENcnENcnENcnENcnENcnENcnENcnFOCnF
OCnFOCnFOCnFOCnFOCnFOCnFOCnENcnENcnFO42FO42FO42GOD6GOD6GOD6DOTBDOTBCOD>BO4:BO4:C
OD>DOTBDOTBENT6FNd:GO4>HODBHODBHODBHODBGO4>EP4:EP4:EP4>EP4>FP4JFOdNGP4RGP4RIOTFI
OTFHODBHODBHODBHODBIOTFIOTFGO4>GO4>HODBHODBHODBIOTFIOTFIOTFJOdJJOdJJOdJKP4NKP4NK
P4NLPDRLPDRKP4NKP4NKP4NKP4NKP4NKP4NKP4NKP4NIOTFIOTFJOdJJOdJJOdJJOdJIOTFIOTFIOTFI
OTFIOTFHODBIOTFJOdJKP4NLPDRJPD>JPD>JP4BJP4BJOdJJOdL00::=LJ:=LJ:=LJ:=LJ>>LZ>>LZB?
LjB?Lj>>Lj>>Lj>>Lj>>Lj>>Lj>>Lj>>Lj>>Lin<LIn<LIn<LIn<LJ2=LZ2=LZ2=LZ2=LZ2=LZ2=LZ2=
LZ2=LZ2=LZ2=LZ2=LZ2=LYj;L9j;L9j;L9j;L9j;L9j;L9j;L9j;L9f;KYf;KYj<Kij<Kin=L9n=L9n=
L9n=L9f;KYf;KYf;KYf;KYf;KYf;KYj<Kij<Kif;KYf;KYf;KYf;KYf;KYf;KYf;KYf;KY^8KIb9KYf:
Kif:Kif:Kif:Kib9KY^8KIj9KIj9KIj9KIj9KIj9KIj9KIj9KIj9KIj9KYj9KYn:Kij9KYj9KYj9KYj9
KYn:Ki^9K9^9K9^9K9^9K9^9K9^9K9^9K9^9K9f8K9f8K9f8K9f8K9f8K9f8K9f8K9f8K9f9JYf9JYf9
JYf9JYf9JYf9JYf9JYf9JYb8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JI^7J9^7J9^7J9^7J9^7J9^7J9^7
J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7
J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9^7J9Z6IiZ6Ii^7J9b8JIb8JI^7J9Z6
IiZ6Iib7J9b7J9b7J9b7J9b7J9b7J9b7J9b7J9^6Ii^6Ii^6Ii^6Ii^6Ii^6Ii^6Ii^6Ii^7I9^7I9^7
I9^7I9^7I9^7I9^7I9^7I9^8HY^8HY^8HY^8HY^8HY^8HY^8HY^8HY^8Hi^8Hi^8Hi^8Hi^8Hi^8Hi^8
Hi^8Hif5HIf5HIf5HIf5HIj6HYj6HYj6HYj6HYb6GIb6GIb6GIb6GIb6GIb6GIb6GIb6GIN5G9N5G9N5
G9N5G9N5G9N5G9N5G9N5G9^4GY^4GY^4GY^4GY^4GY^4GY^4GY^4GYZ4FiZ4FiZ4FiZ4FiZ4FiZ4FiZ4
FiZ4FiV3FYV3FYV3FYV3FYV3FYV3FYV3FYV3FYR2F9R2F9R2F9R2F9R2F9R2F9R2F9R2F9V0F9V0F9R0
EYR0EYR1E9V2E9V2E9Z3EIV2E9V2E9V2E9V2E9V2E9V2E9V2E9V2E9R1DiR1DiR1DiR1DiR1DiR1DiR1
DiR1DiR2DYR2DYR2DYR2DYR2DYR2DYR2DYR2DYF0C9J1CIJ1CYJ1CYN1DIN0DYN0DYR1DiN1DIN1DIN1
DIN1DIN1DIN1DIN1DIN1DI=mCI=mCI=mCI=mCI=mCI=mCI=mCI=mCIAnCYAnCYEoCiEoCiJ0D9J0D9J0
D9J0D9AnCYAnCYEoCiEoCiJ0D9J0D9J0D9J0D9AnCYAnCYAnCYEoCiEoCiJ0D9J0D9J0D9N2CiJ1CYF0
CIF0CIAoC9F0CIF0CIJ1CYIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIo
CIIoCIN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiAoBiAoBiAo
BiAoBiAoBiAoBiAoBiAoBiB2AiB2AiB1B9B0BIB0BIAoBiAoBiAoC9F0BIF0BIF0BIF0BIF0BIF0BIF0
BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BIF0BI=nAiAoB9AoB9F0BIF0BIJ1BYJ1BYN2BiAoB9AoB9Ao
B9AoB9AoB9AoB9AoB9AoB960B9=oB9=oB9AoB9AoB9InB9InB9QnB9IoAiIoAiIoAiIoAiIoAiIoAiIo
AiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiIoAiAmAIAmAIAmAIEnAYEnAYIoAiIoAiIoAiAmAIAmAIAm
AIEnAYEnAYIoAiIoAiIoAiIoAiIoAiIoAiIoAiEnAYEnAYAmAIAmAIAmAIAmAIAmAIAmAIAmAIAmAIAm
AIAmAIAmAI=lA99k@i9k@i9k@i9k@i=lA9AmAI=lA9=lA9=lA9=lA9=lA9=lA9=lA9=lA95j@Y5j@Y9k
@i=lA9=lA99k@i5j@Y5j@Y9k@i9k@i9k@i9k@i9k@i9k@i9k@i9k@i=lA9=lA9=lA99k@i5j@Y5j@Y1i
@I1i@IEj@IEj@IEj@IEj@IEj@IEj@IEj@IEj@I=h?iAi@9Ai@9Ai@9Ej@IEj@IEj@IIk@Y5k@I5k@I5k
@I5k@I5k@I5k@I5k@I5k@I=h?iAi@9Ai@9Ai@9Ej@IEj@IEj@IIk@Xmi?i1j@91j@91j@95k@I5k@I5k
@I9l@YEj@IEj@IEj@IEj@IEj@IEj@IEj@IEj@I5k@I5k@I5k@I5k@I9l@Y9l@Y=m@i=m@i9l@Y9l@Y9l
@Y9l@Y9l@Y9l@Y9l@Y9l@Y=m@i=m@i9l@Y9l@Y5k@I5k@I5k@I5k@I5k@I5k@I5k@I5k@I9l@Y9l@Y=m
@i=m@iIl@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Mm@IMm@IMm@IQn@YQn@YMm@IMm@IMm
@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IMm@IEj@IEj@IEj@IEj@IIk@YIk@YMl
@iMl@iIl@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Ek?iEk?iEk?iIl@9Il@9Il@9Il@9Il@9Ek?iEk?iEk
?iEk?iIl@9Il@9Mm@IMm@IAo@Y=n@I9m@99m@99m@99m@9=n@IAo@YEj@IEj@IMl@iQmA9QmA9QmA9Ml
@iMl@iAo@IAo@IF0@iF0@iEoAIIoAiIoAiIoAiQmA9QmA9QmA9QmA9QmA9QmA9QmA9QmA9Ml@iMl@iQm
A9QmA9QmA9UnAIUnAIUnAIUnAIUnAIYoAYYoAY^0Ai^0Ai^0Ai^0AiYoAYYoAYYoAYYoAYYoAYYoAYYo
AYYoAYQmA9UnAIUnAIYoAYYoAYUnAIUnAIQmA9UnAIUnAIQmA9QmA9QmA9UnAIYoAY^0Ai^2A9^2A9^1
AI^1AI^0Ai^0B000XHa`XHa`XXeaXXeaXXeaXhibXhibXhibXXebXXebXXebXXebXXebXXebXXebXXeb
WX]`WX]`WhaaWhaaWhaaX8ebX8ebX8ebWhaaWhaaWhaaWhaaWhaaWhaaWhaaWhaaWX]`WX]`WX]`WX]`
WX]`WX]`WX]`WX]`WH]^WH]^WH]^WXa_WXa_Whe`Whe`Whe`W8Y]W8Y]W8Y]WH]^WH]^WH]^WXa_WXa_
WH]^WH]^WH]^WH]^WH]^WH]^WH]^WH]^VhQ]VhQ]W8U^WHY_WHY_W8U^VhQ]VhQ]WXU]WXU]WXU]WXU]
WXU]WXU]WXU]WXU]W8M/WXU^WhY_WhY_WHQ]W8M/WHQ]WhY_VhU/VhU/VhU/VhU/VhU/VhU/VhU/VhU/
W8M[W8M[W8M[W8M[WHQ/WHQ/WHQ/WXU]WHUZWHUZWHUZWHUZWHUZWHUZWHUZWHUZVhMXVhMXVhMXVhMX
VhMXVhMXVhMXVhMXVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIW
VXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIW
VXIWVXIWVXIWVXIWVHEVVXIWVhMXVhMXVhMXVhMXVXIWVHEVVhIWVhIWVhIWVhIWVhIWVhIWVhIWVhIW
VXEVVXEVVXEVVXEVVXEVVXEVVXEVVXEVVhMTVhMTVhMTVhMTVhMTVhMTVhMTVhMTVXMQVXMQVXMQVXMQ
VXMQVXMQVXMQVXMQVXMRVXMRVXMRVXMRVXMRVXMRVXMRVXMRW8APW8APWHEQWHEQWHEQWXIRWXIRWXIR
W8IMW8IMW8IMW8IMW8IMW8IMW8IMW8IMUhELUhELUhELUhELUhELUhELUhELUhELVhANVhANVhANVhAN
VhANVhANVhANVhANVXAKVXAKVXAKVXAKVXAKVXAKVXAKVXAKV89IV89IV89IV89IVH=JVH=JVH=JVXAK
Uh5GUh5GUh5GUh5GUh5GUh5GUh5GUh5GV7mGV7mGUgmEUgmEV85DV85CVX=EVX=EV85CV85CV85CV85C
V85CV85CV85CV85CUh1BUh1BUh1BUh1BUh1BUh1BUh1BUh1BUh5AUh5AUh5AUh5AUh5AUh5AUh5AUh5A
UH1<UH1<UH1=UX5>UX1@Uh1BUh1BUh1BUX1@UX1@UX1@UX1@UX1@UX1@UX1@UX1@Tge=Tge=Tge=Tge=
Tge=Tge=Tge=Tge=U7i>U7i>U7i>UGm?UGm?UX1@UX1@UX1@U7i>U7i>U7i>UGm?UGm?UX1@UX1@UX1@
U7i>U7i>UGm?UGm?UGm?UX1@UX1@UX1@UX5>UH1=U7m<U7m<U7m<UH1=UX5>UX5>UWm=UWm=UWm=UWm=
UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=UWm=Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;
Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;Uh9;U7m;U7m;U7m;U7m;U7m;U7m;U7m;U7m;U897U897U897U858
U819U819U7m;U7m;UH19UH19UH19UH19UH19UH19UH19UH19UH19UH19UH19UH19UH19UH19UH19UH19
Tgi7U7m8U7m8U7m8U7m8U7m8UH19UH19U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8TH17Th17Th17U817
U817UWm7UWm7V7m7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7UWm7
U7e5U7e5U7e5U7e5UGi6UGi6UGi6UWm7U7e5U7e5U7e5U7e5UGi6UGi6UGi6UWm7UGi6UGi6UWm7UWm7
UGi6U7e5Tga4Tga4TW]3Tga4Tga4Tga4U7e5U7e5U7e5U7e5Tge3Tge3TWa2TG]1TG]1TWa2Tge3Tge3
Tga4Tga4Tga4Tga4Tga4Tga4Tga4Tga4T7U1TGY2TW]3TW]3TW]3TW]3TGY2T7U1TGY2TGY2TGY2TGY2
TGY2TGY2TGY2TGY2TW]3TW]3TW]3TGY2TGY2TGY2TGY2TGY2U7U0U7U0U7U0U7U0U7U0U7U0U7U0U7U0
TgPoTgPoTgPoU7U0U7U0UGY1UGY1UGY1TG]1TG]1TG]1TG]1TG]1TG]1TG]1TG]1TgPoTgPoTgPoU7U0
U7U0UGY1UGY1UGY1SgToSgToSgToT7Y0T7Y0TG]1TG]1TG]1U7U0U7U0U7U0U7U0U7U0U7U0U7U0U7U0
T7Y0T7Y0TG]1TG]1TG]1TWa2TWa2TWa2TG]1TG]1TG]1TG]1TG]1TG]1TG]1TG]1TWa2TWa2TWa2TG]1
TG]1TG]1T7Y0T7Y0T7Y0T7Y0TG]1TG]1TG]1TWa2TWa2TWa2UG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/o
UG/oUG/oUWa0UWa0Uge1Uge1Uge1Uge1UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0
UWa0UWa0UWa0UWa0U7U0U7U0UGY1UGY1UGY1UW]2UW]2UW]2Uge1Uge1Uge1Uge1Uge1Uge1Uge1Uge1
U7XnU7XnUG/oUG/oUG/oUWa0UWa0UWa0U7XnU7XnUG/oUG/oUG/oUWa0UWa0UWa0Tgi1TWe0TG`oTG`o
TG`oTG`oTWe0Tgi1U7U0UGY1UW]2Uga3Uga3Uga3Uga3UW]2Tgi0Tgi0Tgi1U7m2U7i4UGi6UGi6UGi6
UW]2Uga3V7e4V7e4V7e4V7e4Uga3UW]2Uga3Uga3V7e4V7e4V7e4VGi5VGi5VGi5V7e4V7e4VGi5VGi5
VGi5VWm6VWm6VWm6V7e4V7e4V7e4V7e4V7e4V7e4V7e4V7e4V7e4V7e4VGi5VWm6VWm6VGi5V7e4V7e4
VGi5V7e4V7e4Uga3V7e4VGi5VWm6Vh17VX53VX53VX14VX14VWm6VWm7002QS72QS72QS72RSG6RSG6R
SG6SSW:SSW:RSG:RSG:RSG:RSG:RSG:RSG:RSG:RSG:MRVnNRg2NRg2NRg2OS76PSG:PSG:PSG:OS76O
S76OS76OS76OS76OS76OS76OS76NRg2NRg2NRg2NRg2NRg2NRg2NRg2NRg2MRfjMRfjMRfjMRfjNS6nN
S6nNS6nOSG2KRFbKRFbLRVfLRVfMRfjMRfjNS6nNS6nLRVfLRVfLRVfLRVfLRVfLRVfLRVfLRVfJQfbK
R6fLRFjLRFjLRFjLRFjKR6fJQfbMR6bMR6bMR6bMR6bMR6bMR6bMR6bMR6bKQV^NRFjPRg2ORVnLQfbK
QV^MR6fORVnJR6^JR6^JR6^JR6^JR6^JR6^JR6^JR6^KQVZKQVZKQVZLQf^MR6bMR6bMR6bNRFfMRFZM
RFZMRFZMRFZMRFZMRFZMRFZMRFZKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRJQVNJQVNJQVNJQVNJQVNJ
QVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJ
QVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNJQVNIQFJJQVNJQVNKQfRKQfRJ
QVNJQVNIQFJKQVNKQVNKQVNKQVNKQVNKQVNKQVNKQVNJQFJJQFJJQFJJQFJJQFJJQFJJQFJJQFJKQfBK
QfBKQfBKQfBKQfBKQfBKQfBKQfBJQf6JQf6JQf6JQf6JQf6JQf6JQf6JQf6JQf:JQf:JQf:JQf:JQf:J
Qf:JQf:JQf:KPenLQ62LQ62LQ62MQF6NQV:NQV:NQV:LQUbLQUbLQUbLQUbLQUbLQUbLQUbLQUbFQEZF
QEZFQEZFQEZFQEZFQEZFQEZFQEZJPefJPefJPefJPefJPefJPefJPefJPefIPeZIPeZIPeZIPeZIPeZI
PeZIPeZIPeZGPERGPERGPERHPUVIPeZIPeZIPeZJQ5^GPUFGPUFGPUFGPUFGPUFGPUFGPUFGPUFHOeNG
OUJGOeFGOeFGP5>HPE>JPeFJPeFHPE>HPE>HPE>HPE>HPE>HPE>HPE>HPE>GP5:GP5:GP5:GP5:GP5:G
P5:GP5:GP5:GPE6GPE6GPE6GPE6GPE6GPE6GPE6GPE6EP4bEP4bEP4fFPDjFP52FOe6GP5:GP5:FP52F
P52FP52FP52FP52FP52FP52FP52DOTjDOTjDOTjDOTjDOTjDOTjDOTjDOTjDOTjDOTjDOTjDOTjEOdnE
OdnEOdnFP52DOTjDOTjDOTjDOTjEOdnEOdnEOdnFP52CODfCODfCODfDOTjDOTjDOTjEOdnEOdnDOd^D
Od^COTZCOTZDOd^EP4bFPDfGPTjFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfFOdfF
OdfFOdfFOdfGPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^GPT^COdRC
OdRCOdRCOdRCOdRCOdRCOdRCOdRCPDBCPDBCPDJCPDJCP4NCOdRCOdRCOTZDOdRDOdRDOdRDOdRDOdRD
OdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRCOTNCOTNCOTNCOTNCOTNC
OTNCOTNCOTNCOTNCOTNCOTNCOTN@OdJBOdJBOdJCOdJCOdJEOTJEOTJGOTJEOTJEOTJEOTJEOTJEOTJE
OTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJEOTJCO4BCO4BDODFDODFDODFEOTJEOTJEOTJCO4BC
O4BDODFDODFDODFEOTJEOTJEOTJDODFDODFEOTJFOdNFOdNDODFCO4BBNd>BNd>BNd>BNd>CO4BCO4BD
ODFDODFEOTJCOD>BO4:BO4:ANd6ANd6BO4:BO4:COD>ANT:ANT:ANT:ANT:ANT:ANT:ANT:ANT:@ND6@
ND6ANT:BNd>BNd>ANT:@ND6@ND6ANT:ANT:ANT:ANT:ANT:ANT:ANT:ANT:@ND6@ND6@ND6ANT:ANT:A
NT:ANT:ANT:DND2DND2DND2DND2DND2DND2DND2DND2CN3nCN3nCN3nDND2DND2DND2ENT6ENT6@NT2@
NT2@NT2@NT2@NT2@NT2@NT2@NT2CN3nCN3nCN3nDND2DND2DND2ENT6ENT6?NCn?NCn?NCn@NT2@NT2@
NT2ANd6ANd6DND2DND2DND2DND2DND2DND2DND2DND2@NT2@NT2@NT2ANd6ANd6ANd6BO4:BO4:ANd6A
Nd6ANd6ANd6ANd6ANd6ANd6ANd6BO4:BO4:ANd6ANd6ANd6@NT2@NT2@NT2@NT2@NT2@NT2ANd6ANd6A
Nd6BO4:BO4:ENcnENcnENcnENcnENcnENcnENcnENcnENcnENcnENcnFO42FO42GOD6GOD6GOD6FO42F
O42FO42FO42FO42FO42FO42FO42FO42FO42FO42FO42FO42FO42FO42FO42DND2DND2DND2ENT6ENT6E
NT6FNd:FNd:ENcnENcnENcnENcnENcnENcnENcnENcnCN3nDND2DND2ENT6ENT6FNd:FNd:FNd:DNSjD
NSjDNSjENcnENcnENcnFO42FO42BOCnAO3jAO3j@Ncf@NcfAO3jAO3jBOCnDND2ENT6FNd:GO4>GO4>G
O4>FNd:FNd:BOCnBOCnBOD2BOD2COD>CO4BCO4BDODFFNd:FNd:HODBIOTFIOTFHODBFNd:FNd:GO4>G
O4>HODBHODBHODBIOTFIOTFIOTFGO4>GO4>GO4>GO4>HODBHODBIOTFIOTFGO4>GO4>GO4>GO4>GO4>G
O4>GO4>GO4>GO4>HODBIOTFIOTFIOTFIOTFHODBGO4>HODBHODBGO4>GO4>GO4>HODBJOdJJOdJIP4:I
P4:IOd>IOd>IOTFIOTH00:6<L:6<L:6<L:6<L::=LJ:=LJ>>LZ>>LZ:=LZ:=LZ:=LZ:=LZ:=LZ:=LZ:=
LZ:=LYf:Kif:Kij;L9j;L9n<LIn<LJ2=LZ2=LYn<LIn<LIn<LIn<LIn<LIn<LIn<LIn<LIf:Kif:Kif:
Kif:Kif:Kif:Kif:Kif:Kib:KIf;KYf;KYf;KYj<Kij<Kij<Kij<Ki^9K9^9K9^9K9b:KIf;KYf;KYj<
Kij<Kib:KIb:KIb:KIb:KIb:KIb:KIb:KIb:KIZ7K9^8KIb9KYb9KYb9KYb9KY^8KIZ7K9f8K9f8K9f8
K9f8K9f8K9f8K9f8K9f8K9^6Jij9KZ2;L9n:Kib7K9^6Jif8KIn:KiZ8JiZ8JiZ8JiZ8JiZ8JiZ8JiZ8
JiZ8JiZ5JI^6JY^6JYb7Jib7Jif8K9f8K9j9KIf9JYf9JYf9JYf9JYf9JYf9JYf9JYf9JY^7J9^7J9^7
J9^7J9^7J9^7J9^7J9^7J9Z6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6
IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6
IiZ6IiZ6IiZ6IiZ6IiZ6IiV5IYV5IYZ6Ii^7J9^7J9Z6IiV5IYV5IY^6Ii^6Ii^6Ii^6Ii^6Ii^6Ii^6
Ii^6IiZ5IYZ5IYZ5IYZ5IYZ5IYZ5IYZ5IYZ5IY^7I9^7I9^7I9^7I9^7I9^7I9^7I9^7I9Z7HIZ7HIZ7
HIZ7HIZ7HIZ7HIZ7HIZ7HIZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYZ7HYZ7HY^3Gi^3Gib4H9b4H9f5HIf5HIj6
HYj6HY^5Fi^5Fi^5Fi^5Fi^5Fi^5Fi^5Fi^5FiJ5FYJ5FYJ5FYJ5FYJ5FYJ5FYJ5FYJ5FYZ3GIZ3GIZ3
GIZ3GIZ3GIZ3GIZ3GIZ3GIV3FYV3FYV3FYV3FYV3FYV3FYV3FYV3FYJ0EiN1F9N1F9R2FIR2FIV3FYV3
FYZ4FiN2EIN2EIN2EIN2EIN2EIN2EIN2EIN2EIMnEYMnEYInE9InE9N0DiR1DiZ3EIZ3EIR1DiR1DiR1
DiR1DiR1DiR1DiR1DiR1DiN0DYN0DYN0DYN0DYN0DYN0DYN0DYN0DYN1DIN1DIN1DIN1DIN1DIN1DIN1
DIN1DIAoBiF0C9F0CIF0CIJ0D9IoDIIoDIN0DYJ0D9J0D9J0D9J0D9J0D9J0D9J0D9J0D9EoCiEoCiEo
CiEoCiEoCiEoCiEoCiEoCi=mCIAnCYAnCYAnCYEoCiEoCiEoCiEoCi=mCIAnCYAnCYAnCYEoCiEoCiEo
CiEoCi5kBi5kBi9lC99lC99lC9=mCI=mCI=mCI=nBY=nBY=nBY=nBYAoBiF0C9N2CYR3CiEnC9EnC9En
C9EnC9EnC9EnC9EnC9EnC9EnC9EnC9EnC9EnC9EnC9EnC9EnC9EnC9N2BiN2BiN2BiN2BiN2BiN2BiN2
BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2BiN2Bi=oB9=oB9=oB9=oB9=oB9=oB9=oB9=oB9>1A9>1A9>1
AY>1AY>0Ai=oB9=oB9=oB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9Ao
B9AoB9F0BIAoB9AoB9=nAi=nAi9mAY9mAY5lAI=nAi=nAi=nAi=nAi=nAi=nAi=nAi=nAi1oAY9oAY9o
AY=oAY=oAYEnAYEnAYMnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEnAYEn
AYEnAY=lA9=lA9=lA9AmAIAmAIEnAYEnAYEnAY=lA9=lA9=lA9AmAIAmAIEnAYEnAYEnAY=lA9AmAIEn
AYIoAiIoAiAmAI9k@i5j@Y5j@Y5j@Y9k@i=lA9=lA9AmAIAmAIEnAY=n@I9m@95l?i5l?i5l?i5l?i9m
@9=n@Hmh@8mh@8mh@8mh@8mh@8mh@8mh@8mh@91i@I1i@I5j@Y9k@i9k@i5j@Y1i@I1i@I5j@Y5j@Y5j
@Y5j@Y5j@Y5j@Y5j@Y5j@Xmh@8mh@91i@I1i@I5j@Y9k@i9k@i9k@iAi@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai
@9Ai@99g?Y=h?i=h?i=h?iAi@9Ai@9Ai@9Ej@Hih?Xih?Xih?Xih?Xih?Xih?Xih?Xih?Y9g?Y=h?i=h
?i=h?iAi@9Ai@9Ai@9Ej@Hih?Xmi?hmi?hmi?i1j@91j@91j@95k@IAi@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai
@9Ai@91j@91j@91j@91j@95k@I5k@I9l@Y9l@Y5k@I5k@I5k@I5k@I5k@I5k@I5k@I5k@I9l@Y9l@Y5k
@I5k@I1j@91j@91j@91j@91j@91j@91j@91j@95k@I5k@I9l@Y9l@YEk?iEk?iEk?iEk?iEk?iEk?iEk
?iEk?iEk?iEk?iEk?iIl@9Il@9Il@9Mm@IMm@IIl@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Il
@9Il@9Il@9Il@9Il@9Il@9Ai@9Ai@9Ai@9Ai@9Ej@IEj@IIk@YIk@YAj?YAj?YAj?YAj?YAj?YAj?YAj
?YAj?Y=h?i=h?iAi@9Ai@9Ej@IIk@YIk@YIk@YAj?YAj?YAj?YAj?YEk?iEk?iIl@9Il@99m?i5l?Y1k
?I1k?I1k?I1k?I5l?Y9m?iAi@9Ai@9Ik@YMl@iMl@iMl@iIk@YIk@Y5l?Y5l?Y5l?i5l?i9l@Y9k@i9k
@i=lA9Ej@IIk@YQmA9UnAIUnAIQmA9Ik@YEj@IMl@iMl@iQmA9QmA9QmA9UnAIUnAIUnAIIk@YIk@YIk
@YMl@iMl@iMl@iQmA9QmA9Ik@YIk@YIk@YIk@YIk@YIk@YIk@YIk@YMl@iQmA9QmA9UnAIUnAIQmA9Qm
A9Ml@iQmA9QmA9Ml@iMl@iMl@iQmA9UnAIYoAYMn@9Mn@9Mm@IMm@IMl@iMlA000XXm^XHi]X8a]X8a]
X8]_X8]`XHaaXXebY8mcXhibXhibXXeaXXeaXHa`X8]_X8]_XXeaXXeaXXeaXXeaXXeaXXeaXXeaXXea
XXebXXebXHaaXHaaXHaaX8]`X8]`X8]`X8]_X8]_X8]_X8]_X8]_X8]_X8]_X8]_WhY^WhY^WhY^WhY^
X8]_X8]_X8]_XHa`W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]W8Y]VXQ[VXQ[VhU/VhU/W8Y]W8Y]W8Y]W8Y]
W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^VXM/VXM/VhQ]VhQ]
W8U^W8U^W8U^W8U^VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]VhQ]WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/
W8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYW8QYVhMXVHEVV8AUVhMXVhMXVhMXVhMX
VhMXVhMXVhMXVhMXVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVHEVVHEVVHEVVXIWVXIWVhMXVhMXVhMX
W8UVVhQUVhQUVXMTVXMTVHISVHISV8ERVXEYVXEYVXEYVXEYVXEYVXEYVXEYVXEYVXEVVXEVVXEVVhIW
VhIWW8MXW8MXW8MXVhIWVhIWVhIWVhIWVhIWVhIWVhIWVhIWVhIZVXEYVXIWVHIUVHISV8IQUhIOUhMM
VHERVHERVHERVHERVHERVHERVHERVHERWHEQWHEQWHEQWHEQWHEQWHEQWHEQWHEQXHYTWHIPVX=MVX=M
WXMQX8USX8USWhQRVX=MVX=MVX=MVX=MVX=MVX=MVX=MVX=MWXQOWHMNWHMNW8IMVhELVXAKVXAKVXAK
WXQOWHMNVhELVH=JV89IVH=JVXAKVhELVX=MVX=MVhANW8EOW8EOVhANVX=MVX=MV89IV89IV89IV89I
V89IV89IV89IV89IUh9EUh9EUh9EUh9EUh9EUh9EUh9EUh9EV8=FV8=FV8=FV8=FV8=FV8=FV8=FV8=F
V85CV85CV85CV85CV85CV85CV85CV85CUX1@UX1@Uh5AV89BV89BUh5AUX1@UX1@UX1@UX1@UX1@UX1@
UX1@UX1@UX1@UX1@V89BV89BUh5AUh5AUh5AUX1@UX1@UX1@U7i>U7i>U7i>U7i>UGm?UGm?UGm?UX1@
V89BV89BUX1@UGm?U7i>U7i>UGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?UH1=UH1=UH1=UH1=
UH1=UH1=UH1=UH1=UWm?UWm?UWm?UWm?UWm?UWm?UWm?UWm?T7e:Sga9SW]8SGY7SGY7Sga9TGi;TWm<
UGi<UGi<UGi<UGi<UWm=UWm=Uh1>Uh1>Tga:U7e;U7e;U7e;UGi<UGi<UGi<UWm=UX5:UX5:UX5:UX5:
UX5:UX5:UX5:UX5:U7e;U7e;U7e;U7e;U7e;U7e;U7e;U7e;UX5:UX5:UX5:UX5:UX5:UX5:UX5:UX5:
U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8Uh9;UX5:U7m8Tgi7TWe6Tgi7U7m8UH19TWe6U7m8UH19U7m8
TWe6TWe6Tgi7UH19UH19UH19UH19UH19UH19UH19UH19UH19TWe6TWe6Tgi7Tgi7U7m8U7m8U7m8U7m8
U817U817Tgm6Tgi7TWa8TG]7TGY8TGY8Tg]5Tg]5U7a6U7a6U7a6UGe7UGe7UGe7U7e5U7e5U7e5U7e5
U7e5U7e5U7e5U7e5Tge3Tge3Tge3U7i4UGm5UGm5UX16UX16Tgi1U7m2UH13UH13UH13UH13U7m2Tgi1
TG`oTWa2U7i4UWm7UWm7UWi8UGe7U7a8Tga4Tga4Tga4Tga4Tga4Tga4Tga4Tga4Tga4TW]3TW]3TGY2
TGY2TW]3TW]3Tga4Tge3Tge3Tge3TWa2TWa2TG]1TG]1TG]1TWa2TG]1T7Y0T7Y0T7Y0T7Y0TG]1TWa2
T7U1T7U1T7U1T7U1T7U1T7U1T7U1T7U1TGY2TGY2TGY2TGY2TGY2TGY2TGY2TGY2TG]1TG]1TG]1TG]1
TG]1TG]1TG]1TG]1UGY1UGY1UGY1UGY1UGY1UGY1UGY1UGY1U7U0TgPoTWLnTGHmTGHmTWLnTgPoU7U0
TWPlTWPlTGLkTGLkTWPlTgTmU7XnUG/oU7U0U7U0U7U0TgPoTWLnTWLnTGHmTGHmU7XnU7XnU7XnU7Xn
U7XnU7XnU7XnU7XnU7U0U7U0U7U0U7U0U7U0U7U0U7U0U7U0SgXmSgXmTGTmTGTmTgTmTgTmUGTmUGTm
TG`oTG`oTg/oTg/oUG/oUG/oUg/oUg/oU7XnU7XnU7XnU7XnU7XnU7XnU7XnU7XnUWa0UWa0UWa0UG/o
UG/oU7XnTgTmTgTmU7XnU7XnU7XnUG/oUG/oUG/oUWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0UWa0
V7i2Uge1Uge1UWa0UWa0UG/oUG/oU7XnUG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/oUG/o
UG/oUG/oUG/oUG/oU7XnU7XnU7XnU7XnU7XnU7XnU7XnU7XnTWPlTWPlTgTmTgTmU7XnUG/oUG/oUG/o
Tgi1TWe0U7a0Tg/oUG/oU7XnUGTmUGTmUGY1UGY1UGY1UGY1UGY1UGY1UGY1UGY1UWa0UG/oU7XnU7Xn
U7XnU7XnUG/oUWa0Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3Uga3
VX14VGm3V7i2Uge1Uge1Uge1V7i2VGm3Uga3Uga3Uga3V7e4VGi5VGi5VWm6VWm6Uga3Uga3Uga3Uga3
Uga3Uga3Uga3Uga3UW]2Uga3VGi5VWm6VWm6VGi5Uga3UW]2Uga4Uga4V7e5VGi6VWm7Vh18W859W859
VWm6VWm6VWm6VGi5VGi5VGi5002RSfjQSVfPS6fPS6fPRfnPRg2QS76RSG:SSW:SSW:RSG6RSG6QS72Q
S72PRfnPRfnRSG6RSG6RSG6RSG6RSG6RSG6RSG6RSG6RSG:QS76QS76QS76PRg2PRg2PRg2ORVnORVjO
RVjORVjORVjORVjORVjORVjORVjNRFfORVjORVjORVjPRfnPRfnPRfnPRfnLRVfLRVfLRVfLRVfLRVfL
RVfLRVfLRVfJR6^JR6^KRFbKRFbKRFbLRVfLRVfLRVfLRFjLRFjLRFjLRFjLRFjLRFjLRFjLRFjLRFjL
RFjLRFjLRFjLRFjLRFjLRFjLRFjJQfbJQfbKR6fKR6fKR6fLRFjLRFjLRFjKR6fKR6fKR6fKR6fKR6fK
R6fKR6fKR6fMR6bMR6bMR6bMR6bMR6bMR6bMR6bMR6bLR6VLR6VLR6VLR6VLR6VLR6VLR6VLR6VKQfRL
R6VLR6VLR6VLR6VKQfRIQFJHQ6FKQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRJQVNJQVNJQVNJQVNJQVNJ
QVNJQVNJQVNIQFJIQFJIQFJJQVNJQVNJQVNKQfRKQfRKR6FKR6FKR6FJQfBIQV>IQV>IQV>HQF:JQFVJ
QFVJQFVJQFVJQFVJQFVJQFVJQFVJQFJJQFJJQFJKQVNKQVNKQVNLQfRLQfRKQVNKQVNKQVNKQVNKQVNK
QVNKQVNKQVNJQFVJQVNIQFJIQVFHQF:HQV6GQUnGQUnIQF:IQF:IQF:IQF:IQF:IQF:IQF:IQF:MQF6M
QF6MQF6MQF6MQF6MQF6MQF6MQF6PRF>MQV2JPefKQ5jMQV2PRF>PRF>NQf6KQ5jKQ5jKQ5jKQ5jKQ5jK
Q5jKQ5jKQ5jKQEbKQEbKQEbKQEbLQUfLQUfLQUfLQUfMQejLQUfJQ5^IPeZHPUVIPeZJQ5^JQ5^IPUbJ
PefKQ5jKQ5jKQ5jKQ5jJPefIPUbHPUVHPUVHPUVHPUVHPUVHPUVHPUVHPUVGPUFGPUFGPUFGPUFGPUFG
PUFGPUFGPUFGPUFGPUFGPUFGPUFGPUFGPUFGPUFGPUFHPE>HPE>HPE>HPE>HPE>HPE>HPE>HPE>FP52F
P52GPE6HPU:HPU:GPE6FP52FP52FP52FP52FP52FP52FP52FP52FP52FP52FP52FP52FP52EOdnEOdnE
OdnDOTjDOTjCODfDOTjDOTjDOTjEOdnEOdnEOdnEOdnHPU:GPE6FP52EOdnDOTjDOTjEOdnEOdnDOTjD
OTjDOTjDOTjDOTjDOTjDOTjDOTjDOdbDOdbDOdbDOdbDOdbDOdbDOdbDOdbEOTjEOTjEOTjEOTjEOTjE
OTjEOTjEOTjBODZAO4V@NdR@NdR@NdRBODZCOT^DOdbCO4ZCO4ZCO4ZDOD^DOD^EOTbEOTbEOTbCO4ZC
O4ZDOD^DOD^DOD^EOTbEOTbEOTbEP4VEP4VEP4VEP4VEP4VEP4VEP4VEP4VEOTbEOTbEOTbEOTbEOTbE
OTbEOTbEOTbEP4VEP4VEP4VEP4VEP4VEP4VEP4VEP4VDOdRDOdRDOdRDOdRDOdRDOdRDOdRDOdRGPT^F
PDZDOdRCOTNCOTNCOTNDOdREP4VBODJCOTNEP4VDOdRBODJBODJCOTNDOdRDOdRDOdRDOdRDOdRDOdRD
OdRDOdRDOdRBODJBODJCOTNCOTNCOTNDOdRDOdRDOdRCOdJCOdJBOTFBODJBO4RBO4RANTRANTRCNdFC
NdFCNdFDO4JDO4JEODNEODNEODNDODFDODFDODFDODFDODFDODFDODFDODFCOD>COD>DOTBDOTBDOTBD
OTBEOdFEOdFDOTBDOTBEOdFEOdFEOdFDOTBCOD>BO4:AO3nBO4:DOTBEOTJFOdNEODNEODNDO4RCO4BC
O4BCO4BCO4BCO4BCO4BCO4BCO4BCO4BBNd>ANT:ANT:ANT:ANT:BNd>CO4BANd6ANd6ANd6ANd6@NT2@
NT2?NCn?NCnBO4:ANd6@NT2@NT2@NT2@NT2ANd6BO4:@ND6@ND6@ND6@ND6@ND6@ND6@ND6@ND6ANT:A
NT:ANT:ANT:ANT:ANT:ANT:ANT:ANd6ANd6ANd6ANd6ANd6ANd6ANd6ANd6ENT6ENT6ENT6ENT6ENT6E
NT6ENT6ENT6DND2CN3nBMcjAMSfAMSfBMcjCN3nDND2CNCfBN3bBN3bAMc^BN3bBN3bCNCfDNSjDND2D
ND2CN3nCN3nBMcjBMcjAMSfAMSfDNSjDNSjDNSjDNSjDNSjDNSjDNSjDNSjDND2DND2DND2DND2DND2D
ND2DND2DND2>NCb>NCb@N3b@N3bBN3bBN3bDN3bDN3bAO3nAO3nCNcnCNcnENcnENcnGNcnGNcnDNSjD
NSjDNSjDNSjDNSjDNSjDNSjDNSjENcnENcnENcnENcnENcnDNSjDNSjDNSjDNSjDNSjDNSjDNSjENcnE
NcnFO42FO42DNSjDNSjDNSjDNSjDNSjDNSjDNSjDNSjFO42FO42ENcnENcnDNSjDNSjCNCfCNCfENcnE
NcnENcnENcnENcnDNSjDNSjDNSjENcnENcnENcnENcnENcnENcnENcnENcnDNSjDNSjDNSjDNSjDNSjD
NSjDNSjDNSjCNCfCNCfCNCfCNCfDNSjDNSjDNSjDNSjBOD2BOD2CNcnCNcnDNSjDNSjENCfENCfENT6E
NT6ENT6ENT6ENT6ENT6ENT6ENT6FO42ENcnDNSjDNSjDNSjDNSjENcnFO42GO4>GO4>GO4>GO4>GO4>G
O4>GO4>GO4>GO4>GO4>GO4>GO4>GO4>GO4>GO4>GO4>IOd>IOd>HOT:GOD6GOD6GOD6HOT:IOd>GO4>G
O4>HODBHODBHODBHODBIOTFIOTFGO4>GO4>GO4>GO4>GO4>GO4>GO4>GO4>GO4>HODBHODBIOTFIOTFH
ODBHODBGO4>GO4BGO4BHODFIOTJJOdNJOdNKP4RLPDVIOTFIOTFIOTFIOTFIOTFIOTD00:6>KJ6>KJ2<
KIn;K9n:KZ2;L:6<LJ6<LJ:=LJ:=LJ:=LJ:=LJ6<L:6<L:6<L:2;Kj6<L:6<L:6<L:6<L:6<L:6<L:6<
L:6<L:6<LJ6<LJ6<LJ2;L:2;L:2;L9n:Kin:Kin:KYn:KYn:KYn:KYn:KYn:KYn:KYn:KYj9KIj9KIj9
KIn:KYn:KZ2;Kj2;Kj2;Kib:KIb:KIb:KIb:KIb:KIb:KIb:KIb:KIZ8JiZ8JiZ8Ji^9K9^9K9^9K9b:
KIb:KIb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYb9KYZ7K9Z7K9Z7
K9^8KI^8KI^8KIb9KYb9KY^8KI^8KI^8KI^8KI^8KI^8KI^8KI^8KIf8K9f8K9f8K9f8K9f8K9f8K9f8
K9f8K9b8JIb8JIb8JIb8JIb8JIb8JIb8JIb8JI^7J9^7J9b8JIb8JI^7J9Z6IiV5IYV5IY^7J9^7J9^7
J9^7J9^7J9^7J9^7J9^7J9V5IYV5IYV5IYV5IYV5IYV5IYV5IYV5IYR4IIV5IYV5IYV5IYZ6IiZ6IiZ6
IiZ6IiZ7I9Z7I9Z7I9Z7I9V6HiV6HiV6HiR5HYV5IYV5IYV5IYV5IYV5IYV5IYV5IYV5IYV4IIZ5IYZ5
IYZ5IY^6Ii^6Ii^6Ii^6IiZ5IYZ5IYZ5IYZ5IYZ5IYZ5IYZ5IYZ5IYV5IYV5IYV6IIV6IIR5HYR6HIR6
HIN5H9Z6HiZ6HiZ6HiZ6HiZ6HiZ6HiZ6HiZ6Hib4H9b4H9b4H9b4H9b4H9b4H9b4H9b4H9j7HIb5GiZ3
GI^4GYf6H9n8HYj7HIj7HIb5Gib5Gib5Gib5Gib5Gib5Gib5Gib5GiV3FYV3FYZ4Fi^5G9b6GIb6GIf7
GYf7GYb6GI^5G9Z4FiV3FYV3FYV3FYZ4FiZ4FiV3FYV3FYZ4FiZ4FiZ4FiZ4FiV3FYV3FYR2F9R2F9R2
F9R2F9R2F9R2F9R2F9R2F9N2EIN2EIN2EIN2EIN2EIN2EIN2EIN2EIF0DiF0DiF0DiF0DiF0DiF0DiF0
DiF0DiN0DYN0DYN0DYN0DYN0DYN0DYN0DYN0DYEoCiJ0D9N1DIN1DIN1DIN1DIJ0D9EoCiEoCiEoCiEo
CiEoCiEoCiEoCiEoCiEoCiEoCiEoCiAnCYAnCYAnCY=mCI=mCI=mCI=mCI=mCI=mCIAnCYAnCYEoCiEo
CiEoCiN1DIJ0D9EoCiAnCYAnCYAnCYAnCYEoCiAnCYAnCYAnCYAnCYAnCYAnCYAnCYAnCYAoC9AoC9Ao
C9AoC9AoC9AoC9AoC9AoC9EnCYEnCYEnCYEnCYEnCYEnCYEnCYEnCY9mBY9mBY5lBI5lBI9mBY=nBiAo
C9AoC99kBI9kBI9kBI9kBI=lBY=lBY=lBYAmBi=lBY=lBY=lBYAmBiAmBiEnC9EnC9EnC9F0BIF0BIF0
BIF0BIF0BIF0BIF0BIF0BIIoCIIoCIIoCIIoCIIoCIIoCIIoCIIoCIF0BIF0BIF0BIF0BIF0BIF0BIF0
BIF0BIAoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9J1BYF0BIAoB9=nAi=nAi=nAi=nAiAoB95lAI=nAiAo
B9AoB99mAY5lAI=nAiAoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB99mAY9mAY9mAY=nAi=nAi=nAiAo
B9AoB95mA95mA95mA99mAY9lB99lB99kBI9kBI=kAI=kAI=kAI=kAIAlAYAlAYEmAiEmAiAmAIAmAIAm
AIAmAIAmAIAmAIAmAIAmAIAnA9AnA9AnA9AnA9AnA9=m@i=m@i=m@iAnA9EoAIEoAIEoAIAnA9=m@i9l
@Y5k@I9m@99l@YAnA9EnAYEnAYEmAiAlAYAlB9=lA9=lA9=lA9=lA9=lA9=lA9=lA9=lA99k@i9k@i5j
@Y1i@I1i@I5j@Y9k@i9k@i1j@91j@91j@8mi?hmi?hih?Xih?Xih?Y5k@I5k@I1j@8mi?hmi?i1j@95k
@I5k@Hmh@8mh@8mh@8mh@8mh@8mh@8mh@8mh@91i@I1i@I1i@I1i@I1i@I1i@I1i@I1i@I1j@91j@91j
@91j@91j@91j@91j@91j@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@9=h?i9g?Y9g?Y5f?I5f?I9g?Y9g
?Y=h?iAj?Y=i?I9h?95g>i5g>i5g>i9h?99h?9=h?i=h?i=h?i9g?Y9g?Y9g?Y5f?I5f?I=i?I=i?I=i
?I=i?I=i?I=i?I=i?I=i?I=h?i=h?i=h?i=h?i=h?i=h?i=h?i=h?hii?8ii?91h?91h?99h?99h?9Ah
?9Ah?91k?Y1k?Y9j?Y9j?YAj?YAj?YIj?YIj?Y=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?IAj?YAj?YAj
?YAj?YAj?YEk?iEk?iEk?i=i?I=i?IAj?YAj?YEk?iEk?iEk?iEk?i=i?I=i?I=i?I=i?I=i?I=i?I=i
?I=i?IAj?YAj?Y=i?I=i?I=i?I9h?99h?99h?9Il@9Il@9Ek?iEk?iAj?Y=i?I=i?I=i?IAj?YAj?YAj
?YAj?YAj?YAj?YAj?YAj?Y=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?IAj?YAj?YAj?Y=i?I=i?I=i?I=i
?I=i?I5l?i5l?i=k?i=k?iAj?YAj?YIj?YEi?IAi@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@9Ai@9Ek?iEk?iAj
?Y=i?I=i?IAj?YEk?iEk?iIk@YIk@YIk@YIk@YIk@YIk@YIk@YIk@YMl@iMl@iMl@iMl@iMl@iMl@iMl
@iMl@iUo@iQn@YMm@IMm@IMm@IMm@IQn@YUo@iQmA9QmA9QmA9QmA9QmA9Ml@iMl@iMl@iMl@iMl@iMl
@iMl@iMl@iMl@iMl@iMl@iQmA9QmA9Ml@iMl@iMl@iMl@iQmA9QmA9Ik@iMlA9MlA9QmAIUnAYYoAiYo
AiYoAiMl@iMl@iQmA9QmA9UnAIYoAP00XHi]X8e/Wh]/Wh]/WhY^WhY_X8]`XHaaXHa`XHa`XHa`XHa`
XHa`XHa`XHa`XHa`XHa`XHa`XHa`XHa`XHa`XHa`XHa`XHa`XHaaXHaaX8]`X8]`X8]`WhY_WhY_WhY_
WhY^WhY^WhY^WhY^WhY^WhY^WhY^WhY^WXU]WXU]WXU]WXU]WhY^WhY^X8]_X8]_W8Y]W8Y]W8Y]W8Y]
W8Y]W8Y]W8Y]W8Y]VHMZVHMZVXQ[VXQ[VhU/VhU/VhU/VhU/W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^
W8U^W8U^W8U^W8U^W8U^W8U^W8U^W8U^VHI[VHI[VXM/VXM/VhQ]VhQ]VhQ]VhQ]VXM/VXM/VXM/VXM/
VXM/VXM/VXM/VXM/W8M[W8M[W8M[W8M[W8M[W8M[W8M[W8M[VhMXVhMXVhMXVhMXVhMXVhMXVhMXVhMX
VHEVVXIWVhMXVhMXVhMXVXIWVHEVVHEVVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWVHEVVHEVVHEVVHEV
VHEVVHEVVHEVVHEVV8AUV8AUV8AUVHEVVHEVVXIWVXIWVXIWVHISVHISVHISVHISVHISVHISVHISVHIS
VHEVVHEVVHEVVHEVVHEVVHEVVHEVVHEVVHAUVHAUVHAUVXEVVXEVVhIWVhIWVhIWVXEVVXEVVXEVVXEV
VXEVVXEVVXEVVXEVV8ETV8ETV8ETV8ERV8ERV8ERV8ERV8ERVXISVXISVXISVXISVXISVXISVXISVXIS
W8APW8APW8APW8APW8APW8APW8APW8APW8EOVhANVhANVhANW8EOWHIPWHIPWHIPW8EOW8EOW8EOW8EO
W8EOW8EOW8EOW8EOVH=JVH=JVXAKVXAKVhELVhELW8IMW8IMVXAKVXAKVXAKVH=JVH=JVH=JVH=JVXAK
V89IV89IVH=JVXAKVXAKVH=JV89IV89IUh5GUh5GUh5GUh5GUh5GUh5GUh5GUh5GUX5DUX5DUX5DUX5D
UX5DUX5DUX5DUX5DUH1CUH1CUH1CUH1CUH1CUH1CUH1CUH1CUh1BUh1BUh1BUh1BUh1BUh1BUh1BUh1B
UGm?UGm?UX1@Uh5AUh5AUX1@UGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?UGm?U7i>
U7i>Tge=Tge=Tge=Tge=Tge=Tge=Tge=U7i>U7i>UGm?UGm?UGm?UGm?U7i>Tge=Tge=Tge=U7i>U7i>
Tge=Tge=Tge=Tge=Tge=Tge=Tge=Tge=Tgi;Tgi;Tgi;Tgi;Tgi;Tgi;Tgi;Tgi;U7e=U7e=U7e=U7e=
U7e=U7e=U7e=U7e=Tga:Tga:Tga:Tga:U7e;U7e;UGi<UGi<TW]9TW]9TW]9Tga:Tga:Tga:U7e;U7e;
TW]9Tga:Tga:Tga:U7e;U7e;U7e;UGi<UH19UH19UH19UH19UH19UH19UH19UH19UWm=UWm=UWm=UWm=
UWm=UWm=UWm=UWm=U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8U7m8
UH19UH19U7m8Tgi7Tgi7Tgi7Tgi7Tgi7TGa5Tgi7U7m8Tgi7TGa5TGa5TWe6U7m8Tgi7Tgi7Tgi7Tgi7
Tgi7Tgi7Tgi7Tgi7TGa5TGa5TWe6TWe6Tgi7Tgi7Tgi7Tgi7T7a3T7a3T7a3TGa5TWa8TWa8Tga:Tga:
TWY4TWY4Tg]5Tg]5Tg]5U7a6U7a6U7a6Tga4Tga4Tga4Tga4Tga4Tga4Tga4Tga4UGm5UGm5U7i4U7i4
Tge3TWa2TWa2TWa2U7e5U7e5UGi6UGi6U7e5Tga4TGY2T7U1Tgi1Tge3Tge3U7e5U7e5U7a6Tg]5Tg]7
TW]3TW]3TW]3TW]3TW]3TW]3TW]3TW]3TW]3TGY2TGY2T7U1T7U1TGY2TGY2TW]3T7Y0T7Y0T7Y0SgTo
SgToSgToSWPnSWPnTG]1T7Y0SgToSgToSgToSgToT7Y0TG]1SgQ0SgQ0SgQ0SgQ0SgQ0SgQ0SgQ0SgQ0
T7U1T7U1T7U1T7U1T7U1T7U1T7U1T7U1SgToSgToSgToSgToSgToSgToSgToSgToTgPoTgPoTgPoTgPo
TgPoTgPoTgPoTgPoTWLnTWLnTGHmTGHmTGHmTGHmTWLnTWLnU7XnTgTmTWPlTGLkT7HjT7HjTGLkTGLk
TWLnTWLnTWLnTWLnTWLnTGHmTGHmTGHmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTgPoTgPoTgPoTgPo
TgPoTgPoTgPoTgPoSWTlSWTlT7PlT7PlTWPlTWPlU7PlU7PlSgXmSgXmTGTmTGTmTgTmTgTmUGTmUGTm
TgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTWPlTgTmTgTmU7XnU7XnUG/oUG/oUG/oTgTmTgTmTgTmU7Xn
U7XnU7XnUG/oUG/oTgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTm
UWa0UG/oUG/oU7XnTgTmTgTmTWPlTWPlU7XnU7XnU7XnU7XnU7XnU7XnU7XnU7XnTgTmTgTmTgTmTgTm
TgTmTgTmTgTmTgTmU7XnU7XnU7XnTgTmTWPlTWPlTGLkTGLkT7/nT7/nTWXnTWXnU7XnU7XnUWXnUWXn
U7U0U7U0U7U0U7U0U7U0U7U0U7U0U7U0UG/oU7XnTgTmTgTmTgTmTgTmU7XnUG/oUGY1UGY1UGY1UGY1
UGY1UGY1UGY1UGY1UW]2UW]2UW]2UW]2UW]2UW]2UW]2UW]2V7i2Uge1UWa0UWa0UWa0Uge1V7i2VGm3
VGi5VGi5V7e4V7e4Uga3UW]2UW]2UW]2UW]2UW]2UW]2UW]2UW]2UW]2UW]2UW]2VGi5V7e4UW]2UGY1
UGY1UW]2V7e4VGi5UW]2UW]2Uga3Uga3V7e4V7e4VGi5VGi5UW]2UW]2Uga3V7e4VGi5VWm6002PSFbP
SFbORfbNRV^NRFfORVnPRg2PRg2PRfnPRfnPRfnPRfnPRfnQS72QS72QS72PRfnPRfnPRfnPRfnPRfnP
RfnPRfnPRfnPRg2PRg2PRg2ORVnORVnORVnNRFjNRFjNRFfNRFfNRFfNRFfNRFfNRFfNRFfNRFfMR6bM
R6bNRFfNRFfNRFfORVjORVjORVjKRFbKRFbKRFbKRFbKRFbKRFbKRFbKRFbIQfZIQfZIQfZJR6^JR6^J
R6^KRFbKRFbKR6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fKR6fIQV^I
QV^IQV^JQfbJQfbJQfbKR6fKR6fJQfbJQfbJQfbJQfbJQfbJQfbJQfbJQfbLQf^LQf^LQf^LQf^LQf^L
Qf^LQf^LQf^KQfRKQfRKQfRKQfRKQfRKQfRKQfRKQfRHQ6FIQFJJQVNKQfRKQfRJQVNJQVNIQFJJQVNJ
QVNJQVNJQVNJQVNJQVNJQVNJQVNIQFJIQFJIQFJIQFJIQFJIQFJIQFJIQFJGPfBHQ6FHQ6FHQ6FIQFJI
QFJIQFJJQVNHQF:HQF:HQF:HQF:IQV>IQV>IQV>IQV>IQVFIQVFIQVFIQVFIQVFIQVFIQVFIQVFHPfBI
Q6FIQ6FIQ6FJQFJJQFJJQFJKQVNJQFJJQFJJQFJJQFJJQFJJQFJJQFJJQFJGQ66GQ66GQ66GQ66GQ66H
QFBHQFBHQFBJQV>JQV>JQV>JQV>JQV>JQV>JQV>JQV>KPenKPenKPenKPenKPenKPenKPenKPenIPUbJ
PefKQ5jKQ5jKQ5jKQ5jLQEnLQEnKQ5jKQ5jKQ5jKQ5jKQ5jKQ5jKQ5jKQ5jKQEbKQEbKQEbJQ5^JQ5^I
PeZIPeZIPeZHPUVIPeZIPeZIPeZIPeZIPeZIPeZIPeZGPENGPENHPURIPeVIPeVHPURGPENGPENGPUFG
PUFGPUFGPUFGPUFGPUFGPUFGPUFFPEBFPEBFPEBFPEBFPEBFPEBFPEBFPEBFPEBFPEBFPEBFPEBFPEBF
PEBFPEBFPEBGP5:GP5:GP5:GP5:GP5:GP5:GP5:GP5:DOTjEOdnFP52FP52FP52FP52EOdnDOTjDOTjD
OTjDOTjDOTjDOTjDOTjDOTjDOTjFP52FP52FP52EOdnEOdnDOTjDOTjDOTjBO4bBO4bCODfCODfCODfD
OTjDOTjDOTjDOTjCODfBO4bBO4bBO4bCODfDOTjDOTjBO4bBO4bBO4bBO4bBO4bBO4bBO4bBO4bBODZB
ODZBODZBODZBODZBODZBODZBODZCO4bCO4bCO4bCO4bCO4bCO4bCO4bCO4bBNdVBNdVCO4ZCO4ZDOD^D
OD^DOD^DOD^CO4ZCO4ZCO4ZDOD^DOD^DOD^EOTbEOTbBNdVBNdVBNdVCO4ZCO4ZDOD^DOD^DOD^DOdRD
OdRDOdRDOdRDOdRDOdRDOdRDOdREOTbEOTbEOTbEOTbEOTbEOTbEOTbEOTbCOTNCOTNCOTNCOTNCOTNC
OTNCOTNCOTNCOTNCOTNCOTNCOTNCOTNCOTNCOTNCOTNDOdRDOdRDOdRDOdRCOTNCOTNBODJBODJAO4FB
ODJCOTNCOTNAO4F@NdBBODJCOTNBODJBODJBODJBODJBODJBODJBODJBODJAO4FAO4FAO4FBODJBODJB
ODJCOTNCOTN?Nd:?Nd:@O4>@NdBANdNBO4RBNdVBNdVBNTBBNTBBNTBCNdFCNdFCNdFDO4JDO4JCO4BC
O4BCO4BCO4BCO4BCO4BCO4BCO4BDOTBDOTBDOTBCOD>BO4:BO4:ANd6ANd6CO4BCO4BDODFDODFCO4BB
Nd>ANT:ANT:COT6COD>COD>BNd>BNd>BNTBCNdFCNdNBNd>BNd>BNd>BNd>BNd>BNd>BNd>BNd>ANT:A
NT:@ND6@ND6@ND6@ND6ANT:ANT:ANd6ANd6ANd6@NT2@NT2@NT2?NCn?NCn@NT2@NT2?NCn>N3j>N3j?
NCn@NT2@NT2>Mcn>Mcn>Mcn>Mcn>Mcn>Mcn>Mcn>Mcn?N42?N42?N42?N42?N42?N42?N42?N42>N3j>
N3j>N3j>N3j>N3j>N3j>N3j>N3jBMcjBMcjBMcjBMcjBMcjBMcjBMcjBMcjAMSfAMSfAMSfAMSfAMSfA
MSfAMSfAMSfDNSjCNCfBN3b@MSZ@MSZ@MSZ@MSZAMc^AMSfAMSfAMSfAMSfAMSfAMSfAMSfAMSfBN3bB
N3bBN3bBN3bBN3bBN3bBN3bBN3bBMcjBMcjBMcjBMcjBMcjBMcjBMcjBMcj=N3^=N3^?Mc^?Mc^AMc^A
Mc^CMc^CMc^>NCb>NCb@N3b@N3bBN3bBN3bDN3bDN3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bB
N3bBN3bCNCfDNSjDNSjENcnENcnBN3bBN3bCNCfCNCfDNSjDNSjDNSjDNSjDNSjDNSjDNSjDNSjDNSjD
NSjDNSjDNSjDNSjDNSjDNSjDNSjDNSjDNSjDNSjENcnENcnDNSjDNSjDNSjCNCfCNCfBN3bBN3bCNCfC
NCfCNCfCNCfCNCfCNCfCNCfCNCfBN3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bDNSjDNSjCNCfCNCfBN3bA
Mc^AMc^AMc^?NSf?NSfANCfANCfCNCfDNSjFNSjFNSjCN3nCN3nCN3nCN3nCN3nCN3nCN3nCN3nDNSjD
NSjCNCfBN3bBN3bCNCfDNSjDNSjDND2DND2DND2DND2DND2DND2DND2DND2FNd:FNd:FNd:FNd:FNd:F
Nd:FNd:FNd:FO42FO42FO42ENcnFO42GOD6HOT:IOd>HODBHODBHODBGO4>FNd:FNd:ENT6ENT6FNd:F
Nd:FNd:FNd:FNd:FNd:FNd:FNd:IOTFHODBFNd:ENT6ENT6FNd:HODBIOTFFO42FO42FO42FO42GOD6G
OD6GOD6GOD6ENT6FNd:FNd:GO4>HODBIOTD00:2=K9n<Jij:Jij:Jij9KIj9KYn:Kj2;L9n:KYn:KYn:
KZ2;Kj2;Kj2;Kj6<L:6<L:2;Kj2;Kj2;Kj2;Kj2;Kj2;Kj2;Kj2;Kj2;L:2;L9n:Kin:Kin:Kij9KYj9
KYj9KYj9KIj9KIj9KIj9KIj9KIj9KIj9KIj9KIf8K9f8K9f8K9f8K9j9KIj9KIn:KYn:KY^9K9^9K9^9
K9^9K9^9K9^9K9^9K9^9K9R6JIV7JYV7JYV7JYZ8JiZ8JiZ8JiZ8Ji^8KI^8KI^8KI^8KI^8KI^8KI^8
KI^8KI^8KI^8KI^8KI^8KI^8KI^8KI^8KI^8KIR5JYV6JiV6JiV6JiZ7K9Z7K9Z7K9Z7K9V6JiV6JiV6
JiV6JiV6JiV6JiV6JiV6Ji^6JY^6JY^6JY^6JY^6JY^6JY^6JY^6JYZ6IiZ6IiZ6IiZ6IiZ6IiZ6IiZ6
IiZ6IiN3I9R4IIV5IYZ6IiZ6IiZ6IiZ6IiV5IYV5IYV5IYV5IYV5IYV5IYV5IYV5IYV5IYR4IIR4IIR4
IIR4IIR4IIR4IIR4IIR4IIN3I9N3I9N3I9R4IIR4IIV5IYV5IYV5IYN4HIN4HIR5HYR5HYR5HYV6HiV6
HiV6HiR5I9R5I9R5I9R5I9R5I9R5I9R5I9R5I9R3I9R3I9R3I9V4IIV4IIZ5IYZ5IYZ5IYV4IIV4IIV4
IIV4IIV4IIV4IIV4IIV4IIJ4GiJ4GiJ4GiN4HIN4HiN4HiR4IIR4IIR4HIR4HIR4HIR4HIR4HIR4HIR4
HIR4HI^3Gi^3Gi^3Gi^3Gi^3Gi^3Gi^3Gi^3GiN0FYV2G9^4GYb5GiZ3GIZ3GIZ3GI^4GYZ3GIZ3GIZ3
GIZ3GIZ3GIZ3GIZ3GIZ3GIb6GIb6GI^5G9Z4FiV3FYR2FIR2FIN1F9N1F9N1F9R2FIV3FYZ4FiZ4FiV3
FYR2FIJ0EYJ0EYN1EiR2F9R2F9N1EiJ0EYJ0EYJ2DiJ2DiJ2DiJ2DiJ2DiJ2DiJ2DiJ2DiF0DiF0DiF0
DiF0DiF0DiF0DiF0DiF0DiN2EIN2EIN2EIN2EIN2EIN2EIN2EIN2EIIoDIIoDIIoDIIoDIIoDIIoDIIo
DIIoDIAnCYEoCiEoCiJ0D9J0D9EoCiEoCiAnCYAnCYAnCYAnCYAnCYAnCYAnCYAnCYAnCYJ0D9J0D9J0
D9EoCiEoCiEoCiAnCYAnCY9lC99lC99lC99lC9=mCI=mCIAnCYAnCY9lC99lC95kBi5kBi5kBi9lC9=m
CIAnCY5kBi5kBi5kBi5kBi5kBi5kBi5kBi5kBi5lBI5lBI5lBI5lBI5lBI5lBI5lBI5lBI9kBi9kBi9k
Bi9kBi9kBi9kBi9kBi9kBi9iAi=jB9AkBIElBYElBYElBYAkBIAkBI=lBY=lBY=lBYAmBiAmBiEnC9En
C9EnC99kBI9kBI9kBI9kBI=lBY=lBY=lBYAmBiAoB9AoB9AoB9AoB9AoB9AoB9AoB9AoB9AmBiAmBiAm
BiAmBiAmBiAmBiAmBiAmBi9mAY9mAY9mAY9mAY9mAY9mAY9mAY9mAY=nAi=nAi=nAi=nAi=nAi=nAi=n
Ai=nAi=nAi=nAiAoB9AoB9=nAi9mAY5lAI5lAI1kA99mAY=nAi9mAY5lAI1kA95lAI=nAi5lAI5lAI5l
AI5lAI5lAI5lAI5lAI5lAI1kA95lAI5lAI5lAI9mAY9mAY9mAY9mAY1l@i1l@i1l@i1kA91jAY5kAi5j
B95jB95i@i5i@i9jA99jA9=kAI=kAI=kAI=kAI9k@i9k@i9k@i9k@i9k@i9k@i9k@i9k@i=m@i=m@i=m
@i9l@Y9l@Y9l@Y9l@Y9l@Y5i@i9jA9=kAI=kAI=kAI=kAI9jA99jA9Ao@YAnA99l@Y5j@Y5j@Y5i@i9j
A99jAY5j@Y5j@Y5j@Y5j@Y5j@Y5j@Y5j@Y5j@Y5j@Y1i@I1i@Hmh@8mh@91i@I1i@I5j@Y5k@I5k@I5k
@I5k@I1j@91j@8mi?hmi?i1j@8mi?hmi?hih?Xih?Xmi?hmi?i1j@8ig?hig?hig?hig?hig?hig?hig
?hig?hmh@8mh@8mh@8mh@8mh@8mh@8mh@8mh@8eg?Heg?Heg?Heg?Heg?Heg?Heg?Heg?I5f?I5f?I5f
?I5f?I5f?I5f?I5f?I5f?I1e?91e?95f?I9g?Y9g?Y5f?I1e?91e?99h?99h?95g>i1f>Y1f>Y1f>Y5g
>i5g>i1e?91e?91e?91e?95f?I5f?I5f?I9g?Y9h?99h?99h?99h?99h?99h?99h?99h?99g?Y9g?Y9g
?Y9g?Y9g?Y9g?Y9g?Y9g?Xeh>heh>hmg>hmg>i5g>i5g>i=g>i=g>heh>heh>hmg>hmg>i5g>i5g>i=g
>i=g>i9h?99h?99h?99h?99h?99h?99h?99h?99h?99h?9=i?I=i?I=i?I=i?I=i?IAj?Y9h?99h?99h
?9=i?I=i?IAj?YAj?YAj?YAj?YAj?YAj?YAj?YAj?YAj?YAj?YAj?Y=i?IAj?YAj?YAj?YEk?iEk?iEk
?iEk?i=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I=i?I9h?99h?99h
?99h?99h?99h?99h?99h?99h?99h?99h?99h?99h?95g>i5g>i5g>hii?8ii?91h?95i?I=i?I=i?IIj
?YIj?Y=h?i=h?i=h?i=h?i=h?i=h?i=h?i=h?iAj?Y=i?I=i?I9h?99h?9=i?I=i?IAj?Y=h?i=h?i=h
?i=h?i=h?i=h?i=h?i=h?iEj@IEj@IEj@IEj@IEj@IEj@IEj@IEj@IEk?iEk?iEk?iEk?iIl@9Mm@IQn
@YUo@iMl@iMl@iMl@iIk@YIk@YIk@YIk@YIk@YEj@IEj@IEj@IEj@IEj@IEj@IEj@IEj@IMl@iMl@iIk
@YIk@YIk@YIk@YMl@iMl@iIl@9Il@9Il@9Il@9Il@9Il@9Il@9Il@9Ik@YIk@YIk@YMl@iQmA9QmA000
Wha[Wha[WXY[WHUZWHQ/WXU^WhY_WhY_WXU]WXU]WhY^WhY^X8]_X8]_XHa`XHa`X8]_X8]_X8]_X8]_
X8]_X8]_X8]_X8]_X8]`WhY_WhY_WhY_WXU^WXU^WXU^WHQ]WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/WHQ/
W8M[W8M[WHQ/WHQ/WXU]WXU]WXU]WXU]VXQ[VXQ[VXQ[VXQ[VXQ[VXQ[VXQ[VXQ[V8IYV8IYVHMZVHMZ
VHMZVXQ[VXQ[VXQ[VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/VXM/
V8EZV8EZVHI[VHI[VHI[VXM/VXM/VXM/VHI[VHI[VHI[VHI[VHI[VHI[VHI[VHI[VhIZVhIZVhIZVhIZ
VhIZVhIZVhIZVhIZVXIWVXIWVXIWVXIWVXIWVXIWVXIWVXIWUX9SUh=TV8AUVXIWVXIWVXIWVXIWVHEV
VHEVVHEVVHEVVHEVVHEVVHEVVHEVVHEVV8AUV8AUV8AUV8AUV8AUV8AUV8AUV8AUUh=TUh=TUh=TV8AU
V8AUV8AUVHEVVHEVUX=PUhAQUhAQUhAQV8ERVHISVHISVHISV8ERV8ERV8ERV8ERV8ERV8ERV8ERV8ER
V8=TV8=TV8=TVHAUVHAUVHAUVXEVVXEVVHAUVHAUVHAUVHAUVHAUVHAUVHAUVHAUUHAMUHAMUXAOUX=P
UhASUh=TV8AUV8=WUh=PUh=PUh=PUh=PUh=PUh=PUh=PUh=PVX9NVX9NVX9NVX9NVX9NVX9NVX9NVX9N
UGiHV85KW8EOW8EOVX=MV85KVH9LVhANVH9LVH9LVH9LVH9LVH9LVH9LVH9LVH9LVXAKVXAKVXAKVH=J
VH=JVH=JVH=JVH=JUGmFUX1GV89IVH=JVXAKVXAKVH=JV89IUH1CUX5DUX5DUh9EUh9EUX5DUX5DUH1C
UX9CUX9CUX9CUX9CUX9CUX9CUX9CUX9CUH1CUH1CUH1CUH1CUH1CUH1CUH1CUH1CUH1CUH1CUH1CUH1C
UH1CUH1CUH1CUH1CUWmAUWmAUWmAUWmAUWmAUWmAUWmAUWmAU7i>U7i>UGm?UX1@UX1@UGm?U7i>U7i>
Tge=Tge=Tge=Tge=Tge=Tge=Tge=Tge=UGm?UGm?U7i>U7i>U7i>Tge=Tge=Tge=TG];TG];TWa<TWa<
Tge=Tge=Tge=Tge=TG];TG];T7Y:T7Y:TG];TWa<Tge=U7i>T7Y:T7Y:T7Y:T7Y:T7Y:T7Y:T7Y:T7Y:
T7]8T7]8T7]8T7]8T7]8T7]8T7]8T7]8TGY:TGY:TGY:TGY:TGY:TGY:TGY:TGY:T7M5TGQ6TgY8U7]9
U7]9U7]9TgY8TWU7TGY8TW]9TW]9TW]9Tga:Tga:Tga:U7e;TGY8TGY8TW]9TW]9TW]9Tga:Tga:Tga:
Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7Tgi7Tga:Tga:Tga:Tga:Tga:Tga:Tga:Tga:TGa5TGa5TGa5TGa5
TGa5TGa5TGa5TGa5TWe6TWe6TWe6TWe6TWe6TWe6TWe6TWe6TWe6TWe6Tgi7U7m8U7m8TWe6TGa5T7]4
T7]4TGa5Tgi7TWe6T7]4T7]4TGa5TWe6T7]4T7]4T7]4T7]4T7]4T7]4T7]4T7]4T7]4T7]4TGa5TGa5
TGa5TWe6TWe6TWe6TGe4TGe4T7a3T7]4T7Y6T7Y6SgQ6SgQ6TGU3TGU3TGU3TWY4TWY4Tg]5Tg]5Tg]5
TW]3TW]3TW]3TW]3TW]3TW]3TW]3TW]3TG]1TG]1TWa2TWa2TWa2TWa2Tge3Tge3SgM1T7Q2TGU3Tg]5
Tg]5U7a6Tg]5Tg]5UH13U7i4TWa2TGY2T7U1TGU3TGU3TWY6TGY2TGY2TGY2TGY2TGY2TGY2TGY2TGY2
TGY2T7U1SgQ0SgQ0SgQ0SgQ0T7U1TGY2T7Y0T7Y0SgToSgToSgToSWPnSWPnSWPnT7Y0SgToSWPnSWPn
SWPnSWPnSgToT7Y0SGHnSGHnSGHnSGHnSGHnSGHnSGHnSGHnSgQ0SgQ0SgQ0SgQ0SgQ0SgQ0SgQ0SgQ0
S7HlS7HlS7HlS7HlS7HlS7HlS7HlS7HlT7DlT7DlT7DlT7DlT7DlT7DlT7DlT7DlSg@kT7DlTGHmTWLn
TWLnTGHmT7DlSg@kTGLkT7HjT7HjSgDiSgDiT7HjTGLkTWPlSg@kSg@kT7DlT7DlTGHmTGHmTWLnTWLn
TGLkTGLkTGLkTGLkTGLkTGLkTGLkTGLkTGHmTGHmTGHmTGHmTGHmTGHmTGHmTGHmS7LjS7LjSWHjSWHj
T7HjT7HjTWHjTWHjS7LjS7LjSWHjSWHjT7HjT7HjTWHjTWHjTGLkTGLkTGLkTGLkTGLkTGLkTGLkTGLk
TgTmTgTmTgTmTgTmTWPlTWPlTWPlTWPlTWPlTWPlTWPlTWPlTgTmTgTmTgTmU7XnTgTmTgTmTgTmTgTm
TgTmTgTmTgTmTgTmTGLkTWPlTWPlTgTmTgTmU7XnU7XnU7XnTGLkTGLkTGLkTWPlTgTmU7XnU7XnUG/o
TgTmTgTmTgTmTgTmTgTmTgTmTgTmTgTmTGLkTGLkTGLkTGLkTGLkTGLkTGLkTGLkTGLkTGLkTGLkTGLk
TWPlTWPlTWPlTWPlSGPkSGPkT7PlT7PlTgTmTgTmUWXnUWXnTgPoTgPoTgPoTgPoTgPoTgPoTgPoTgPo
U7XnTgTmTWPlTWPlTWPlTWPlTgTmU7XnTgPoTgPoTgPoTgPoTgPoTgPoTgPoTgPoUGY1UGY1UGY1UGY1
UGY1UGY1UGY1UGY1U7XnU7XnU7XnU7XnUG/oUge1V7i2VGm3UGY1UGY1UW]2UW]2UW]2UW]2Uga3Uga3
UGY1UGY1UGY1UGY1UGY1UGY1UGY1UGY1UGY1UW]2UW]2Uga3Uga3UW]2UW]2UGY1UG`nUG`nUG`nUG`n
UG`nUG`nUG`nUG`nUga3Uga3Uga3Uga3Uga3Uga3002OS6^OS6^NRV^MRFZMR6bNRFjORVnORVnNRFfN
RFfNRFfORVjPRfnPRfnQS72QS72ORVjORVjORVjORVjORVjORVjORVjORVjORVnORVnORVnNRFjNRFjN
RFjMR6fMR6fMR6bMR6bMR6bMR6bMR6bMR6bMR6bMR6bLQf^LQf^MR6bMR6bMR6bNRFfNRFfNRFfJR6^J
R6^JR6^JR6^JR6^JR6^JR6^JR6^HQVVHQVVHQVVIQfZIQfZIQfZJR6^JR6^JQfbJQfbJQfbJQfbJQfbJ
QfbJQfbJQfbJQfbJQfbJQfbJQfbJQfbJQfbJQfbJQfbHQFZHQFZHQFZIQV^IQV^IQV^JQfbJQfbIQV^I
QV^IQV^IQV^IQV^IQV^IQV^IQV^KQVZKQVZKQVZKQVZKQVZKQVZKQVZKQVZJQVNJQVNJQVNJQVNJQVNJ
QVNJQVNJQVNFPV>GPfBHQ6FIQFJJQVNJQVNJQVNIQFJIQFJIQFJIQFJIQFJIQFJIQFJIQFJIQFJHQ6FH
Q6FHQ6FHQ6FHQ6FHQ6FHQ6FHQ6FFPV>GPfBGPfBGPfBHQ6FHQ6FHQ6FIQFJFPf2FPf2GQ66GQ66HQF:H
QF:IQV>IQV>HQF:HQF:HQF:HQF:HQF:HQF:HQF:HQF:GPV>HPfBHPfBHPfBIQ6FIQ6FIQ6FJQFJIQ6FI
Q6FIQ6FIQ6FIQ6FIQ6FIQ6FIQ6FEQE^EQ5fEPejFPf2GQ6>GPfBHPfNHPfNFPUnFPUnFPUnFPUnFPUnF
PUnFPUnFPUnJPUjJPUjJPUjJPUjJPUjJPUjJPUjJPUjDOENHPE^LQEnLQEnJPefHPE^IPUbKQ5jHPE^H
PE^HPE^HPE^HPE^HPE^HPE^HPE^GPERGPERHPUVIPeZJQ5^JQ5^KQEbKQEbEOeJFP5NHPUVIPeZJQ5^J
Q5^IPeZHPUVEP5>EP5>FPEBGPUFGPUFFPEBEP5>EP5>FPU>FPU>FPU>FPU>FPU>FPU>FPU>FPU>EP5>E
P5>EP5>EP5>EP5>EP5>EP5>EP5>DOe:DOe:DOe:DOe:DOe:DOe:DOe:DOe:FOe6FOe6FOe6FOe6FOe6F
Oe6FOe6FOe6CODfDOTjEOdnEOdnEOdnEOdnDOTjCODfCODfCODfCODfCODfCODfCODfCODfCODfCODfC
ODfCODfBO4bBO4bBO4bANd^ANd^ANd^ANd^BO4bBO4bBO4bCODfCODfCODf@NTZ@NTZ@NTZ@NTZ@NTZA
Nd^CODfDOTj@NTZ@NTZ@NTZ@NTZ@NTZ@NTZ@NTZ@NTZ@NdR@NdR@NdR@NdR@NdR@NdR@NdR@NdRANTZA
NTZANTZANTZANTZANTZANTZANTZAMTBBMdFDNDNENTRFNdVENTRDNDNCN4J@NDN@NDN@NDNANTRANTRA
NTRBNdVBNdVANTRANTRANTRBNdVBNdVCO4ZCO4ZCO4ZCOTNCOTNCOTNCOTNCOTNCOTNCOTNCOTNBNdVB
NdVBNdVBNdVBNdVBNdVBNdVBNdVAO4FAO4FAO4FAO4FAO4FAO4FAO4FAO4FBODJBODJBODJBODJBODJB
ODJBODJBODJAO4FBODJCOTNDOdRDOdRBODJ@NdB?NT>@NdBAO4FBODJBODJ@NdB?NT>AO4FBODJ@NdB@
NdB@NdB@NdB@NdB@NdB@NdB@NdB@NdB@NdB@NdBAO4FAO4FAO4FBODJBODJAODBAODBAODB@NdB?NDF?
NDF>MdF>MdFAND>AND>AND>BNTBBNTBBNTBCNdFCNdFBNd>BNd>BNd>BNd>BNd>BNd>BNd>BNd>@NT2@
NT2ANd6ANd6BO4:COD>COD>COD>>MT:?Md>@N4BBNTJCNdNDO4RDO4RDO4REP4>DOTBBO4:@ND6@ND6@
N4:AND>BNTJANT:ANT:ANT:ANT:ANT:ANT:ANT:ANT:ANT:@ND6?N42?N42?N42?N42@ND6ANT:>N3j>
N3j>N3j=Mcf=Mcf=Mcf<MSb<MSb?NCn?NCn>N3j=Mcf=Mcf>N3j?NCn?NCn=MSj=MSj=MSj=MSj=MSj=
MSj=MSj=MSj>Mcn>Mcn>Mcn>Mcn>Mcn>Mcn>Mcn>Mcn<MSb<MSb<MSb<MSb<MSb<MSb<MSb<MSb@MCb@
MCb@MCb@MCb@MCb@MCb@MCb@MCb>LcZ?M3^AMSfBMcjBMcjAMSf?M3^>LcZ@MSZ?MCV?MCV?MCV?MCVA
Mc^BN3bCNCf>LcZ?M3^?M3^@MCb@MCbAMSfBMcjBMcjAMc^AMc^AMc^AMc^AMc^AMc^AMc^AMc^AMSfA
MSfAMSfAMSfAMSfAMSfAMSfAMSf<McZ<McZ>MSZ>MSZ@MSZ@MSZBMSZBMSZ<McZ<McZ>MSZ>MSZ@MSZ@
MSZBMSZBMSZAMc^AMc^AMc^AMc^AMc^AMc^AMc^AMc^DNSjDNSjCNCfCNCfBN3bAMc^AMc^AMc^AMc^B
N3bBN3bBN3bCNCfCNCfCNCfCNCfAMc^AMc^AMc^AMc^AMc^AMc^AMc^AMc^@MSZ@MSZ@MSZAMc^BN3bB
N3bCNCfCNCf?MCV@MSZAMc^BN3bCNCfDNSjENcnFO42BN3bBN3bBN3bBN3bBN3bBN3bBN3bBN3bAMc^A
Mc^AMc^AMc^AMc^AMc^AMc^AMc^@MSZ@MSZ@MSZAMc^BN3bBN3bCNCfCNCf=N3^=N3^?Mc^@N3bCNCfC
NCfFNSjFNSjBMcjBMcjBMcjBMcjBMcjBMcjBMcjBMcjCNCfCNCfBN3bAMc^AMc^BN3bCNCfCNCfBMcjB
McjBMcjBMcjBMcjBMcjBMcjBMcjENT6ENT6ENT6ENT6ENT6ENT6ENT6ENT6DNSjDNSjDNSjDNSjENcnG
OD6IOd>IOd>DND2DND2ENT6ENT6FNd:GO4>GO4>GO4>ENT6ENT6ENT6ENT6ENT6ENT6ENT6ENT6DND2E
NT6GO4>HODBHODBGO4>ENT6DND2EO3jEO3jEO3jEO3jDNcfDNcfDNcfDNcfGO4>GO4>GO4>GO4>GO4>G
O4<00280000<0000ooooobD0000<00001`00P2D0000<00000000P300000<00003`00P4/0000@0000
000000D0000X000030000040000>000050@00001000@000000000000E@000:X0003o000T000095D0
02BZ000To`00B@0004UE0019ZP00BOl006d0001]E@00KJX006go002B0000TUD009:Z002Bo`00]P00
0;IE002fZP00]_l00=/0003KE@00fjX00=_o003o0000oeD00?nZ003oo`0T0000901E02@0ZP0T0?l0
92@002@TE@0T9:X092Co02A9000TBED094VZ02A9o`0TK@0096eE02A]ZP0TKOl0998002BBE@0TTZX0
99;o02Bf000T]UD09;JZ02Bfo`0Tf`009=]E02CKZP0Tfol09?l002CoE@0TojX09?oo04T0001905D0
B@2Z04T0o`199000BBAE04TTZP199?l0BDT004U9E@19BJX0BDWo04U]0019KED0BFfZ04U]o`19TP00
BI9E04VBZP19T_l0BKH004VfE@19]ZX0BKKo04WK0019feD0BM^Z04WKo`19o`00BOmE04WoZP19ool0
K@0006d0E@1]0:X0K@3o06dT001]95D0KBBZ06dTo`1]B@00KDUE06e9ZP1]BOl0KFd006e]E@1]KJX0
KFgo06fB001]TUD0KI:Z06fBo`1]]P00KKIE06ffZP1]]_l0KM/006gKE@1]fjX0KM_o06go001]oeD0
KOnZ06goo`2B0000TP1E0980ZP2B0?l0TR@0098TE@2B9:X0TRCo0999002BBED0TTVZ0999o`2BK@00
TVeE099]ZP2BKOl0TY8009:BE@2BTZX0TY;o09:f002B]UD0T[JZ09:fo`2Bf`00T]]E09;KZP2Bfol0
T_l009;oE@2BojX0T_oo0;H0002f05D0]P2Z0;H0o`2f9000]RAE0;HTZP2f9?l0]TT00;I9E@2fBJX0
]TWo0;I]002fKED0]VfZ0;I]o`2fTP00]Y9E0;JBZP2fT_l0][H00;JfE@2f]ZX0][Ko0;KK002ffeD0
]]^Z0;KKo`2fo`00]_mE0;KoZP2fool0f`000=/0E@3K0:X0f`3o0=/T003K95D0fbBZ0=/To`3KB@00
fdUE0=]9ZP3KBOl0ffd00=]]E@3KKJX0ffgo0=^B003KTUD0fi:Z0=^Bo`3K]P00fkIE0=^fZP3K]_l0
fm/00=_KE@3KfjX0fm_o0=_o003KoeD0fonZ0=_oo`3o0000o`1E0?l0ZP3o0?l0ob@00?lTE@3o9:X0
obCo0?m9003oBED0odVZ0?m9o`3oK@00ofeE0?m]ZP3oKOl0oi800?nBE@3oTZX0oi;o0?nf003o]UD0
okJZ0?nfo`3of`00om]E0?oKZP3ofol0ool00?ooE@3oojX0oooo01@4
\>"], "Graphics",
  ImageSize->{461.5, 212.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["2 Nomenclature & Data", "Section"],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell["\<\
Physical data necessary to formulate the model is defined in this section. \
Some of it is obtained from the reports noted above. Missing data was \
estimated, sometimes from figures in those reports and in some cases simply \
educated (?) guesses.\
\>", "Text"],

Cell[BoxData[{
    \(\(Off[General::spell];\)\), "\n", 
    \(\(Off[General::spell1];\)\)}], "Input",
  CellLabel->"In[3]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Notation", "Subsection"],

Cell[TextData[{
  "\n   hgbw = height of c.g. above ground, normalized by wing span  \n   M = \
mach number [0.24   2.6]\n   alpha = angle of attack (rad)               \
(deg) [-4.0   32.0]\n   beta = angle of sideslip (rad)              (deg) \
[-32.0  32.0]\n   qbar = dynamic pressure (lb/ft2) [0.0  1200.0] (V approx \
1000 ft/sec, M approx .9  @ sea level)\n   V = airspeed (ft/sec)\n   p = roll \
rate (rad/sec)\n   q = pitch rate (rad/sec)\n   r = yaw rate (rad/sec)\n   \n \
  T = Thrust\n   delle = leading edge flap deflection (deg)   [0.0 50.0]\n   \
delte = trailing edge flap deflection (deg) [-40.0 40.0]\n   dels = \
horizontal tail deflection (deg) [-15.0 15.0]\n   dele = elevator deflection \
(deg) [-30.0 30.0]\n   delr = rudder deflection\n\n    dsp1 = spoiler-slot \
deflector #1 (deg) [0.0 60.0]\n    dsp2 = spoiler-slot deflector #2 (deg) \
[0.0 60.0]\n    dsp3 = spoiler-slot deflector #3 (deg) [0.0 60.0]\n    dsp4 = \
spoiler-slot deflector #4 (deg) [0.0 60.0]\n    dgear = landing gear \
deflection (deg) [0.0 90.0]\n    \nParameters:\nltot - total lebgth 325 ft \n\
l - nominal distance from wing/fuselage aerodynamic center to horizontal tail \
aerodynamic center (reference length) 160 ft.\nlv - horizontal distance from \
wing/fuselage aerodynamic center to vertical tail aerodynamic center 150 ft.\n\
lt - vertical distance engine thrust cl to cm 18.245 ft.\nzv - vertical \
distance from wing/fuselage aerodynamic center to tail aerodynamic center *** \
ft.\nb or span - wing span 130 ft\ncbar - mean aerodynamic chord 86 ft.\nS - \
horizontal tail/wing/fuselage surface area (reference area) 6748.48 ft^2\n\n\
",
  StyleBox["Variations in Xcg between Forward (47.3 %, kap=-.027) and Aft \
(56.6 %, kap=.066)",
    FontFamily->"Times New Roman"],
  "\ngw = gross weight (lbf) [280000.0 650000.0]\nrho=air density (slug/ft3) \
2.3769E-3 at sea level\nIxx=3.18526*^6, Iyy=4.39539*^7,  Izz=4.66537*^7,  \
Ixz=1.55467*^5"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[" Data", "Subsection"],

Cell["Rigid airframe inertial data", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InertiaData\  = \ {Ix \[Rule] 9496, \ Iy \[Rule] 55814, \ 
        Iz \[Rule] 63100, Ixz \[Rule] 982, 
        m \[Rule] 20500*\ 0.03108}\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({Ix \[Rule] 9496, Iy \[Rule] 55814, Iz \[Rule] 63100, Ixz \[Rule] 982, 
      m \[Rule] 637.14`}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["Geometric data:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(AeroData\)\(=\)\(\ \)\({S \[Rule] 1.3333\ *\ 15\ *\ 15, \ 
        b \[Rule] 24*15/12, \ cbar \[Rule] 9.056*15/12, \ lt \[Rule] 0, 
        kappa \[Rule] kappa}\)\( (*kappa : \ 
          the\ offset\ of\ the\ c . g\ from\ the\ reference\ c . 
              g\[IndentingNewLine]\ \(lt : \ 
              offset\ of\ thrust\ from\ origin\ of\ body\ frame\ axes\)*) \
\)\)\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({S \[Rule] 299.99249999999995`, b \[Rule] 30, 
      cbar \[Rule] 11.319999999999999`, lt \[Rule] 0, 
      kappa \[Rule] kappa}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Data = \(\({\[Rho] \[Rule] rho, g -> 32.1302, 
          xcg \[Rule] \ 0\ *\ cbar + \ kappa, 
          xcgref \[Rule] 0\ *\ cbar}\)\(/.\)\(AeroData\)\(\ \)\( (*\[Rho], 
          g\ values\ are\ those\ at\ sea\ level*) \)\)\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \({\[Rho] \[Rule] rho, g \[Rule] 32.1302`, xcg \[Rule] kappa, 
      xcgref \[Rule] 0}\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3 Aerodynamics: Lift, Drag & Moment Coefficents", "Section"],

Cell["Introduction", "Subsection"],

Cell[CellGroupData[{

Cell["Aerodynamic Coefficients", "Subsection"],

Cell[BoxData[{
    \(\(Cx[alpha_\ , dele_] := \ 
        a0\  + \ a1\ alpha\  + \ a2\ dele\^2\  + \ a3\ dele\  + \ 
          a4\ alpha\ dele\  + \ a5\ alpha\^2\  + \ 
          a6\ alpha\^3;\)\), "\[IndentingNewLine]", 
    \(\(Cxq[alpha_]\  := \ 
        b0\  + \ b1\ alpha\  + \ b2\ alpha\^2\  + \ b3\ alpha\^3\  + \ 
          b4\ alpha\^4;\)\), "\[IndentingNewLine]", 
    \(\(Cy[beta_, \ dela_, delr_] := \ 
        c0\ beta\ \  + \ c1\ dela\  + \ 
          c2\ delr;\)\), "\[IndentingNewLine]", 
    \(\(Cyp[alpha_] := \ 
        d0\  + \ d1\ alpha\  + \ d2\ alpha\^2\  + \ 
          d3\ alpha\^3;\)\), "\[IndentingNewLine]", 
    \(\(Cyr[alpha_] := \ 
        e0\  + \ e1\ alpha\  + \ e2\ alpha\^2\  + \ 
          e3\ alpha\^3;\)\), "\[IndentingNewLine]", 
    \(\(Cz[alpha_, \ beta_, \ 
          dele_] := \((f0\  + \ f1\ alpha\  + \ f2\ alpha\^2\  + \ 
                f3\ alpha\^3\  + \ f4\ alpha\^4)\) \((1 - \ beta\^2)\)\  + \ 
          f5\ dele;\)\), "\[IndentingNewLine]", 
    \(\(Czq[alpha_] := 
        g0\  + \ g1\ alpha\  + \ g2\ alpha\^2\  + \ g3\ alpha\^3\  + \ 
          g4\ alpha\^4;\)\), "\[IndentingNewLine]", 
    \(\(Cl[alpha_, beta_] := 
        h0\ beta\  + \ h1\ alpha\ beta\  + \ h2\ alpha\^2\ beta\  + \ 
          h3\ beta\^2\  + \ h4\ alpha\ beta\^2\  + \ h5\ alpha\^3\ beta\  + \ 
          h6\ alpha\^4\ beta\  + \ 
          h7\ alpha\^\(\(2\)\(\ \)\)\ beta\^2\ ;\)\), "\[IndentingNewLine]", 
    \(\(Clp[alpha_]\  := \ 
        i0\  + \ i1\ alpha\  + \ i2\ alpha\^2\  + \ 
          i3\ alpha\^3;\)\), "\[IndentingNewLine]", 
    \(\(Clr[alpha_] := 
        j0\  + \ j1\ alpha\  + \ j2\ alpha\^2\  + \ j3\ alpha\^3\  + \ 
          j4\ alpha\^4\ ;\)\), "\[IndentingNewLine]", 
    \(\(Cldela[alpha_, beta_] := \ 
        k0\  + \ k1\ alpha\  + \ k2\ beta\  + \ k3\ alpha\^2\  + \ 
          k4\ alpha\ beta\  + \ k5\ alpha\^2\ beta\  + \ 
          k6\ alpha\^3\ ;\)\), "\[IndentingNewLine]", 
    \(\(Cldelr[alpha_, beta_] := 
        l0\  + \ l1\ alpha\  + \ l2\ beta\ \  + \ l3\ alpha\ beta\  + \ 
          l4\ alpha\^2\ beta\  + \ l5\ alpha\^3\ \ beta\  + \ 
          l6\ beta\^2;\)\), "\[IndentingNewLine]", 
    \(\(Cm[alpha_, dele_]\  := \ 
        m0\  + \ m1\ alpha\  + \ m2\ dele\  + \ m3\ alpha\ dele\  + \ 
          m4\ dele\^2\  + \ m5\ alpha\^2\ dele\  + \ m6\ dele\^3\  + \ 
          m7\ alpha\ dele\^2\ ;\)\), "\[IndentingNewLine]", 
    \(\(Cmq[alpha_] := \ 
        n0\  + \ n1\ alpha\  + \ n2\ alpha\^2\  + \ n3\ alpha\^3\  + \ 
          n4\ alpha\^4\  + \ n5\ \ alpha\^5\ ;\)\), "\[IndentingNewLine]", 
    \(\(Cn[alpha_, \ beta_] := \ 
        o0\ beta\  + o1\ alpha\ beta\  + \ \ o2\ beta\^2\  + \ 
          o3\ alpha\ beta\^2\  + \ o4\ alpha\^2\ beta\ \  + 
          o5\ alpha\^\(\(2\)\(\ \)\)\ beta\^2\  + \ 
          o6\ alpha\^3\ beta;\)\), "\[IndentingNewLine]", 
    \(\(Cnp[alpha_] := \ 
        p0\  + p1\ alpha\  + \ p2\ alpha\^2\  + \ p3\ alpha\^3\  + \ 
          p4\ alpha\^4\ ;\)\), "\[IndentingNewLine]", 
    \(Cnr[alpha_] := \ q0\  + q1\ alpha\  + \ q2\ alpha\^2; 
    Cndela[alpha_, beta_] := \ 
      r0\  + \ r1\ alpha\  + \ r2\ beta\  + \ r3\ alpha\ beta\  + \ 
        r4\ alpha\^2\ beta\  + \ r5\ alpha\^3\ beta\  + \ r6\ alpha\^2\  + \ 
        r7\ alpha\^\(\(3\)\(\ \)\) + \ r8\ beta\^3\  + \ 
        r9\ alpha\ beta\^3\ ;\), "\[IndentingNewLine]", 
    \(\(Cndelr[alpha_, beta_] := \ 
        s0\  + \ s1\ alpha\  + \ s2\ beta\  + \ s3\ alpha\ beta\  + \ 
          s4\ alpha\^2\ beta\  + \ s5\ alpha\^2;\)\)}], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(ptilda\  = \ \(p\ b\)\/\(2\ V\); \ 
    qtilda\  = \ \(q\ cbar\)\/\(2\ V\); \ 
    rtilda\  = \(r\ b\)\/\(2\ V\);\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[{
    \(\(CX[alpha_, dele_] := 
        Evaluate[
          Cx[alpha\ , dele]\  + \ 
            Cxq[alpha]\ qtilda]\ ;\)\), "\[IndentingNewLine]", 
    \(\(CY[beta_, dela_, delr_, alpha_] := 
        Evaluate[
          Cy[beta, \ dela, delr]\  + \ Cyp[alpha]\ ptilda\  + \ 
            Cyr[alpha]\ rtilda];\)\), "\[IndentingNewLine]", 
    \(\(CZ[alpha_, beta_, dele_] := \ 
        Evaluate[
          Cz[alpha, \ beta, \ dele]\ \  + \ 
            Czq[alpha]\ qtilda];\)\), "\[IndentingNewLine]", 
    \(\(CL[alpha_, beta_, dela_, delr_]\  := 
        Evaluate[
          Cl[alpha, beta]\  + \ Clp[alpha]\ ptilda\  + \ 
            Clr[alpha]\ rtilda\  + \ Cldela[alpha, beta]\ dela\  + \ 
            Cldelr[alpha, beta]\ delr];\)\ \), "\[IndentingNewLine]", 
    \(\(CM[alpha_, dele_, beta_] := \ 
        Evaluate[
          Cm[alpha, dele]\  + \ Cmq[alpha]\ qtilda\  + \ 
            CZ[alpha, \ beta, \ 
                dele]\ \ \((xcgref\  - \ 
                  xcg)\)];\)\), "\[IndentingNewLine]", 
    \(\(CN[alpha_, beta_, dela_, delr_] := 
        Evaluate[
          Cn[alpha, \ beta]\  + \ Cnp[alpha]\ ptilda\  + \ 
            Cnr[alpha]\ rtilda\  + \ Cndela[alpha, beta]\ dela + \ 
            Cndelr[alpha, beta]\ delr - 
            CY[beta, dela, delr, 
                alpha]\ \ \((xcgref\  - \ xcg)\)\ cbar\/b\ ];\)\)}], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\(ParameterValues = {a0\  \[Rule] \(-1.943367\)*10^\(-2\)\ , 
          h0\  \[Rule] \(-1.058583\)*10^\(-1\)\ , 
          n0 -> \ \(-5.159153\)*10^0, \na1\  -> 2.136104*10^\(-1\)\ , 
          h1\  \[Rule] \(-5.776677\)*10^\(-1\), \ 
          n1\  \[Rule] \(-3.554716\)*10^0, \n
          a2 -> \ \(-2.903457\)*10^\(-1\)\ , 
          h2\  \[Rule] \(-1.672435\)*10^\(-2\)\ , 
          n2 -> \ \(-3.598636\)*10^1, \n
          a3\  \[Rule] \(-3.348641\)*10^\(-3\), \ 
          h3\  -> 1.357256*10^\(-1\)\ , n3 -> \ 2.247355*10^2, \n
          a4 -> \ \(-2.060504\)*10^\(-1\)\ , h4 -> \ 2.172952*10^\(-1\)\ , 
          n4 -> \ \(-4.120991\)*10^2, \na5 -> \ 6.988016*10^\(-1\), \ 
          h5\  -> 3.464156*10^0, \ n5 -> \ 2.411750*10^2, \n
          a6\  \[Rule] \(-9.035381\)*10^\(-01\)\ , 
          h6 -> \ \(-2.835451\)*10^0\ , o0 -> \ 2.993363*10^\(-1\), \n
          b0\  -> 4.833383*10^\(-1\)\ , h7 -> \ \(-1.098104\)*10^0\ , 
          o1 -> \ 6.594004*10^\(-2\), \nb1 -> \ 8.644627*10^0, \ 
          i0 -> \ \(-4.126806\)*10^\(-1\)\ , 
          o2 -> \ \(-2.003125\)*10^\(-1\), \nb2 -> \ 1.131098*10^1, \ 
          i1 -> \ \(-1.189974\)*10^\(-1\), \ 
          o3 -> \ \(-6.233977\)*10^\(-2\), \n
          b3\  \[Rule] \(-7.422961\)*10^1\ , i2 -> \ 1.247721*10^0\ , 
          o4 -> \ \(-2.107885\)*10^0, \nb4\  -> 6.075776*10^1, \ 
          i3 -> \ \(-7.391132\)*10^\(-1\), \ o5 -> \ 2.141420*10^0, \n
          c0\  \[Rule] \(-1.145916\)*10^0, \ j0 -> \ 6.250437*10^\(-2\)\ , 
          o6 -> \ 8.476901*10^\(-1\), \nc1 -> \ 6.016057*10^\(-2\)\ , 
          j1 -> \ 6.067723*10^\(-1\), \ p0 -> \ 2.677652*10^\(-2\), \n
          c2\  -> 1.642479*10^\(-1\)\ , j2 -> \ \(-1.101964\)*10^0\ , 
          p1\  \[Rule] \(-3.298246\)*10^\(-1\), \n
          d0 -> \ \(-1.006733\)*10^\(-1\), \ j3 -> \ 9.100087*10^0, \ 
          p2\  -> 1.926178*10^\(-1\), \nd1\  -> 8.679799*10^\(-1\), \ 
          j4 -> \ \(-1.192672\)*10^1, \ p3 -> \ 4.013325*10^0, \n
          d2 -> \ 4.260586*10^0\ , k0 -> \ \(-1.463144\)*10^\(-1\), \ 
          p4 -> \ \(-4.404302\)*10^0, \nd3 -> \ \(-6.923267\)*10^0, \ 
          k1 -> \ \(-4.073901\)*10^\(-2\)\ , 
          q0 -> \ \(-3.698756\)*10^\(-1\), \ne0\  -> 8.071648*10^\(-1\), \ 
          k2\  -> 3.253159*10^\(-2\), \ 
          q1\  \[Rule] \(-1.167551\)*10^\(-1\), \n
          e1\  -> 1.189633*10^\(-1\)\ , k3 -> \ 4.851209*10^\(-1\), \ 
          q2 -> \ \(-7.641297\)*10^\(-1\), \ne2 -> \ 4.177702*10^0, \ 
          k4\  -> 2.978850*10^\(-1\), \ r0 -> \ \(-3.348717\)*10^\(-2\), \n
          e3\  \[Rule] \(-9.162236\)*10^0\ , 
          k5 -> \ \(-3.746393\)*10^\(-1\), \ r1 -> \ 4.276655*10^\(-2\), \n
          f0 -> \ \(-1.378278\)*10^\(-1\)\ , 
          k6 -> \ \(-3.213068\)*10^\(-1\), \ r2\  -> 6.573646*10^\(-3\), \n
          f1\  \[Rule] \(-4.211369\)*10^0\ , l0 -> \ 2.635729*10^\(-2\), \ 
          r3 -> \ 3.535831*10^\(-1\), \nf2 -> \ 4.775187*10^0, \ 
          l1 -> \ \(-2.192910\)*10^\(-2\)\ , 
          r4\  \[Rule] \(-1.373308\)*10^0, \nf3 -> \ \(-1.026225\)*10^1\ , 
          l2 -> \ \(-3.152901\)*10^\(-3\)\ , r5 -> \ 1.237582*10^0, \n
          f4 -> \ 8.399763*10^0, \ l3 -> \ \(-5.817803\)*10^\(-2\)\ , 
          r6\  -> 2.302543*10^\(-1\), \n
          f5\  \[Rule] \(-4.354000\)*10^\(-1\), \ 
          l4\  -> 4.516159*10^\(-1\), \ 
          r7\  \[Rule] \(-2.512876\)*10^\(-1\), \n
          g0 -> \ \(-3.054956\)*10^1\ , l5 -> \ \(-4.928702\)*10^\(-1\), \ 
          r8 -> \ 1.588105 - 1, \ng1\  \[Rule] \(-4.132305\)*10^1, \ 
          l6 -> \ \(-1.579864\)*10^\(-2\)\ , 
          r9 -> \ \(-5.199526\)*10^\(-1\), \ng2\  -> 3.292788*10^2, \ 
          m0 -> \ \(-2.029370\)*10^\(-2\), \ 
          s0\  \[Rule] \(-8.115894\)*10^\(-2\), \n
          g3\  \[Rule] \(-6.848038\)*10^2, \ m1 -> \ 4.660702*10^\(-2\)\ , 
          s1\  \[Rule] \(-1.156580\)*10^\(-2\), \ng4\  -> 4.080244*10^2, \ 
          m2 -> \ \(-6.012308\)*10^\(-1\), \ s2\  -> 2.514167*10^\(-2\), \n
          m3\  \[Rule] \(-8.062977\)*10^\(-2\)\ , 
          s3 -> \ 2.038748*10^\(-1\), \nm4 -> \ 8.320429*10^\(-2\)\ , 
          s4 -> \ \(-3.337476\)*10^\(-1\), \nm5\  -> 5.018538*10^\(-1\)\ , 
          s5\  -> 1.004297*10^\(-1\), \nm6 -> \ 6.378864*10^\(-1\), \n
          m7\  -> 4.226356*10^\(-1\)};\)\)], "Input",
  CellLabel->"In[33]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Body Forces & Moments", "Subsection"],

Cell[BoxData[
    \(\(AeroRules = \ 
        Inner[Rule, {X, Y, Z, L, M, N}, 
          1\/2\ \[Rho]\ V\^2\ S\ {CX[alpha, dele], 
                CY[beta, dela, delr, alpha], CZ[alpha, beta, dele], 
                CL[alpha, beta, dela, delr], CM[alpha, dele, beta], 
                CN[alpha, beta, dela, delr]} /. ParameterValues, 
          List];\)\)], "Input",
  CellLabel->"In[34]:="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4 Basic Equations", "Section",
  Evaluatable->False],

Cell["Introduction", "Subsection"],

Cell[CellGroupData[{

Cell["Dynamics", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(r1 = {6}; H1 = IdentityMatrix[6];\), "\n", 
    \(q1 = {phi, theta, psi, x, y, z}; p1 = {p, q, r, u, v, w};\), "\n", 
    \(\(JointLst = {{r1, H1, q1, p1}};\)\), "\n", 
    \(\({JV, JX, JH} = Joints[JointLst];\)\)}], "Input",
  CellLabel->"In[35]:=",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell[BoxData[
    \("  *** Dynamics successfully loaded ***"\)], "Print",
  CellLabel->"From In[35]:="],

Cell[BoxData[
    \("Computing joint 1 kinematics"\)], "Print",
  CellLabel->"From In[35]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(JL = \(JX[\([1]\)]\)[\([{1, 2, 3}, {1, 2, 3}]\)]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({{Cos[psi]\ Cos[theta], \(-Cos[phi]\)\ Sin[psi] + 
          Cos[psi]\ Sin[phi]\ Sin[theta], 
        Sin[phi]\ Sin[psi] + 
          Cos[phi]\ Cos[psi]\ Sin[theta]}, {Cos[theta]\ Sin[psi], 
        Cos[phi]\ Cos[psi] + 
          Sin[phi]\ Sin[psi]\ Sin[theta], \(-Cos[psi]\)\ Sin[phi] + 
          Cos[phi]\ Sin[psi]\ Sin[theta]}, {\(-Sin[theta]\), 
        Cos[theta]\ Sin[phi], Cos[phi]\ Cos[theta]}}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[BoxData[{
    \(com1 = {xcg, 0, 0}; mass1 = m; out1 = {1, {xcgref, 0, 0}};\), "\n", 
    \(\(Inertia1 = {{Ix, 0, \(-Ixz\)}, {0, Iy, 0}, {\(-Ixz\), 0, 
            Iz}};\)\  (*Inertia\ about\ xcgref*) \), "\n", 
    \(\(Inertia2 = RgdBdyInrShift[Inertia1, {xcgref - xcg, 0, 0}, m];\)\  (*\ 
      Inertia\ about\ xcg\ *) \), "\n", 
    \(\(BodyLst = {{com1, {out1}, mass1, Inertia2}};\)\), "\n", 
    \(\(TreeLst = {{{1, 1}}};\)\)}], "Input",
  CellLabel->"In[40]:=",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(T1 = L; T2 = M + \ lt\ T\ ; T3 = N; F1 = X + T; F2 = Y; 
    F3 = Z;\), "\n", 
    \(PE = 0; Q = {T1, T2, T3, F1, F2, F3};\), "\n", 
    \(\({JV, JX, JH, MM, Cp, Fp, pp, qq} = 
        CreateModel[JointLst, BodyLst, TreeLst, \(-g\), PE, Q, JV, JX, 
          JH];\)\)}], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \("Computing Potential Functions"\)], "Print",
  CellLabel->"From In[45]:="],

Cell[BoxData[
    \("Computing Inertia Matrix"\)], "Print",
  CellLabel->"From In[45]:="],

Cell[BoxData[
    \("Computing Poincare Function"\)], "Print",
  CellLabel->"From In[45]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MM\  // MatrixForm\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"Ix", "0", \(-Ixz\), "0", "0", "0"},
            {"0", \(Iy + m\ xcg\^2 + m\ \((\(-xcg\) + xcgref)\)\^2\), "0", 
              "0", "0", \(\(-m\)\ xcg\)},
            {\(-Ixz\), 
              "0", \(Iz + m\ xcg\^2 + m\ \((\(-xcg\) + xcgref)\)\^2\), 
              "0", \(m\ xcg\), "0"},
            {"0", "0", "0", "m", "0", "0"},
            {"0", "0", \(m\ xcg\), "0", "m", "0"},
            {"0", \(\(-m\)\ xcg\), "0", "0", "0", "m"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[48]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cp // MatrixForm\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(-Ixz\)\ q\), \(\(-m\)\ v\ xcg - 
                r\ \((Iy + m\ xcg\^2 + 
                      m\ \((\(-xcg\) + xcgref)\)\^2)\)\), \(\(-m\)\ w\ xcg + 
                q\ \((Iz + m\ xcg\^2 + m\ \((\(-xcg\) + xcgref)\)\^2)\)\), 
              "0", \(\(-m\)\ w + m\ q\ xcg\), \(m\ v + m\ r\ xcg\)},
            {\(Ixz\ p + Ix\ r\), \(m\ u\ xcg\), \(\(-Ixz\)\ r - 
                p\ \((Iz + m\ xcg\^2 + 
                      m\ \((\(-xcg\) + xcgref)\)\^2)\)\), \(m\ w\), \(\(-m\)\ \
p\ xcg\), \(\(-m\)\ u\)},
            {\(\(-Ix\)\ q\), \(p\ \((Iy + m\ xcg\^2 + 
                    m\ \((\(-xcg\) + xcgref)\)\^2)\)\), \(Ixz\ q + 
                m\ u\ xcg\), \(\(-m\)\ v\), \(m\ u\), \(\(-m\)\ p\ xcg\)},
            {"0", \(\(-m\)\ q\ xcg\), \(\(-m\)\ r\ xcg\), 
              "0", \(\(-m\)\ r\), \(m\ q\)},
            {"0", \(m\ p\ xcg\), "0", \(m\ r\), "0", \(\(-m\)\ p\)},
            {"0", "0", \(m\ p\ xcg\), \(\(-m\)\ q\), \(m\ p\), "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[49]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Fp // MatrixForm\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-L\)},
            {\(\(-M\) - lt\ T + g\ m\ xcg\ Cos[phi]\ Cos[theta]\)},
            {\(\(-N\) - g\ m\ xcg\ Cos[theta]\ Sin[phi]\)},
            {\(\(-T\) - X + g\ m\ Sin[theta]\)},
            {\(\(-Y\) - g\ m\ Cos[theta]\ Sin[phi]\)},
            {\(\(-Z\) - g\ m\ Cos[phi]\ Cos[theta]\)}
            }], "\[NoBreak]", ")"}],
      MatrixForm[ {
        Times[ -1, L], 
        Plus[ 
          Times[ -1, M], 
          Times[ -1, lt, T], 
          Times[ g, m, xcg, 
            Cos[ phi], 
            Cos[ theta]]], 
        Plus[ 
          Times[ -1, N], 
          Times[ -1, g, m, xcg, 
            Cos[ theta], 
            Sin[ phi]]], 
        Plus[ 
          Times[ -1, T], 
          Times[ -1, X], 
          Times[ g, m, 
            Sin[ theta]]], 
        Plus[ 
          Times[ -1, Y], 
          Times[ -1, g, m, 
            Cos[ theta], 
            Sin[ phi]]], 
        Plus[ 
          Times[ -1, Z], 
          Times[ -1, g, m, 
            Cos[ phi], 
            Cos[ theta]]]}]]], "Output",
  CellLabel->"Out[50]//MatrixForm="]
}, Open  ]],

Cell[BoxData[
    \(\(VarDefs = {V -> \@\(u\^2 + v\^2 + w\^2\), alpha -> ArcTan[w\/u], 
          beta \[Rule] ArcSin[v/\@\(u\^2 + v\^2 + w\^2\)]};\)\)], "Input",
  CellLabel->"In[51]:=",
  PageWidth->Infinity],

Cell[BoxData[{
    \(\(MM = \(MM /. InertiaData\) /. Data\ ;\)\), "\[IndentingNewLine]", 
    \(\(Cp = \(Cp /. InertiaData\) /. Data\ ;\)\), "\[IndentingNewLine]", 
    \(\(Fp = \(\(\(\(Fp /. AeroRules\) /. InertiaData\) /. AeroData\) /. 
            Data\)\  /. VarDefs;\)\)}], "Input",
  CellLabel->"In[52]:=",
  PageWidth->Infinity],

Cell[CellGroupData[{

Cell[BoxData[
    \(MM\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \({{9496, 0, \(-982\), 0, 0, 0}, {0, 55814 + 1274.28`\ kappa\^2, 0, 0, 
        0, \(-637.14`\)\ kappa}, {\(-982\), 0, 63100 + 1274.28`\ kappa\^2, 0, 
        637.14`\ kappa, 0}, {0, 0, 0, 637.14`, 0, 0}, {0, 0, 637.14`\ kappa, 
        0, 637.14`, 0}, {0, \(-637.14`\)\ kappa, 0, 0, 0, 
        637.14`}}\)], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Fp /. {v \[Rule] 0, w \[Rule] 0}\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \({\(-149.99624999999997`\)\ rho\ u\^2\ \((\(-0.1463144`\)\ dela + 
            0.02635729`\ delr - \(6.190209`\ p\)\/\@u\^2 + \
\(0.9375655500000001`\ r\)\/\@u\^2)\), \(-149.99624999999997`\)\ rho\ u\^2\ \
\((\(-0.0202937`\) - 0.6012308`\ dele + 0.08320429000000001`\ dele\^2 + 
              0.6378864`\ dele\^3 - \(29.200805979999995`\ q\)\/\@u\^2 - 
              kappa\ \((\(-0.1378278`\) - 
                    0.4354`\ dele - \(172.91050959999998`\ q\)\/\@u\^2)\))\) \
+ 20471.435628`\ kappa\ Cos[phi]\ Cos[
            theta], \(-149.99624999999997`\)\ rho\ u\^2\ \
\((\(-0.033487170000000004`\)\ dela - 
              0.08115894000000001`\ delr + \(0.4016478`\ p\)\/\@u\^2 - \
\(5.548133999999999`\ r\)\/\@u\^2 + 
              0.3773333333333333`\ kappa\ \((0.06016057`\ dela + 
                    0.1642479`\ delr - \(1.5100995000000002`\ p\)\/\@u\^2 + \
\(12.107472`\ r\)\/\@u\^2)\))\) - 
        20471.435628`\ kappa\ Cos[theta]\ Sin[phi], \(-T\) - 
        149.99624999999997`\ rho\ u\^2\ \((\(-0.01943367`\) - 
              0.0033486410000000003`\ dele - 
              0.2903457`\ dele\^2 + \(2.735694778`\ q\)\/\@u\^2)\) + 
        20471.435628`\ Sin[
            theta], \(-149.99624999999997`\)\ rho\ u\^2\ \((0.06016057`\ dela \
+ 0.1642479`\ delr - \(1.5100995000000002`\ p\)\/\@u\^2 + \(12.107472`\ r\)\/\
\@u\^2)\) - 
        20471.435628`\ Cos[theta]\ Sin[
            phi], \(-149.99624999999997`\)\ rho\ u\^2\ \((\(-0.1378278`\) - 
              0.4354`\ dele - \(172.91050959999998`\ q\)\/\@u\^2)\) - 
        20471.435628`\ Cos[phi]\ Cos[theta]}\)], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cp\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \({{\(-982\)\ q, \(-\((55814 + 1274.28`\ kappa\^2)\)\)\ r - 
          637.14`\ kappa\ v, \((63100 + 1274.28`\ kappa\^2)\)\ q - 
          637.14`\ kappa\ w, 0, 637.14`\ kappa\ q - 637.14`\ w, 
        637.14`\ kappa\ r + 637.14`\ v}, {982\ p + 9496\ r, 
        637.14`\ kappa\ u, \(-\((63100 + 1274.28`\ kappa\^2)\)\)\ p - 982\ r, 
        637.14`\ w, \(-637.14`\)\ kappa\ p, \(-637.14`\)\ u}, {\(-9496\)\ q, \
\((55814 + 1274.28`\ kappa\^2)\)\ p, 
        982\ q + 637.14`\ kappa\ u, \(-637.14`\)\ v, 
        637.14`\ u, \(-637.14`\)\ kappa\ p}, {0, \(-637.14`\)\ kappa\ q, \
\(-637.14`\)\ kappa\ r, 0, \(-637.14`\)\ r, 637.14`\ q}, {0, 
        637.14`\ kappa\ p, 0, 637.14`\ r, 0, \(-637.14`\)\ p}, {0, 0, 
        637.14`\ kappa\ p, \(-637.14`\)\ q, 637.14`\ p, 0}}\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Determining the equilibrium point - straight and level flight\
\>", "Subsection"],

Cell[BoxData[
    \(\(pdot\  = \ Simplify[\(-Cp . pp\) - Fp];\)\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[{
    \(\(a\  = \ Cos[alpha]\ Cos[beta];\)\), "\[IndentingNewLine]", 
    \(\(b\  = \ 
        Sin[phi]\ Sin[beta]\  + \ 
          Cos[phi]\ Sin[alpha]\ Cos[beta];\)\), "\[IndentingNewLine]", 
    \(\(G\  = \ \(\((\((JV[\([1]\)] . pp)\)[\([3]\)])\)\ V\)\/g;\)\)}], \
"Input",
  CellLabel->"In[59]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Constraints\  = \ {Tan[
            theta] - \(a\ b\  + \ Sin[theta - alpha]\ \@\(a\^2\  - \ \
Sin[theta - alpha]\^2\  + \ b\^2\)\)\/\(a\^2\  - \ Sin[theta - alpha]\^2\), \ 
        G\ Cos[beta]\ \((Sin[alpha]\ Tan[theta]\  + \ 
              Cos[alpha]\ Cos[phi])\)}\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \({\(-\(\((Cos[alpha]\ Cos[
                    beta]\ \((Cos[beta]\ Cos[phi]\ Sin[alpha] + 
                      Sin[beta]\ Sin[phi])\) - 
                Sin[alpha - 
                      theta]\ \@\(Cos[alpha]\^2\ Cos[beta]\^2 + \((Cos[beta]\ \
Cos[phi]\ Sin[alpha] + Sin[beta]\ Sin[phi])\)\^2 - Sin[alpha - \
theta]\^2\))\)/\((Cos[alpha]\^2\ Cos[beta]\^2 - 
                Sin[alpha - theta]\^2)\)\)\) + 
        Tan[theta], \(V\ Cos[beta]\ \((r\ Cos[phi]\ Sec[theta] + q\ \
Sec[theta]\ Sin[phi])\)\ \((Cos[alpha]\ Cos[phi] + Sin[alpha]\ \
Tan[theta])\)\)\/g}\)], "Output",
  CellLabel->"Out[62]="]
}, Open  ]],

Cell[BoxData[
    \(\(Constraints\  = \ \(Constraints /. VarDefs\) /. Data;\)\)], "Input",
  CellLabel->"In[63]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(EqlConditions = {p \[Rule] 0, v \[Rule] 0, q \[Rule] 0, r \[Rule] 0, 
          theta \[Rule] 5\ Pi/180, w \[Rule] u\ Tan[5\ Pi/180], 
          phi \[Rule] 0, kappa \[Rule] 0, rho \[Rule] 2.3769/1000} // 
        N\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \({p \[Rule] 0.`, v \[Rule] 0.`, q \[Rule] 0.`, r \[Rule] 0.`, 
      theta \[Rule] 0.08726646259971647`, w \[Rule] 0.08748866352592401`\ u, 
      phi \[Rule] 0.`, kappa \[Rule] 0.`, rho \[Rule] 0.0023769`}\)], "Output",\

  CellLabel->"Out[64]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[Simplify[Constraints /. EqlConditions]]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \({0.`, 0}\)], "Output",
  CellLabel->"Out[65]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eqns = Chop[Expand[pdot /. EqlConditions]]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \({\(-0.052590867762119506`\)\ dela\ u\^2 + 
        0.008781491699679048`\ delr\ u\^2, \(-0.005829441086043877`\)\ u\^2 - 
        0.21714999401296708`\ dele\ u\^2 + 
        0.043141573007877125`\ dele\^2\ u\^2 + 
        0.2291638991818373`\ dele\^3\ u\^2, \(-0.010119710016897154`\)\ dela\ \
u\^2 - 0.029244592065066025`\ delr\ u\^2, \(-1784.203177269212`\) + T + 
        0.001411357199438186`\ u\^2 - 0.007662884878005711`\ dele\ u\^2 - 
        0.10430815380713553`\ dele\^2\ u\^2, 
      0.021612987513453596`\ dela\ u\^2 + 
        0.05900688460583028`\ delr\ u\^2, \(\(20393.53563494006`\)\(\
\[InvisibleSpace]\)\) - 0.1707563629448787`\ u\^2 - 
        0.15641964102663417`\ dele\ u\^2}\)], "Output",
  CellLabel->"Out[66]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reduce[
      Eqns[\([6]\)] \[Equal] 0\  && \ Eqns[\([2]\)] \[Equal] 0, {u, 
        dele}]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(dele == \(-1.0597531811068759`\) && u == \(-2021.5730019223715`\) || 
      dele == \(-1.0597531811068759`\) && u == 2021.5730019223715` || 
      dele == \(-0.026723487822301974`\) && u == \(-349.8965638436902`\) || 
      dele == \(-0.026723487822301974`\) && u == 349.8965638436902` || 
      dele == 0.8982202587271241` && u == \(-255.96915743197343`\) || 
      dele == 0.8982202587271241` && u == 255.96915743197343`\)], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eqns1 = \ 
      Eqns /. {dela \[Rule] 0, delr \[Rule] 0, 
          dele \[Rule] \(-0.026723487822301974`\), 
          u -> 349.8965638436902`}\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \({0, \(-4.028111177944993`*^-12\), 0, \(-1595.463261228444`\) + T, 0, 
      1.0231815394945443`*^-12}\)], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell["\<\
Eql Point
p = 0 , q = 0 , r =0 , u = 349.897 ,  v = 0 , w =  u Tan [5 Degree] , dela =0 \
, delr = 0 , dele = -0.0267235 , T = 1595.46\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EqlPoint\  = \ {p -> 0, q -> 0, r -> 0, u -> 349.8965638436902`, 
          v -> 0, w -> 349.8965638436902`\ \ Tan[5\ Degree], 
          theta \[Rule] 5\ Pi/180\ , phi\  \[Rule] 0\ , \ dela -> 0, 
          delr -> 0, dele -> \(-0.026723487822301974`\), 
          T -> 1595.463261228444`, \ kappa \[Rule] 0, \ 
          rho \[Rule] 2.3769/1000} // N\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \({p \[Rule] 0.`, q \[Rule] 0.`, r \[Rule] 0.`, 
      u \[Rule] 349.8965638436902`, v \[Rule] 0.`, 
      w \[Rule] 30.6119827429976`, theta \[Rule] 0.08726646259971647`, 
      phi \[Rule] 0.`, dela \[Rule] 0.`, delr \[Rule] 0.`, 
      dele \[Rule] \(-0.026723487822301974`\), T \[Rule] 1595.463261228444`, 
      kappa \[Rule] 0.`, rho \[Rule] 0.0023769`}\)], "Output",
  CellLabel->"Out[69]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pdot /. EqlPoint\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \({0.`, \(-3.8333723940640845`*^-12\), 0.`, 0.`, 0.`, 
      3.637978807091713`*^-12}\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Constraints /. EqlPoint\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \({0.`, 0.`}\)], "Output",
  CellLabel->"Out[71]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5 Creating MATLAB/SIMULINK Simulations", "Section",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["Introduction", "Subsection"],

Cell["\<\
It is possible to create the source code for a SIMULINK S-function using the \
ProPac function CreateModelMex or CreateControllerMex. We do this for the \
model generated above. \
\>", "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Heading and Flight Path Angle", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({uu, vv, ww} = JL . {u, v, w};\)\), "\[IndentingNewLine]", 
    \(gamma = ArcTan[uu, ww]\), "\[IndentingNewLine]", 
    \(PSI = ArcSin[vv/\@\(u\^2 + v\^2 + w\^2\)]\)}], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(ArcTan[
      u\ Cos[psi]\ Cos[theta] + 
        w\ \((Sin[phi]\ Sin[psi] + Cos[phi]\ Cos[psi]\ Sin[theta])\) + 
        v\ \((\(-Cos[phi]\)\ Sin[psi] + Cos[psi]\ Sin[phi]\ Sin[theta])\), 
      w\ Cos[phi]\ Cos[theta] + v\ Cos[theta]\ Sin[phi] - 
        u\ Sin[theta]]\)], "Output",
  CellLabel->"Out[73]="],

Cell[BoxData[
    \(ArcSin[\(u\ Cos[theta]\ Sin[psi] + w\ \((\(-Cos[psi]\)\ Sin[phi] + \
Cos[phi]\ Sin[psi]\ Sin[theta])\) + v\ \((Cos[phi]\ Cos[psi] + Sin[phi]\ \
Sin[psi]\ Sin[theta])\)\)\/\@\(u\^2 + v\^2 + w\^2\)]\)], "Output",
  CellLabel->"Out[74]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      PSI /. {theta \[Rule] 0, phi \[Rule] 0, w \[Rule] 0, 
          v \[Rule] 0}]\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(ArcSin[\(u\ Sin[psi]\)\/\@u\^2]\)], "Output",
  CellLabel->"Out[75]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[\((gamma /. {psi \[Rule] 0, phi \[Rule] 0, 
              v \[Rule] 0})\) /. {u \[Rule] V\ Cos[alpha], 
          w \[Rule] V\ Sin[alpha]}]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(ArcTan[V\ Cos[alpha - theta], V\ Sin[alpha - theta]]\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Create the S-Function", "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(Options[CreateModelMEX]\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \("  *** MEXTools successfully loaded ***"\)], "Print",
  CellLabel->"From In[77]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"AssignMaxSize", "\[Rule]", 
          InterpretationBox["\[Infinity]",
            DirectedInfinity[ 1]]}], 
        ",", \(MinimumBreakVariables \[Rule] 10\)}], "}"}]], "Output",
  CellLabel->"Out[77]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Inputs = {T, dele, dela, delr};\)\), "\n", 
    \(\(Outputs = 
        Flatten[{V /. VarDefs, alpha /. VarDefs, beta /. VarDefs, PSI, gamma, 
            pp, qq}];\)\), "\n", 
    \(\(MEXFilename = "\<F16.c\>";\)\), "\n", 
    \(\(PassedParams = {"\<X0\>", "\<kappa\>", \ "\<rho\>"};\)\), "\n", 
    \(\(PassedParamsDimensions = {{2\ Length[pp], 1}, {1, 1}, {1, 
            1}};\)\), "\n", 
    \(\(CreateModelMEX[pp, qq, Inputs, Outputs, PassedParams, 
        PassedParamsDimensions, JV, Cp, Fp, MM, MEXFilename, 
        AssignMaxSize \[Rule] 5000];\)\)}], "Input",
  CellLabel->"In[78]:=",
  PageWidth->Infinity,
  AspectRatioFixed->True],

Cell[BoxData[
    \("...Generating Header Code"\)], "Print",
  CellLabel->"From In[78]:="],

Cell[BoxData[
    \("...Generating Initial Condition Function Code"\)], "Print",
  CellLabel->"From In[78]:="],

Cell[BoxData[
    \("...Generating State Derivative Function Code"\)], "Print",
  CellLabel->"From In[78]:="],

Cell[BoxData[
    \("...Collecting all function terms"\)], "Print",
  CellLabel->"From In[78]:="],

Cell[BoxData[
    \("...Generating temp variable declarations"\)], "Print",
  CellLabel->"From In[78]:="],

Cell[BoxData[
    \("...Converting Expressions to C form"\)], "Print",
  CellLabel->"From In[78]:="],

Cell[BoxData[
    \("...Generating Output Function Code"\)], "Print",
  CellLabel->"From In[78]:="],

Cell[BoxData[
    \("MEX File created with name: F16.c"\)], "Print",
  CellLabel->"From In[78]:="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Transform to Wind Coordinates and set up State Equations  ",
  Cell[BoxData[
      \(TraditionalForm\`x\& . \)]],
  " = f(x) with f(0) =0."
}], "Subsection"],

Cell[BoxData[
    \(\(RHSofPlant\  = \ 
        Join[JV[\([1]\)] . 
            pp, \((Inverse[MM] . pdot /. {kappa \[Rule] 0, 
                rho -> 2.3769/1000})\)];\)\)], "Input",
  CellLabel->"In[84]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(WindTrans = {u\  \[Rule] \ V\ Cos[beta]\ Cos[alpha], \ 
          v\  \[Rule] \ V\ Sin[beta]\ , \ 
          w\  \[Rule] \ 
            V\ Cos[beta]\ Sin[alpha]};\)\), "\[IndentingNewLine]", 
    \(\(InvWindTrans = {V \[Rule] \@\(u\^2 + v\^2 + w\^2\), 
          alpha \[Rule] ArcTan[u, w], 
          beta \[Rule] 
            ArcSin[v/\@\(u\^2 + v\^2 + w\^2\)]};\)\), "\[IndentingNewLine]", 
    \(\({RHS, States} = 
        StateTransformation[RHSofPlant, Join[qq, pp], 
          WindTrans, {V, alpha, beta}];\)\), "\[IndentingNewLine]", 
    \(NewPSI = Simplify[PSI /. WindTrans]\), "\[IndentingNewLine]", 
    \(Newgamma = Simplify[gamma /. WindTrans]\)}], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(ArcSin[\(1\/\@V\^2\)\((V\ \((Cos[
                  beta]\ \((\(-Cos[psi]\)\ Sin[alpha]\ Sin[phi] + 
                    Cos[alpha]\ Cos[theta]\ Sin[psi])\) + 
              Sin[beta]\ Sin[phi]\ Sin[psi]\ Sin[theta] + 
              Cos[phi]\ \((Cos[psi]\ Sin[beta] + 
                    Cos[beta]\ Sin[alpha]\ Sin[psi]\ Sin[
                        theta])\))\))\)]\)], "Output",
  CellLabel->"Out[88]="],

Cell[BoxData[
    \(ArcTan[
      V\ \((Cos[alpha]\ Cos[beta]\ Cos[psi]\ Cos[theta] + 
            Cos[beta]\ Sin[
                alpha]\ \((Sin[phi]\ Sin[psi] + 
                  Cos[phi]\ Cos[psi]\ Sin[theta])\) + 
            Sin[beta]\ \((\(-Cos[phi]\)\ Sin[psi] + 
                  Cos[psi]\ Sin[phi]\ Sin[theta])\))\), 
      V\ \((Cos[theta]\ Sin[beta]\ Sin[phi] + 
            Cos[beta]\ \((Cos[phi]\ Cos[theta]\ Sin[alpha] - 
                  Cos[alpha]\ Sin[theta])\))\)]\)], "Output",
  CellLabel->"Out[89]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(States\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \({phi, theta, psi, x, y, z, p, q, r, V, alpha, beta}\)], "Output",
  CellLabel->"Out[90]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Equilibrium\  = \ {p -> 0, q -> 0, r -> 0, 
          V -> \@\(349.8965638436902`\^2\  + \ \((349.8965638436902`\ \ Tan[5\
\ Degree])\)\^2\)\ , beta\  \[Rule] 0, alpha\  \[Rule] \ 5\ Pi/180, \ 
          theta \[Rule] 5\ Pi/180\ , phi\  \[Rule] 0\ , psi \[Rule] 0, \ 
          dela -> 0, delr -> 0, dele -> \(-0.026723487822301974`\), 
          T -> 1595.463261228444`} // N\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \({p \[Rule] 0.`, q \[Rule] 0.`, r \[Rule] 0.`, 
      V \[Rule] 351.23311187454857`, beta \[Rule] 0.`, 
      alpha \[Rule] 0.08726646259971647`, theta \[Rule] 0.08726646259971647`, 
      phi \[Rule] 0.`, psi \[Rule] 0.`, dela \[Rule] 0.`, delr \[Rule] 0.`, 
      dele \[Rule] \(-0.026723487822301974`\), 
      T \[Rule] 1595.463261228444`}\)], "Output",
  CellLabel->"Out[91]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[Expand[RHS /. Equilibrium]]\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \({0, 0, 0, 351.23311187454857`, 0, 0, 0, 0, 0, 0, 0, 0}\)], "Output",
  CellLabel->"Out[92]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(StatesNew\  = \ Drop[States\ , {4, 6}]\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \({phi, theta, psi, p, q, r, V, alpha, beta}\)], "Output",
  CellLabel->"Out[93]="]
}, Open  ]],

Cell[BoxData[
    \(\(RHSNew\  = \ Chop[PowerExpand[Drop[RHS, {4, 6}]]];\)\)], "Input",
  CellLabel->"In[94]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Controls\  = \ {T, \ dele, \ dela\ , \ delr}\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \({T, dele, dela, delr}\)], "Output",
  CellLabel->"Out[95]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Shift = 
      Chop[Join[StatesNew, \ 
            Controls] + \((Join[StatesNew, \ Controls] /. 
              Equilibrium)\)]\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \({phi, \(\(0.08726646259971647`\)\(\[InvisibleSpace]\)\) + theta, psi, 
      p, q, r, \(\(351.23311187454857`\)\(\[InvisibleSpace]\)\) + 
        V, \(\(0.08726646259971647`\)\(\[InvisibleSpace]\)\) + alpha, 
      beta, \(\(1595.463261228444`\)\(\[InvisibleSpace]\)\) + 
        T, \(-0.026723487822301974`\) + dele, dela, delr}\)], "Output",
  CellLabel->"Out[96]="]
}, Open  ]],

Cell[BoxData[
    \(\(SRHS = 
        RHSNew /. Inner[Rule, \ Join[StatesNew, \ Controls], Shift, 
            List];\)\)], "Input",
  CellLabel->"In[97]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(SRHS /. 
      Inner[Rule, \ Join[StatesNew, \ Controls], Table[0, {i, 13}], 
        List]\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \({0, 0, 0, 0, \(-6.864515414690963`*^-17\), 0, 9.952937973830482`*^-16, 
      3.238948657199923`*^-17, 0}\)], "Output",
  CellLabel->"Out[98]="]
}, Open  ]],

Cell[BoxData[
    \(\(MoreOutputs = {NewPSI, Newgamma} /. 
          Inner[Rule, \ Join[StatesNew, \ Controls], Shift, 
            List];\)\)], "Input",
  CellLabel->"In[99]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Creating S-Function for the linearized system", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(A\  = \ 
        Jacobian[SRHS, \ StatesNew] /. 
          Inner[Rule, \ Join[StatesNew, \ Controls], Table[0, {i, 13}], 
            List];\)\), "\n", 
    \(\(B\  = \ 
        Jacobian[SRHS, Controls] /. 
          Inner[Rule, \ Join[StatesNew, \ Controls], Table[0, {i, 13}], 
            List];\)\), "\[IndentingNewLine]", 
    \(\(CC = 
        Jacobian[Join[StatesNew, MoreOutputs], StatesNew] /. 
          Inner[Rule, \ Join[StatesNew, \ Controls], Table[0, {i, 13}], 
            List];\)\), "\[IndentingNewLine]", 
    \(\(DD = 
        Jacobian[Join[StatesNew, MoreOutputs], Controls] /. 
          Inner[Rule, \ Join[StatesNew, \ Controls], Table[0, {i, 13}], 
            List];\)\)}], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \("  *** LinearControl successfully loaded ***"\)], "Print",
  CellLabel->"From In[100]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(A // MatrixForm\), "\[IndentingNewLine]", 
    \(B // MatrixForm\), "\[IndentingNewLine]", 
    \(CC // MatrixForm\), "\[IndentingNewLine]", 
    \(DD // MatrixForm\)}], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "1", "0", "0.08748866352592401`", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "1.0038198375433474`", "0", "0", "0"},
            {"0", "0", "0", \(-0.08202827670533286`\), "0", 
              "0.02108314038223125`", "0", "0", \(-0.69472607993958`\)},
            {"0", "0", "0", "0", \(-0.07132540444220162`\), 
              "0", \(-3.908808812503299`*^-19\), "0.03681868812761227`", 
              "0"},
            {"0", "0", "0", \(-0.001220833343778434`\), 
              "0", \(-0.011158847820318432`\), "0", "0", 
              "0.19104986407991328`"},
            {"0", \(-32.1302`\), "0", "0", \(-1.6939047208999618`\), 
              "0", \(-0.01420465555625047`\), "0.43654354394899003`", "0"},
            {"0", "9.2155080632016`*^-19", "0", "0", "0.8984322112198924`", 
              "0", \(-0.0005173595600689243`\), \(-0.7083973186893024`\), 
              "0"},
            {"0.09113017482263977`", "0", "0", "0.08718023056622294`", 
              "0", \(-0.989116616482552`\), "0", 
              "0", \(-0.22521881852704356`\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[104]//MatrixForm="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", \(-0.6811567781073065`\), "0.10752113624280261`"},
            {"0", \(-0.48029773169617523`\), "0", "0"},
            {"0", 
              "0", \(-0.03023498923466656`\), \(-0.055067505884816625`\)},
            {"0.001563541290912116`", \(-3.0192534254134906`\), "0", "0"},
            {\(-3.894625343818882`*^-7\), \(-0.08514851311201466`\), "0", 
              "0"},
            {"0", "0", "0.011823984041861272`", "0.032281352196450695`"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[105]//MatrixForm="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "1", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "1", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "1", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "1", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1"},
            {\(-0.08715574274765817`\), "0", "1.`", "0", "0", "0", "0", "0", 
              "1.`"},
            {"0", \(-1.`\), "0", "0", "0", "0", "0", "1.`", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[106]//MatrixForm="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[107]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvalues[A]\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    \({\(-0.757799525371036`\), \(-0.010495846287438916`\) + 
        0.5141271480610147`\ \[ImaginaryI], \(-0.010495846287438916`\) - 
        0.5141271480610147`\ \[ImaginaryI], \(-0.2947495014867532`\), \
\(-0.05718855324950391`\) + 
        0.08396960763119608`\ \[ImaginaryI], \(-0.05718855324950391`\) - 
        0.08396960763119608`\ \[ImaginaryI], 
      0.07824925318229048`, \(-0.002664748991063504`\), 0.`}\)], "Output",
  CellLabel->"Out[108]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ControllablePair[A, B]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[109]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CreateControllerMEX[StatesNew, Controls, C . StatesNew, 
      A . StatesNew + 
        B . Controls, {"\<X0\>"}, {{Length[StatesNew], 
          1}}, "\<LinearF16.c\>"]\)], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \("...Generating Header Code"\)], "Print",
  CellLabel->"From In[110]:="],

Cell[BoxData[
    \("...Generating Initial Condition Function Code"\)], "Print",
  CellLabel->"From In[110]:="],

Cell[BoxData[
    \("...Generating State Derivative Function Code"\)], "Print",
  CellLabel->"From In[110]:="],

Cell[BoxData[
    \("...Removing Function terms"\)], "Print",
  CellLabel->"From In[110]:="],

Cell[BoxData[
    \("...Generating temp variable declarations"\)], "Print",
  CellLabel->"From In[110]:="],

Cell[BoxData[
    \("...Converting Expressions to C form"\)], "Print",
  CellLabel->"From In[110]:="],

Cell[BoxData[
    \("...Generating Output Function Code"\)], "Print",
  CellLabel->"From In[110]:="],

Cell[BoxData[
    \("MEX File created with name: LinearF16.c"\)], "Print",
  CellLabel->"From In[110]:="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6 Regulator Design for stuck elevator", "Section"],

Cell["\<\
We design a regulator that regualates some variables in the event of the \
elevator being stuck. The states x, y and z are dropped in the design; thus \
we have the remaining 9 states in body coordinates - phi, theta, psi, p, q, \
r, u, v, w. The are three effective contols - Thrust, dela, dele. Thus we \
should be able to regualate three variables. Various cases are considered.\
\>", "Text"],

Cell[BoxData[
    \(\(Plant12States\  = \ RHSofPlant;\)\)], "Input",
  CellLabel->"In[123]:="],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Original12States\  = Join[qq, pp]\), "\[IndentingNewLine]", 
    \(OriginalControls\  = Inputs\)}], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \({phi, theta, psi, x, y, z, p, q, r, u, v, w}\)], "Output",
  CellLabel->"Out[133]="],

Cell[BoxData[
    \({T, dele, dela, delr}\)], "Output",
  CellLabel->"Out[134]="]
}, Open  ]],

Cell[BoxData[
    \(\(EqlPoint\  = \ {p -> 0, q -> 0, r -> 0, u -> 349.8965638436902`, 
            v -> 0, w -> 349.8965638436902`\ \ Tan[5\ Degree], 
            theta \[Rule] 5\ Pi/180\ , phi\  \[Rule] 0\ , \ dela -> 0, 
            delr -> 0, dele -> \(-0.026723487822301974`\), 
            T -> 1595.463261228444`, psi \[Rule] 0, z \[Rule] 0, x \[Rule] 0, 
            y \[Rule] 0} // N;\)\)], "Input",
  CellLabel->"In[125]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Shift = 
      Chop[Join[Original12States, \ 
            OriginalControls] + \((Join[Original12States, \ 
                OriginalControls] /. EqlPoint)\)]\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \({phi, \(\(0.08726646259971647`\)\(\[InvisibleSpace]\)\) + theta, psi, 
      x, y, z, p, q, r, \(\(349.8965638436902`\)\(\[InvisibleSpace]\)\) + u, 
      v, \(\(30.6119827429976`\)\(\[InvisibleSpace]\)\) + 
        w, \(\(1595.463261228444`\)\(\[InvisibleSpace]\)\) + 
        T, \(-0.026723487822301974`\) + dele, dela, delr}\)], "Output",
  CellLabel->"Out[126]="]
}, Open  ]],

Cell[BoxData[
    \(\(ShiftedPlant12States = 
        Plant12States /. 
          Inner[Rule, \ Join[Original12States, \ OriginalControls], Shift, 
            List];\)\)], "Input",
  CellLabel->"In[127]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShiftedPlant12States /. 
      Inner[Rule, \ Join[Original12States, \ OriginalControls], 
        Table[0, {i, 16}], List]\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \({0, 0, 0, 351.23311187454857`, 0, 3.552713678800501`*^-15, 
      0, \(-6.868119815931638`*^-17\), 0, 0.`, 0, 
      5.709857813183465`*^-15}\)], "Output",
  CellLabel->"Out[128]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(A12StatePlant\  = \ 
        Jacob[ShiftedPlant12States, Original12States] /. 
          Inner[Rule, \ Join[Original12States, \ OriginalControls], 
            Table[0, {i, 16}], List];\)\), "\[IndentingNewLine]", 
    \(% // MatrixForm\)}], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0", "0", "0", "1", "0", "0.08748866352592401`", 
              "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "1", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "1.0038198375433474`", 
              "0", "0", "0"},
            {"0", "3.552713678800501`*^-15", "0", "0", "0", "0", "0", "0", 
              "0", "0.9961946980917455`", "0", "0.08715574274765817`"},
            {\(-30.6119827429976`\), "0", "351.23311187454857`", "0", "0", 
              "0", "0", "0", "0", "0", "1", "0"},
            {"0", \(-351.23311187454857`\), "0", "0", "0", "0", "0", "0", 
              "0", \(-0.08715574274765817`\), "0", "0.9961946980917455`"},
            {"0", "0", "0", "0", "0", "0", \(-0.08202827670533284`\), "0", 
              "0.02108314038223125`", "0", \(-0.0019779629438460176`\), "0"},
            {"0", "0", "0", "0", "0", "0", "0", \(-0.07132540444220162`\), 
              "0", \(-9.13626876928029`*^-6\), "0", 
              "0.00010442802988495425`"},
            {"0", "0", "0", "0", "0", "0", \(-0.0012208333437784334`\), 
              "0", \(-0.011158847820318436`\), "0", "0.0005439403564779831`", 
              "0"},
            {"0", \(-32.0079348886274`\), "0", "0", "0", "0", 
              "0", \(-29.190250247649637`\), "0", \(-0.0038086055737509414`\),
               "0", "0.06288641319896489`"},
            {"32.0079348886274`", "0", "0", "0", "0", "0", 
              "30.620583675715125`", "0", \(-347.41050721399114`\), 
              "0", \(-0.22521881852704362`\), "0"},
            {"0", \(-2.8003314456308064`\), "0", "0", "0", "0", "0", 
              "314.210710028235`", "0", \(-0.12007028339512539`\), 
              "0", \(-0.718793368671802`\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[130]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(B12StatePlant\  = \ 
        Jacob[ShiftedPlant12States, OriginalControls] /. 
          Inner[Rule, \ Join[Original12States, \ OriginalControls], 
            Table[0, {i, 16}], List];\)\), "\[IndentingNewLine]", 
    \(% // MatrixForm\)}], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", "0", "0"},
            {"0", "0", \(-0.6811567781073065`\), "0.10752113624280264`"},
            {"0", \(-0.48029773169617535`\), "0", "0"},
            {"0", 
              "0", \(-0.030234989234666568`\), \(-0.055067505884816625`\)},
            {"0.0015695137646357159`", \(-0.40119944061536406`\), "0", "0"},
            {"0", "0", "4.152974709777938`", "11.338279787477674`"},
            {"0", \(-30.05631742912865`\), "0", "0"}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[132]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(States\  = \ \ Drop[Original12States, {4, 6}]\)], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \({phi, theta, psi, p, q, r, u, v, w}\)], "Output",
  CellLabel->"Out[135]="]
}, Open  ]],

Cell[BoxData[
    \(Plant\  = \ Drop[ShiftedPlant12States, {4, 6}]; 
    EffControls\  = \ {T, \ dela\ , \ delr};\)], "Input",
  CellLabel->"In[136]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(SeriesExp\  = \ 
      Map[\((# \[Rule] Series\ [#[dele], {dele, 0, 2}])\) /. #[0] \[Rule] 
              0 &, Join[States, EffControls]]\)], "Input",
  CellLabel->"In[137]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"phi", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["phi", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["phi", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ phi][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ phi][ 0]]}, 1, 3, 1]]}], ",", 
        RowBox[{"theta", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["theta", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["theta", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ theta][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ theta][ 0]]}, 1, 3, 1]]}], ",", 
        RowBox[{"psi", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["psi", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["psi", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ psi][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ psi][ 0]]}, 1, 3, 1]]}], ",", 
        RowBox[{"p", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["p", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["p", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ p][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ p][ 0]]}, 1, 3, 1]]}], ",", 
        RowBox[{"q", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["q", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["q", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ q][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ q][ 0]]}, 1, 3, 1]]}], ",", 
        RowBox[{"r", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["r", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["r", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ r][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ r][ 0]]}, 1, 3, 1]]}], ",", 
        RowBox[{"u", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["u", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["u", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ u][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ u][ 0]]}, 1, 3, 1]]}], ",", 
        RowBox[{"v", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["v", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["v", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ v][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ v][ 0]]}, 1, 3, 1]]}], ",", 
        RowBox[{"w", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["w", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["w", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ w][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ w][ 0]]}, 1, 3, 1]]}], ",", 
        RowBox[{"T", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["T", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["T", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ T][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ T][ 0]]}, 1, 3, 1]]}], ",", 
        RowBox[{"dela", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["dela", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["dela", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ dela][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ dela][ 0]]}, 1, 3, 1]]}], ",", 
        RowBox[{"delr", "\[Rule]", 
          InterpretationBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["delr", "\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], " ", "dele"}], 
              "+", 
              RowBox[{\(1\/2\), " ", 
                RowBox[{
                  SuperscriptBox["delr", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "0", "]"}], 
                " ", \(dele\^2\)}], "+", 
              InterpretationBox[\(O[dele]\^3\),
                SeriesData[ dele, 0, {}, 1, 3, 1]]}],
            SeriesData[ dele, 0, {
              Derivative[ 1][ delr][ 0], 
              Times[ 
                Rational[ 1, 2], 
                Derivative[ 2][ delr][ 0]]}, 1, 3, 1]]}]}], "}"}]], "Output",
  CellLabel->"Out[137]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Case 1", "Subsection"],

Cell[BoxData[
    \(\(RegVars\  = \ {phi, gamma, PSI} /. 
          Inner[Rule, \ Join[Original12States, \ OriginalControls], Shift, 
            List];\)\)], "Input",
  CellLabel->"In[143]:="],

Cell[BoxData[
    \(\(DesignEqns\  = \ Join[Plant, \ RegVars\ ] /. SeriesExp;\)\)], "Input",\

  CellLabel->"In[144]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(FirstTerms\  = 
      Flatten[\ Solve[
          Coefficient[DesignEqns, \ \ dele^1] \[Equal] Table[0, {i, 12}], 
          Map[\(#'\)[0] &, Join[States, EffControls]]]]\)], "Input",
  CellLabel->"In[145]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["phi", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["theta", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
          "13.044944187893753`"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["psi", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["p", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["q", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["r", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["u", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-18433.588612860025`\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["v", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["w", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
          "2986.588103695301`"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["T", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
          "101891.96511465349`"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["dela", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["delr", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}]}],
       "}"}]], "Output",
  CellLabel->"Out[145]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SecondTerms\  = 
      Flatten[\ Solve[
          Coefficient[\((DesignEqns /. FirstTerms)\), \ \ dele^2] \[Equal] 
            Table[0, {i, 12}], 
          Map[\(#''\)[0] &, Join[States, EffControls]]]]\)], "Input",
  CellLabel->"In[146]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["phi", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["theta", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
          "103.46674955478882`"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["psi", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["p", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["q", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-1.8375687974466667`*^-13\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["r", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["u", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
          "2.871815065576282`*^6"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["v", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["w", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-186382.14754137342`\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["T", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
          "2.7417862420429863`*^7"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["dela", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["delr", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}]}],
       "}"}]], "Output",
  CellLabel->"Out[146]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Case 2", "Subsection"],

Cell[BoxData[
    \(\(RegVars\  = \ {phi, gamma, \@\(u\^2 + v\^2 + w\^2\)} /. 
          Inner[Rule, \ Join[Original12States, \ OriginalControls], Shift, 
            List];\)\)], "Input",
  CellLabel->"In[150]:="],

Cell[BoxData[
    \(\(DesignEqns\  = \ Join[Plant, \ RegVars\ ] /. SeriesExp;\)\)], "Input",\

  CellLabel->"In[151]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(FirstTerms\  = 
      Flatten[\ Solve[
          Coefficient[DesignEqns, \ \ dele^1] \[Equal] Table[0, {i, 12}], 
          Map[\(#'\)[0] &, Join[States, EffControls]]]]\)], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[152]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Case 3", "Subsection"],

Cell[BoxData[
    \(\(RegVars\  = \ {phi, PSI, \@\(u\^2 + v\^2 + w\^2\)} /. 
          Inner[Rule, \ Join[Original12States, \ OriginalControls], Shift, 
            List];\)\)], "Input",
  CellLabel->"In[153]:="],

Cell[BoxData[
    \(\(DesignEqns\  = \ Join[Plant, \ RegVars\ ] /. SeriesExp;\)\)], "Input",\

  CellLabel->"In[154]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(FirstTerms\  = 
      Flatten[\ Solve[
          Coefficient[DesignEqns, \ \ dele^1] \[Equal] Table[0, {i, 12}], 
          Map[\(#'\)[0] &, Join[States, EffControls]]]]\)], "Input",
  CellLabel->"In[155]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["phi", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["theta", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-1165.2032704346884`\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["psi", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["p", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["q", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-1.30101306459847`*^-15\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["r", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["u", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-399.33160636317615`\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["v", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["w", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
          "4564.381146876808`"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["T", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-2.3946210931608904`*^7\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["dela", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["delr", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}]}],
       "}"}]], "Output",
  CellLabel->"Out[155]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SecondTerms\  = 
      Flatten[\ Solve[
          Coefficient[\((DesignEqns /. FirstTerms)\), \ \ dele^2] \[Equal] 
            Table[0, {i, 12}], 
          Map[\(#''\)[0] &, Join[States, EffControls]]]]\)], "Input",
  CellLabel->"In[156]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["phi", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["theta", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-1.550698095820281`*^7\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["psi", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["p", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["q", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
          "6.658315689498157`*^-12"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["r", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["u", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-62709.41966512955`\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["v", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["w", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
          "30993.401623838014`"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["T", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-3.186726948468474`*^11\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["dela", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["delr", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0.`"}]}],
       "}"}]], "Output",
  CellLabel->"Out[156]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Case 4", "Subsection"],

Cell[BoxData[
    \(\(RegVars\  = \ {gamma, PSI, \@\(u\^2 + v\^2 + w\^2\)} /. 
          Inner[Rule, \ Join[Original12States, \ OriginalControls], Shift, 
            List];\)\)], "Input",
  CellLabel->"In[157]:="],

Cell[BoxData[
    \(\(DesignEqns\  = \ Join[Plant, \ RegVars\ ] /. SeriesExp;\)\)], "Input",\

  CellLabel->"In[158]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(FirstTerms\  = 
      Flatten[\ Solve[
          Coefficient[DesignEqns, \ \ dele^1] \[Equal] Table[0, {i, 12}], 
          Map[\(#'\)[0] &, Join[States, EffControls]]]]\)], "Input",
  CellLabel->"In[159]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[159]="]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 670}},
WindowSize->{906, 630},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> "Textbook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 60, 1, 69, "Title"],
Cell[1839, 56, 55, 3, 62, "Subtitle"],
Cell[1897, 61, 97, 3, 50, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2019, 68, 34, 0, 85, "Section"],

Cell[CellGroupData[{
Cell[2078, 72, 251, 5, 50, "Input"],
Cell[2332, 79, 677, 10, 70, "Print"]
}, Open  ]],
Cell[3024, 92, 716, 12, 72, "Text"],
Cell[3743, 106, 2109042, 26040, 221, 2108944, 26037, "GraphicsData", \
"Metafile", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[2112822, 26151, 40, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[2112887, 26155, 34, 0, 44, "Subsection"],
Cell[2112924, 26157, 272, 5, 42, "Text"],
Cell[2113199, 26164, 125, 3, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2113361, 26172, 30, 0, 38, "Subsection"],
Cell[2113394, 26174, 1963, 29, 950, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2115394, 26208, 27, 0, 38, "Subsection"],
Cell[2115424, 26210, 44, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[2115493, 26214, 194, 4, 30, "Input"],
Cell[2115690, 26220, 154, 3, 70, "Output"]
}, Open  ]],
Cell[2115859, 26226, 31, 0, 25, "Text"],

Cell[CellGroupData[{
Cell[2115915, 26230, 431, 8, 70, "Input"],
Cell[2116349, 26240, 186, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2116572, 26249, 281, 5, 30, "Input"],
Cell[2116856, 26256, 142, 3, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2117059, 26266, 66, 0, 85, "Section"],
Cell[2117128, 26268, 34, 0, 44, "Subsection"],

Cell[CellGroupData[{
Cell[2117187, 26272, 46, 0, 44, "Subsection"],
Cell[2117236, 26274, 3545, 67, 431, "Input"],
Cell[2120784, 26343, 171, 4, 42, "Input"],
Cell[2120958, 26349, 1391, 31, 204, "Input"],
Cell[2122352, 26382, 4332, 70, 790, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2126721, 26457, 43, 0, 38, "Subsection"],
Cell[2126767, 26459, 390, 8, 86, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2127206, 26473, 58, 1, 85, "Section",
  Evaluatable->False],
Cell[2127267, 26476, 34, 0, 43, "Subsection"],

Cell[CellGroupData[{
Cell[2127326, 26480, 30, 0, 43, "Subsection"],

Cell[CellGroupData[{
Cell[2127381, 26484, 320, 7, 90, "Input"],
Cell[2127704, 26493, 103, 2, 28, "Print"],
Cell[2127810, 26497, 93, 2, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2127940, 26504, 106, 2, 30, "Input"],
Cell[2128049, 26508, 463, 9, 81, "Output"]
}, Open  ]],
Cell[2128527, 26520, 520, 10, 110, "Input"],

Cell[CellGroupData[{
Cell[2129072, 26534, 325, 7, 70, "Input"],
Cell[2129400, 26543, 94, 2, 28, "Print"],
Cell[2129497, 26547, 89, 2, 28, "Print"],
Cell[2129589, 26551, 92, 2, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2129718, 26558, 76, 2, 30, "Input"],
Cell[2129797, 26562, 668, 15, 120, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2130502, 26582, 74, 2, 30, "Input"],
Cell[2130579, 26586, 1180, 22, 122, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2131796, 26613, 74, 2, 30, "Input"],
Cell[2131873, 26617, 1157, 38, 114, "Output"]
}, Open  ]],
Cell[2133045, 26658, 210, 4, 40, "Input"],
Cell[2133258, 26664, 335, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[2133618, 26674, 60, 2, 30, "Input"],
Cell[2133681, 26678, 362, 6, 62, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2134080, 26689, 90, 2, 30, "Input"],
Cell[2134173, 26693, 1632, 28, 349, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2135842, 26726, 60, 2, 30, "Input"],
Cell[2135905, 26730, 829, 13, 100, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2136783, 26749, 91, 2, 27, "Subsection"],
Cell[2136877, 26753, 101, 2, 31, "Input"],
Cell[2136981, 26757, 314, 7, 86, "Input"],

Cell[CellGroupData[{
Cell[2137320, 26768, 325, 6, 74, "Input"],
Cell[2137648, 26776, 623, 12, 131, "Output"]
}, Open  ]],
Cell[2138286, 26791, 115, 2, 31, "Input"],

Cell[CellGroupData[{
Cell[2138426, 26797, 273, 5, 51, "Input"],
Cell[2138702, 26804, 266, 5, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2139005, 26814, 102, 2, 31, "Input"],
Cell[2139110, 26818, 67, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2139214, 26825, 100, 2, 31, "Input"],
Cell[2139317, 26829, 754, 13, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2140108, 26847, 149, 4, 31, "Input"],
Cell[2140260, 26853, 481, 7, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2140778, 26865, 203, 5, 31, "Input"],
Cell[2140984, 26872, 160, 3, 30, "Output"]
}, Open  ]],
Cell[2141159, 26878, 158, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[2141342, 26886, 410, 7, 91, "Input"],
Cell[2141755, 26895, 416, 7, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2142208, 26907, 74, 2, 31, "Input"],
Cell[2142285, 26911, 142, 3, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2142464, 26919, 81, 2, 31, "Input"],
Cell[2142548, 26923, 69, 2, 30, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2142678, 26932, 79, 1, 56, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2142782, 26937, 34, 0, 43, "Subsection"],
Cell[2142819, 26939, 224, 5, 44, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2143080, 26949, 51, 0, 27, "Subsection"],

Cell[CellGroupData[{
Cell[2143156, 26953, 225, 4, 76, "Input"],
Cell[2143384, 26959, 329, 7, 43, "Output"],
Cell[2143716, 26968, 255, 4, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2144008, 26977, 151, 4, 30, "Input"],
Cell[2144162, 26983, 90, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2144289, 26990, 206, 4, 30, "Input"],
Cell[2144498, 26996, 111, 2, 24, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2144658, 27004, 65, 1, 27, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2144748, 27009, 81, 2, 30, "Input"],
Cell[2144832, 27013, 103, 2, 28, "Print"],
Cell[2144938, 27017, 268, 7, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2145243, 27029, 666, 14, 130, "Input"],
Cell[2145912, 27045, 90, 2, 28, "Print"],
Cell[2146005, 27049, 110, 2, 28, "Print"],
Cell[2146118, 27053, 109, 2, 28, "Print"],
Cell[2146230, 27057, 97, 2, 28, "Print"],
Cell[2146330, 27061, 105, 2, 28, "Print"],
Cell[2146438, 27065, 100, 2, 28, "Print"],
Cell[2146541, 27069, 99, 2, 28, "Print"],
Cell[2146643, 27073, 98, 2, 28, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2146790, 27081, 176, 5, 27, "Subsection"],
Cell[2146969, 27088, 208, 5, 30, "Input"],

Cell[CellGroupData[{
Cell[2147202, 27097, 719, 14, 117, "Input"],
Cell[2147924, 27113, 426, 8, 93, "Output"],
Cell[2148353, 27123, 524, 11, 81, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2148914, 27139, 64, 2, 30, "Input"],
Cell[2148981, 27143, 110, 2, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2149128, 27150, 434, 7, 95, "Input"],
Cell[2149565, 27159, 401, 7, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2150003, 27171, 90, 2, 30, "Input"],
Cell[2150096, 27175, 113, 2, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2150246, 27182, 96, 2, 30, "Input"],
Cell[2150345, 27186, 101, 2, 24, "Output"]
}, Open  ]],
Cell[2150461, 27191, 112, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[2150598, 27197, 102, 2, 30, "Input"],
Cell[2150703, 27201, 80, 2, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2150820, 27208, 185, 5, 30, "Input"],
Cell[2151008, 27215, 388, 6, 24, "Output"]
}, Open  ]],
Cell[2151411, 27224, 157, 4, 30, "Input"],

Cell[CellGroupData[{
Cell[2151593, 27232, 149, 4, 30, "Input"],
Cell[2151745, 27238, 164, 3, 24, "Output"]
}, Open  ]],
Cell[2151924, 27244, 178, 4, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2152139, 27253, 67, 0, 27, "Subsection"],

Cell[CellGroupData[{
Cell[2152231, 27257, 756, 17, 130, "Input"],
Cell[2152990, 27276, 109, 2, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2153136, 27283, 225, 5, 90, "Input"],
Cell[2153364, 27290, 1361, 25, 168, "Output"],
Cell[2154728, 27317, 787, 17, 164, "Output"],
Cell[2155518, 27336, 914, 18, 194, "Output"],
Cell[2156435, 27356, 591, 17, 194, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2157063, 27378, 73, 2, 30, "Input"],
Cell[2157139, 27382, 471, 8, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2157647, 27395, 81, 2, 30, "Input"],
Cell[2157731, 27399, 64, 2, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2157832, 27406, 228, 5, 50, "Input"],
Cell[2158063, 27413, 91, 2, 28, "Print"],
Cell[2158157, 27417, 111, 2, 28, "Print"],
Cell[2158271, 27421, 110, 2, 28, "Print"],
Cell[2158384, 27425, 92, 2, 28, "Print"],
Cell[2158479, 27429, 106, 2, 28, "Print"],
Cell[2158588, 27433, 101, 2, 28, "Print"],
Cell[2158692, 27437, 100, 2, 28, "Print"],
Cell[2158795, 27441, 105, 2, 28, "Print"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2158961, 27450, 56, 0, 56, "Section"],
Cell[2159020, 27452, 405, 6, 59, "Text"],
Cell[2159428, 27460, 94, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[2159547, 27466, 155, 3, 50, "Input"],
Cell[2159705, 27471, 104, 2, 24, "Output"],
Cell[2159812, 27475, 81, 2, 24, "Output"]
}, Open  ]],
Cell[2159908, 27480, 434, 7, 70, "Input"],

Cell[CellGroupData[{
Cell[2160367, 27491, 215, 5, 30, "Input"],
Cell[2160585, 27498, 387, 6, 24, "Output"]
}, Open  ]],
Cell[2160987, 27507, 207, 5, 30, "Input"],

Cell[CellGroupData[{
Cell[2161219, 27516, 181, 4, 30, "Input"],
Cell[2161403, 27522, 201, 4, 24, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2161641, 27531, 299, 6, 70, "Input"],
Cell[2161943, 27539, 1978, 34, 216, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2163958, 27578, 299, 6, 70, "Input"],
Cell[2164260, 27586, 846, 19, 210, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2165143, 27610, 104, 2, 30, "Input"],
Cell[2165250, 27614, 95, 2, 24, "Output"]
}, Open  ]],
Cell[2165360, 27619, 152, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[2165537, 27626, 196, 4, 30, "Input"],
Cell[2165736, 27632, 9756, 243, 207, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2175529, 27880, 28, 0, 44, "Subsection"],
Cell[2175560, 27882, 193, 4, 30, "Input"],
Cell[2175756, 27888, 120, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[2175901, 27895, 228, 5, 50, "Input"],
Cell[2176132, 27902, 2236, 63, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2178405, 27970, 263, 6, 70, "Input"],
Cell[2178671, 27978, 2364, 63, 43, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2181084, 28047, 28, 0, 38, "Subsection"],
Cell[2181115, 28049, 214, 4, 34, "Input"],
Cell[2181332, 28055, 120, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[2181477, 28062, 228, 5, 50, "Input"],
Cell[2181708, 28069, 62, 2, 24, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2181819, 28077, 28, 0, 38, "Subsection"],
Cell[2181850, 28079, 212, 4, 34, "Input"],
Cell[2182065, 28085, 120, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[2182210, 28092, 228, 5, 50, "Input"],
Cell[2182441, 28099, 2269, 63, 43, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2184747, 28167, 263, 6, 70, "Input"],
Cell[2185013, 28175, 2365, 63, 43, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2187427, 28244, 28, 0, 38, "Subsection"],
Cell[2187458, 28246, 214, 4, 34, "Input"],
Cell[2187675, 28252, 120, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[2187820, 28259, 228, 5, 50, "Input"],
Cell[2188051, 28266, 62, 2, 24, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

